---
title: L'architetto come intellettuale
author: Marco Biraghi
date: 2019
lang: it
...

> Ma ciò che ci appare necessario è sempre anche altamente improbabile.
> 
> *Massimo Cacciari*

# Introduzione

La constatazione della crisi dell'intellettuale nell'epoca contemporanea
è ormai talmente diffusa e generalizzata da essere divenuta un luogo
comune; un argomento oggetto di facili ironie[^1] e oggi quasi "di
moda", non fosse che l'intellettuale in quanto tale raramente si lascia
rapportare alla moda.

In realtà, la crisi dell'intellettuale ha origini ben più lontane e
profonde, tanto da aver generato, a partire dalla seconda metà del
Novecento, una lunga serie di diagnosi al capezzale del malato, vuoi per
prescrivergli possibili rimedi, vuoi per preconizzarne il decesso ormai
prossimo[^2].

Come tutto ciò che viene insistentemente osservato o ripetuto, anche la
categoria di "intellettuale" ha perduto, nel corso del tempo, il suo
contenuto, o piuttosto ha visto progressivamente venir meno il suo
senso, finendo per apparire un corpo svuotato. Lasciando da parte
antichi e nuovi pregiudizi, per cercare di comprendere che cosa sia
l'intellettuale, e quale possa essere il suo eventuale ruolo -- e, più
nello specifico, quale possa essere il ruolo dell'architetto inteso come
intellettuale -- nel mondo attuale, è opportuno ripartire dalla
"classica" analisi fatta da Antonio Gramsci[^3]. Per questi,
innanzitutto, "tutti gli uomini sono intellettuali", anche se "non tutti
gli uomini hanno nella società la funzione di intellettuali"[^4]. Da
ciò deriva che "non si può parlare di non-intellettuali, perché
non-intellettuali non esistono. (...) Non c'è attività umana da cui si
possa escludere ogni intervento intellettuale, non si può separare
l'*homo faber* dall'*homo sapiens*"[^5].

Questa precisazione (o questa non-distinzione) risulta fondamentale per
non confinare la categoria dell'"intellettuale" all'interno di una
gabbia separata, dorata o meno che sia.

> Ogni uomo (...), all'infuori della sua professione esplica una qualche
> attività intellettuale, è cioè un "filosofo", un artista, un uomo di
> gusto, partecipa di una concezione del mondo, ha una consapevole linea
> di condotta morale, quindi contribuisce a sostenere o a modificare una
> concezione del mondo, cioè a suscitare nuovi modi di pensare[^6].

Il problema semmai per Gramsci consiste nella "creazione di un nuovo
ceto intellettuale" che sia capace di

> ... elaborare criticamente l'attività intellettuale che in ognuno
> esiste in un certo grado di sviluppo, modificando il suo rapporto con
> lo sforzo muscolare-nervoso verso un nuovo equilibrio e ottenendo che
> lo stesso sforzo muscolare-nervoso, in quanto elemento di un'attività
> pratica generale, che innova perpetuamente il mondo fisico e sociale,
> diventi il fondamento di una nuova e integrale concezione del
> mondo[^7].

In questo senso Gramsci, al di là della figura dell'intellettuale
"tradizionale", appartenente a una "categoria sociale
cristallizzata"[^8] e legato alle funzioni culturali più consuete, vede
un terreno d'azione più fertile per l'intellettuale nell'applicazione
diretta di questi allo "sviluppo delle forme reali di vita"[^9]:

> Nel mondo moderno l'educazione tecnica, strettamente legata al lavoro
> industriale anche il più primitivo o squalificato, deve formare la
> base del nuovo tipo di intellettuale.

Di conseguenza,

> ... il modo di essere del nuovo intellettuale non può più consistere
> nell'eloquenza, motrice esteriore e momentanea degli affetti e delle
> passioni, ma nel mescolarsi attivamente alla vita pratica, come
> costruttore, organizzatore, "persuasore permanentemente".

Con l'ulteriore avvertenza che tale tipo di intellettuale deve altresí
oltrepassare la "tecnica-lavoro" per giungere "alla tecnica-scienza e
alla concezione umanistica storica, senza la quale si rimane
"specialista"".

Non è un caso che per Gramsci l'effetto più immediato di tale ingresso
nel mondo tecnico-scientifico (ma anche storico-umanistico) da parte
degli intellettuali sia la relazione che questi istituiscono con la
politica. Politica da intendersi nel senso più originario, come *technē
politikē*, come arte-tecnica di indirizzo e gestione della *polis*, e
più in generale della cosa pubblica. Se ciò dapprima produce una classe
di "intellettuali di partito" "pronti a piegarsi in caso di necessità
all'ineludibile disciplina richiesta dalla tattica e
dall'organizzazione", come rileva Habermas[^10], in seguito -- e in
particolare dopo il termine del secondo conflitto mondiale -- le cose
cambieranno:

> Gli intellettuali che si imposero dopo il 1945 -- come Camus e Sartre,
> Adorno e Marcuse, Max Frisch e Heinrich Böll -- assomigliavano ai
> modelli più antichi di scrittori e professori che assumevano sí
> posizioni di parte, ma non erano politicamente legati a nessun
> partito. Cogliendo una data occasione, senza essere stati richiesti o
> averlo concordato con qualcuno, essi si inducevano, al di là della
> loro professione, a fare un uso pubblico del loro sapere
> professionale. Senza pretendere alcuno *status* elitario, non si
> richiamavano ad altra legittimazione che non fosse il loro ruolo di
> cittadino di uno Stato democratico[^11].

All'interno dei rapporti tra intellettuali e politica -- cosí come
ovviamente di quelli tra intellettuali e mondo della tecnica -- rientra
a pieno titolo anche la figura dell'architetto. Vale la pena forse
citare a questo proposito quanto scriveva Manfredo Tafuri nelle pagine
finali di *Progetto e utopia*:

> La riflessione sull'architettura, in quanto critica dell'ideologia
> concreta, "realizzata" dall'architettura stessa, non può che (...)
> raggiungere una dimensione specificamente politica. È solo a questo
> punto -- dopo, cioè, aver fatto ragione di ogni ideologia disciplinare
> -- che è lecito riproporre il tema dei ruoli nuovi del tecnico,
> dell'organizzatore dell'edilizia, del *planner*, nell'ambito delle
> nuove forme dello sviluppo capitalistico. E quindi, delle tangenze
> possibili o delle inevitabili contraddittorietà fra tale tipo di
> lavoro tecnico-intellettuale e le condizioni materiali della lotta di
> classe[^12].

Quest'ultimo accenno non deve far perdere di vista l'attualità della
notazione tafuriana. Il fatto che oggi la "lotta di classe" possa
apparire un reperto archeologico (questione che verrà ridiscussa più
oltre) non deve indurre l'idea che la relazione tra architetti e
politica sia venuta meno; e lo stesso vale per quella tra architetti e
sfera intellettuale.

Che l'architetto sia un intellettuale è cosa evidente non soltanto
nell'ottica della distinzione gramsciana tra "sforzo di elaborazione
intellettuale-cerebrale e sforzo muscolare-nervoso"[^13]: lo è anche in
un senso immediatamente intuitivo, almeno per "noi moderni". Ed è
probabilmente inutile rispolverare le vecchie analisi marxiste sulla
separazione tra lavoro intellettuale e lavoro manuale[^14] per affermare
qualcosa che risulta di per sé sufficientemente chiaro. Del resto, già
la celeberrima definizione datane da Vitruvio ("Et ut litteratus sit,
peritus graphidos, eruditus geometria, historias complures noverit,
philosophos diligenter audierit, musicam scierit, medicinae non sit
ignarus, responsa iurisconsultorum noverit, astrologiam caelique
rationes cognitas habeat")[^15] fa emergere il carattere
iperintellettuale della preparazione dell'architetto, una somma di
conoscenze "tecnico-scientifiche" e "storico-umanistiche", per dirla con
le parole di Gramsci.

> Il sapere dell'architetto è ricco degli apporti di numerosi ambiti
> disciplinari \[o "specialismi", come li si denominerebbe oggi\] e di
> conoscenze relative a vari campi, e al suo giudizio vengono sottoposti
> i risultati prodotti dalle altre tecniche[^16].

Proprio quest'ultima considerazione vitruviana illumina il senso che ha
per lui tale accumulazione di saperi, e di conseguenza il ruolo
rivestito dall'architetto: non tanto quello dell'erudito, del
multi-*connoisseur* fine a se stesso, quanto piuttosto quello del
coordinatore, del supervisore, del regista (dal latino *regere*,
dirigere); tutte attività per le quali necessita -- al di là delle
singole competenze -- il possesso di uno sguardo ampio e di una visione
sintetica. Una comprensione e un'organizzazione di molti elementi
contemporaneamente, per le quali sono appunto richieste spiccate
capacità intellettuali.

E tuttavia, se l'architetto possiede storicamente una vocazione
intellettuale, ciò non significa che il suo non sia anche -- e molto --
un lavoro manuale. Basti solo pensare al disegno, o a tutte le attività
che stanno dietro, e *dentro*, il compimento di un'opera di
architettura, e che prevedono per l'appunto l'erogazione di un lavoro
ri-produttivo, vale a dire non squisitamente produttivo o
"creativo"[^17]. All'interno di questa pluralità di attività svolte
dall'architetto, l'attività intellettuale non è distinguibile come una
dimensione isolata e specifica: piuttosto, si tratta della modalità
generale entro cui questi *comprende* tutte le proprie attività, incluse
quelle manuali come, appunto, il disegno (per Filarete "fondamento e via
d'ogni arte che di mano si faccia"[^18], vale a dire strumento per
comunicare l'"idea"). Una modalità di *comprehendere* (letteralmente,
di mettere insieme i particolari aspetti sensibili che una molteplicità
di entità hanno tra loro in comune) che definisce in quanto tale il suo
operare da architetto, ma che alcuni tra loro dimostrano di possedere in
maniera più accentuata di altri. E lo stesso vale anche per alcune
epoche. Ad esempio, in Italia -- dalla metà degli anni cinquanta fino
all'incirca alla metà degli anni settanta, come si vedrà meglio più
oltre -- la spiccata attitudine degli architetti a pensare e ad agire
come intellettuali ha fortemente influenzato, nel bene e nel male, il
quadro complessivo dell'epoca: da un lato concorrendo a dar vita a uno
dei momenti più fecondi della recente storia disciplinare italiana,
mediante la produzione di alcuni edifici di altissima qualità, cosí come
con l'elaborazione di altrettanto fondamentali contributi teorici;
dall'altro facendo fin troppo spesso astrazione dal campo di
applicazione concreto dell'architettura, e dando cosí spazio al fiorire
-- avvenuto precisamente in quel periodo -- della speculazione
edilizia[^19] e al compiersi di un vero assalto ai territori italiani,
di cui proprio la parte migliore dell'architettura italiana, arroccata
in una posizione di aristocratica "separatezza", ha finito per rendersi
involontariamente complice.

Sono probabilmente i cascami di questa stagione della cultura
architettonica italiana, intensa ma contraddittoria, ad aver lasciato in
eredità alle fasi storiche successive -- in particolar modo nel nostro
paese -- un'idea di architetto come prototipo per eccellenza
dell'intellettuale fumoso e inconcludente: una sorta di Fuffas *ante
litteram*, una figura un po' ridicola e un po' patetica,
autoreferenziale e incapace di rapportarsi alla realtà. Questo modello
pur parodistico dell'architetto intellettuale ha però sicuramente
giocato un ruolo nella scarsa considerazione di cui la categoria nel suo
complesso ha goduto in Italia nello scorso cinquantennio, e fors'anche
nella collettiva "ritirata" degli architetti da posizioni di impegno
politico e sociale, vale a dire, in una parola sola, intellettuale.

D'altronde, la crisi dell'architetto intellettuale (cosí come quella
dell'intellettuale *tout court*) va di pari passo con la crisi più
generale -- ed epocale -- di un sistema di valori a cui tradizionalmente
il mondo degli intellettuali si rifaceva. E ciò su scala planetaria,
non certo solo locale. Ed è sintomatico che sia proprio un architetto
intellettuale -- Tomás Maldonado, d'origini argentine ma con lunghe
frequentazioni europee e italiane -- a tornare a interrogarsi, nel 1995,
sul mutevole significato della figura dell'intellettuale nel corso del
tempo e sul suo incerto destino in quello attuale[^20]. Un'incertezza
(o una "crisi d'identità")[^21] che troverebbe una sua spiegazione, tra
le altre possibili, nella "democratizzazione del sapere" e nella
diffusione generalizzata del lavoro intellettuale (e -- andrebbe
aggiunto -- nell'elevata taylorizzazione e proletarizzazione subita dai
lavoratori di tali settori), che avrebbe come effetto la crescita
smisurata di un "pensiero operante", vale a dire direttamente applicato
ai contesti produttivi e comunicativi. Ciò che non impedisce tuttavia a
Maldonado di chiudere la sua analisi sulle note di una "sorprendente"
speranza in merito alla possibilità di una futura rinascita di un
"pensiero discorrente", dialogico, capace in ultima analisi di tornare a
"scompaginare (...) l'appiattimento della nostra visione del
mondo"[^22].

Gli eventi, almeno per il momento, non sembrano aver dato ragione alle
attese di Maldonado. Il generalizzato ritorno in auge, in tempi più
recenti, dell'architetto come professionista, ovvero come figura
"semplicemente" dotata di capacità tecniche e di competenze specifiche,
e disinteressata invece allo sviluppo di un proprio pensiero teorico,
sembra segnare un cambio di tendenza dal significato apparentemente
inequivocabile e forse irrevocabile. Di ciò potrebbe costituire
un'ulteriore conferma, da vent'anni circa a questa parte, l'imporsi del
fenomeno dell'*archistar* (o *star architect*, o *starchitect*)[^23]:
una nuova forma di celebrità fortemente mediatizzata che non ha paragoni
con quella sperimentata da architetti di epoche precedenti, e che
assimila invece l'architetto contemporaneo ad altri protagonisti dello
*show business* globale (attori, personaggi televisivi, sportivi, ecc.).
Una notorietà originata assai più dall'aspetto spettacolare e
sorprendente dei loro edifici che non dalla comprensione (ma in fondo si
potrebbe anche dire: dalla sussistenza stessa) del loro "messaggio".

Le conseguenze di questo fenomeno, anche dopo che esso pare avere ormai
superato la sua fase più acuta, non hanno tardato a farsi sentire:
l'architettura, nel corso degli ultimi due decenni, sembra avere
accresciuto la propria popolarità presso un pubblico sempre più
allargato. Non che ovviamente l'architettura di oggi sia più conosciuta
o studiata di quella delle epoche precedenti: piuttosto, essa pare
essere entrata nell'orizzonte percettivo di persone che per il resto
continuano a non occuparsene affatto, almeno in maniera diretta e
cosciente.

Se tale impressione corrisponde effettivamente alla realtà, ciò è da far
risalire, oltreché alla sporadica capacità dell'architettura attuale di
"scandalizzare" i ben (poco) pensanti, a quella di dare forma e sostanza
-- almeno in apparenza -- ai "desideri" della società contemporanea,
vale a dire di rispondere soddisfacentemente alle sue "attese". Il
discorso in realtà è un po' più complicato. Affermare che nel corso
della sua storia l'architettura sia sempre stata espressione delle
società in cui si è sviluppata è una verità tanto ovvia da rischiare di
essere confutabile. Nella *polis* greca, il tempio, il teatro, persino
gli edifici sportivi (si pensi a Olimpia, a Nemea o a Epidauro), ben al
di là dall'essere semplici contenitori di funzioni sociali, svolgevano
il ruolo di riattivatori rituali di un fondamento rimosso da cui
l'intera comunità originava. Nella città romana (soprattutto con
l'espansione imperiale), gli edifici e gli spazi pubblici si facevano
portatori di un messaggio politico che non era affatto espressione della
realtà in cui si inserivano. Nella città rinascimentale, gli edifici
rappresentavano frammenti di un ordine dotato di una ben precisa
funzione ideologica, che spesso però è entrato in conflitto con la città
precedente. E altrettanto si potrebbe dire delle altre epoche.

Rispetto alle attese cui architettura e città hanno saputo rispondere
nel corso del Novecento (per la gran parte attese di tipo sociale:
richieste di abitazioni per tutti, di servizi sociali, di spazi
pubblici), quelle odierne possiedono un carattere ben diverso. In
realtà non tanto diverso da risultare imprevedibile. Lo spazio della
città, nella storia, è stato teatro di una continua "contesa" tra idee
di suo uso addirittura opposte:

> Da un lato la città come un luogo di *otium*, luogo di scambio umano,
> sicuramente fattivo, attivo, intelligente, una dimora insomma, e da un
> altro il luogo dove poter sviluppare nel modo più efficace i
> *nec-otia*[^24].

Oggi all'architettura (e alla città) sembra non si chieda nulla di più
che dar forma visibile e tangibile ai *negotia*, agli affari, vale a
dire a quello "spirito commerciale" cui sono improntate nel modo più
profondo e completo le società -- e all'interno di esse, le *vite* --
occidentali[^25]. Ciò non va inteso in un senso ristretto,
limitatamente a quegli spazi destinati alla vendita di cui pure gli
architetti nell'ultimo secolo si sono intensamente occupati[^26].
Piuttosto, svettanti grattacieli e sfavillanti shopping center -- ma
anche edifici per l'intrattenimento e il tempo libero variamente
concepiti -- paiono rispondere perfettamente "a tono" alle più o meno
esplicite richieste dei cittadini-consumatori che non soltanto li
utilizzano, ma che addirittura sembrano aderire totalmente al programma
"ideologico" di cui questi edifici costituiscono l'oggettivazione. Un
programma "ideologico" -- quello disposto dal sistema capitalistico --
che si lascia assumere senza troppi pensieri, con leggerezza, e nel
quale i cittadini-consumatori paiono felici di rispecchiarsi.

Si potrebbe obiettare che tali domande "collettive" sono probabilmente
assai poco spontanee, poco realistiche, e che addirittura esse sono del
tutto irreali, nel senso che non sono formulate affatto dalla
maggioranza di coloro che usufruiscono delle città e dei suoi edifici; e
che piuttosto sono il prodotto della *simulazione di un desiderio* che
le forze economiche oggi dominanti nelle nostre società proiettano
sull'inconscio collettivo dei cittadini-consumatori, con un'intensità
tanto maggiore al crescere delle dimensioni dei contesti urbani[^27].
Ma, quale che sia la verità, questa "illusione di soddisfazione sociale"
nei confronti dell'architettura urbana per il momento funziona, e trova
una piena rispondenza negli architetti incaricati di realizzarla.

L'architetto -- oggi come nei momenti storici precedenti -- mette la
propria opera a disposizione della società in cui vive. Lo faceva
Filippo Brunelleschi con la Repubblica di Firenze, lo facevano Gian
Lorenzo Bernini e Francesco Borromini con il Papato di Roma, e lo fanno
gli architetti attuali con i loro committenti. In apparenza, non vi è
nessuna differenza; in realtà, i modi in cui gli architetti si sono
messi al servizio della società nel corso del tempo presentano tra di
loro difformità consistenti[^28]. L'architetto ha spesso rivestito un
ruolo di consigliere e di propositore, oltreché di realizzatore. E in
non poche occasioni è arrivato anche a calarsi -- in passato -- nei
panni del pensatore, dell'utopista, del sognatore, declinando
l'etimologia del progetto nel suo senso più diretto e immediato: quello
di un'evocazione -- qui e ora -- del futuro (*proiectus* in latino è
propriamente l'azione del gettare in avanti, e dunque del proiettare).

Oggi invece, almeno in una gran parte dei casi, l'architetto appare
preda di intricate dinamiche che, se da un lato le/gli vietano di porsi
in una posizione di "ingenua" neutralità, dall'altro la/lo portano a
vedere in maniera quasi "connaturata" ("naturalizzata", si potrebbe dire
in termini marxisti) il proprio ruolo di "operatore specializzato"
all'interno di un processo ben più vasto e composito di cui il proprio
progetto rappresenta con tutta evidenza soltanto un "momento". Ed è
degno di nota che, proprio in questo ambito, all'architetto sia
richiesto non soltanto di svolgere ruoli esecutivi, ma anche -- in
alcuni casi particolarmente complessi -- di fornire contributi
"ideativi", spingendosi al di là delle proprie "tradizionali competenze
disciplinari"[^29], in qualità di "suggeritore" di possibili funzioni e
utilizzi, sempre comunque inseriti in una logica complessiva che non
le/gli è dato in alcun modo di mettere in discussione, per non parlare
poi di criticarla apertamente. Ciò, ben lungi dal conferire
all'architetto un ruolo "decisionale" autonomo, finisce per attestarne
la posizione ancillare, riducendo il suo contributo a uno "scandaglio
preliminare di ipotesi formalizzate"[^30]. Ed è dunque palese come,
stando le cose in questo modo, la sua "massima aspirazione" possa essere
quella di limitarsi a farsi interprete di "programmi ideologici" già
stabiliti da altri, aggiungendovi al più il valore di un'effettiva o
presunta "originalità" della forma.

Quale sia il messaggio in questione, potrebbe risultare a questo punto
quasi enigmatico, se non fosse invece sin troppo evidente, trattandosi
dell'"eterna" (nella logica capitalistica) esortazione al consumo di cui
il sistema ha endemicamente bisogno; un consumo che non va inteso
esclusivamente nel senso dell'acquisizione di merci, di beni materiali,
ma anche in quello più astratto e generale dell'assunzione del sistema
in quanto tale come *valore*. In questo senso, l'esortazione al consumo
capitalistico -- consumo di sé, oltreché di ogni singola merce -- si
traduce immediatamente nell'*affermazione* (niente affatto nella
semplice "richiesta") di un *consenso* nei propri stessi confronti[^31]:
nei confronti delle proprie "regole", dei propri "valori". In
quest'opera cosí importante di persuasione, che il capitalismo conduce
in quel modo seduttivo e apparentemente non coercitivo che gli è
proprio, l'architettura ha l'incombenza fondamentale di tradurre tutto
ciò in oggetti, spazi e luoghi concreti.

A cinquant'anni di distanza dal saggio *Per una critica dell'ideologia
architettonica*[^32], e a poco meno dalla sua già citata rielaborazione
in forma di libro, in cui Tafuri stilava una lucida diagnosi in merito
ai "compiti che lo sviluppo capitalistico ha tolto all'architettura" --
primo e fondamentale fra questi, la dimensione utopica -- lasciando ad
essa soltanto il "dramma" di "vedersi obbligata a tornare *pura
architettura*, istanza di forma priva di utopia, nei casi migliori,
sublime inutilità"[^33], l'architetto si ritrova a fare i conti con una
condizione nella quale davvero la possibilità dell'utopia sembra essere
ormai tramontata, e in cui non rimane null'altro che la dimensione della
realtà (sublimemente inutile, o piuttosto pragmaticamente utilissima)
quale suo campo d'azione. Una realtà niente affatto neutrale, e che
anzi il suo stesso apporto -- insieme a quello di altre forze[^34] --
contribuisce a configurare nella sua forma consensuale.

Individuare le condizioni in cui l'architetto odierno si trova,
riconoscerne i limiti, cercare di comprendere i modi di un loro
possibile superamento, è quanto si prefigge il presente libro. A
partire dalla chiara consapevolezza che non è in ogni caso proponibile
alcuna inversione di rotta, alcun semplicistico e nostalgico "ritorno
alle origini". I percorsi della storia, per quanto tortuosi e
apparentemente (o effettivamente) poco logici, sono sempre e comunque
incontrovertibili. Ciò su cui dunque è necessario interrogarsi, dopo
avere debitamente esplorato il profilo e il campo d'azione degli
architetti di un passato lontano o recente che hanno esercitato il
proprio ruolo di intellettuali, è quale sia il senso oggi -- e, ancora
di più, quale potrà essere il senso *in futuro* -- di un architetto
capace di andare oltre l'esecuzione di incarichi assegnati, un
architetto che sappia farsi interprete *attivo* della realtà,
prefigurando per essa possibilità alternative, o quantomeno cercando di
metterla in crisi.

[^1]: Vedi ad esempio *Intello Academy* dell'economista e psicanalista
Corinne Maier, tradotto in italiano con l'imbarazzante titolo
*Intellettualoidi di tutto il mondo, unitevi!*, Bompiani, Milano 2007.

[^2]: Vedi, tra i molti altri, Elémire Zolla, *L'eclissi
dell'intellettuale*, Bompiani, Milano 1959; Zygmunt Bauman, *La
decadenza degli intellettuali. Da legislatori a interpreti*, Bollati
Boringhieri, Torino 2007; Frank Furedi, *Che fine hanno fatto gli
intellettuali?*, Cortina, Milano 2007.

[^3]: Antonio Gramsci, *Quaderni del carcere* (1929-35), 4 voll., a cura
di Valentino Gerratana, Einaudi, Torino 2014.

[^4]: Gramsci, *Quaderni del carcere* cit., vol. III, Quaderno 12
(XXIX), § 1, p. 1516.

[^5]: *Ibid.*, § 3, p. 1550.

[^6]: *Ibid.*, pp. 1550-51.

[^7]: *Ibid.*, p. 1551.

[^8]: *Ibid.*, Quaderno 11 (XVIII), § 16, p. 1406.

[^9]: *Ibid.*, vol III, Quaderno 12 (XXIX), § 3, p. 1551.

[^10]: Jürgen Habermas, *Il ruolo dell'intellettuale e la causa
dell'Europa*, Laterza, Roma-Bari 2011, p. 7.

[^11]: *Ibid*. Su ciò vedi anche Michael Walzer, *L'intellettuale
militante. Critica sociale e impegno politico nel Novecento*, il
Mulino, Bologna 1991.

[^12]: Manfredo Tafuri, *Progetto e utopia. Architettura e sviluppo
capitalistico*, Laterza, Roma-Bari 1973, pp. 169-70.

[^13]: Gramsci, *Quaderni del carcere* cit., vol. III, Quaderno 12
(XXIX), § 3, p. 1550.

[^14]: Oltre a Karl Marx e Friedrich Engels, *L'ideologia tedesca*
(1845), Editori Riuniti, Roma 1971, p. 21 e *passim*, vedi, tra gli
altri, Alfred Sohn-Rethel, *Lavoro intellettuale e lavoro manuale. Per
la teoria della sintesi sociale*, Feltrinelli, Milano 1977.

[^15]: "... e che tu abbia una istruzione letteraria, che sia esperto
nel disegno, preparato in geometria, che conosca un buon numero di
racconti storici, che abbia seguito con attenzione lezioni di filosofia,
che conosca la musica, che abbia qualche nozione di medicina, che
conosca i pareri dei giuristi, che abbia acquisito le leggi
dell'astronomia": Vitruvio, *De Architectura*, 2 voll., Einaudi, Torino
1997, libro I.3, p. 14.

[^16]: *Ibid.*, libro I.1, p. 13.

[^17]: Per la distinzione tra "lavoro" e "opera" vedi Hannah Arendt,
*Vita activa. La condizione umana* (1958), Bompiani, Milano 2011,
pp. 58 sgg. Per un'applicazione di questa distinzione all'architettura,
vedi Pier Vittorio Aureli, *Labor and Work in Architecture*, in "Harvard
Design Magazine", n. 46, 2018, pp. 71-81.

[^18]: Antonio Averlino detto il Filarete, *Trattato di architettura*
(1464 circa), 2 voll., a cura di Anna Maria Finoli e Liliana Grassi, Il
Polifilo, Milano 1972, libro I, pp. 10-11.

[^19]: Emblematico al proposito è il racconto di Italo Calvino, *La
speculazione edilizia*, Einaudi, Torino 1963 (ma finito di scrivere nel
1957), il cui protagonista è un giovane intellettuale che, trascinato
dallo "spirito dell'epoca", si imbarca in un'operazione immobiliare
sulla Riviera ligure affiancato a un equivoco imprenditore edile.

[^20]: Tomás Maldonado, *Che cos'è un intellettuale? Avventure e
disavventure di un ruolo*, Feltrinelli, Milano 1995. Altrettanto
sintomatico, comunque, è il fatto che, tra tutti i nomi citati nel
libro, non ve ne sia neppure uno d'un architetto.

[^21]: *Ibid.*, p. 95.

[^22]: *Ibid.*, p. 94.

[^23]: Gabriella Lo Ricco e Silvia Micheli, *Lo spettacolo
dell'architettura. Profilo dell'archistar*^©^, Bruno Mondadori, Milano
2003.

[^24]: Massimo Cacciari, *La città*, Pazzini Editore, Rimini 2009,
p. 23.

[^25]: *The Harvard Design School Guide to Shopping*, a cura di Chuihua
Judy Chung, Jeffrey Inaba, Rem Koolhaas e Sze Tsung Leong, Taschen, Köln
2001.

[^26]: Vedi, ad esempio, Dario Scodeller, *Negozi. L'architetto nello
spazio della merce*, Electa, Milano 2007.

[^27]: Su ciò vedi Jean Baudrillard, *La società dei consumi. I suoi
miti e le sue strutture*, il Mulino, Bologna
2010. Al proposito vedi anche le ricerche condotte da Vanni Codeluppi,
*Lo spettacolo della merce. I luoghi del consumo dai 'passages' a
'Disney World'*, Bompiani, Milano 2000; Id., *La vetrinizzazione
sociale. Il processo di spettacolarizzazione degli individui e della
società*, Bollati Boringhieri, Torino 2007; Id., *Metropoli e luoghi del
consumo*, Mimesis, Milano 2014.

[^28]: Spiro Kostof (a cura di), *The Architect. Chapters in the
History of the Profession*, University of California Press, Berkeley
2000, che tuttavia -- per quanto riguarda i periodi dal 1700 in avanti
-- si limita ad analizzare il contesto anglosassone e nordamericano.

[^29]: Manfredo Tafuri, *Storia dell'architettura italiana 1944-1985*,
Einaudi, Torino 1986, p. 206. Il "caso" in questione è quello del
Lingotto di Torino.

[^30]: *Ibid.*, p. 207. più in generale vedi anche -- per limitarsi alla
sola Italia -- il capitolo *"Reconversio urbis I": Venezia, Milano,
Torino, Firenze*, in Marco Biraghi e Silvia Micheli, *Storia
dell'architettura italiana 1985-2015*, Einaudi, Torino 2013, pp. 38-59.

[^31]: Interessante a questo proposito constatare come la società
capitalistica abbia il proprio modello nella fabbrica. E non a caso
proprio qui mutano -- con il passare del tempo -- i rapporti sociali,
indirizzandosi progressivamente verso l'ottenimento di un consenso.
Sull'argomento vedi il fondamentale Michael Burawoy, *Manufacturing
Consent: Changes in the Labor Process under Monopoly Capitalism*,
University of Chicago Press, Chicago 1979. "Per comprendere le dinamiche
sociali che avvengono nelle fabbriche a capitalismo sviluppato occorre
riconoscere che le politiche di produzione un tempo fondate unicamente
su metodi coercitivi si modificano e si ampliano in modo da rendere
possibile un progressivo coinvolgimento consensuale della manodopera nel
proprio lavoro. In altri termini, con l'evoluzione storica del
capitalismo, le politiche di produzione passano gradualmente dal
dispotismo all'egemonia. Con questa espressione, tratta da Gramsci,
Burawoy intende una politica che combina organicamente forza e
persuasione, coercizione e consenso, e che fornisce una base ideologica
di legittimazione al proprio esercizio che è accettata anche da coloro
su cui il potere è esercitato": Giuseppe Bonazzi, *Storia del pensiero
organizzativo*, Franco Angeli, Milano 2008, p. 145.

[^32]: Manfredo Tafuri, *Per una critica dell'ideologia architettonica*,
in "Contropiano", n. 1, 1969, pp. 31-79.

[^33]: Tafuri, *Progetto e utopia* cit., p. 3.

[^34]: Edward S. Herman e Noam Chomsky, *La fabbrica del consenso. La
politica e i mass media*, Il Saggiatore, Milano 2014.

# L'architettura come merce e l'architetto come "rifornitore"

Una trasformazione profonda, lenta e apparentemente inesorabile ha avuto
luogo con particolare intensità nel corso degli ultimi cento anni: la
trasformazione dell'architettura (intesa come fatto concreto, materiale,
tridimensionale) da "oggetto d'uso" a merce. Questo fenomeno non
costituisce nulla di sorprendente, o di anormale, considerato il
contesto generale nel quale si svolge. Ciò nondimeno, per chi se ne
occupa da un punto di vista "interno" (disciplinare o "scientifico" che
dir si voglia), cosí come per chi la osserva distrattamente da lontano,
da "fuori", l'architettura può risultare "strana" in queste vesti.
Perciò, provare a fissare brevemente tale fenomeno può valere a
intenderlo nell'ottica della disciplina e a cercare di comprendere le
sue conseguenze in un senso più generale.

Tale trasformazione in realtà ha avuto inizio ben da prima: in quanto
oggetto d'uso, l'architettura ha da gran tempo cessato di essere
prodotta da colei/colui cui era destinata, proprietario o fruitore che
fosse, e dunque il suo valore d'uso si è presto tramutato in valore
d'uso sociale; e in qualità di valore d'uso sociale è divenuto un
oggetto di scambio e ha acquisito un valore di scambio[^1]. Con ciò
l'architettura, come qualsiasi altro oggetto nelle società nelle quali
predomina il modo di produzione capitalistico, ha già virtualmente
compiuto la sua trasmutazione in merce: arrivando anzi a costituire --
come a tutti ben noto -- uno dei fondamenti stessi della ricchezza
pubblica e privata, e rappresentando valori economici spesso assai
cospicui, nella forma di proprietà immobiliari dotate di un proprio
specifico mercato.

Ma pur se tecnicamente avvenuto ormai da lungo tempo, il passaggio
dell'architettura da oggetto d'uso a merce è privo fino al principio del
XX secolo di un elemento fondamentale al suo definitivo compimento: il
trapassare del carattere di merce dal livello del puro valore di scambio
alla totalità dei suoi aspetti. Progettazione, rappresentazione,
costruzione, commercializzazione, sono tutti momenti del processo
produttivo dell'architettura che a vario titolo vengono sottoposti a una
più o meno palese e intensa mercificazione. La storia dell'architettura
del Novecento è, sotto molti riguardi, la storia del progressivo cammino
di questa, non tanto o soltanto verso una "modernità" genericamente o
stilisticamente intesa, quanto piuttosto verso il suo divenire *prodotto
di consumo*[^2]. L'abitazione, di questo processo, rappresenta il caso
forse maggiormente emblematico. Se si pone mente allo sviluppo della
residenza, in tutte le sue forme e a tutti i suoi livelli, nel corso
dell'ultimo secolo[^3], ad esempio, non si può che constatare il suo
completo coinvolgimento in questo processo: l'industrializzazione dei
metodi costruttivi, la standardizzazione e la prefabbricazione dei
componenti edilizi e degli elementi d'arredo, la serializzazione dei
"modelli" abitativi, le stesse tecniche di pubblicizzazione e di
vendita: non c'è campo in cui la residenza non abbia adottato le
medesime strategie utilizzate per gli altri prodotti di consumo. Ciò --
si badi bene -- ha avuto conseguenze tanto positive quanto negative.
Cosí, dagli inizi del Novecento in avanti, la residenza è stata spesso
oggetto di ricerche e di sperimentazioni tecnicamente e socialmente
all'avanguardia, volte a migliorarne le "prestazioni", e non di rado
anche a diminuirne i costi; ma è stata pure oggetto di sfruttamenti
intensivi e di operazioni a carattere puramente speculativo, oltreché
funzionali a precise politiche di ghettizzazione sociale, come risulta
evidente osservando quanto è accaduto nelle periferie delle città di
molti paesi occidentali, in particolare negli anni cinquanta e sessanta.

Non sono qui in discussione gli esiti di queste operazioni. E il
problema non è neppure quello di distribuire "promozioni e bocciature"
ai rispettivi architetti. La funzione dell'architettura rimane comunque
strutturale al sistema; e neppure il "mito riformista", che ha
lungamente attraversato l'Europa nel corso del Novecento, è riuscito ad
avere ragione delle sue contraddizioni.

A questa vicenda appartengono alcune delle migliori idee e realizzazioni
-- in termini di impegno politico sul piano urbano e di studio di
soluzioni innovative alla scala architettonica -- che si possano
annoverare nell'ambito del XX secolo. Si pensi ad esempio al caso della
Francoforte di Ernst May. Il lavoro svolto in qualità di assessore
all'edilizia, con la collaborazione di un ingente numero di architetti
che formeranno la cosiddetta "brigata May", rivela in pieno lo sforzo
per riscattare le condizioni di partenza -- in termini di possibilità
economiche e di standard dimensionali -- delle numerose *Siedlungen*
(per un ammontare totale di circa 12 000 appartamenti) progettate tra il
1926 e il 1930, mediante l'impiego di equipaggiamenti tecnologici e di
dispositivi di altra natura del tutto inusitato per quelle che sono e
rimangono a tutti gli effetti case popolari. Dovendo sottostare a
vincoli dimensionali alquanto esigui (40-45 mq per un alloggio per
quattro persone), May e i suoi collaboratori riservano una particolare
attenzione ai servizi (tra essi la famosa *Frankfurter Küche*, la
cucina-laboratorio ultra-efficente di Margarete Schütte-Lihotzky)[^4],
agli impianti, agli spazi comuni, agli edifici pubblici e alle
attrezzature collettive. In questo senso, la dotazione di impianti di
riscaldamento e di lavanderie centralizzati, di asili infantili, di
campi da gioco e di ricreazione, di centri sociali, e persino
l'installazione in ciascun complesso residenziale di impianti-radio
centrali per offrire "la possibilità di promuovere in futuro lo spirito
comunitario attraverso trasmissioni radiofoniche interne che abbracciano
la sfera di una *Siedlung*"[^5], pongono in evidenza l'importanza che
May assegna a tutto ciò che può fungere da fattore di connessione
sociale. Si tratta di una complessa operazione culturale e
organizzativa condotta sia con strumenti specificamente architettonici
(la standardizzazione delle componenti edilizie e l'utilizzo per la
costruzione di pannelli prefabbricati) sia con altri mezzi, tra cui --
oltre a quelli già citati -- la pubblicazione di una rivista mensile,
"Das neue Frankfurt", che tra il 1926 e il 1931 affronta una serie di
questioni cruciali come l'*Existenzminimum*, l'istruzione e l'igiene, ma
anche questioni a prima vista estranee alla cultura architettonica, come
la fotografia sperimentale, il teatro, il film documentario,
l'automobile utilitaria. Nonostante la molteplicità degli approcci,
ogni elemento messo in campo da May risulta riconducibile a una
concezione unitaria che pone al suo centro -- come ha scritto Giorgio
Grassi -- uno "stile di vita" ispirato "a una disciplina rigorosa, a una
norma morale"[^6]. È significativo che tutti questi accorgimenti si
connettano tra loro secondo una metodologia che attinge dal repertorio
della tecnica avanguardistica del "montaggio" (non a caso Tafuri, a
proposito della nuova Francoforte di May, evoca la "catena di
montaggio")[^7]. E tuttavia, questo "sogno di un "socialismo dal volto
umano" (...) mistifica il proprio essere tutto rivolto a stimolare i
processi produttivi"[^8]: un'anticipazione della "meccanizzazione" della
casa borghese.

Diverso il caso -- ma non diversi gli effetti -- delle proposte
residenziali avanzate da Le Corbusier a partire dai primi anni venti.
La *machine-à-habiter* è per lui lo strumento sociale per "evitare la
rivoluzione"[^9], ovvero per attuarla in termini architettonici, in modo
pacifico. Come l'automobile utilitaria (la stessa di cui si occupava
"Das neue Frankfurt"), l'architettura prodotta in serie gli appare
destinata a cambiare la vita dei suoi utenti, e non semplicemente a
mettere loro a disposizione le proprie prestazioni in una versione più
aggiornata. Quale diretta conseguenza di ciò, i tradizionali elementi
dell'edificio (pareti, finestre, coperture, ecc.) risultano
profondamente aggiornati, come lo sarebbero i pezzi di un meccanismo per
effetto di un'innovazione tecnologica, di un ruolo e di un funzionamento
differenti, e non per ragioni estetiche o di "gusto". Montandoli uno a
uno secondo un "sistema logico" che dalla cellula elementare della
Maison Dom-Ino giunge fino al complesso macchinario urbano della Ville
Radieuse, Le Corbusier pone in evidenza il necessario legame tra tutte
le parti -- o i "pezzi" -- della costruzione dello spazio sociale, da
quello privato a quello pubblico, e ne mostra la riducibilità a un unico
"discorso".

Che la "rivoluzione" architettonica attuata (o quantomeno, attuabile) in
questo modo sia concepita da Le Corbusier in termini del tutto
antirivoluzionari da un punto di vista politico -- com'è reso esplicito
dall'aut aut che egli stesso insistentemente propone: "Architettura o
rivoluzione" --, non la priva affatto di un carattere a propria volta
politico: infatti

> ... la strategia politica dietro questo progetto è chiara: la Maison
> Dom-Ino doveva risolvere la penuria di abitazioni per lavoratori, e i
> lavoratori erano intesi come i potenziali proprietari delle proprie
> abitazioni. Il modello Dom-Ino inscriveva la proprietà privata --
> ovvero il miglior modo, per il capitale, per controllare i lavoratori
> -- direttamente nel processo costruttivo della casa. Qui il legame
> tra forma urbana e investimento economico già stabilito dalla
> trasformazione di Parigi di Haussmann è perfezionato alla scala della
> singola abitazione[^10].

L'intento politico del ciclo che connette la cellula alla città va
dunque valutato nella sua interezza come espressione della volontà di
costruire un mondo nuovo per l'"uomo nuovo" prodotto dal capitalismo
(vale a dire per "l'uomo contemporaneo" di cui lo stesso Le Corbusier
parla, il quale "avverte (...) l'esistenza di un mondo che si va
elaborando regolarmente, logicamente, chiaramente, che produce con
purezza cose utili e utilizzabili")[^11]. E se le condizioni di
esistenza capitalistiche non risultano in alcun modo sovvertite bensì
casomai potenziate dal programma lecorbusieriano, è in ogni caso una
mutazione fondamentale quella di cui esso si fa interprete, come
riconosce anche Benjamin: "La *ville contemporaine* di Le Corbusier è
pur sempre un complesso edilizio lungo una strada maestra. Senonché,
col fatto che questa strada è ora percorsa da automobili e che nel
centro del complesso atterrano gli aerei, tutto si è trasformato"[^12].
Inoltre, in quanto "regolabile e movibile" e priva di "aura"[^13], la
*machine-à-habiter* costituisce "l'epilogo della "casa" come figurazione
mitologica"[^14]. Essa è pronta per diventare un prodotto di serie, un
dispositivo, vale a dire un prodotto dell'industria:

> La grande industria deve occuparsi della costruzione e produrre in
> serie gli elementi della casa. (...) Se si sradicano dal proprio cuore
> e dalla propria mente i concetti sorpassati della casa e si esamina la
> questione da un punto di vista critico e oggettivo, si arriverà alla
> casa-strumento, casa in serie, sana (anche moralmente) e bella
> dell'estetica degli strumenti di lavoro che accompagnano la nostra
> esistenza[^15].

Da qui alla casa-merce il passo è breve.

Tuttavia, nonostante i fervidi auspici di Le Corbusier, è soprattutto
sotto un profilo formale e figurativo che l'architettura mostra --
soprattutto a partire dal secondo dopoguerra, e in modo ancora più
evidente negli ultimi trent'anni -- la sua integrale assimilazione a una
merce. È stato nel corso di questo periodo, infatti, che si è verificato
un sempre più rilevante processo di identificazione dell'architettura
con l'immagine. Facendo ricorso a diversi "espedienti", essa ha fatto
gradualmente registrare lo spostamento del proprio "baricentro" dalla
mitologia centrale del moderno, consistente essenzialmente nella
rappresentazione delle funzioni, a quella -- precipuamente postmoderna
-- della comunicazione e della mediatizzazione di se stessa. Nel
compiere questa "evoluzione" l'architettura si dichiara idonea, prima
che a ogni altra cosa, alla propria diffusione e circolazione. Ed è
precisamente in quest'ottica che va intesa la sua trasformazione in
immagine.

Già nel 1967, con sorprendente lucidità, Guy Debord aveva diagnosticato
il destino che attendeva "tutta la vita delle società nelle quali
predominano condizioni moderne di produzione"[^16], vale a dire il modo
di produzione capitalistico: trasformarsi in "un'immensa accumulazione
di spettacoli". Per Debord, nell'epoca del capitalismo avanzato, tutto
ciò che in precedenza "era direttamente vissuto si è allontanato in una
rappresentazione". In essa l'accumulazione del capitale è giunta a un
tale grado da farsi spettacolo, "da divenire immagine"[^17]. E se "lo
spettacolo (...) è l'equivalente generale astratto di tutte le
merci"[^18], nella proliferazione delle immagini dobbiamo riconoscere
null'altro che la proliferazione totale della merce. Anche il
rovesciamento dell'affermazione di Debord proposto più recentemente da
Matteo Pasquinelli ("Il capitale è spettacolo ad un tale grado di
accumulazione da trasformarsi in una skyline di cemento")[^19] non
sposta -- e anzi conferma -- la propensione del capitale a investire in
merce-architettura. Ed è proprio in quanto merce che essa persegue
l'obiettivo che accomuna tutte le merci nell'epoca moderna e
contemporanea: presentarsi come perenne novità. "La novità è una qualità
indipendente dal valore d'uso della merce"[^20]: non si potrebbe
esprimere in maniera più sintetica la relazione che interconnette merce,
nuovo e apparenza. Essa appartiene al regno dell'immaginario, non a
quello dell'utile.

Nonostante l'affermazione di Alois Riegl che il "valore di novità" sia
il *beatus possidens* di "un luogo occupato per millenni", esso ha fatto
il suo ingresso nell'ambito architettonico relativamente di
recente[^21]. L'apposizione del prefisso neo- di fronte alla parata
degli stili del passato, lungo tutto l'Ottocento, costituisce la prima
avvisaglia di un fenomeno in precedenza del tutto sconosciuto, almeno in
quei termini; mentre la denominazione di Art Nouveau, utilizzata tra
fine Ottocento e primo Novecento per indicare il complesso di
manifestazioni artistiche tese a segnare una svolta rispetto al passato,
da un lato, e a dare un volto alla classe borghese divenuta soggetto
ormai dominante sulla scena della storia, dall'altro, parla chiaramente
dell'ansia di arte e architettura di quel periodo di caratterizzarsi in
senso innovativo; anzi, di identificarsi *tout court* con il nuovo.
Cosí come -- in maniera se possibile ancora più esplicita -- è
significativo che negli anni venti e trenta, soprattutto in ambito
tedesco e olandese, vengano impiegate formule come "Neues Bauen", "Neue
Baukunst" o "Nieuwbouw" per riferirsi all'insieme delle esperienze
relative all'architettura moderna[^22]. Soltanto in seguito il termine
"nuovo" scomparirà dal lessico ufficiale dell'architettura, per
penetrare in compenso sempre più nel profondo della sua
ideologia. "Nuovo" a questo punto non è più l'attributo di una
determinata "famiglia" architettonica, comprendente edifici e progetti
contraddistinti da caratteri comuni e riconoscibili, riconducibili nel
loro complesso alla categoria di "moderno", quanto piuttosto quello di
ogni architettura dotata di una propria spiccata individualità, ovvero
-- per dirlo in modo più preciso -- di una propria *singolarità*;
un'architettura la cui "novità" è dunque fondamentalmente rappresentata
dalla propensione per una "differenza" che è spesso sinonimo di
stravaganza. Il "nuovo", in quest'ottica, serve all'architettura
soprattutto per distinguersi, per attrarre l'attenzione: un accorgimento
che essa ha evidentemente assimilato dalla pubblicità, e che, nel
rimarcare la sua riduzione a immagine, ne conferma in pieno il carattere
di merce. Cosí come, secondo Tafuri, per converso, "non è un caso che
il destino dei formalismi si concluda sempre nell'utilizzazione
"pubblicitaria" del *lavoro sulla forma*"[^23].

In realtà il potere delle immagini *sub specie architecturae* ha una
storia ben più lunga e prestigiosa. Anche volendo limitarsi al XX
secolo, si potrebbero ricordare i grandi edifici del potere politico nei
regimi totalitari, cosí come quelli del potere economico nelle
democrazie: edifici che, nell'adempimento delle proprie funzioni,
trasmettono un fascio di idee che comprendono variamente -- e spesso
contemporaneamente -- ufficialità, autorità, eternità, inattaccabilità,
solidità, stabilità. Del tutto diverso è invece il discorso per quanto
riguarda quegli edifici il cui "scopo" precipuo è rivestire il ruolo di
*icone*[^24]. Gli "edifici iconici", nella definizione che ne dà Pier
Vittorio Aureli,

> ... sono tipicamente landmarks singolari il cui scopo è interamente
> iscritto all'interno della logica dell'urbanizzazione. E infatti,
> l'obiettivo dell'edificio iconico è un'architettura post-politica
> spogliata da qualsiasi significato che non sia la celebrazione della
> performance economica aziendale[^25].

Prima di questa fase, l'iconicità ha rappresentato la caratteristica
distintiva di alcuni edifici eccezionali, nel senso che -- letteralmente
-- costituivano delle eccezioni. Nel corso del XX secolo edifici
iconici in un modo del tutto diverso da quelli successivi sono stati ad
esempio il Salomon R. Guggenheim Museum (1943-59) a New York di Frank
Lloyd Wright e l'Opera House (1957-73) di Sydney, di Jørn Utzon. In
entrambi i casi i loro autori hanno fatto ricorso a soluzioni formali
che sembrano aver tenuto conto della singolarità di cui essi ritenevano
fossero portatori i loro edifici. In realtà, nel caso del Guggenheim,
ciò che viene progressivamente emergendo dalla lunghissima gestazione
dell'edificio è -- più di ogni altra cosa -- una volontà
"iconoclasta"[^26], anziché iconica, e di conseguenza un autoritratto
della personalità del suo autore, di cui esso ha finito per diventare il
massimo emblema; mentre nel caso dell'Opera House -- pur tra le enormi
difficoltà progettuali e realizzative che hanno portato il suo autore a
disconoscerne la paternità[^27] -- è non soltanto Sydney ma addirittura
l'Australia intera a essere "condensata" nella sua celebre immagine.

Ma è forse con il Centre Georges Pompidou (1971-77) che architettura e
immagine sembrano arrivare a identificarsi perfettamente. E tuttavia,
ancora una volta, con molte radicali differenze rispetto non solo ai
suoi successori, ma anche a ogni banale pretesa simbolica. Per quanto
assai rilevante sotto molteplici punti di vista, infatti, il Centre
Pompidou non può certo ambire a rappresentare, come parte per il tutto,
il luogo in cui sorge -- Parigi o la Francia --, e neppure l'intera
opera dei suoi autori: Renzo Piano, Richard Rogers o Peter Rice. Esso
piuttosto rappresenta nella maniera più compiuta il tentativo delle
autorità francesi -- e del presidente Pompidou in primo luogo -- di dare
vita a un edificio che rispondesse, incorporandole, alle istanze del
Maggio '68 francese. Ciò di cui la grande "macchina per
comunicare"[^28] è la rappresentazione è la totale *autonomia* della sua
immagine rispetto a qualsiasi suo "contenuto". Come ha rilevato Jean
Baudrillard,

> ... con il suo intreccio di tubi (...) con la sua fragilità
> (calcolata?), che dissuade da ogni mentalità o monumentalità
> tradizionale,

la macchina Beaubourg

> ... proclama apertamente che il nostro tempo non sarà mai più quello
> della durata, che la nostra sola temporalità è quella del ciclo
> accelerato e del riciclaggio, quella del circuito e del transito di
> fluidi[^29].

In questo processo di trasmutazione il Centre Pompidou si afferma come
immagine, non certo dell'istituzione museale che nega di essere, bensì
della "rottura delle molecole culturali e \[del\] loro ricombinarsi in
prodotti di sintesi". Immagine dunque della frantumazione di
un'immagine, sostituita da un festoso apparato di strutture metalliche,
tubi colorati e spazi liberi (almeno nelle intenzioni) per usi diversi.

È interessante notare al proposito come -- attraverso un'operazione di
grande complessità, condotta in tempi rapidissimi (il bando di concorso
è messo a punto già nel 1970, ad appena due anni di distanza dall'acme
del movimento) e in cui sono coinvolti numerosissimi soggetti con
svariate competenze -- la "controcultura" del '68, ovvero la cultura
"alternativa" sviluppatasi in Francia e non solo in quell'intorno di
anni, venga fatta propria, integrata in un edificio sorto per volontà di
un potere destinato comunque ad affermare (e a confermare) la propria
indiscussa centralità. E non è meno sorprendente il fatto che il potere
compia un cosí vistoso "spostamento" dalla propria auto-rappresentazione
tradizionale di quanto lo sia il fatto che per farlo utilizzi le
medesime "armi" del nemico (tra essi, gli echi del progetto del Fun
Palace di Cedric Price per Joan Littlewood e dei disegni "tecno-utopici"
di Archigram). Ed è altresí interessante che le istanze di rinnovamento
e le aspirazioni di egemonia culturale dello Stato francese vengano
incanalate in una forma corrispondente a ciò che nuovamente Baudrillard
definirà un "ipermercato della cultura", ovvero "un oggetto da
consumare, (...) un edificio da manipolare"[^30]: dove i processi di
reificazione e di mercificazione sono ormai trasparenti.

Pur radicandosi sul medesimo "ceppo", la ramificazione del discorso
relativa agli *iconic buildings* si sviluppa in un modo differente, a
partire proprio dal ruolo da essi occupato all'interno dei rispettivi
contesti urbani. Il Guggenheim Museum di Bilbao (1991-97) di Frank O.
Gehry si è guadagnato il titolo di capostipite della famiglia degli
*iconic buildings* non soltanto per le sue forme vistose e sorprendenti
ma anche per lo studiato posizionamento in un punto strategico della
città, sulla riva del fiume Nervión[^31]. L'intera vicenda del
Guggenheim -- compresi gli articolati rapporti tra il governo dei Paesi
Baschi, il direttore della Solomon R. Guggenheim Foundation, Thomas
Krens, e l'architetto Gehry -- costituisce in questo senso un esempio da
manuale, che in molte altre occasioni in seguito si è cercato di
replicare[^32]. È soprattutto in queste ultime, tuttavia, che in modo
sempre più lampante emerge come le presunte "eccezioni" siano in realtà
funzionali a confermare la regola. Eccentricità formali e appariscenze
cromatiche propagano ai quattro venti il roboante annuncio che "tutto
rimarrà come prima", ovvero che non è in corso alcuna "rivoluzione", o
meglio ancora che l'"ordine costituito" non verrà minimamente smentito o
scalfito dal nuovo inserimento. "Piuttosto che essere forme agonistiche,
le "icone" contemporanee sono la manifestazione finale e celebrativa
della *Grundnorm* dell'urbanizzazione: la vittoria dell'ottimizzazione
economica sul giudizio politico"[^33]. Nell'estensione sconfinata delle
città contemporanee, gli edifici iconici assumono il valore di un
"richiamo" (da intendersi nel senso in cui la medicina utilizza il
termine: la re-inoculazione di una sostanza per consolidare uno stato
d'immunità. Dove l'immunità in questione è riferita a qualsiasi
cambiamento sostanziale da parte dell'"organismo" complessivo).

Ma che cosa ne è dell'architetto allorché l'architettura abbia fatto il
suo ingresso nel "circuito" della spettacolarizzazione capitalistica? Da
quel momento in avanti -- e poi con sempre maggiore frequenza -- si
trova a rivestire il ruolo del "creatore di spettacoli". Non si tratta
ovviamente di un ruolo inedito per lui: in svariati momenti della storia
agli architetti è spettato il compito di allestire feste, di mettere in
scena rappresentazioni e di progettare edifici effimeri di vario
genere[^34]; e la "festa del capitale", da questo punto di vista, non
pare discostarsi troppo dalla festa barocca. Ma anche nel vero e
proprio esercizio della loro professione gli architetti hanno avuto
spesso modo di conferire ai propri edifici caratteri altamente
spettacolari. Ciò di per sé non costituisce un problema, al di fuori di
quei casi in cui tale spettacolarità assume tratti del tutto gratuiti;
cosí come, per converso, non per forza di cose l'elemento che accomuna
tra loro gli edifici iconici contemporanei è un'esplicita
spettacolarità. In fondo, lo stesso fenomeno degli *iconic buildings*
costituisce soltanto il caso particolare (e forse oggi -- almeno in
parte -- esaurito, o comunque "attutito" rispetto ad alcuni anni fa) di
un discorso più vasto e generalizzato; la punta di un iceberg la cui
"spettacolarità" consente a esso di emergere con maggiore evidenza.

Sulla possibile reversibilità di questo aspetto hanno contato coloro che
-- in controtendenza rispetto all'orientamento più largamente diffuso --
hanno cercato di mettere in scacco tale spettacolarizzazione. Cercare
di farlo, tuttavia, può costringere a compiere "salti" singolari,
apportatori di illuminanti paradossi. Nel 2006 lo studio OMA ha
progettato il Dubai Renaissance, un bianco volume monolitico di 300
metri di altezza per 200 di larghezza, destinato a uffici, hotel e suite
residenziali. Nel testo di presentazione dell'edificio si legge:

> L'ambizione di questo progetto è di concludere la fase attuale
> dell'idolatria architettonica -- l'età dell'icona -- in cui
> l'ossessione del genio individuale supera di gran lunga l'impegno per
> lo sforzo collettivo necessario a costruire la città. Invece di
> un'architettura della forma e dell'immagine, abbiamo creato una
> reintegrazione di architettura e ingegneria, dove l'intelligenza non è
> investita in effetti, ma in una logica strutturale e concettuale, che
> offre un nuovo tipo di prestazioni e funzionalità[^35].

L'edificio che ne deriva s'ispira a una nuova Simplicity^TM^ (si badi
bene, affiancata dal *trademark*) che tra i suoi attributi enumera
qualità come *pure*, *straight*, *substantial*, *objective*,
*predictable*, *original*, *honest* e *fair*. Nonostante le sue "buone"
intenzioni, tuttavia, il Dubai Renaissance risulta soltanto una falsa
reazione all'"idolatria architettonica": come appare evidente dalla
tavola elaborata dallo stesso OMA, dove esso è messo a confronto con una
parata di "vanità" architettoniche (dalle Petronas Towers di César Pelli
a Kuala Lumpur, al Burj al-'Arab di Tom Wright nella stessa Dubai),
dalle quali in realtà si distingue soltanto per le sembianze candide e
per i lineamenti uniformi. Pur rinunciando all'espressività delle forme
e all'impatto dei colori, il Dubai Renaissance è animato dalla medesima
volontà di stupire presente negli altri edifici iconici che insieme a
esso compongono una surreale "città analoga" nel deserto arabico.

Affermare una "iconoclastia" in luogo di una "iconolatria", cosí come
vagheggiare una città post-iconica[^36] in un mondo post-iconico, da
questo punto di vista, appaiono tentativi ineffettuali destinati al
fallimento, o a essere rapidamente assorbiti nelle capaci fauci di un
onnivoro capitalismo.

Come già detto, comunque, il nocciolo della questione non sta
nell'"originalità" del ruolo degli architetti odierni rispetto a quello
rivestito da essi in passato; né nell'eccentricità dei loro progetti
rispetto alla "canonicità" (vera o presunta) di quelli di altre epoche
storiche. E non consiste neppure nella posizione oggi assunta dagli
architetti nei confronti della società in cui operano. Il vero problema
è piuttosto quale posizione occupino gli architetti nei processi
produttivi attuali. Non si tratta dunque di un problema soggettivo,
bensì di un problema -- come già ben compreso da Walter Benjamin negli
anni trenta[^37] -- *tecnico*. Detto in altri termini, il problema è se
-- e in quale misura -- gli architetti odierni, esercitando il loro
ruolo di "creatori di spettacoli", oppure piuttosto rivestendone un
altro, riescano a operare una *trasformazione* dell'apparato produttivo,
e se -- e quanto -- invece compiano nei confronti di questo un "semplice
rifornimento"[^38].

Come chiarisce lo stesso Benjamin,

> ... rifornire un apparato produttivo senza trasformarlo (nella misura
> del possibile) rappresenta un procedimento estremamente oppugnabile
> persino quando i contenuti di cui è rifornito questo apparato sembrano
> di natura rivoluzionaria.

In questa prospettiva, il "rifornitore" di un apparato produttivo è
colui che si limita a perpetuarlo, o che al più lo rinnova "dall'interno
(...) secondo la moda", di conseguenza "lasciandolo cosí com'è"[^39].
Significativamente, per indicare i "rifornitori", Benjamin fa ricorso
anche al termine francese *routiniers* (coloro che si conformano
all'abitudine, che ripetono stancamente il già noto), intendendo con
esso coloro che rinunciano ad apportare correzioni al sistema di
produzione[^40]. A ciò egli contrappone il *Produzent* (produttore):
non semplicemente colui che produce (o piuttosto, che banalmente
ri-produce), quanto piuttosto colui che trasforma in senso tecnico
l'apparato produttivo.

La domanda da porsi a questo punto è: sono in grado gli architetti
attuali, con il loro intervento, di trasformare l'apparato produttivo
nel quale sono inseriti?

Le trasformazioni verificatasi nell'architettura nel corso dell'ultimo
secolo -- e poi, in modo sempre più rapido, nel corso degli ultimi
decenni (trasformazioni che, al di là degli aspetti strutturali e di
quelli estetico-formali, hanno contrassegnato il suo progressivo
*divenir-merce*) -- hanno inesorabilmente modificato anche la posizione
occupata dagli architetti all'interno dell'apparato produttivo. Non che
in precedenza questi godessero di una maggiore indipendenza, ma ancora
nel corso degli anni venti e nei primi anni trenta, e successivamente
tra gli anni cinquanta e sessanta, vi sono stati tentativi -- pur spesso
conclusisi in delusioni, sconfitte, o in strategici ripiegamenti -- di
*spostare* sostanzialmente il senso del lavoro dell'architetto, a volte
anche a costo di scontri o di rinunce: si pensi ad esempio
all'impostazione della didattica del Bauhaus di Dessau da parte di
Hannes Meyer, tutta improntata a una "scientificizzazione spinta dei
processi architettonici"[^41]; o ai progetti radicali -- architettonici
e urbani -- di Ludwig Hilberseimer, rigorosi al punto da superare ogni
ipotesi funzionalista o formalista, e rivolgersi piuttosto a un soggetto
post-umanista[^42]; o al ripensamento profondo della stessa idea di
progetto -- e conseguentemente di oggetto -- architettonico da parte di
Cedric Price[^43]; o ancora, alla monumentale opera "minimale" compiuta
da Aldo van Eyck con la realizzazione di oltre settecento *playgrounds*
nell'ambito dell'intervento per la municipalità di Amsterdam[^44]. In
seguito, invece, una stessa "sorte" epocale sembra aver coinvolto molti
architetti, più ancora che a compiere una consapevole o prudente
ritirata verso posizioni più riparate, ad "accomodarsi" semplicemente
nei ruoli loro offerti da un intendimento sociale. Al punto che oggi
una delle loro funzioni preminenti, per dirla ancora una volta con le
parole di Benjamin, "è quella di rinnovare il mondo dall'interno -- in
altre parole: secondo la moda --, lasciandolo cosí com'è".

Ma se, come si è visto, la trasformazione dell'architettura in merce ha
quale suo necessario corollario la trasformazione dell'architetto in
"rifornitore" (*rifornitore di merci*), vi è però un'ulteriore ed
estrema trasformazione che questi subisce nel corso di tale processo, e
in diretta conseguenza di esso: la trasformazione dell'architetto stesso
in merce. Ciò può essere inteso in due accezioni diverse,
corrispondenti a due "profili" di architetti ritenuti -- nella gran
parte dei casi, a torto -- altrettanto diversi tra loro. La prima
accezione è quella che tende a identificare l'architetto contemporaneo
con un moderno demiurgo, dotato di spiccate doti autoriali e di una
forte riconoscibilità stilistica. Questa figura si confonde con il mito
dell'architetto-*archistar*. In qualità di merce -- e merce di "lusso"
-- l'architetto-*archistar* ha fama di essere molto prezioso, e perciò
anche altrettanto desiderato e "corteggiato"; inoltre, lo si ritiene
capace di disporre pienamente dei propri strumenti, delle proprie
tecniche, dei propri linguaggi, e ancora di più, di disporre di sé nel
senso più generale, di autodeterminarsi, ma al tempo stesso pure di
essere libero d'imporre le proprie scelte. Per tutte queste ragioni,
*in quanto merce*, l'architetto-*archistar* induce l'idea di non essere
"soggetto" al mercato, bensì piuttosto di occuparvi una posizione
privilegiata, se non addirittura di dominarlo. Questa prima accezione
-- che è la più largamente diffusa -- è al tempo stesso anche la più
facilmente falsificabile.

La seconda accezione è legata a una situazione come quella attuale, in
cui una grandissima sovrabbondanza di architetti disponibili sul mercato
fa aumentare a dismisura la concorrenza tra loro, costringendo molti ad
accettare condizioni di pesante deprezzamento del proprio lavoro.
L'architetto in questo modo finisce per vendere se stesso come una merce
svalutata. È il caso di moltissimi giovani architetti che lavorano
gratis, o sottopagati, senza contratto, senza orari, senza riposi
settimanali, senza ferie pagate, senza pensione. Di questi
architetti-lavoratori sfruttati e delle condizioni di produzione del
progetto negli studi contemporanei bisognerà tornare a parlare più
oltre. In questo caso come nell'altro, comunque, al di là delle
differenze più o meno apparenti, la mercificazione investe direttamente
l'architetto, il quale in tal modo -- oltre che delle proprie "merci" --
rifornisce il mercato anche di se stesso.

[^1]: Per le nozioni di valore d'uso, valore d'uso sociale, valore di
  scambio, il riferimento è ovviamente Karl Marx, *Il Capitale*,
  Editori Riuniti, Roma 1980, vol. I, pp. 67 e sgg.

[^2]: Per un'utile (per quanto episodica) lettura in tal senso vedi
  *Architecture and Capitalism. 1845 to the Present*, a cura di Peggy
  Deamer, Routledge, New York 2014.

[^3]: Sul tema vedi, tra gli altri, le interessanti raccolte *Housing in
  Europa 1. 1900-1960* e *Housing in Europa 2. 1960-1979*, Luigi
  Parma, Bologna 1978 e 1979; Roger Sherwood, *Modern Housing
  Prototypes*, Harvard University Press, Cambridge (Mass.) 1978; e
  inoltre *Las formas de la residencia en la ciudad moderna*, a cura
  di Carlos Martí Arís, Edicions UPC, Barcelona 2000.

[^4]: Vedi *Die Frankfurter Küche von Margarete Schütte-Lihotzky*, a
  cura di Peter Neover, Ernst & Sohn, Berlin 1991.

[^5]: Ernst May, *Cinque anni di attività di edilizia residenziale a
  Francoforte sul Meno*, in "Das neue Frankfurt", n. 2-3, 1930, ora in
  G. Grassi (a cura di), *Das neue Frankfurt 1926-1931*, Edizioni
  Dedalo, Bari 1975, p. 208.

[^6]: Giorgio Grassi, *Das neue Frankfurt e l'architettura della nuova
  Francoforte*, in Grassi (a cura di), *Das neue Frankfurt 1926-1931*
  cit., p. 9.

[^7]: Tafuri, *Progetto e utopia* cit., p. 107; Manfredo Tafuri e
  Francesco Dal Co, *Architettura contemporanea*, Electa, Milano 1976,
  p. 153.

[^8]: Francesco Dal Co, *Architetti e città -- Unione Sovietica
  1917-1934*, in *Socialismo, città, architettura -- URSS 1917-1937.
  Il contributo degli architetti europei*, testi di Alberto Asor Rosa,
  Bruno Cassetti, Giorgio Ciucci, Francesco Dal Co, Marco De Michelis,
  Rita Di Leo, Kurt Junghanns, Gerritt Oorthuys, Vítězslav Procházka,
  Hans Schmidt, Manfredo Tafuri, Officina Edizioni, Roma 1971, p. 106.

[^9]: Le Corbusier, *Verso una architettura* (1923), Longanesi, Milano
  1973, p. 243.

[^10]: Pier Vittorio Aureli, *Means to an End. The Rise and Fall of the
  Architec­tural Project of the City*, in Id. (a cura di), *The City
  as a Project*, Ruby Press, Berlin 2013, p. 37.

[^11]: Le Corbusier, *Verso una architettura* cit., pp. 241-43.

[^12]: Walter Benjamin, *Parigi capitale del* *XIX* *secolo*, Einaudi,
  Torino 1986, p. 533.

[^13]: Vedi Walter Benjamin, *Esperienza e povertà* (1933), in Id.,
  *Esperienza e povertà*, a cura di Massimo Palma, Castelvecchi, Roma
  2018, p. 55.

[^14]: Benjamin, *Parigi capitale del* *XIX* *secolo* cit.

[^15]: Le Corbusier, *Verso una architettura* cit., p. 187.

[^16]: Guy Debord, *La società dello spettacolo* (1967), Sugarco, Milano
  1990, p. 85.

[^17]: *Ibid.*, p. 97.

[^18]: Debord, *La società dello spettacolo* cit., p. 108.

[^19]: Matteo Pasquinelli, *Oltre le rovine della Città Creativa: la
  fabbrica della cultura e il sabotaggio della rendita*, in Marco
  Baravalle (a cura di), *L'arte della sovversione*, Manifestolibri,
  Roma 2009, p. 152. L'affermazione originale di Debord recita "Lo
  spettacolo è il capitale ad un tal grado di accumulazione da
  divenire immagine".

[^20]: Benjamin, *Parigi capitale del* *XIX* *secolo* cit., p. 15.

[^21]: Alois Riegl, *Il culto moderno dei monumenti. Il suo carattere e
  i suoi inizi* (1903), a cura di Sandro Scarrocchia, Abscondita,
  Milano 2017, p. 55.

[^22]: Vedi, tra i molti altri, Ludwig Hilberseimer, *Internationale
  Neue Baukunst*, Julius Hoffmann, Stuttgart 1927; Bruno Taut, *Die
  neue Baukunst in Europa und Amerika*, Julius Hoffmann, Stuttgart
  1929; Adolf Behne, *Neues Wohnen, neues Bauen*, Hesse & Becker,
  Leipzig 1930; Jacobus Johannes Pieter Oud, *Nieuwe bouwkunst in
  Holland en Europa*, De Driehoek, 's-Graveland 1935.

[^23]: Manfredo Tafuri, *Lavoro intellettuale e sviluppo capitalistico*,
  in "Contropiano", n. 2, 1970, p. 268.

[^24]: Charles Jencks, *The Iconic Building. The Power of Enigma*,
  Rizzoli, New York 2005.

[^25]: Pier Vittorio Aureli, *The Possibility of an Absolute
  Architecture*, MIT Press, Cambridge (Mass.) 2011, p. XII.

[^26]: Francesco Dal Co, *The Guggenheim. Frank Lloyd Wright's
  Iconoclastic Masterpiece*, Yale University Press, New Haven 2017.

[^27]: Françoise Fromonot, *Jørn Utzon architetto della Sydney Opera
  House*, Electa, Milano 1998.

[^28]: Francesco Dal Co, *Centre Pompidou. Renzo Piano, Richard Rogers,
  and the Making of a Modern Monument*, Yale University Press, New
  Haven 2016.

[^29]: Jean Baudrillard, *L'effetto Beaubourg. Implosione e
  dissuasione*, in Id., *Simulacri e impostura. Bestie, Beaubourg,
  apparenze e altri oggetti*, a cura di Matteo G. Brega, Pgreco,
  Milano 2008, pp. 27-44, e in particolare p. 31.

[^30]: Baudrillard, *L'effetto Beaubourg* cit., pp. 35 e 38.

[^31]: Coosje Van Bruggen, *Frank O. Gehry. Guggenheim Museum Bilbao*,
  Guggenheim Museum Publ., New York 1999; John Rajchman, *Effetto
  Bilbao*, in "Casabella", n. 673-74, 1999-2000, pp. 10-11.

[^32]: Vedi ad esempio Davide Ponzini e Michele Nastasi,
  *Starchitecture. Scene, attori e spettacoli nelle città
  contemporanee*, Allemandi, Torino 2011.

[^33]: Aureli, *The Possibility of an Absolute Architecture* cit., p.
  XII.

[^34]: Sul tema della festa barocca vedi, tra gli altri, Marcello
  Fagiolo, *La festa barocca*, De Luca, Roma 1997, nonché Id. (a cura
  di), *Le capitali della festa. Italia settentrionale e Italia
  centrale e meridionale*, 2 voll., De Luca, Roma 2007-2008.

[^35]: Vedi http://www.oma.eu/projects/2006/dubai-renaissance/.

[^36]: Josep Lluís Mateo e altri (a cura di), *Iconoclastia. News from
  a Post-Iconic World. Architectural Papers IV*, ETH --
  Eidgenössische Technische Hochschule -- Ed. Actar, Zürich --
  Barcelona 2009.

[^37]: Walter Benjamin, *L'autore come produttore* (1934), in Id.,
  *Avanguardia e rivoluzione. Saggi sulla letteratura*, Einaudi,
  Torino 1973, pp. 199-217 (ora in *Opere complete*, VI. *Scritti
  1934-1937*, ivi 2004). Si tratta del medesimo saggio citato da
  Manfredo Tafuri in *La sfera e il labirinto. Avanguardie e
  architettura da Piranesi agli anni '70*, Einaudi, Torino 1980,
  p. 352, a proposito delle ricerche architettoniche degli anni
  sessanta e settanta. Sulle sue considerazioni al proposito si dovrà
  tornare più oltre.

[^38]: Benjamin, *L'autore come produttore* cit., p. 207.

[^39]: *Ibid.*, p. 209.

[^40]: *Ibid.*, p. 208.

[^41]: Francesco Dal Co, *Hannes Meyer e la venerabile scuola di
  Dessau*, in Hannes Meyer, *Scritti 1921-1942. Architettura o
  rivoluzione*, a cura di F. Dal Co, Marsilio, Padova 1969, p. 38.

[^42]: K. Michael Hays, *Modernism and the Posthumanist Subject. The
  Architecture of Hannes Meyer and Ludwig Hilberseimer*, The MIT
  Press, Cambridge (Mass.) 1992.

[^43]: Stanley Mathews, *From Agit-Prop to Free Space: The Architecture
  of Cedric Price*, Black Dog Publishing, London 2007.

[^44]: Liane Lefaivre e Ingeborg de Roode (a cura di), *Aldo van Eyck.
  Playgrounds*, NAi Publishers, Rotterdam 2002.

# Il ruolo dell'architetto intellettuale

L'esordio della storia dell'architettura moderna viene fatto coincidere,
secondo il parere di molti studiosi, con la concezione della cupola di
Santa Maria del Fiore da parte di Filippo Brunelleschi[^1]. La nota
vicenda legata al completamento del Duomo di Firenze, risolvibile
tradizionalmente facendo ricorso all'impiego di armature (centine) di
legno, nella circostanza non applicabili a causa delle grandi dimensioni
dello spazio da voltare, diviene l'occasione per Brunelleschi non
soltanto per applicare il proprio sapere costruttivo, frutto dello
studio diretto dell'antico, ma anche per affermare e difendere, "per la
prima volta, (...) la "professionalità" dell'architetto contro il vago
"magistero" dell'artefice, la priorità dell'invenzione tecnica sulla
perizia del mestiere"[^2]. Non si tratta soltanto di una
"rivendicazione di categoria": nella distinzione tra il momento del
progetto e quello dell'esecuzione è in gioco anche la distinzione tra
un'attività "liberale" e un'attività "meccanica", e dunque l'assunzione
da parte dell'individuo colto del compito di organizzare e guidare la
società. È la nascita dell'intellettuale come soggetto attivo, oltreché
come figura speculativa.

Significativamente, Antonio Manetti, il primo biografo di Brunelleschi,
ne mette in rilievo sopra ogni altra cosa il grande e meraviglioso
"intelletto"[^3]. Un intelletto che non agisce certo nell'isolamento e
che necessita degli altri per poter compiere la propria "azione"[^4], ma
che al tempo medesimo pone se stesso e il proprio operare su un piano
completamente diverso rispetto a quello occupato dai suoi interlocutori.
Non a caso, tutte le sue biografie non mancano di riportare -- sia pure
in versioni differenti -- un episodio emblematico: nel 1430, in seguito
alle proteste dei "maestri di cazzuola" per le fatiche e i pericoli del
lavoro sulla cupola, egli decide di licenziarli e di sostituirli con
maestranze lombarde, salvo in seguito riassumerli tutti (tranne uno) a
un salario più basso[^5]. Si tratta della dimostrazione più evidente
del fatto che la supremazia dell'uomo d'intelletto si esercita in
termini di potere di comando e di controllo, ma assume anche
connotazioni che ne distinguono non tanto la mansione o il ruolo quanto
piuttosto l'appartenenza a una *classe*. Ciò che l'episodio fa emergere
impetuosamente -- cosí come l'intero intervento di Brunelleschi a Santa
Maria del Fiore -- è cioè "il tema della moderna divisione sociale del
lavoro"[^6].

La coincidenza del sorgere della figura dell'architetto come
intellettuale e del manifestarsi di rapporti di classe prefiguranti
quelli che si instaureranno con la rivoluzione industriale tra la
borghesia e il proletariato non è evidentemente casuale. Come rileva
ancora Tafuri, "l'intellettuale-architetto (...) rivendicando
l'autonomia del proprio ruolo, (...) si pone all'avanguardia delle nuove
classi al potere". E aggiunge: "tanto da poter persino entrare in
conflitto con esse là dove queste non siano disposte ad essere
conseguenti fino in fondo con le proprie premesse".

L'episodio a cui allude Tafuri è probabilmente quello riferito da
Vasari, secondo il quale, avendo ricevuto da Cosimo de' Medici
l'incarico di progettare un palazzo in piazza San Lorenzo, a Firenze,
Brunelleschi ne "fece un bellissimo e gran modello"; ma poi, "parendo a
Cosimo troppo sontuosa e gran fabbrica, più per fuggire l'invidia che la
spesa, lasciò di metterla in opera"; al che Brunelleschi, "intendendo la
resoluzione di Cosimo, che non voleva tal cosa mettere in opera, con
sdegno in mille pezzi il disegno ruppe"[^7].

Non sono tuttavia numerosi i casi in cui l'architetto si ribellerà -- o
addirittura, si opporrà concretamente -- al potere e ai potenti, nei
secoli successivi. E semmai un indizio della sempre maggiore
assimilazione degli architetti al sistema di potere di volta in volta
vigente si lascia rintracciare nel loro parallelo cercare rifugio in
un'attività che tende sempre meno a identificarsi -- come accadeva
ancora nel caso di Brunelleschi -- con il solo progetto architettonico,
e che si apre via via ad altre espressioni e linguaggi: dal disegno come
tecnica (almeno potenzialmente) affrancata dalla realizzazione concreta,
alla scrittura come pratica finalizzata non esclusivamente a
verbalizzare le "regole" dell'architettura ma anche a produrre su di
essa "discorsi" di natura diversa, spesso scopertamente soggettivi: non
più trattati, insomma, quanto piuttosto "punti di vista", "opinioni"
sull'architettura. Ciò che ne deriva è una forma di indipendenza
dell'architetto non solo nei confronti della committenza ma anche nei
confronti della propria stessa attività; sviluppando la *teoria* come
una dimensione al tempo stesso organica e autonoma di questa,
l'architetto porta a compimento il processo di autoaffermazione di sé
come intellettuale.

In questo senso, Leon Battista Alberti incarna al suo massimo grado la
figura dell'intellettuale-umanista che estende *anche* all'architettura
il proprio ambito d'interessi, tanto scrivendone (nella forma canonica
del trattato)[^8], quanto progettandola (senza però interessarsi
attivamente alle fasi costruttive)[^9]. E infatti nella definizione che
egli dà dell'architetto si preoccupa prima di ogni altra cosa di
sgombrare il campo dai possibili equivoci circa il ruolo di questi come
artista-intellettuale, distinguendolo nettamente da quello di altre
figure che si occupano in modo diverso di costruzioni, come il *faber
tignarius*:

> ... non prenderò certo in considerazione un carpentiere, per
> paragonarlo ai più qualificati esponenti delle altre discipline: il
> lavoro del carpentiere infatti non è che strumentale rispetto a quello
> dell'architetto[^10].

E invece

> ... architetto chiamerò colui che con metodo sicuro e perfetto sappia
> progettare razionalmente e realizzare praticamente, attraverso lo
> spostamento dei pesi e mediante la riunione e la congiunzione dei
> corpi, opere che nel modo migliore si adattino ai più importanti
> bisogni dell'uomo.

Dove anche il "realizzare praticamente" va inteso piuttosto come
capacità di compiere *reali* verifiche delle ipotesi progettuali
formulate che non come un diretto intervento dell'architetto nelle fasi
costruttive dell'edificio.

Pur non essendo possibile seguire analiticamente le avventure
dell'architetto intellettuale dal Rinascimento in avanti (in larga parte
coincidenti, del resto -- almeno fino a tempi abbastanza recenti --, con
la storia dell'architettura *tout court*), non si può mancare almeno di
ricordare il ruolo occupato all'interno di esse da Andrea Palladio: non
soltanto in qualità di progettista di un'imprescindibile "rete" di
edifici in terra veneta, ma soprattutto in quanto autore dei *Quattro
Libri dell'Architettura* (1570). Sono proprio questi ultimi a
costituire il perfetto paradigma -- a ben guardare mai eguagliato da
alcuno né prima né dopo di lui -- del tradursi *in atto* di
un'intellettualità architettonica. Fuggendo "la lunghezza delle
parole", limitandosi dunque a "quelle avvertenze, che mi parranno più
necessarie"[^11], e affiancandovi "alcuni disegni" di cui fornisce le
"misure, da' quali potrà ciascuno facilmente, secondo che se gli
offerirà l'occasione, esercitando l'acutezza del suo ingegno, pigliar
partito e far opera degna di esser lodata"[^12], Palladio consegue la
più compiuta sintesi tra testi e immagini raggiunta in un trattato: dove
i disegni "dicono" ciò a cui le parole alludono soltanto. La
sorprendente "perspicuità" dell'*opus* palladiano, se costituisce
l'irrefutabile presupposto della sua fortuna planetaria[^13], è anche lo
specchio ingannevole con il quale abbagliare coloro che non sono "in
tale arte istruiti". Ciò rende *I Quattro Libri*, al tempo stesso, "per
tutti e per nessuno", o perlomeno per quel numero ristretto
d'"intendenti" che sappia comprenderne e applicarne il codice sotteso.
Ed è straordinariamente significativo che sia proprio lo strumento del
disegno -- nella semplice forma della proiezione ortogonale in pianta,
sezione e alzato -- a rendere pienamente effettuale l'operazione
intellettuale compiuta dall'architetto. Con una notazione ulteriore:
pur raccogliendo opere esemplari realizzate da autori antichi e
"moderni" (tra questi ultimi, soltanto Donato Bramante, oltre a se
stesso), il trattato di Palladio richiede di essere letto come una
teoria generale della progettazione basata sul sistema degli ordini e
delle proporzioni; una teoria capace di approssimarsi tanto all'"idea"
da distanziarsi persino dalla realtà[^14].

Sarà Giovanni Battista Piranesi -- trecento anni più tardi -- a mostrare
invece come l'architetto possa ormai concepire se stesso in modo quasi
del tutto svincolato dalla produzione progettuale, senza con questo
cessare di considerarsi architetto a tutti gli effetti. Piranesi fa del
disegno qualcosa di più di un mezzo di prefigurazione o di
rappresentazione della realtà: e infatti, nelle *Antichità Romane*
(1756), come nelle *Vedute di Roma* (1778), esso ha il compito di
dissezionare e di catalogare in ogni sua parte il "corpo" della città,
al fine di farne non tanto un semplice rilievo, quanto piuttosto un
approfondito studio analitico-critico[^15]; nel caso delle *Carceri
d'invenzione* (1761) e del *Campo Marzio dell'Antica Roma* (1762),
invece, il disegno rimane volutamente incerto tra memoria archeologica e
progetto del nuovo, escludendo comunque dal proprio orizzonte qualsiasi
eventualità di realizzazione. In entrambi i casi, oltrepassa il valore
di strumento meramente tecnico, per divenire un vero e proprio
dispositivo che permette a Piranesi di definire senza condizionamenti il
proprio campo d'azione. Un'assenza di condizionamenti che si può
misurare innanzitutto sul piano intellettuale. Non per nulla, il testo
teorico più importante di Piranesi, il *Parere sull'Architettura*
(1765), è organizzato in forma *dialogica*, vale a dire la modalità
espressiva più lontana dalla prescrittività della trattatistica. Nella
composizione dialettica delle opinioni sostenute da Protopiro e
Didascalo è sintetizzabile il "parere" piranesiano, sostenitore del
"libero gioco della creatività, che si esprime nella sede "privilegiata"
dell'ornamento", ma anche della necessità di dotare quest'ultimo dei
"criteri compositivi" ispirati "ai metodi con i quali la natura crea e
dispone i propri fenomeni"[^16].

La libertà creativa individuale, sia pur temperata dal riferimento al
piano "oggettivo" e condivisibile della natura, è dunque la
manifestazione della presa di coscienza del ruolo ormai compiutamente
*intellettuale* dell'architetto. Ma è anche la chiara manifestazione di
una crisi. Mentre si emancipa progressivamente dalla "fisica" del
potere (soltanto più tardi scoprirà di essere inesorabilmente immerso
nella sua "microfisica")[^17], l'architetto intellettuale si trova
sempre di più al cospetto di una frantumazione che riguarda la
disciplina di cui si occupa non meno che il proprio io. Ancora una
volta, Piranesi è il precoce annunciatore di entrambi i fenomeni. Ma
più in generale, il fiorire -- tra XVII e XIX secolo -- di
polemiche[^18], pamphlet e saggi[^19] di ogni genere relativi
all'architettura è indice dell'affermarsi di certezze proclamate con
tanto più vigore e animosità quanto più si rivelano il frutto di una
costitutiva arbitrarietà e soggettività. Tramontata l'epoca in cui
poteva esercitare le sue funzioni ricorrendo *sola mente* ai lucidi
schemi desunti dagli *aeterna exempla* del classico, ora l'architetto è
costretto a ripiegarsi su se stesso per trovare frammenti di "verità"
individuali, ma sempre più spesso per nascondere la propria
inadeguatezza e per coprire i propri dubbi. La "personalità"
dell'architetto, in certi casi, inizia ad assumere maggiore importanza
della sua stessa opera.

L'affermarsi di una dimensione teorica ormai non più correlata con una
stretta normatività comporta la necessità di connotare fortemente
ciascuna teoria, al fine di differenziare l'una dall'altra, in un gioco
di prese di posizione e di distanza che in molti casi ha l'effetto di
radicalizzarle. Si ripensi all'*incipit* di *Architecture. Essai sur
l'art* di Étienne-Louis Boullée: "Che cos'è l'architettura? La definirò
forse con Vitruvio l'arte del costruire? No"[^20]. La "sacralità"
degli antichi -- e di Vitruvio quale massima autorità in materia
architettonica -- viene deliberatamente infranta. Per Boullée
l'architettura ha piuttosto a che fare con la "poesia", ovvero con il
"carattere" che ciascun tipo di costruzione deve esprimere, sulla base
di un preciso rapporto *analogico* tra forma e contenuto degli edifici:
"Le immagini che essi offrono ai nostri sensi dovrebbero suscitare in
noi sentimenti corrispondenti all'uso al quale essi sono
consacrati"[^21].

La radicalizzazione della teoria si manifesta però al suo massimo grado
nell'opera di un allievo di Boullée, Jean-Nicolas-Louis Durand. Nei due
libri del *Précis des leçons données à l'École Polytechnique*
(1802-809), la *raison* è ormai diventata un'*ideé fixe*, una vera e
propria ossessione; ed è nelle tavole che l'accompagnano (in particolar
modo della seconda parte), più ancora che nel testo, che essa trova la
sua più piena espressione: planimetrie e alzati le cui combinazioni e
permutazioni rigorosamente geometriche lasciano pochi dubbi in merito
alla "natura" della teoria sostenuta. Il cui autore, con altrettanta
chiarezza, risulta tramutato in un suo "sostenitore"[^22].

Ma è proprio a fronte dell'esasperazione delle posizioni e
dell'inoperatività che spesso vi si associa -- e al conseguente rischio
di isolamento nel quale con sempre maggiore frequenza incorre
l'architetto intellettuale -- che questi tende ad "aprire" la propria
visione a una dimensione più allargata, collettiva, caratterizzata non
di rado in senso spiccatamente utopico. A partire da *L'architecture
considérée sous le rapport de l'art, des moeurs et de la législation*
(1804) di Claude-Nicolas Ledoux, l'architetto si propone come
"pensatore" -- o "ripensatore" -- della città e della società.
Affiancandosi, o sostituendosi addirittura, alle tradizionali figure di
riferimento (il filosofo, il politico, l'industriale, il pedagogo, il
filantropo)[^23], l'architetto si appropria del mito riformista, sia
pure proiettato in un mondo soltanto immaginato, in senso grafico o
letterario. Gli esiti di questo passaggio si lasceranno rintracciare
ancora nella *Cité industrielle* (1917) di Tony Garnier[^24] e nella
*Ville contemporaine de trois millions d'habitants* (1922) di Le
Corbusier[^25].

Proprio Le Corbusier può essere considerato l'architetto intellettuale
più significativo e influente del XX secolo. Il suo apporto, in questo
senso, non è valutabile esclusivamente in termini produttivi, cosí come
non lo è neppure in chiave meramente progettuale, o almeno non
nell'accezione usuale del termine, come fase preparatoria "in vista"
della sua realizzazione concreta. Dalla Maison Dom-Ino alla Ville
Radieuse e oltre, Le Corbusier elabora un discorso articolato in varie
"puntate" ma unitario, le cui singole parti scaturiscono da un'*idea di
spazio* e da un'*idea di costruzione e struttura* ben precise, declinate
su scale diverse, fino a giungere a formulare una visione "totale",
completamente alternativa al mondo reale; una visione che affida
all'architettura il compito di ripensare radicalmente la società.

Anche sotto il profilo pubblicistico, non soltanto Le Corbusier si
rivela probabilmente il più prolifico scrittore di architettura del
secolo[^26], ma pure quello più di ogni altro capace di funzionalizzare
tale attività al ruolo autoassegnatosi di architetto intellettuale: che
non consiste né nell'assolvere a compiti puramente tecnici, di semplice
illustrazione e diffusione dei progetti, né nell'affermare valori
esclusivamente ideologici o letterari, l'intenzione del raggiungimento
dei quali potrebbe anche prescindere dallo svolgimento di un'attività
progettuale. Adottando via via la forma del manifesto, del pamphlet,
dello scritto polemico, i libri di Le Corbusier si presentano come vere
e proprie "crociate"[^27] combattute con le armi della critica, della
provocazione e dell'ironia; il tutto finalizzato a fornire ogni supporto
possibile a una concezione dell'architettura che -- come poc'anzi
rilevato -- è tanto ideale quanto concreta, ovvero traducibile in
termini spaziali e in termini costruttivo-strutturali: perfetta sintesi
del compito che per tutta la vita Le Corbusier ostinatamente persegue.

È nell'Italia del secondo dopoguerra, tuttavia, che la figura
dell'architetto intellettuale assume una forte connotazione sociale, e
in certi casi pure politica, con il conseguente riconoscimento del suo
ruolo anche al di fuori dell'ambito strettamente disciplinare.
Emblematico, in questo senso, è il caso di Bruno Zevi: laureatosi nel
1942 alla Graduate School of Design di Harvard diretta da Walter
Gropius, negli anni successivi Zevi torna in Italia dove lavora come
architetto, ma soprattutto si fa propagatore della "buona novella"
dell'architettura organica di Frank Lloyd Wright[^28]. Non meno
importante è la posizione da lui assunta all'interno di svariate
istituzioni, tra le quali l'Istituto Nazionale di Urbanistica (INU), di
cui riveste la carica di segretario generale dal 1952 al 1968, e
l'IN/ARCH (Istituto Nazionale di Architettura), da lui stesso fondato
nel 1959. Un impegno civile che verrà profuso anche all'interno di
movimenti e partiti politici, a partire dalla militanza in Giustizia e
Libertà, negli anni della guerra e della Resistenza, per passare poi al
Partito d'Azione, a Unità Popolare, al Partito socialista unificato e
infine al Partito radicale, per il quale nel 1987 sarà eletto deputato
al parlamento e del quale diverrà presidente tra la fine degli anni
ottanta e i primi novanta[^29].

Ma è l'implicazione nel campo della produzione culturale direttamente
legata all'architettura ciò che caratterizza in modo particolare
l'azione di Zevi. Il forte coinvolgimento in qualità di redattore
dapprima e poi di condirettore nella rivista "Metron", tra il 1946 e il
1954, e la fondazione nel 1955 e la direzione fino al 2000 di
"L'architettura. Cronache e storia", insieme a una produzione libraria
qualitativamente e quantitativamente ragguardevole -- in cui spiccano,
tra i molti altri, titoli fondamentali quali *Saper vedere
l'architettura*, *Storia dell'architettura moderna*, *Poetica
dell'architettura neoplastica*, *Il linguaggio moderno
dell'architettura*[^30] -- sono i segni tangibili di un coinvolgimento
che va evidentemente oltre il consueto piano di lavoro dello studioso e
dello storico. È proprio *Verso un'architettura organica*, del resto,
che dà avvio a quello che a tutti gli effetti -- anche al di là del più
immediato riferimento wrightiano -- è un tentativo di portare un
contributo fattivo, da architetto e da intellettuale, alla ricostruzione
italiana. In quest'ottica va letta la *Prefazione*, datata febbraio
1944, in cui sottolinea che

> ... forse sarebbe stato più esatto intitolare questo libretto "verso
> un'edilizia organica", stabilendo cosí dall'inizio che, invece di fare
> una storia dell'arte, ci si accingeva al compito più modesto di
> trovare un indirizzo comune nel lavoro contemporaneo[^31].

Un concetto su cui ritorna più oltre con chiarezza ancora maggiore:

> Alla fine del conflitto mondiale, l'Italia avrà bisogno di pane e di
> case. Nelle sue terre distrutte, contadini, operai, intellettuali
> domanderanno case. L'opera degli architetti dovrà rispondere alle
> esigenze materiali e psicologiche dell'edilizia di un paese finalmente
> libero[^32].

Un'edilizia organica, nell'auspicio di Zevi: vale a dire che "ha alla
sua base un'idea sociale, non un'idea figurativa; (...) che vuole
essere, prima che umanistica, umana"[^33].

Nella medesima prospettiva va inscritto anche il suo coinvolgimento
nella realizzazione del *Manuale dell'architetto*[^34]: una complessa
operazione, a cui partecipano, tra gli altri, Gustavo Colonnetti, Mario
Ridolfi, Pier Luigi Nervi e Mario Fiorentino, che ha come scopo
l'"alfabetizzazione" degli architetti italiani in vista della
ricostruzione. Ed è appunto questa finalità *operativa* che
contraddistingue la totalità degli interventi di Zevi: dalla scrittura
all'insegnamento, dalla pratica professionale alla difesa del
territorio, nulla è concepito come impegno puramente "accademico";
piuttosto, come altrettante "cause" per le quali battersi con veemente
passione. Una finalità che non manca di toccare anche la storia, da lui
utilizzata per affermare le proprie convinzioni -- in campo progettuale
come in campo politico-ideologico --, oltreché per fini conoscitivi.

Tafuri, definendo tale attitudine storico-critica "operativa" come

> ... un'analisi dell'architettura (o delle arti in generale), che abbia
> come suo obiettivo non un astratto rilevamento, bensì la
> "progettazione" di un preciso indirizzo poetico, anticipato nelle sue
> strutture, e fatto scaturire da analisi storiche programmaticamente
> finalizzate e deformate[^35],

ha voluto criticarne gli intendimenti strumentali, non sufficientemente
distaccati a suo avviso dal raggiungimento di presunti propositi
esterni. Al "punto di incontro fra la storia e la progettazione, --
come scrive ancora Tafuri, -- la critica operativa *progetta* la storia
passata proiettandola verso il futuro". Tra coloro che egli vede come
"i più validi assertori, in Europa, di un rilancio ideologico rivolto a
colmare il salto fra impegno civile e azione culturale"[^36], nel
secondo dopoguerra, Tafuri cita tre soli nomi: Jean-Paul Sartre, Elio
Vittorini e -- appunto -- Bruno Zevi. E se quelli dei primi due, dal
punto di vista tafuriano, sembrano parlare legittimamente di un ruolo di
*engagement* intellettuale che mescola fino a fonderle del tutto
letteratura e politica, giungendo a un'"identificazione tra pensiero e
azione", il nome di Zevi -- in quella stessa ottica -- pare stare a
testimoniare piuttosto una "forzatura" di tale identificazione. Vi è
insomma un intento apertamente polemico nei confronti di Zevi *in
quanto* architetto intellettuale che si servirebbe della storia per
affermare il proprio credo progettuale. "La storia, -- scrive Tafuri, --
per sua natura, è un gioco di equilibrio, che la critica operativa forza
facendo precipitare la dimensione del presente"[^37]. In ciò dunque
consisterebbe ai suoi occhi l'"errore" di Zevi: nell'"*attualizzare* la
storia*"*, nel "renderla duttile strumento per l'azione*"*[^38].

Il più emblematico *casus* di attualizzazione storica zeviana (nonché
flagrante ragione di "rottura" tra i due) si verificherà in occasione
della Mostra critica delle opere michelangiolesche (Roma, Palazzo delle
Esposizioni, 1964). L'attualità di Michelangelo verrà "dimostrata" da
Zevi mediante letture volumetriche e spaziali che fanno dell'artista
rinascimentale a tutti gli effetti un "moderno"[^39]; e a ciò vanno
aggiunti i discussi "plastici critici" realizzati dagli studenti dello
IUAV di Venezia ed esposti in mostra. La censura nei confronti di
questi da parte di Tafuri non avviene però sulla base del presunto
"scandalo" che essi susciterebbero, bollato invece come "ingenuo";
piuttosto sulla base di una duplice incoerenza: da una lato la mancanza
di "sorveglianza" delle loro trasformazioni rispetto agli originali, e
dall'altro il tentativo (fallito) di "una dilettantesca traduzione del
linguaggio architettonico in astratti e astorici giochi scultorei"[^40].

La condanna tafuriana del modo di interpretare il ruolo dell'architetto
intellettuale da parte di Zevi non avrebbe in fondo particolare
rilevanza in questo contesto, se non fosse che lo stesso Tafuri
imprimerà una svolta decisiva alla propria carriera staccandosi --
intorno alla metà degli anni sessanta -- dallo studio AUA (Architetti
Urbanisti Associati)[^41], con cui aveva collaborato tanto da un punto
di vista teorico che progettuale, per dedicarsi interamente alla storia.
In realtà, già negli intendimenti del gruppo, composto da giovani
architetti romani (tra cui Giorgio Piccinato e Vieri Quilici), vi era
una presa di distanza dall'architettura come pratica professionale
separata dagli altri "piani d'azione" della realtà; e infatti in AUA,
nel nome e nei fatti, l'attività progettuale è affiancata da -- e
integrata con -- ricerche urbane[^42] e piani urbanistici.

> Il gruppo concepisce il proprio mestiere come una vera e propria
> militanza etica e politica. La professione architettonica, la critica
> e la storiografia, non sono intesi tanto come discipline tecniche,
> come mestieri o specialismi del mercato del lavoro, bensì come
> "impegno integrale", come componenti di un universo disciplinare che
> agisce allo stesso tempo politicamente e tecnicamente, contribuendo in
> maniera attiva alla trasformazione della città e della realtà. In tal
> senso, è comprensibile la vicinanza che il gruppo esprime nei
> confronti delle istanze riformatrici delle avanguardie degli anni
> venti, e come sembri evidente anche il riferimento alla figura
> dell'intellettuale organico nella celebre definizione di Antonio
> Gramsci[^43].

La storia praticata da Tafuri, però, sarà concepita in modo affatto
diverso rispetto a quella di Zevi: una storia caratterizzata dalla "più
totale indifferenza nei confronti dell'*azione positiva*"[^44] (ovvero
di quell'azione che cerchi di modellare l'architettura a propria
immagine, sulla base dell'autorità del passato), e impegnata piuttosto
in una "continua *contestazione del presente*"[^45], che si traduce in
una "minaccia (...) ai tranquillizzanti miti in cui si acquietano le
inquietudini e i dubbi degli architetti moderni"[^46]. Il compito
dell'intellettuale impegnato nel campo della storia dell'architettura,
in questo senso, diviene quello di "esasperare" la condizione di disagio
in cui versano l'architetto e l'architettura "di fronte alla dinamica
dello sviluppo capitalista"[^47], mostrando tutta la problematicità di
una situazione "assurda eppure reale".

> ... Ponendo di continuo in crisi gli obiettivi apparentemente
> avanzati su cui rischiano di acquietarsi la ricerca e il dibattito, il
> critico deve (...) -- con un rigore cui è obbligato dalle vicende
> storiche in cui opera -- (...) stimola\[re\] dubbi sempre più
> coscienti, dissensi sempre più costruttivi, disagi sempre più
> generalizzati.

L'attività storica diviene cosí per Tafuri ""critica delle ideologie
architettoniche", e, in quanto tale, attività "politica" -- anche se
mediatamente politica"[^48]; più che l'enunciazione di una vaga
intenzione, la formulazione di un vero e proprio "programma" che -- con
un anno di anticipo rispetto alla pubblicazione del saggio intitolato
precisamente *Per una critica dell'ideologia architettonica* -- ne
preannuncia a grandi linee i contenuti e, ancor di più, il disegno
strategico complessivo:

> La messa in luce di ciò che l'architettura è, *in quanto disciplina
> storicamente condizionata e istituzionalmente funzionale al
> "progresso" della borghesia precapitalistica prima, alle nuove
> prospettive della "Zivilisation" capitalistica poi*, va quindi
> riconosciuto come l'unico scopo rivestito di senso storico, da parte
> di chi intenda forzare il ruolo istituzionale assegnato agli
> intellettuali dall'Illuminismo in poi[^49].

Si tratta da un lato di un'opera di demistificazione, vale a dire del
disvelamento delle "incrostazioni" ideologiche che rivestono (spesso
arrivando a occultarla del tutto) la vicenda dell'architettura moderna,
a partire da Brunelleschi in avanti; e dall'altro del tentativo di
istituire rapporti positivi, costruttivi, con la funzione più
intrinsecamente politica della storia. Ciò che ne deriva non è soltanto
un "progetto" storico radicalmente diverso dalla "storia progettuale"
zeviana[^50], ma anche una figura di storico in grado di riappropriarsi
correttamente del proprio ruolo di intellettuale.

Ciò nondimeno, malgrado la presenza di almeno altre due personalità di
alto profilo intellettuale operanti nell'ambito degli studi
storico-architettonici -- Giulio Carlo Argan e Leonardo Benevolo[^51] --
non è prevalentemente dal punto di vista storico che l'architetto
intellettuale italiano giunge a occupare un posto di particolare rilievo
nel panorama architettonico degli anni cinquanta, sessanta e settanta. È
anzi proprio attraverso la pacifica e proficua convivenza e integrazione
di attività progettuale (architettonica o urbanistica) e attività
culturale (significativamente segnata, in molti casi, se non da una vera
e propria militanza, da una dichiarata *appartenenza* politica) che
alcuni dei principali protagonisti della scena italiana acquisiranno
autorevolezza a livello nazionale e internazionale, e conferiranno
all'Italia un singolare primato nella produzione di architetti
intellettuali.

Nel rilevare *"*la scissione tra architetti e intellettuali"[^52], a
partire dalla seconda metà del Novecento, con particolare riferimento
alla Francia, Jean-Louis Cohen ha nel contempo evidenziato l'esistenza
-- per converso -- di un intenso rapporto tra architetti e intellettuali
in Italia, ovvero "il fatto che gli architetti italiani siano degli
intellettuali"[^53]. Le ragioni individuate a supporto di questa
peculiare situazione sono molteplici:

> Se i rapporti tra intellettuali italiani e architetti sono cosí
> particolari, è senza dubbio prima di tutto perché gli architetti
> stessi, in linea con i pionieri dell'architettura razionale del
> periodo fascista, sono capaci di scrivere e di chiarire
> intellettualmente i loro punti di riferimento e il loro approccio
> progettuale[^54].

A ciò va aggiunta la specificità delle scuole di architettura italiane
in cui la gran parte di tali architetti sono inseriti, che reclutano i
propri insegnanti "sulla base della loro produzione culturale (articoli,
libri) tanto quanto su quella delle loro opere architettoniche"[^55].
Inoltre -- nota Cohen -- in assenza di un forte controllo statale delle
commesse pubbliche, come accade in Francia, il sistema politico e
amministrativo frammentato e spesso clientelare italiano favorisce lo
sviluppo di competenze da parte dell'architetto che esulano da quelle
puramente progettuali, ivi compresa una certa *"*aura culturale".
Infine in Italia, tra gli anni cinquanta e settanta, si riscontra una
vera e propria esplosione nel campo della produzione editoriale di
architettura, riguardante tanto i libri che le riviste[^56], cui si
aggiunge il contributo critico apportato da associazioni quali il
Movimento di Studi per l'Architettura (MSA), composto, tra gli altri, da
Franco Albini, Lodovico Belgiojoso, Piero Bottoni, Giancarlo De Carlo,
Ignazio Gardella, Marco Zanuso, o il Movimento Comunità di Adriano
Olivetti[^57], oltreché il citato APAO; senza dimenticare ambiti
culturali più ampi, qual è il Gruppo 63, con le riviste a esso correlate
come "Marcatré" e "Quindici"[^58]; o ancora, riviste apertamente
politiche come "Contropiano*",* diretta da Alberto Asor Rosa e Massimo
Cacciari (dopo l'abbandono di Antonio Negri all'indomani dell'uscita del
primo numero, a causa di insanabili dissidi sulla linea politica da
conferire alla rivista), espressione della corrente operaista nel
periodo a cavallo tra anni sessanta e settanta, cui collaborano, tra gli
altri, Manfredo Tafuri, Francesco Dal Co e Marco De Michelis. Tutto ciò
-- conclude Cohen -- rende la "qualità intellettuale del dibattito
italiano il frutto meno di un caso che di una necessità"[^59].

Dalla ricchezza complessiva di questo quadro si stagliano un ristretto
numero di individualità di grande rilevanza e influenza: Giuseppe
Samonà, Ludovico Quaroni, Ernesto Nathan Rogers, Vittorio Gregotti,
Carlo Aymonino, Aldo Rossi, per nominarne solo qualcuna. Significativo
è che per tutti costoro non soltanto la dimensione operativa si intrecci
costantemente con quella teorica, ma che per lo più la questione
architettonica sia affiancata dalla questione urbana. *L'urbanistica e
l'avvenire delle città*[^60], *La Torre di Babele*[^61], *Il problema
del costruire nelle preesistenze ambientali*[^62], *Il territorio
dell'architettura*[^63], *Origini e sviluppo della città moderna*[^64],
*L'architettura della città*[^65] sono soltanto una piccola
rappresentanza dei titoli di scritti che testimoniano l'interesse degli
architetti appena citati per la disciplina intesa in un senso che non è
mai restrittivamente localistico o settoriale, cosí come l'urbanistica
non vi è mai intesa come questione puramente tecnica o gestionale.
Persino nel caso di studi pubblicati in quegli anni, sotto la guida di
alcuni dei medesimi autori, dedicati all'analisi di luoghi o casi
specifici[^66], la circoscrizione e precisione del campo di ricerca non
vanno mai disgiunte dall'intenzione di dare a tali studi un carattere
emblematico e generalizzabile, in particolar modo da un punto di vista
metodologico.

Con tutto ciò, diversi rimangono gli approcci alla figura
dell'architetto *sub specie intellectualis*. Per Samonà è soprattutto
la direzione dell'Istituto Universitario di Architettura di Venezia
(IUAV) a divenire l'occasione per compiere una grande operazione
culturale, oltreché didattica: chiamando a raccolta, a partire dal
secondo dopoguerra, un corpo docente altamente qualificato --
comprendente personaggi del calibro di Franco Albini, Ignazio Gardella,
Saverio Muratori, Lodovico Belgiojoso, Giancarlo De Carlo, Luigi
Piccinato, Giovanni Astengo e Bruno Zevi, rinnovato poi nel corso degli
anni sessanta con l'immissione, tra gli altri, di Carlo Aymonino, Guido
Canella, Gino Valle, Gianugo Polesello, Luciano Semerani, Costantino
Dardi, Leonardo Benevolo, Manfredo Tafuri e Mario Manieri Elia -- egli
ha posto le fondamenta di quella che assumerà vasta notorietà
internazionale sotto il nome di "Scuola di Venezia"[^67].

Per Ludovico Quaroni i campi d'applicazione della particolare modalità
con cui egli declina il ruolo di architetto intellettuale sono
molteplici: quello di un impegno politico che incrocia, tra gli altri,
il Movimento Comunità di Adriano Olivetti, e che si connette
fattivamente ai numerosi piani urbanistici e ai progetti di quartieri
popolari da lui elaborati nel corso della sua carriera; quella di una
produzione saggistica che testimonia -- più che di una propensione
"teorica" nei confronti dell'architettura e della città -- di un'assidua
presenza nel dibattito vivo e attuale del suo tempo, spesso attuata per
mezzo di apparizioni su testate secondarie o comunque defilate rispetto
ai più consueti luoghi di elaborazione culturale[^68]; e infine quello
dell'insegnamento universitario (a Firenze, Napoli e Roma), vero e
proprio fronte di affermazione e verifica d'un atteggiamento dialettico
di cui beneficeranno intere generazioni di allievi (molti dei quali
destinati a loro volta a un illustre futuro)[^69], anziché luogo di
semplice esposizione di "certezze" disciplinari[^70].

Per Ernesto Nathan Rogers, invece, lo strumento principale della propria
azione culturale sono le riviste: dapprima "Domus", di cui diviene
direttore subito dopo la guerra, e poi "Casabella", da lui diretta dal
1953 al 1964. È in special modo nella redazione di
"Casabella-Continuità" (secondo la nuova denominazione da lui data alla
testata) e attraverso i suoi editoriali che Rogers svolge un'opera di
"educazione" all'architettura moderna, rivista alla luce del rapporto
con la città storica e intesa come paradigma non soltanto estetico ma
anche *etico* per la ricostruzione dell'Italia dopo il secondo conflitto
mondiale e il ventennio fascista. In questo senso vanno intesi i numeri
di "Casabella-Continuità" che inquadrano tematiche più generali, spesso
relative a problematiche urbane e territoriali, all'interno delle quali
i singoli progetti di architettura si inseriscono non come semplice
vetrina per la vanità dell'architetto di turno[^71]. Ma è soprattutto
grazie a Rogers che ha luogo il decisivo incontro tra la cultura
architettonica del periodo e la corrente più avanzata della filosofia
italiana, rappresentata in quel momento da Antonio Banfi e da Enzo Paci.
Con quest'ultimo in particolare il dialogo tra architettura e filosofia
si fa serrato, apportando tangibili conseguenze sull'uno e sull'altro
fronte[^72]. Dal punto di vista dell'architettura, Rogers coglie dalla
lezione di Paci elementi che gli consentono di mettere a fuoco più
compiutamente un pensiero che già aveva sviluppato in modo embrionale
fin dal primo editoriale di "Casabella-Continuità":

> Noi crediamo nel fecondo ciclo *uomo-architettura-uomo* e vogliamo
> rappresentarne il drammatico svolgimento: le crisi; le poche,
> indispensabili certezze e i molti dubbi, ancor più necessari; siccome
> pensiamo che essere vivi significhi, soprattutto, accettare la fatica
> del quotidiano rinnovamento, col rifiuto delle posizioni acquisite,
> nell'ansia fino all'angoscia, nel perpetuarsi dell'agone,
> nell'allargare il campo dell'umana "simpatia"[^73].

Dall'acquisizione di una maggior consapevolezza filosofica derivano le
evoluzioni di tale pensiero, come dimostra l'utilizzo di concetti come
"esperienza"[^74] o di coppie di termini come "continuità-crisi", o
"discontinuità-continuità" al di fuori di una dimensione puramente
esistenziale e intuitiva. Cosí è, ad esempio, nella valutazione del
contributo dato dall'architettura moderna, non riducibile per Rogers a
semplici "apparenze figurative", e da ricondurre invece alle

> ... espressioni di un metodo che ha tentato di stabilire nuove e più
> chiare relazioni tra i contenuti e le forme, entro la fenomenologia di
> un processo storico-pragmatico, sempre aperto, che, come esclude ogni
> apriorismo nella determinazione di quelle relazioni, cosí non può
> essere giudicato per schemi[^75].

Nella prospettiva filosofica di Paci, d'altronde, la crisi
dell'architettura moderna è

> ... da addebitare a una troppo rigida e dogmatica interpretazione del
> razionalismo del Movimento Moderno che, saldandosi all'istanza
> tecnicista del processo di industrializzazione edilizia in atto, ha
> finito per produrre il declassamento dell'architettura da Arte ad un
> "insieme coerente e strumentale di operazioni tecniche"[^76].

Ma va inscritta anche in un discorso molto più ampio che riguarda la
"storicità" della crisi e la sua necessità per "prospettare un nuovo
orizzonte"[^77] nel quale il passato possa rivivere in forma
trasformata.

Questa prospettiva induce Rogers a una profonda revisione del senso
dell'architettura. Logica e ragione (ovvero le categorie che l'avevano
innervata ancora negli anni tra le due guerre) non sono più sufficienti
per lui a definire -- ma soprattutto a *incarnare* nella maniera più
compiuta -- un'architettura che, pur senza rinunciare alla sua
"missione" di modernità, debba però farsi carico di tutte le
contraddizioni che lo stesso sviluppo moderno ha incontrato sul suo
cammino. Ciò rende niente affatto semplice, e anzi del tutto
*drammatico*, il compito dell'architetto: "Fra gli altri uomini,
l'architetto rappresenta questa personalità singolare cui è devoluto il
compito di tentare la sintesi tra gli opposti poli"[^78]. Si tratta di
quella che Rogers concepisce come una vera e propria "lotta tra utilità
e bellezza". "Dobbiamo sentire in ogni momento creativo il dramma
fondamentale dell'esistenza perché la vita pone continuamente in
contraddizione i bisogni pratici e le aspirazioni spirituali"[^79]; un
dramma che l'architetto deve affrontare *operativamente*, lasciando che
le contraddizioni convivano "traducendole" in opera. Ma anche:
"Dobbiamo aspirare all'universale dando valore alle energie latenti
nella contingenza"[^80]. Ciò comporta una diversa concezione della
temporalità e della spazialità (intesa anche in senso allargato, come
ambiente o contesto) del progetto, portatrici entrambe di "occasioni"
che l'architetto non deve mancare di cogliere[^81].

Frutto non secondario dell'intenso lavoro svolto da Rogers in vista
della costruzione di un agire progettuale "in relazione", sarà uno
stuolo di seguaci cresciuti all'interno della stessa redazione di
"Casabella-Continuità", la cui precipua caratteristica è la libertà
intellettuale e la capacità di esercitarla in modi che non ricalcano
però quasi per nulla quelli del "maestro". Cosí Vittorio Gregotti ha
ereditato da Rogers la vocazione per la conduzione di riviste ("Edilizia
moderna", "Casabella", "Rassegna") come forma di militanza che trova
espressione nella scelta delle tematiche da affrontare e delle opere da
presentare, oltreché -- in maniera ancora più diretta ed esplicita --
attraverso gli editoriali da lui pubblicati mensilmente. A tale
cospicuo lavoro svolto nell'ambito dei periodici (cosí come pure dei
quotidiani) Gregotti ha affiancato nel corso degli anni una altrettanto
considerevole produzione libraria che, con ritmo cadenzato, ha
accompagnato il trascorrere delle diverse stagioni
dell'architettura[^82]. Senza dimenticare il suo ruolo di direttore
della sezione Arti visive e Architettura della Biennale di Venezia del
1976, preludio alle successive Biennali Internazionali di Architettura.
Tutti questi fattori hanno determinato l'indiscussa centralità di
Gregotti all'interno del panorama architettonico italiano e
internazionale, una centralità ribadita anche sotto il profilo
progettuale e costruttivo[^83].

Nel caso di Carlo Aymonino e Aldo Rossi -- a loro volta membri della
redazione della "Casabella-Continuità" rogersiana -- il modello cui
entrambi si ispirano è l'intellettuale culturalmente e politicamente
impegnato che domina la scena nell'Italia degli anni cinquanta,
discendente a sua volta dalla concezione gramsciana dell'"intellettuale
organico" inteso come "costruttore", e non come semplice "oratore",
disponibile a confrontarsi con la realtà, a "mescolarsi attivamente alla
vita pratica"[^84]; un intellettuale che però, proprio nel dopoguerra,
conosce una profonda crisi d'identità e di coscienza che lo porta spesso
a entrare in rotta di collisione con la linea dettata dal Partito
comunista italiano, che pure in questo campo costituisce per molti di
loro un punto di riferimento imprescindibile.

Strettamente legate al Pci sono le riviste "Critica marxista", "Il
Contemporaneo", "Società", "Voce comunista", su cui scrivono -- in
particolar modo nel periodo giovanile -- Aymonino e Rossi[^85]. Ma è
soprattutto con la produzione di ricerche all'interno dell'università,
che non di rado troveranno la via della pubblicazione come semplici
dispense[^86], che Aymonino e Rossi (ma con loro anche altri giovani
architetti e professori come Costantino Dardi, Luciano Semerani, Gianugo
Polesello, Guido Canella, Giorgio Grassi) giungono a definire l'esatta
"funzione" dell'architetto intellettuale italiano degli anni sessanta e
settanta: quella di mettere a punto un apparato teorico utilizzabile in
vista di un agire pratico, al di fuori però di qualsiasi prospettiva
"personale", soggettiva, e in grado piuttosto -- stante la "natura
collettiva dell'architettura"[^87] -- di essere condivisa dal maggior
numero di persone possibile, e dunque socializzabile. A questo fine
sono indispensabili una metodologia rigorosa, una strumentazione chiara
e obiettivi altrettanto riconoscibili. Si legga ad esempio quanto
scrive Rossi a introduzione del volume che raccoglie i contributi al
dibattito svoltosi all'interno del gruppo di ricerca da lui diretto alla
Facoltà di architettura del Politecnico di Milano nell'anno accademico
1968-69:

> La nostra ricerca si propone principalmente la costruzione di una
> teoria razionale dell'architettura. Tale costruzione è principalmente
> fondata sullo studio dei rapporti esistenti tra l'analisi urbana e la
> progettazione architettonica[^88].

Un metodo, appunto, il più possibile oggettivo e condivisibile.

E tuttavia, dietro la "scientificità" dell'approccio alla ricerca emerge
la determinazione da parte del giovane Rossi a ridare *necessità* al
processo progettuale, prendendo le distanze dall'empirismo
"professionalistico" imperante nell'Italia degli anni cinquanta e
sessanta, e al tempo stesso a riconquistare per l'architetto una
*libertà intellettuale* che la stretta osservanza dell'"ortodossia"
moderna non riusciva (più) a garantire. Per Rossi, come per gli altri
architetti animati da un'ideologia comunista, ciò che è in gioco è una
"visione del mondo"[^89] di cui l'architetto e l'architettura devono
farsi portatori, *oltre* le pratiche del mestiere e l'adempimento delle
funzioni.

È un'impostazione condivisa anche da Antonio Monestiroli (non a caso tra
i membri del gruppo di ricerca diretto da Rossi alla fine degli anni
sessanta): un architetto che alla costruzione di una "visione del mondo"
oggettiva e condivisa dedicherà il suo costante e coerente impegno
intellettuale.

> Questo legame stretto (...) fra il progetto e la collettività, fa sí
> che il progetto acquisti un senso compiuto quando è determinato
> esplicitamente da una volontà collettiva, quando cioè si manifesta
> generalmente la volontà di definizione da parte della collettività
> della città sua propria e dell'architettura. Questo è il motivo per
> cui, solo quando si verificano queste condizioni, l'architettura
> raggiunge il suo massimo sviluppo. Questo è anche il motivo per cui
> quando l'impegno della collettività nei confronti dell'architettura
> viene meno, questa o si riduce al suo aspetto tecnico-costruttivo, o
> ricerca nostalgicamente se stessa, o si deforma a criticare la realtà
> che la nega[^90].

Da ciò discende quasi logicamente la definizione che egli dà del
progetto di architettura, "che consiste nello *svelamento della sua
ragione collettiva*, del senso della sua appartenenza alla
collettività*"*[^91].

Ed è proprio la coscienza del valore e della necessità di una *visione
collettiva* che contraddistingue la stagione degli architetti
intellettuali italiani da quella immediatamente successiva, che
annovera, tra gli altri, teorici come Peter Eisenman e Rem Koolhaas. La
distanza che separa questi ultimi da una concezione *politica* del ruolo
dell'architetto è del tutto evidente, distanza non colmata neppure dal
fatto che loro "incubatore" sia stato l'Institute for Architecture and
Urban Studies di New York, strettamente legato all'Italia, e in
particolar modo allo IUAV, a partire dai primi anni settanta[^92]. Se
la "traduzione americana" della teoria si configura come un tentativo di
riscatto dell'architettura dal dominio dei grandi studi commerciali (il
cui unico "impegno" consiste nell'eterna ripetizione delle soluzioni
elaborate dal *Functionalist style*) e da una classe di architetti più
colti ma sin troppo compiacenti nel fornire risposte alle eterogenee
richieste del mercato attraverso il nuovo eclettismo *post-modern*, ciò
non può avvenire che a costo di uno "svuotamento" di senso: la riduzione
al "grado zero" di "ogni ideologia, ogni sogno di funzione sociale, ogni
residuo utopico", come ha lucidamente scritto Tafuri[^93]. È l'avvio di
una trasformazione radicale dell'architetto intellettuale che, anche
allorché sopravvive in quanto tale -- e ancor di più, proprio *per*
sopravvivere in quanto tale --, deve rinunciare a ogni possibilità di
connotare politicamente e socialmente il suo agire, ponendosi al centro
di un universo di discorso interamente autoriferito[^94]. Non a caso le
speculazioni eisenmaniane tendono verso la concettualizzazione e
l'astrazione[^95], tanto quanto -- simmetricamente -- le analisi di
Koolhaas provengono direttamente dalla realtà[^96].

Ma prima di analizzare quali siano gli apporti derivanti all'architetto
intellettuale da questi due autori, vale la pena ricordare come siano
Robert Venturi e Denise Scott Brown -- prima dello stesso Koolhaas -- a
spalancare allo sguardo degli architetti (e non solo, ovviamente) le
porte di una realtà che non è niente affatto "possibile" (e quindi
ancora potenziale) e "diversa dalla realtà che ci circonda"[^97], ma è
invece del tutto tangibile e verificabile. In qualità di esploratore
urbano armato di macchina fotografica, l'intellettuale scende
letteralmente in strada e si dispone a imparare da essa, senza più la
mediazione di quegli "apparati" che l'avevano tradizionalmente
supportato fin lí: i libri e -- si potrebbe dire, in una certa misura --
la stessa cultura. *Complexity and Contradiction in Architecture* (1966)
ma soprattutto *Learning from Las Vegas* (1972)[^98] si propongono come
nuovi canoni per letture degli edifici e della città che a questo punto
si aprono a una molteplicità di fenomeni, di stimolazioni, di
interferenze. Per parafrasare l'*incipit* di *Delirious New York* di
Rem Koolhaas, "una montagna di realtà priva di qualsiasi teoria"; e nel
momento in cui è la realtà a parlare, le teorie che se ne lasciano
dedurre si trovano inscritte direttamente nella materia. Dalle
intelligenti analisi di Venturi e Scott Brown nascerà un'intera
generazione di "detective dello spazio"[^99].

Per Koolhaas la realtà -- anche grazie allo studio OMA ("an
international practice operating within the traditional boundaries of
architecture and urbanism")[^100] e alla sua "costola" culturale AMO ("a
research and design studio, applies architectural thinking to domains
beyond ... AMO often works in parallel with OMA's clients to fertilize
architecture with intelligence from this array of disciplines") -- è la
base d'appoggio per costruire un'idea di architettura che si spinge
spesso assai oltre il semplice edificio, per divenire interpretazione di
singoli fenomeni, di complessi urbani o di interi territori[^101]. Lo
sguardo sfaccettato e disincantato adottato in queste letture -- che
intrecciano sociologia, economia, politica e arti -- è divenuto una
modalità di osservazione che ha rapidamente fatto scuola, pur con
rivisitazioni, deformazioni ed eccessi[^102].

Nonostante le evidenti difformità -- "stilistiche" non meno che
sostanziali --, Koolhaas risulta ancor oggi, all'interno del panorama
internazionale e in un'epoca qual è quella odierna inequivocabilmente
postmoderna, l'unico erede (non è dato sapere quanto volontario o
inconsapevole) di una tradizione intellettuale che affonda le sue radici
nel moderno; una tradizione fondamentalmente *critica*, che sottopone la
realtà al vaglio delle contraddizioni che essa stessa genera, senza con
questo ridurle all'unità. È in questa accettazione -- e utilizzazione --
della funzione produttiva della contraddizione che Koolhaas appare
finalmente libero dalla nostalgia per il feticcio della "coerenza";
anche se questo implica al tempo medesimo aver fatto piazza pulita di
ogni "ideologia", con tutte le distorsioni ma pure con le possibilità di
ancorarsi a un "cielo delle stelle fisse" dal punto di vista valoriale
che questa portava con sé. E anche se questo comporta -- per usare le
parole che Tafuri riserva a Venturi -- una "disincantata accettazione
della realtà fino al cinismo"[^103].

Indiscutibilmente moderno, almeno nei suoi presupposti, è altresí il
"progetto" eisenmaniano di fornire un contrappeso alla "insostenibile
leggerezza" di un'epoca in cui sembra essersi dissolta ogni necessità di
conferire "significato" alle cose. Finendo con l'incorrere, tuttavia,
nel problema opposto. L'intero operare di Eisenman, tanto progettuale
che teorico, pare irretito in un *entretien infini* con un inesauribile
numero di interpretazioni e di significati, in qualche modo tutti
equivalenti, tutti possibili[^104]. Ciò genera un gioco di specchi
tanto affascinante (si pensi al proposito all'intenso dialogo da lui
intrattenuto con Jacques Derrida)[^105] quanto sospetto di essere, alla
lunga, sterile. E dove quanto si afferma non è più una visione
complessiva -- o quantomeno estesa -- del mondo, oppure è una
*Weltanschauung sub specie architecturae*, e dunque esposta al rischio
di essere autoreferenziale.

Dalla frammentazione di cui Eisenman si fa portatore emerge però anche
una straordinaria ricchezza interpretativa, a testimonianza del fatto
che la pluralità dei punti di vista costituisce ormai uno strumento
intellettuale imprescindibile in una prospettiva postmoderna. La stessa
pluralità di punti di vista e ricchezza interpretativa che si può
rintracciare nelle pagine della rivista "Oppositions" che lo stesso
Eisenman -- affiancato dallo storico dell'architettura inglese Kenneth
Frampton e dal critico d'origini argentine Mario Gandelsonas -- dirige
dal 1973 al 1984[^106]. Fin dal nome, "Oppositions" preannuncia una
conflittualità che rimane tuttavia interamente confinata al piano della
teoria. Ma proprio su questo terreno si registrano contributi
significativi da parte di autori dagli sguardi molti diversi. Tra loro,
oltre a nomi già segnalati, si possono menzionare Rafael Moneo e Bernard
Tschumi, due autori che incarnano in senso diametralmente opposto la
figura dell'architetto intellettuale. Il primo, concentrando la propria
attenzione sulla materialità degli edifici, sul loro essere portatori di
una vita che eccede tanto quella di chi li frequenta e abita, quanto
quella di chi li ha progettati; ma anche interrogandosi -- da architetto
-- sulle opere e sul mestiere di altri architetti, animato dalla volontà
di andare al di là di quanto a loro riguardo potrebbe apparire
scontato[^107]. Il secondo, cercando di spostare l'architettura sul
piano dell'evento, e più in generale di spostarla rispetto ai piani sui
quali di consueto "riposa" da un punto di vista critico; una "messa in
allarme" della disciplina, che utilizza gli strumenti della
"disgiunzione", della "disgregazione" e della "violenza" per farla
reagire[^108].

Da questi affondi sia pure molto parziali si evidenzia una condizione di
crescente criticità -- con l'avvicinarsi al tempo presente --
nell'interpretare il ruolo dell'intellettuale da parte degli architetti;
criticità che trova conferma negli anni novanta del secolo scorso e nei
primi anni del Duemila, improntati a un generale ripiegamento verso
posizioni più pragmatiche, spesso coincidenti con un "isolamento" dentro
gli studi professionali. Se questo mutamento ha almeno in parte
carattere congiunturale (essendo cioè legato alla favorevole contingenza
economica di quel periodo), il riapparire -- in anni più recenti -- di
timidi segnali di inversione di tendenza si lascia forse interpretare
come una conseguenza del proliferare della crisi; una crisi (economica e
sociale) che in molte parti del mondo ha assunto una natura pressoché
endemica. È in ogni caso all'interno di condizioni di crisi evidente --
in cui il mercato del lavoro (anche nel settore dell'architettura)
subisce una significativa contrazione, e soprattutto risente degli
effetti dell'ingresso della produzione economica nella fase
post-fordista[^109] -- che una giovane generazione di architetti
sviluppa un rinnovato interesse per il pensiero radicale degli anni
sessanta e settanta, nelle sue diverse forme: da quello più latamente
politico, a quello dei *Radicals* italiani (Superstudio,
Archizoom)[^110] e di alcuni degli interpreti del neo-razionalismo, in
special modo l'Aldo Rossi dell'*Architettura della città* e il Giorgio
Grassi della *Costruzione logica dell'architettura* (ma anche Guido
Canella, Gianugo Polesello e altri)[^111]. Un *repêchage* che prende le
mosse da presupposti molto distanti da quelli originari, e che in larga
parte è anche estraneo alla cultura e all'ambito di appartenenza dei
"discendenti" più diretti di quei protagonisti.

Nel fatale incontro tra scarse opportunità lavorative e fascinazione per
i "maestri" di un'età precedente si compie il riavvicinamento alla
scrittura critica di molti architetti in quel momento spesso soltanto
ipotetici: se non già una vera e propria riattivazione della coscienza e
del ruolo dell'intellettuale, perlomeno il riaffiorare di questi alla
percezione di un'epoca che aveva finito per dimenticarli. Emblematica
di questo momento è una rivista come "San Rocco", ideata, tra gli altri,
da membri dei gruppi italiani 2A+P/A (Matteo Costanzo, Gianfranco
Bombaci) e baukuh (Pier Paolo Tamburelli, Vittorio Pizzigoni, Andrea
Zanderigo e altri) e del belga Office Kersten Geers David Van Severen, e
diretta da Matteo Ghidoni. Ad essa collaborano autori di generazioni e
di provenienze diverse (tra i quali architetti del calibro di Oliver
Thill, Mark Lee, Freek Persyn, Harry Gugger, Pascal Flammer, Job
Floris). Nel tempo per eccellenza della tirannia delle immagini, "San
Rocco" decide programmaticamente di limitare l'uso di queste (pur
enfatizzandole mediante uno studiatissimo impiego dell'assonometria),
dando spazio ai testi (ma omettendo dalla copertina il nome della
rivista). Inoltre opta per "non durare per sempre", predeterminando in
tal modo il proprio decesso.

Da tutti questi indizi è lecito desumere qualche considerazione: per gli
architetti nati nell'ultimo quarto del secolo scorso la riscoperta della
cultura degli anni sessanta e settanta -- e con essa degli architetti
intellettuali che vi fiorivano -- equivale a un ideale ritorno alle
origini; se non il recupero di un "rimosso", di certo un percorso a
ritroso per cercare di ritrovare un filo perduto. È poi significativo
che tale iniziativa abbia come "centro operativo" l'Italia. È proprio in
Italia infatti, più che in ogni altro luogo, che si è mantenuto uno
stretto legame, un dialogo, tra architettura, storia e teoria. Ed è
proprio l'Italia che può forse vantare la maggior concentrazione di
architetti intellettuali nel corso della sua storia. Pur discontinua,
tale presenza si lascia riscontrare anche in momenti difficili (si pensi
ad esempio a Edoardo Persico e a Giuseppe Pagano durante il fascismo).
Infine, le modalità secondo cui ciò avviene sono integralmente figlie
dell'epoca attuale, e non esistono vie rapide e agevoli per mettere in
connessione forme e contenuti di ora con forme e contenuti di allora.

Vi sono infatti alcune caratteristiche peculiari dell'architetto
intellettuale -- e dell'intellettuale *in generale* -- italiano degli
anni sessanta e settanta che difficilmente possono essere fatte oggetto
di illusorie rinascite, e che non casualmente sono scomparse nelle
epoche successive e in altri contesti: tra queste, la consapevolezza non
soltanto del proprio compito ma anche delle condizioni del proprio
operare, ovvero dei propri *limiti storici*. Per Franco Fortini,
scrittore, poeta, critico e saggista, fortemente impegnato in quegli
anni in una lucida analisi delle condizioni di lavoro all'interno
dell'"industria culturale", il ruolo da assegnare all'intellettuale
parte dalla constatazione che lo sviluppo capitalistico realizza la
progressiva distruzione della coscienza degli individui, ovvero -- come
è stato scritto -- la "trasformazione antropologica dell'uomo da
soggetto volitivo a merce, da essere dotato di pensiero, volontà,
desiderio e coscienza a precipitato inerte di tempo ed energia
inintenzionale"[^112]. In questa prospettiva, la trasformazione della
società in senso comunista da lui vagheggiata poteva avvenire soltanto
con il contributo di un lavoro intellettuale capace di concorrere alla
creazione di una coscienza del presente comune e condivisa. E tuttavia,
questo compito non potrebbe essere concepito per Fortini al di fuori di
una verifica attenta e continua dei "criteri di valore" adottati per
leggere la realtà. Cosí, ad esempio, l'"ordine storico, ideologico,
estetico" di un libro e di un autore deve essere continuamente
verificato "sul contesto sociale, produttivo, culturale, che quel libro,
quegli autori, producono e ricevono"[^113]; ciò che implica la necessità
-- come già Benjamin aveva compreso -- di non limitarsi a "schierarsi"
politicamente ma di cercare di modificare *dall'interno* le condizioni
politiche, ovvero i rapporti di produzione dell'epoca[^114]. Ma non
potrebbe essere concepito neppure al di fuori delle condizioni effettive
cui soggiace lo stesso lavoro intellettuale all'interno della società, e
della società capitalista nello specifico: condizioni che sono per molti
versi analoghe a quelle imposte al lavoro operaio. A partire dal fatto
che il lavoro intellettuale diventa sempre più dipendente dall'industria
culturale privata[^115], per giungere a quello -- diretta conseguenza
della "riduzione di ogni forma di lavoro a lavoro industriale"[^116] --
che anche il lavoro intellettuale, all'interno dello sviluppo
capitalistico, tende a divenire lavoro astratto, parcellizzandosi in
mansioni sempre più indifferenziate ed equivalenti tra di loro.

Qualche anno più tardi Tafuri dedicherà un saggio al lavoro
intellettuale che prende le mosse precisamente da questi presupposti:

> ... siamo in presenza di un costante aumento dell'estraneità
> dell'intellettuale al contenuto del proprio lavoro, che si realizza
> tanto più concretamente tanto più quest'ultimo si caratterizza
> esattamente come "lavoro": più esattamente, anzi, come lavoro
> salariato[^117].

Nel solco della linea "operaista" perseguita da Mario Tronti e dalla
rivista "Contropiano" su cui Tafuri scrive, tale tendenza non va
tuttavia rifiutata quanto piuttosto assecondata, portandola fino alle
sue conseguenze ultime:

> Leggere nelle condizioni attuali del lavoro intellettuale una concreta
> tendenza verso un'omogeneizzazione materiale, che passa attraverso i
> processi di ristrutturazione sociale e produttiva capitalistici,
> significa riconoscere nella massificazione e nella mobilità dei ruoli,
> nella perdita dei privilegi tradizionali riservati al lavoro
> intellettuale, nel distacco -- che avviene già nella fase di
> preparazione scolastica e universitaria -- dai contenuti del proprio
> lavoro, nell'estraneità che finalmente anche l'intellettuale è
> *obbligato* a sperimentare nei confronti dell'organizzazione
> capitalistica del lavoro, alcune delle condizioni *positive* da cui
> ripartire, per elaborare un programma di attacco al piano complessivo.

E ancora, più oltre:

> Non crediamo alle ripetute invenzioni di nuovi *alleati* della classe
> operaia. Ma sarebbe suicida non riconoscere che sono le stesse linee
> dello sviluppo capitalista a ricomporre, ai propri fini, una forza
> lavoro tendenzialmente omogenea, che è possibile far funzionare sotto
> il segno degli interessi diretti della classe operaia. Rovesciare
> quello che è stato, per troppo tempo, il disegno capitalista, quello
> che vede come proprio fine *una classe operaia organizzata dal
> capitale*: questo è l'obiettivo da raggiungere ponendosi come compito
> la gestione operaia delle rivendicazioni soggettive dei nuovi strati
> di lavoro intellettuale salariato.
>
> Ma ciò non è possibile se non battendo ogni illusione reazionaria,
> ogni proposta tesa a restituire *dignità* professionale a quegli
> intellettuali "degradati". Mostrare in concreto la reazionarietà di
> ogni discorso che voglia offrire prospettive "alternative" al lavoro
> intellettuale, significa quindi riconoscere che solo *all'interno* del
> ruolo oggettivo imposto dal dominio dello sviluppo è la condizione per
> utilizzare la lotta dei ceti intellettuali assorbiti direttamente
> nella produzione, in un attacco complessivo al piano del capitale: il
> che significa, essenzialmente, estendere l'uso politico della lotta
> *sul* salario a strati sociali sempre più ampi[^118].

L'intellettuale impegnato nella costruzione di un radicale ripensamento
della società a partire dalle condizioni esistenti, ma al tempo stesso
alla ricerca di un orizzonte di senso *autonomo* per il proprio operare
in quanto intellettuale, non può dunque che porsi nella posizione che
Tronti sintetizza nell'espressione "dentro e contro": "*dentro* la
società e *contro* di essa nello stesso tempo"[^119].

Le vicende storiche occorse dopo i primi anni settanta nella società
italiana, cosí come in quelle di molti altri paesi occidentali
industrializzati, porteranno a evoluzioni del tutto distanti da quelle
prefigurate, tra gli altri, da Tronti, Fortini e Tafuri e -- per quanto
riguarda il più specifico campo dell'architettura -- da Aymonino e
Rossi. Proprio quest'ultimo, forse più di ogni altro, diverrà
l'emblematico protagonista del brusco cambio di direzione impresso al
lavoro intellettuale nel corso di meno di un decennio: dalla ricerca di
un piano di lavoro condiviso come fondamento di un'alternativa alla
realtà capitalistico-borghese, alla conquista di una "scrittura"
privata, individuale, autobiografica. E non è probabilmente un caso che
questo passaggio coincida con la "scoperta" dell'America da parte di
Rossi[^120].

A partire da quel momento l'attitudine a essere "dentro e contro"
declinerà vistosamente, fino a scomparire del tutto; una sparizione cui
corrisponde un'altrettanto lunga eclissi della figura dell'architetto
come intellettuale. Le ragioni di questa duplice sparizione (o forse
sarebbe meglio dire "oscuramento") solo apparentemente sono
riconducibili *in toto* alle condizioni politiche e sociali verificatesi
in Italia e in buona parte del mondo dagli anni ottanta in avanti. In
realtà, proprio quelle condizioni costituiscono il compimento e la
conferma di quanto i migliori intellettuali dei decenni precedenti
avevano lucidamente preconizzato[^121]. Non deve quindi stupire che,
con il crescente imporsi di tali condizioni in tutte le società
occidentalizzate, sottoposte agli effetti sempre più penetranti di un
capitalismo al tempo stesso planetariamente esteso e minutamente
pervasivo, siano tornate a emergere (specialmente in Italia)[^122], a
partire dal principio del nuovo millennio, riflessioni filosofiche e
politiche incentrate su temi su cui la cultura si era interrogata nei
decenni precedenti[^123]. E che a fronte del "tutto dentro" del sistema
globalizzato[^124], sia ritornata attuale la possibilità di porsi --
rispetto a esso -- *dentro e contro*.

È alla luce di questa posizione che è forse possibile ripensare anche il
ruolo dell'architetto intellettuale, *oggi*.

[^1]: Su Brunelleschi vedi, tra gli altri, Piero Sanpaolesi,
*Brunelleschi*, Barbera, Firenze 1962; Frank D. Prager e Giustina
Scaglia, *Brunelleschi. Studies of His Technology and Inventions*, The
MIT Press, Cambridge (Mass.) 1970; Eugenio Battisti, *Filippo
Brunelleschi*, Electa, Milano 1976; Arnaldo Bruschi, *Filippo
Brunelleschi*, ivi 2006.

[^2]: Giulio Carlo Argan, *Brunelleschi*, Mondadori, Milano 1955, p. 44.

[^3]: Antonio Manetti, *Vita di Filippo Brunelleschi*, Edizioni Il
Polifilo, Milano 1976, pp. 44 e 88.

[^4]: Arendt, *Vita activa* cit., pp. 137 sgg.

[^5]: Manetti, *Vita di Filippo Brunelleschi* cit., pp. 96-97; Giorgio
Vasari, *Vita di Filippo Brunelleschi*, in *Le vite de' più eccellenti
pittori, scultori ed architetti*, Einaudi, Torino 1986, pp. 316-17;
Cesare Guasti, *La Cupola di Santa Maria del Fiore illustrata con i
documenti dell'archivio dell'Opera secolare*, Barbèra Bianchi, Firenze
1857, pp. 229-30.

[^6]: Manfredo Tafuri, *L'architettura dell'Umanesimo*, Laterza, Bari
1969, p. 19.

[^7]: Vasari, *Vita di Filippo Brunelleschi* cit., p. 324.

[^8]: Il *De re ædificatoria* di Leon Battista Alberti, scritto intorno
alla metà del XV secolo, verrà pubblicato per la prima volta nel 1485 in
latino; vedi *L'architettura*, a cura di Giovanni Orlandi, Edizioni Il
Polifilo, Milano 1988.

[^9]: Alberto Giorgio Cassani, *La fatica del costruire. Tempo e
materia nel pensiero di Leon Battista Alberti*, Edizioni Unicopli,
Milano 2000; Massimo Bulgarelli, *Leon Battista Alberti 1404-1472.
Architettura e storia*, Electa, Milano 2008.

[^10]: Alberti, *L'architettura* cit., p. 6.

[^11]: Andrea Palladio, *I Quattro Libri dell'Architettura*, Domenico
de' Franceschi, Venezia 1570, vol. I, *Proemio ai lettori*, p. 6.

[^12]: *Ibid.*, vol. III, cap. V, p. 12.

[^13]: Vedi, tra gli altri, Rudolf Wittkower, *Palladio e il
palladianesimo*, Einaudi, Torino 1984.

[^14]: Sintomatico -- ma non certo unico -- il caso della Basilica di
Vicenza: "La pianta della Basilica riprodotta nei *Quattro Libri* è solo
un'invenzione, un singolare esempio di progetto ideale e irrealizzabile
di un edificio già costruito in altro modo: in essa Palladio elimina
proprio quelle difficoltà da cui era nato il proprio progetto e senza le
quali il suo intervento non sarebbe stato neppure richiesto": James
Ackerman, *Palladio*, Einaudi, Torino 1972, p. 45.

[^15]: Su Piranesi, vedi John Wilton-Ely, *Giovanni Battista Piranesi
1720-1778*, Electa, Milano 2008.

[^16]: Pierluigi Panza, *Piranesi architetto*, Guerini Studio, Milano
1998, p. 35.

[^17]: Michel Foucault, *Microfisica del potere*, Einaudi, Torino 1977.

[^18]: La più nota è probabilmente la "Querelle des anciens et des
modernes" che, riprendendo la più nota disputa in campo letterario (vedi
Marc Fumaroli, *Le api e i ragni. La disputa degli Antichi e dei
Moderni*, Adelphi, Milano 2005), oppone Claude Perrault e François
Blondel: cfr. Hanno-Walter Kruft, *Storia delle teorie architettoniche.
Da Vitruvio al Settecento*, Laterza, Roma 1988, in particolare il
cap. *La fondazione dell'Accademia di architettura e la crisi del
dogmatismo accademico*, pp. 159-76; Anthony Gerbino, *François Blondel:
Architecture, Erudition, and the Scientific Revolution*, Routledge,
Abingdon-on-Thames 2010.

[^19]: Tra i più celebri e influenti, l'*Essai sur l'architecture*
(1753) di Marc-Antoine Lau­gier e il *Saggio sopra l'architettura*
(1757) di Francesco Algarotti, basato sulle idee (sia pur criticate) di
Carlo Lodoli, denominato il "Socrate" dell'architettura per non aver
lasciato tracce scritte della sua teoria: vedi Andrea Memmo, *Elementi
d'architettura lodoliana*, Pagliarini, Roma 1786.

[^20]: Étienne-Louis Boullée, *Architettura. Saggio sull'arte*, a cura
di Alberto Ferlenga, Einaudi, Torino 2005, p. 5.

[^21]: *Ibid.*, p. 3.

[^22]: Jean-Nicolas-Louis Durand, *Lezioni di architettura*, a cura di
Ernesto D'Alfonso, CLUP, Milano 1986.

[^23]: Tra questi vanno ricordati, tra gli altri, Charles Fourier,
Robert Owen, William Morris, Étienne Cabet, Jean-Baptiste Godin; sul
tema vedi Françoise Choay, *La città. Utopie e realtà*, Einaudi, Torino
1973.

[^24]: Tony Garnier, *Una città industriale*, a cura di Riccardo
Mariani, Jaca book, Milano 1990.

[^25]: Le Corbusier, *Urbanistica* (1925), Il Saggiatore, Milano 1967.

[^26]: Catherine de Smet, *Le Corbusier Architect of Books*, Lars Müller
Pub­lishers, Baden 2005.

[^27]: In particolare, vedi Le Corbusier, *Croisade ou le Crépuscole des
Académies*, Éditions Crés, Paris 1933.

[^28]: A tale azione si connettono strettamente da parte di Bruno Zevi
la fondazione nel 1944 dell'APAO (Associazione per l'Architettura
Organica) e la pubblicazione di *Verso un'architettura organica. Saggio
sullo sviluppo del pensiero architettonico negli ultimi cinquant'anni*,
Einaudi, Torino 1945.

[^29]: Roberto Dulio, *Introduzione a Bruno Zevi*, Laterza, Roma-Bari
2008.

[^30]: Bruno Zevi, *Saper vedere l'architettura*, Einaudi, Torino 1948;
Id., *Storia dell'architettura moderna*, ivi 1950; Id., *Poetica
dell'architettura neoplastica*, Tamburini, Milano 1953; Id., *Il
linguaggio moderno dell'architettura*, Einaudi, Torino 1973.

[^31]: Zevi, *Verso un'architettura organica* cit., p. 13.

[^32]: *Ibid.*, p. 150.

[^33]: *Ibid.*, p. 75.

[^34]: *Manuale dell'architetto*, a cura del Consiglio Nazionale delle
Ricerche (CNR) -- United States Information Service (USIS), Roma 1946.

[^35]: Manfredo Tafuri, *Teorie e storia dell'architettura*, Laterza,
Bari 1968, p. 161.

[^36]: Tafuri, *Teorie e storia dell'architettura* cit., p. 172.

[^37]: *Ibid.*, p. 176.

[^38]: *Ibid.*, p. 173.

[^39]: Bruno Zevi, *Introduzione: Attualità di Michelangiolo
architetto*, in *Michelangiolo architetto*, a cura di Paolo Portoghesi e
Bruno Zevi, Einaudi, Torino 1964, pp. 14-16. Vedi anche *Mostra critica
delle opere michelangiolesche*, catalogo della mostra, Roma -- Palazzo
delle Esposizioni, De Luca, Roma 1964.

[^40]: Tafuri, *Teorie e storia dell'architettura* cit., p. 126.

[^41]: Giorgio Ciucci, *Gli anni della formazione*, in "Casabella",
n. 619-20, 1995, pp. 12-25.

[^42]: Giorgio Piccinato, Vieri Quilici e Manfredo Tafuri, *La città
territorio. Verso una nuova dimensione*, in "Casabella-Continuità",
n. 270, 1962, pp. 6-16; Enrico Fattinnanzi e Manfredo Tafuri,
*Un'ipotesi per la città-territorio di Roma*, in "Casabella-Continuità",
n. 274, 1963, pp. 27-36.

[^43]: Luka Skansi, *Architettura come "oggetto trascurabile". Note a
margine di una discussione di Manfredo Tafuri su realismo e utopia*, in
Alessandro De Magistris e Aurora Scotti (a cura di), *Utopiae finis?
Percorsi tra utopismi e progetto*, Accademia University Press, Torino
2018, p. 219.

[^44]: Tafuri, *Teorie e storia dell'architettura* cit., p. 270.

[^45]: *Ibid.*, p. 266.

[^46]: *Ibid.*, pp. 266-67.

[^47]: *Ibid.*, p. 269.

[^48]: *Ibid.*, p. 270.

[^49]: *Ibid*.

[^50]: Su ciò vedi Marco Biraghi, *Progetto di crisi. Manfredo Tafuri e
l'architettura contemporanea*, Christian Marinotti Edizioni, Milano
2005. Vedi anche il fondamentale saggio di Manfredo Tafuri, *Il
"progetto" storico*, in "Casabella", n. 429, 1977, pp. 11-18 (poi come
*Introduzione* a Id., *La sfera e il labirinto* cit., pp. 3-30).

[^51]: Su Argan, vedi Claudio Gamba (a cura di), *Giulio Carlo Argan.
Intellettuale e storico dell'arte*, Electa, Milano 2012. La figura di
Benevolo attende invece ancora una adeguata storicizzazione.

[^52]: Jean-Louis Cohen, *La coupure entre architectes et intellectuels,
ou les enseignements de l'italophilie*, Mardaga, Bruxelles 2015.

[^53]: Cohen, *La coupure entre architectes et intellectuels* cit.,
p. 69.

[^54]: *Ibid.*, p. 100.

[^55]: *Ibid.*, p. 101.

[^56]: Per quanto riguarda i libri vedi Fiorella Vanini, *La libreria
dell'architetto. Progetti di collane editoriali 1945-1980*, Franco
Angeli, Milano 2012; per le riviste vedi Marco Mulazzani, *Le riviste di
architettura. Costruire con le parole*, in *Storia dell'architettura
italiana. Il secondo Novecento (1945-1996)*, a cura di Giorgio Ciucci e
Giorgio Muratore, Electa, Milano 1997, pp. 430-43.

[^57]: Sul MSA vedi Matilde Baffa, Corinna Morandi, Sara Protasoni e
Augusto Rossari, *Il Movimento di Studi per l'Architettura 1945-1961*,
Laterza, Roma-Bari 1995. Sull'ideologia "comunitaria" olivettiana
esistono moltissimi contributi, oltre ai libri dello stesso Olivetti;
per una sua esposizione sintetica ma approfondita vedi il capitolo
*Aufklärung I. Adriano Olivetti e la 'communitas' dell'intelletto*, in
Tafuri, *Storia dell'architettura italiana 1944-1985* cit., pp. 47-54.

[^58]: Renato Barilli, *La neoavanguardia italiana. Dalla nascita del
"Verri" alla fine di "Quindici"*, il Mulino, Bologna 1995; Andrea
Cortellessa, *Volevamo la Luna*, in *Quindici. Una rivista e il
Sessantotto*, a cura di Nanni Balestrini, Feltrinelli, Milano 2008,
pp. 451-72.

[^59]: Cohen, *La coupure entre architectes et intellectuels* cit.,
p. 101. In merito vedi anche Cina Conforto, Gabriele De Giorgi,
Alessandra Muntoni e Marcello Pazzaglini, *Il dibattito architettonico
in Italia 1945-1975*, Bulzoni, Roma 1977.

[^60]: Giuseppe Samonà, *L'urbanistica e l'avvenire delle città*,
Laterza, Bari 1959. Dello stesso autore è essenziale pure *L'unità
architettura-urbanistica. Scritti e progetti 1929-1973*, a cura di
Pasquale Lovero, Franco Angeli, Milano 1975. Su Samonà vedi Carlo
Aymonino, Giorgio Ciucci, Francesco Dal Co e Manfredo Tafuri, *Giuseppe
Samonà 1923-1975. Cinquant'anni di architetture*, Officina, Roma 1975.

[^61]: Ludovico Quaroni, *La Torre di Babele*, Marsilio, Padova 1967.
Di Quaroni vedi anche *Immagine di Roma*, Laterza, Bari 1969, e
*Progettare un edificio. Otto lezioni di architettura*, Mazzotta,
Milano 1977. Su Quaroni vedi Manfredo Tafuri, *Ludovico Quaroni e lo
sviluppo dell'architettura moderna in Italia*, Edizioni di Comunità,
Milano 1964; Pippo Ciorra, *Ludovico Quaroni 1911-1987. Opere e
progetti*, Electa, Milano 1989.

[^62]: Ernesto Nathan Rogers, *Il problema del costruire nelle
preesistenze ambientali*, in "L'Architettura", n. 22, 1957 (ora in Id.,
*Esperienza dell'architettura*, a cura di Luca Molinari, Skira, Milano
1997, pp. 286-91). Alle tematiche delle preesistenze ambientali -- e
più in generale al rapporto architettura-città -- sono dedicati numerosi
degli editoriali pubblicati da Rogers su "Casabella", raccolti, oltreché
in *Esperienza dell'architettura*, in *Editoriali di architettura*,
Einaudi, Torino 1968; ora a cura di Gabriella Lo Ricco e Mario Viganò,
Zandonai, Rovereto 2009.

[^63]: Vittorio Gregotti, *Il territorio dell'architettura*,
Feltrinelli, Milano 1966.

[^64]: Carlo Aymonino, *Origini e sviluppo della città moderna*,
Marsilio, Padova 1965. Vedi inoltre Id., *Il significato della città*,
Laterza, Bari 1975.

[^65]: Aldo Rossi, *L'architettura della città*, Marsilio, Padova
1966. Sul libro e le sue implicazioni vedi *Aldo Rossi, la storia di un
libro. L'architettura della città, dal 1966 ad oggi*, a cura di
Fernanda De Maio, Alberto Ferlenga e Patrizia Montini Zimolo, Il
Poligrafo - IUAV, Padova-Venezia 2014.

[^66]: Vedi, ad esempio, *La città di Padova. Saggio di analisi
urbana*, scritti di Carlo Aymonino, Manlio Brusatin, Gianni Fabbri,
Mauro Lena, Pasquale Lovero, Sergio Lucianetti e Aldo Rossi, Officina,
Roma 1970.

[^67]: Giovanni Marras e Marco Pogacnik (a cura di), *Giuseppe Samonà e
la Scuola di Architettura a Venezia*, Il Poligrafo, Padova 2006.

[^68]: Ludovico Quaroni, *La città fisica*, a cura di Antonino
Terranova, Laterza, Roma-Bari 1981.

[^69]: Tra loro va ricordato almeno Franco Purini, il cui contributo
alla definizione del profilo dell'architetto intellettuale italiano a
partire dagli anni sessanta -- attraverso la sua "opera di pensiero",
che contempera architettura, disegno e parola -- è fondamentale; tra gli
altri suoi lavori, vedi *Comporre l'architettura*, Laterza, Roma-Bari
2000; *La misura italiana dell'architettura*, Laterza, Roma-Bari 2008.

[^70]: Su ciò vedi in particolar modo Tafuri, *Ludovico Quaroni e lo
sviluppo dell'architettura moderna in Italia* cit., pp. 13-14.

[^71]: Fra le tematiche più generali trattate vanno ricordate, tra le
altre: i Centri Direzionali Italiani (n. 264, 1962), Città e Regione
(n. 270, 1962), i Problemi di Roma (n. 279, 1963), il Piano
Intercomunale Milanese (n. 282, 1963), le Coste Italiane (nn. 283 e 284,
1964), il Fabbisogno del Verde in Italia (n. 286, 1964), i Problemi USA
(n. 294-95, 1964-65).

[^72]: Vedi, tra l'altro, *Enzo Paci. Architettura e filosofia*, in
"aut aut", n. 333, 2007, numero dedicato al filosofo. Va ricordato che
nel 1946, con Banfi, Vittorini, Einaudi e altri, Rogers è membro
fondatore della Casa della cultura di Milano. Enzo Paci farà invece
parte del comitato di redazione di "Casabella-Continuità" a partire dal
numero 215 del 1957.

[^73]: Ernesto N. Rogers, *Continuità*, in "Casabella-Continuità",
n. 199, 1953-54, p. 2.

[^74]: In particolare Rogers si rifà all'uso che John Dewey (studiato in
quel periodo da Paci) ne fa in *Esperienza e educazione* (La Nuova
Italia, Firenze 1949) e in *L'arte come esperienza* (ivi 1951). La
prima raccolta degli editoriali di Rogers si intitola *Esperienza
dell'architettura*, Einaudi, Torino 1958.

[^75]: Ernesto N. Rogers, *Continuità o crisi?*, in
"Casabella-Continuità", n. 215, 1957, p. 3.

[^76]: Enzo Paci, *Fenomenologia e architettura contemporanea*, in Id.,
*Relazioni e significati. Critica e dialettica*, Lampugnani Nigri,
Milano 1966, p. 175.

[^77]: Enzo Paci, *La crisi della cultura e la fenomenologia
dell'architettura contemporanea*, in "La Casa", n. 6, 1959, p. 356.

[^78]: Ernesto N. Rogers, *Il dramma dell'architetto* (1948), in Id.,
*Esperienza dell'architettura* cit., p. 221.

[^79]: *Ibid.*, p. 223.

[^80]: *Ibid.*, p. 225.

[^81]: Massimo Canzian, *Orizzonti del fare architettonico. Progetto
Estetica Teoria nel dibattito italiano del dopoguerra*, Guerini e
Associati, Milano 1995, nonché l'*Introduzione* di Massimo Cacciari,
pp. 11-17.

[^82]: Oltre al citato *Il territorio dell'architettura*, vedi, tra i
molti altri, Vittorio Gregotti, *Dentro l'architettura*, Bollati
Boringhieri, Torino 1991; Id., *Identità e crisi dell'architettura
europea*, Einaudi, Torino 1999; Id., *L'architettura del realismo
critico*, Laterza, Bari 2004; Id., *L'architettura nell'epoca
dell'incessante*, ivi 2006; Id., *Contro la fine dell'architettura*,
Einaudi, Torino 2008; Id., *Architettura e postmetropoli*, ivi 2011;
Id., *Il sublime al tempo del contemporaneo*, ivi 2013; Id., *I racconti
del progetto*, Skira, Milano 2018.

[^83]: Manfredo Tafuri, *Vittorio Gregotti. Progetti e architetture*,
Electa, Milano 1982; Guido Morpurgo (a cura di), *Il territorio
dell'architettura. Gregotti e Associati 1953-2017*, Skira, Milano 2017.

[^84]: Gramsci, *Quaderni del carcere* cit., vol. III, Quaderno 12
(XXIX), § 3, p. 1551.

[^85]: Giovanni Durbiano, *I Nuovi Maestri. Architetti tra politica e
cultura nel dopoguerra*, Marsilio, Venezia 2000, pp. 55-98.

[^86]: Per quanto riguarda i corsi di Carlo Aymonino allo IUAV di
Venezia, cui collaborano, tra gli altri, anche Aldo Rossi, Costantino
Dardi e Gianni Fabbri, vedi *Aspetti e problemi della tipologia
edilizia. Documenti del Corso di caratteri distributivi degli edifici.
Anno accademico 1963-1964*, Libreria Cluva, Venezia 1964; *La formazione
del concetto di tipologia edilizia. Atti del Corso di caratteri
distributivi degli edifici. Anno accademico 1964-1965*, ivi 1965;
*Rapporti tra la tipologia edilizia e la morfologia urbana. Documenti
del Corso di caratteri distributivi degli edifi­ci. Anno accademico
1965-1966*, ivi 1966.

[^87]: Aldo Rossi, *Tipologia, manualistica e architettura*, in
*Rapporti tra la tipologia edilizia e la morfologia urbana* cit., p. 69.

[^88]: Aldo Rossi, *L'obiettivo della nostra ricerca*, in *L'analisi
urbana e la progettazione architettonica. Contributi al dibattito e al
lavoro di gruppo nell'anno accademico 1968-69. Gruppo di ricerca
diretto da Aldo Rossi*, Clup, Milano 1970, p. 13.

[^89]: Durbiano, *I Nuovi Maestri* cit., p. 62.

[^90]: Antonio Monestiroli, *L'architettura della realtà* (1979),
Allemandi, Torino 2004, p. 21.

[^91]: *Ibid.*, p. 22.

[^92]: Joan Ockman, *Venice and New York*, in "Casabella", n. 619-20,
1995, pp. 56-65; Ernesto Ramon Rispoli, *Ponti sull'Atlantico.
L'Institute for Architecture and Urban Studies e le relazioni
Italia-America (1967-1985)*, Quodlibet, Macerata 2012.

[^93]: Tafuri, *La sfera e il labirinto* cit., p. 323.

[^94]: D'altronde, la tendenza a unificare azione intellettuale e
attività politica sembra appartenere costitutivamente alla cultura
italiana, che l'ha ereditata da Benedetto Croce. Al proposito vedi
Eugenio Garin, *Intellettuali italiani del* *XX* *secolo*, Editori
Riuniti, Roma 1996, in particolare il capitolo *Benedetto Croce o della
"separazione impossibile" tra politica e cultura*, pp. 47-67.

[^95]: Peter Eisenman, *Inside Out. Scritti 1963-1988*, Quodlibet,
Macerata 2014; Id., *Written into the Void. Selected Writings
1990-2004*, Yale University Press, New Haven 2007.

[^96]: Rem Koolhaas, *Delirious New York* (1978), a cura di Marco
Biraghi, Electa, Milano 2001; Id., *Junkspace*, a cura di Gabriele
Mastrigli, Quodlibet, Macerata 2006; Id., *Singapore Songlines*, a cura
di Manfredo di Robilant, Quodlibet, Macerata 2010.

[^97]: Monestiroli, *L'architettura della realtà* cit., p. 29.

[^98]: Robert Venturi, *Complessità e contraddizioni nell'architettura*,
Edizioni Dedalo, Bari 1993; Robert Venturi, Denise Scott Brown e Steven
Izenour, *Imparare da Las Vegas. Il simbolismo dimenticato della forma
architettonica*, Quodlibet, Macerata 2010.

[^99]: Vedi, tra gli altri, Mirko Zardini (a cura di), *Paesaggi ibridi.
Un viaggio nella città contemporanea*, Skira, Milano 1996; Stefano
Boeri, *I detective dello spazio*, in "Il Sole -- 24 Ore", supplemento,
16 marzo 1997; Id., *Atlanti eclettici*, in Multiplicity, *USE-Uncertain
States of Europe -- Viaggio nell'Europa che cambia*, Skira, Milano 2003,
pp. 425-45.

[^100]: Vedi http://oma.eu/office.

[^101]: Vedi, tra gli altri, AMO, *History of Europe and The European
Union*, Archis, rivista a unico numero, Amsterdam 2005; Rem Koolhaas,
Ole Bouman e Mitra Khoubrou (a cura di), *Al Manakh: Dubai Guide, Gulf
Survey, Global Agenda*, Archis, Amsterdam 2007; Todd Reisz (a cura di),
*Al Manakh: Gulf Continued*, ivi 2010; *Roadmap 2050. A practical Guide
to a Prosperous, Low-carbon Europe*, OMA, Amsterdam 2010; vedi anche
www.roadmap2050.eu/project/roadmap-2050.

[^102]: Vedi ad esempio MVRDV, *Farmax. Excursions on Density*, 010
Publishers, Rotterdam 1998; Id., *KM3. Excursions on Capacity*, Actar,
Barcelona 2005; BIG -- Bjarke Ingels Group, *Yes Is More. An Archicomic
on Architectural Evo­lution*, Taschen, Köln 2009; Id., *Hot to Cold. An
Odyssey of Architectural Adaptation*, ivi 2015.

[^103]: Tafuri, *La sfera e il labirinto* cit., p. 349.

[^104]: Rimando a questo proposito a Marco Biraghi, *Eisenman o
dell'interpretazione*, in Pier Vittorio Aureli, Marco Biraghi e Franco
Purini, *Peter Eisenman. Tutte le opere*, Electa, Milano 2007,
pp. 22-37.

[^105]: Per le conversazioni tra Eisenman e Derrida, e per i testi di
quest'ultimo su Eisenman, vedi Jacques Derrida, *Adesso l'architettura*,
a cura di Francesco Vitale, Libri Scheiwiller, Milano 2008, pp. 181-238;
vedi anche *Un matrimonio sfortunato. Derrida e l'architettura*, a cura
di Peter Bojanić e Damiano Cantone, in "aut aut", n. 368, 2015.

[^106]: K. Michael Hays (a cura di), *Oppositions Reader. Selected
Readings from a Journal for Ideas and Criticism in Architecture
1973-1984*, Princeton Architec­tural Press, New York 1998.

[^107]: Rafael Moneo, *La solitudine degli edifici e altri scritti*, 2
voll., I. *Questioni intorno all'architettura*; II. *Sugli architetti e
il loro lavoro*, a cura di Andrea Casiraghi e Daniele Vitale, Allemandi,
Torino 1999-2004; Id., *Inquietudine teorica e strategia progettuale
nell'opera di otto architetti contemporanei*, Electa, Milano 2005.

[^108]: "Nelle sue disgregazioni e disgiunzioni, nella sua
caratteristica frammentazione e dissociazione, l'attuale situazione
culturale suggerisce la necessità di abbandonare le categorie di
significato e le storie contestuali stabilite. Varrebbe quindi la pena
di rinunciare a qualunque nozione di architettura postmoderna in favore
di una architettura "postumanista", che evidenzi non solo la dispersione
del soggetto e della forza delle regole sociali, ma anche l'effetto di
questo decentramento sull'intera nozione di forma architettonica
unificata e coerente": Bernard Tschumi, *Disgiunzioni* (1987), in Id.,
*Architettura e disgiunzione*, a cura di Ruben Baiocco e Giovanni
Damiani, Pendragon, Bologna 1996, p. 164.

[^109]: Su ciò vedi, ad esempio, Maurizio Lazzarato, *Immaterial Labor*,
in Paolo Virno e Michael Hardt (a cura di), *Radical Thought in Italy.
A Potential Politics*, University of Minnesota Press, Minneapolis 2006,
pp. 132-46.

[^110]: Gianni Pettena (a cura di), *Radicals. Architettura e Design
1960-1975*, La Biennale di Venezia -- Il Ventilabro, Firenze 1996;
Andrea Branzi, *Modernità debole e diffusa*, Skira, Milano 2006.

[^111]: Giorgio Grassi, *La costruzione logica dell'architettura*,
Marsilio, Venezia 1967. Per una rilettura "aggiornata" di Rossi e di
Grassi, vedi baukuh, *Due saggi sull'architettura*, Sagep editori,
Genova 2012.

[^112]: Daniele Balicco, *Non parlo a tutti. Franco Fortini
intellettuale politico*, Manifestolibri, Roma 2006, p. 43.

[^113]: Franco Fortini, *Verifica dei poteri* (1960), in Id., *Verifica
dei poteri*, Garzanti, Milano 1974, pp. 54-55.

[^114]: Rimando a Benjamin, *L'autore come produttore* cit., p. 201.

[^115]: Franco Fortini, *Astuti come colombe* (1962), in Id., *Verifica
dei poteri* cit., pp. 66-87.

[^116]: Mario Tronti, *La fabbrica e la società*, in "Quaderni Rossi",
n. 2, 1962, p. 21.

[^117]: Tafuri, *Lavoro intellettuale e sviluppo capitalistico* cit.,
pp. 241-81, a p. 280.

[^118]: *Ibid.*, p. 281.

[^119]: Mario Tronti, *Operai e capitale*, Einaudi, Torino 1966, p. 14.

[^120]: Oltre al forte incremento nella produzione di quadri e di
disegni rossiani in corrispondenza dei suoi viaggi negli Stati Uniti e
sotto la spinta del mercato americano, nella seconda metà degli anni
settanta, va ricordato che la prima edizione dell'*Autobiografia
scientifica* è stata pubblicata proprio negli Stati Uniti: Aldo Rossi,
*Scientific Autobiography*, The MIT Press, Cambridge (Mass.) 1981.

[^121]: Su tutti va ricordato ancora il fondamentale Debord, *La società
dello spettacolo* cit.

[^122]: Roberto Esposito, *Pensiero vivente. Origine e attualità della
filosofia italiana*, Einaudi, Torino 2010; Dario Gentili, *Italian
Theory. Dall'operaismo alla biopolitica*, il Mulino, Bologna 2012;
Dario Gentili e Elettra Stimilli (a cura di), *Differenze italiane*,
DeriveApprodi, Roma 2015.

[^123]: Vedi ad esempio Paolo Virno, *Grammatica della moltitudine. Per
una analisi delle forme di vita contemporanee*, DeriveApprodi, Roma
2009; Mario Tronti, *Noi operaisti*, DeriveApprodi, Roma
2009. Un'interessante incursione nel territorio disciplinare è
rappresentato da Marco Assennato, *Linee di fuga. Architettura, teoria,
politica*, :duepunti edizioni, Palermo 2011.

[^124]: Michael Hardt e Antonio Negri, *Impero. Il nuovo ordine della
globalizzazione*, Rizzoli, Milano 2002.

# Le strategie del distacco

> The education of a great intellectual often includes at the moment of
> its beginnings not only the seeds of that person's future development,
> but also the final result[^1].

È sulla scia di questi tentativi che un architetto come Pier Vittorio
Aureli ha ripreso le fila del discorso avviato ormai cinquant'anni fa da
alcuni degli autori citati più sopra -- "*dentro* la società e *contro*
di essa nello stesso tempo" -- con l'evidente intento di analizzarlo non
tanto o soltanto da un punto di vista storico, quanto piuttosto in
un'ottica odierna, e di applicarlo all'ambito dell'architettura e della
città. Nel farlo, Aureli riporta l'attenzione del dibattito
architettonico sul languente fronte della teoria, rendendo quest'ultima
il proprio piano *operativo*. E qui bisogna subito fare attenzione: non
si tratta infatti né di una teoria fine a se stessa, chiusa nel proprio
universo autoreferenziale, né di una teoria dipendente dalla sua
attuazione, dal suo tradursi in "pratica". Tra il piano della teoria e
quello del progetto vi è un'incessante dialettica, in cui entrambe
cooperano per il raggiungimento di un unico fine. Che non è in ogni
caso quello della "realizzazione". Come si vedrà meglio in seguito,
l'operatività del progetto si dispone per Aureli su un terreno
programmaticamente diverso da quello della realtà, almeno in una prima
fase del suo lavoro: una rinuncia a vederne i frutti concreti, o meglio
piuttosto una sua "sottrazione" all'assoggettamento alle dinamiche del
mercato che gli consente di sviluppare il progetto nella pienezza della
sue capacità dimostrative, senza obbligarlo a scendere a compromessi.

Fin dalla sua formazione, compiuta tra lo IUAV di Venezia e il Berlage
Institute di Rotterdam[^2], Aureli dimostra il proprio grado di
consapevolezza nei confronti dei limiti e delle difficoltà che si trova
a dover affrontare un giovane architetto al cospetto di un panorama
contemporaneo di certo non rassicurante da un punto di vista lavorativo.
La sua scelta di lasciare l'Italia per completare i propri studi
all'estero, in questo senso, rappresenta l'espressione di una chiarezza
di idee, di un *progetto* che inizia fin da allora a delinearsi. La
stessa che gli farà raggiungere, nel giro di pochi anni, prestigiose
posizioni di insegnamento: tra le altre, alla Columbia University di New
York, alla Yale School of Architecture di New Haven e all'Architectural
Association School di Londra.

Una chiarezza confermata anche dall'ampiezza di vedute con cui s'accosta
alle tematiche architettoniche. I suoi interessi si appuntano dapprima
sullo studio dei principî insediativi urbani, poi sul concetto di "città
arcipelago", quindi sul tentativo di definizione di un'architettura
*assoluta*[^3]. Fin da subito, l'architettura è concepita non come una
disciplina separata bensì come un crocevia dove si incontrano questioni
sociali, politiche, storiche ed estetiche. Ma soprattutto, prima ancora
che nell'affermazione di un'architettura specifica, vale a dire
nell'elaborazione di una *propria* architettura, l'impegno di Aureli va
in direzione della comprensione delle condizioni di *pensabilità*
dell'architettura in generale nel contesto della città esistente. E ciò
nondimeno, nessun approccio generico all'architettura, nessun suo
inquadramento all'interno di una "mitica" interezza e astoricità. Al
contrario, nell'accostarsi a una sua formulazione teorica, Aureli ne
compie un ripensamento analitico che si muove lungo i solchi della
storia. Raccogliendo la lezione impartita da Manfredo Tafuri nei suoi
corsi universitari allo IUAV e nei suoi libri, Aureli rilegge i momenti
e le opere della storia dell'architettura (e non solo), dei quali si
avvale con un atteggiamento che non ha nulla di vuotamente ostensivo, e
neppure di semplicemente confermativo delle interpretazioni correnti.
Pur non essendo la storia il suo campo d'azione, Aureli fa propria la
concezione storica tafuriana (e benjaminiana) di un passato mai
definitivamente passato, mai "dato per giudicato" una volta per tutte,
bensì piuttosto assimilabile a un campo di forze le cui potenzialità
sono riattivabili e in grado di trasformare ("inquietare", diceva
Tafuri)[^4] il presente.

Ma vi è un altro elemento che Aureli sembra desumere dagli insegnamenti
tafuriani: la necessità di una distanza critica. "La distanza è
fondamentale per la storia"[^5]: è essa che aiuta a non cadere vittime
dell'immedesimazione e delle altre deformazioni derivanti dall'assenza
di "mediazioni". Nel caso di Aureli non si tratta evidentemente di una
distanza da mantenere o da applicare in senso storico: è invece il tempo
presente quello con il quale -- nella misura del possibile -- evitare
d'immedesimarsi, e rispetto al quale dunque cercare di interporre un
"filtro", una forma di "mediazione". Si legga nuovamente Tafuri:

> Lo storico che prende in esame un lavoro contemporaneo deve creare una
> distanza *artificiale*. (...) Il modo che abbiamo di distanziarci
> dalla nostra epoca, e di darci cosí una prospettiva, è quello di
> confrontare le differenze che essa presenta con il passato.

Rispetto all'apparentemente inevitabile immediatezza del tempo presente
Aureli prova a adottare delle forme di *distacco*[^6]. Come si vedrà,
nulla che abbia a che fare con un disinteresse, un disimpegno o
un'estraneazione, e ancor meno con una illusoria mancanza di inerenza
alle condizioni presenti, con una velleitaria "libertà" dai
condizionamenti. La dimensione in cui si colloca il distacco di Aureli
-- ben lungi dall'immaginare alcuna possibile "neutralità" o "alterità"
rispetto alle condizioni presenti -- è quella stessa del "problematico"
in cui si colloca il "progetto" storico tafuriano[^7]. E non è forse un
caso che sia altrettanto in una prospettiva progettuale -- oltreché
teorica -- che Aureli cerchi di declinare il proprio distacco. Anzi, è
proprio in nome di un distacco che in lui trovano un punto di
unificazione attività teorica e attività progettuale, quest'ultima
svolta nell'ambito dello studio Dogma ("L'architettura è come un dogma,
una deliberata decisione sull'indecidibile, una dottrina senza
prova")[^8], fondato nel 2002 insieme a Martino Tattara; uno studio che
elegge programmaticamente a propria sede Bruxelles, in quanto città
"baricentrica" in Europa, oltreché sua capitale[^9]. È proprio questo
impegno progettuale a rendere ancora più significativo lo sforzo di
praticare un distacco; cosí come pure, per converso, è soltanto a
contatto con un'attività operativa che tale distacco acquisisce
pienamente il suo senso.

L'attenzione di Dogma si è appuntata -- in special modo nella fase
iniziale della sua attività -- su progetti a grande scala, culminati con
*Stop City* (2007)[^10], proposta per un modello urbano teorico, e con
*A Simple Heart* (2011)[^11], studio urbano sull'area metropolitana del
nord-ovest dell'Europa. L'aspetto letteralmente sorprendente del primo
progetto -- e tanto più al momento della sua pubblicazione -- consiste
nel modo apparentemente lieve con cui *Stop City* torna a ragionare su
ciò che l'architettura deve avere *in comune* per essere considerata
parte costituente della città. Dopo decenni di architettura che si è
limitata semplicemente a imporre la propria individualità alla città, o
che -- in alternativa -- ha tentato disperatamente di ridarle
un'identità ormai perduta, *Stop City* ha il coraggio (o la
sfrontatezza) d'impostare la questione dell'architettura sul piano della
città, anziché di risolvere la questione della città sul piano
dell'architettura. Lo fa assumendo gli effetti sociali della città
contemporanea (sradicamento, genericità) come propri "attributi politici
(...) ovvero come la forma stessa del "contropiano" dentro e contro la
città post-fordista"[^12].

*A Simple Heart* prende invece esplicitamente spunto dalle riflessioni
sugli effetti della società post-fordista condotte da Paolo Virno e
Giorgio Agamben[^13]. Nel corpo vivo di città come Amsterdam,
Bruxelles, Düsseldorf, Dogma innesta un'enorme cornice quadrata di 800 ×
800 m e alta 20 piani che ha lo scopo di "inquadrare" le condizioni
urbane vigenti (ovvero la trasformazione della città contemporanea in
una "fabbrica sociale" basata sul lavoro vivo, e dunque sui rapporti che
si istituiscono al suo interno tra i lavoratori), facendone al tempo
stesso il dispositivo che rende esplicite tali condizioni. Una
radicalizzazione della situazione esistente, piuttosto che un tentativo
di modificarla, che non si mantiene però indifferente nei suoi
confronti. Ed è interessante che Dogma evochi (come peraltro già fatto
a proposito di *Stop City*) il concetto di *kathecon* (letteralmente,
"ciò che trattiene") desunto dal contesto teologico-politico e qui
reinterpretato come una forza oscillante tra due polarità opposte che
non si oppone al compimento di un processo ma che lo frena aderendo a
esso, "proprio come il concavo aderisce (cosí definendolo) al
convesso"[^14].

In maniera tanto chiara da risultare programmatica, in questi progetti
non c'è né utopia né ironia: lungi dall'essere ipotesi di vita
alternative a quella corrente sulla base di differenti presupposti
sociali o architettonici, o dall'essere invece esasperazioni
caricaturali delle forme di vita metropolitana attuale, essi
costituiscono riflessioni per parole e immagini sul rapporto tra
architettura e città, ovvero sulla possibilità che l'architettura torni
ad avere senso e ruolo nella costruzione della città, e non la città a
rappresentare il luogo di mera accumulazione dell'architettura. Nel
fare ciò Aureli e Tattara evitano accuratamente di caricare
l'architettura da loro proposta di qualsiasi "valore": nessuna
ridondanza estetica, nessuna articolazione morfologica, al di fuori
dell'ossessiva ripetizione di forme elementari e perentorie; e
soprattutto, nessun riguardo per le circostanze effettive del progetto,
nessuna analisi strutturale o distributiva, quasi nessun dettaglio.
Nella misura del possibile, un'*astensione* dall'atto progettuale, o
forse -- ancor meglio -- un'*astrazione* da esso (nel senso in cui si
usa l'espressione "fare astrazione da qualcosa", intendendo cosí di
prescindervi); astensione o astrazione che vale però al tempo stesso
come precisa indicazione del problema: il quale -- con sempre maggiore
frequenza e insistenza negli ultimi decenni -- può essere identificato
nella tendenza a ridurre l'architettura a "oggetto" funzionale
esclusivamente alla creazione -- o al consolidamento -- di un consenso
intorno a operazioni di natura essenzialmente finanziaria; un oggetto la
cui inconfondibile "maschera" assume di sovente le fattezze di
un'iconicità del tutto autoreferenziale.

Da questo punto di vista, la rinuncia a una forma "identitaria" a favore
di una forma "generica" ("un'architettura senza qualità, (...) liberata
dall'immagine, dallo stile, dall'obbligo della stravaganza, dall'inutile
invenzione di nuove forme")[^15], assume per Dogma il valore di una
presa di posizione che non ha nulla a che fare con l'estetica:
piuttosto, l'esortazione a recuperare all'architettura una dimensione
urbana, tornando a farne l'elemento di definizione della *forma* della
città.

Non a caso i due autori, a proposito di *Stop City*, parlano di
"architettura non-figurativa", esattamente come faceva Archizoom a
proposito di *No-Stop City* (1970-71)[^16]: non un'architettura priva di
forma, o di "figura", dunque, quanto piuttosto di "figuratività", ossia
di un'immagine convenzionalmente riconoscibile; in altri termini, si
potrebbe dire, un'architettura non-rappresentativa, non-oggettiva,
proprio come lo è l'arte astratta, che è priva di relazioni con le
apparenze del mondo sensibile; ovvero, nel caso dell'architettura -- in
quanto arte non mimetica -- con le apparenze del mondo architettonico.

In questo duplice principio di "astrazione" è contenuto, sia pure sotto
forma differente, il medesimo atteggiamento di distacco che -- come
detto -- caratterizza la ricerca teorica di Aureli: anzi, si può dire
che ne sia la precisa controparte "operativa". In entrambi i casi la
"presa-di-distanza" che implicano equivale a una presa di coscienza dei
presupposti che sono loro sottesi. Detto altrimenti, per Aureli non vi
può essere progetto -- teorico cosí come architettonico -- che non
soltanto non analizzi nel modo quanto più obiettivo possibile i processi
sui quali esso ineluttabilmente si radica, ma che non rifletta al tempo
stesso sulla propria condizione di necessario distacco/presa-di-distanza
da essi. Infatti, un progetto che aderisse immediatamente (senza alcuna
mediazione, ovvero senza alcuna *meditazione*) ai processi, insomma un
progetto che non si ponesse in una posizione critica (letteralmente: di
messa in crisi) nei confronti dei loro fondamenti, sarebbe un progetto
non soltanto radicato in essi ma interamente determinato, *condizionato*
da essi.

A partire da questo punto si sviluppa la riflessione teorica di Aureli:
affrontando anzitutto la questione dell'autonomia come prima forma di
distacco. Nel primo libro da lui pubblicato, *The Project of Autonomy*
(2008), il tema è sviluppato, non a caso, comprendendo in un unico
abbraccio politica e architettura "Within and Against Capitalism"[^17].
L'autonomia, di questa simultanea e contraddittoria condizione, è
l'incarnazione più esatta: al tempo stesso immersa dentro i processi, e
tuttavia separata da essi. In quanto dotata di un suo proprio *nomos*,
di una norma regolativa sua propria, l'autonomia garantisce il
mantenimento di un'indipendenza, anzi, in una certa misura è la forma
stessa dell'indipendenza, *dentro e contro*.

Oggetto di *The Project of Autonomy* sono le modalità secondo cui si
sono andate determinando posizioni o affermazioni di "autonomia", in
ambito politico e architettonico, intorno agli anni sessanta e settanta.
La simultaneità di tali fenomeni non riveste un ruolo secondario
nell'economia dell'analisi aureliana ma l'aspetto primario è
rappresentato dalle ragioni che hanno portato a fare dell'autonomia uno
strumento -- o in certi casi addirittura un'"arma" -- di lotta,
essenziale all'interno di un ben preciso momento storico.

Per quanto riguarda l'ambito politico, la pratica dell'autonomia è
strettamente conseguente al tentativo di gruppi di intellettuali -- e,
in misura proporzionalmente assai minore, di lavoratori e studenti -- di
conferire nuovo rigore e vigore alla lotta di classe, in un momento
politicamente delicato qual è stato quello attraversato dall'Italia tra
la fine degli anni cinquanta e i primi sessanta, incertamente teso tra
boom economico e apertura di un lungo ciclo di crisi. I luoghi in cui
tale dibattito si sviluppa sono in special modo le riviste
dell'operaismo "classico": in primo luogo "Quaderni Rossi", nata
all'inizio degli anni sessanta e segnata nella sua breve vita dalla
precoce scomparsa del suo fondatore e direttore, Raniero Panzieri[^18];
quindi "Classe operaia", uscita a partire dal gennaio 1964, in seguito
alla scissione da "Quaderni Rossi" da parte di Mario Tronti, cui si
affiancano Alberto Asor Rosa, Sergio Bologna, Massimo Cacciari, Rita Di
Leo e Antonio Negri; infine "Contropiano", diretta (come già detto) da
Asor Rosa e Cacciari tra il 1968 e il 1971.

In questo frangente storico-politico, l'autonomia si presenta
innanzitutto come tattica presa di distanza dalle organizzazioni
ufficiali del movimento operaio: il Partito comunista italiano e i
sindacati, sopra tutti gli altri. Facendo proprio "il punto di vista
operaio"[^19], gli operaisti (cui si è già fatto cenno nel capitolo
precedente) intendevano prendere e dare coscienza della condizione di
sfruttamento della forza lavoro all'interno del sistema capitalistico,
non limitata però soltanto alla classe operaia ma estesa anche alla
borghesia e allo stesso lavoro intellettuale. Al fine di raggiungere
tale obiettivo, se la riappropriazione dei processi produttivi da parte
dei lavoratori -- in termini di auto-organizzazione della cooperazione
del lavoro e di controllo operaio dell'uso delle macchine[^20] --
inquadra ancora i rapporti tra capitale e forza lavoro entro il recinto
chiuso della fabbrica, la "strategia del rifiuto"[^21] del lavoro -- e
dunque l'*autonomia* rispetto a esso -- estende la lotta alla dimensione
sociale e *totale* che è propria del capitalismo compiuto, e al tempo
stesso vale come strumento di riconoscimento da parte della forza lavoro
della propria vera natura. È la separazione della classe lavoratrice
(non della sola classe operaia) dal lavoro, e quindi dal capitale.
Ovvero, come afferma Tronti, "è la separazione della forza politica
dalla categoria economica"[^22]. E non è un caso che, nel processo di
estensione delle dinamiche originariamente interne alla fabbrica
all'intera società, si passi dall'*autonomia operaia* (intesa tanto come
esito di tale separazione quanto come vero e proprio movimento politico
sorto dalle ceneri dell'operaismo) all'*autonomia del politico*[^23],
elaborata dallo stesso Tronti "come possibilità di concepire la storia
della classe operaia (e dunque del Capitale) non solo dal punto di vista
dell'economia politica, ma anche da quello della politica *tout
court*"[^24].

A tale piano di applicazione del concetto e della pratica dell'autonomia
corrispondono secondo Aureli altri piani, non tutti direttamente
collegati all'ambito politico, e ciò nondimeno in un modo o nell'altro a
esso relazionabili. In tal senso in *The Project of Autonomy* egli
riconsidera il modo in cui il progetto dell'autonomia ha preso forma
all'interno del dibattito sull'architettura e sulla città negli anni
sessanta e settanta attraverso il lavoro teorico di Manfredo Tafuri,
Aldo Rossi e Archizoom.

> Per quanto radicalmente differenti, le posizioni di queste tre figure
> centrali dell'architettura italiana degli ultimi cinquant'anni hanno
> condiviso alcuni punti essenziali spesso dimenticati nelle trattazioni
> storiche che hanno affrontato il loro lavoro. Tra i punti che intendo
> mettere in evidenza c'è soprattutto la critica alla
> *professionalizzazione* dell'architettura e al suo ruolo politicamente
> e culturalmente passivo nei confronti delle dinamiche urbane che
> allora segnavano l'impetuoso sviluppo economico italiano ed europeo.
> Inoltre, in modi assai diversi e arrivando a conclusioni opposte tra
> loro, le teorie di Rossi, Tafuri e Archizoom misero in discussione, in
> modi più o meno espliciti, l'orizzonte riformista delle politiche
> urbane del welfare-state, nonché i miti tecnocratici della
> "programmazione economica" e della città-territorio[^25].

In modo particolare, il contributo di Tafuri a un "progetto
dell'autonomia" può essere fatto risalire al periodo in cui
"Contropiano" s'impegna in una vasta e approfondita analisi critica dei
riflessi dello sviluppo capitalistico su diversi contesti e settori
sociali, inserita all'interno di una prospettiva di classe[^26]. In
questo quadro s'inscrive il lungo saggio tafuriano *Per una critica
dell'ideologia architettonica* (1969). "Critica dell'ideologia", in
questo contesto, significa disvelamento dei meccanismi di assimilazione
dell'architettura e della città alle leggi della produzione
capitalistica, ma anche -- e soprattutto -- critica dell'"architetto
moderno *progressista*, ovvero colui che in buona fede credeva fosse
possibile riformare la città capitalista senza fare i conti fino in
fondo con le condizioni in cui essa stessa viene prodotta"[^27]. Alla
constatazione che "la cultura architettonica ha funzionato
consapevolmente o inconsapevolmente come forma di sublimazione delle
sempre più pressanti contraddizioni dello sviluppo urbano"[^28], si
accompagna dunque per Tafuri la presa di coscienza della necessità di
rendere la ricerca storica "autonoma dai condizionamenti ideologici
della professione, soprattutto da quella politicamente
"impegnata""[^29].

Non a caso, in *Per una critica dell'ideologia architettonica* (e poi
nel successivo *Progetto e utopia* che ne costituisce l'evoluzione in
volume), Tafuri riserva una particolare attenzione alla figura e
all'opera di Ludwig Hilberseimer, fino a quel momento marginalizzate
dalla storiografia architettonica. È in esse infatti che egli scorge il
superamento delle "illusioni" legate alla produzione di edifici come
"oggetti" isolati e il riconoscimento della città quale "unità reale del
ciclo di produzione"[^30]: a fronte della quale, per Hilberseimer,
"unico compito adeguato per l'architetto è quello dell'*organizzatore*
di quel ciclo". Alla luce di ciò, "autonomia" giunge a significare
capacità di affrontare radicalmente le condizioni in cui il capitalismo
produce se stesso, senza pensare di poterle eludere.

Differente la concezione dell'autonomia per Aldo Rossi. Nel 1966, con
*L'architettura della città*, egli propone "una teoria della città dal
punto di vista dell'architettura"[^31], secondo l'interpretazione di
Aureli. Non si tratta di una semplice rivendicazione disciplinare,
quanto piuttosto del tentativo di rileggere la realtà della città
attraverso un'"evidenza" storica apparentemente venuta meno agli occhi
dei suoi contemporanei: l'evidenza dei "fatti urbani" come insieme di
oggetti concreti, finiti, definiti, costituiti in ultima analisi di
"materia" architettonica. Detto con le parole di Rossi:
"... l'architettura non rappresenta che un aspetto di una realtà più
complessa, di una particolare struttura, ma nel contempo, essendo il
dato ultimo verificabile di questa realtà, essa costituisce il punto di
vista più concreto con cui affrontare il problema"[^32] della città. Da
ciò discende un modo di intendere l'autonomia dell'architettura che Ezio
Bonfanti, primo esegeta di Rossi, interpreterà correttamente non come
"libertà dell'architettura" bensì come libertà *per* l'architettura,
ovvero come "liberazione della città all'architettura"[^33].

Il progetto dell'autonomia rossiano, in questo senso, va considerato un
progetto *politico*, che prende posizione, e perciò niente affatto
neutrale; un progetto in cui decisione politica e forma urbana
dovrebbero coincidere, in cui l'architettura dovrebbe entrare "come
*parte* contro il *tutto* organico della città". Una "città fatta di
*luoghi*, di fatti singolarmente individuati dentro il piano continuo
dell'urbanizzazione"[^34]. Il concetto di luogo assume un ruolo
determinante nella teoria rossiana della città proprio in virtú del suo
carattere "discretizzante": il luogo si distingue sempre per la propria
finitezza e parzialità, e in quanto portatore di *differenze*. Per
Rossi il luogo -- il *locus* -- è il prodotto del rapporto esistente
"tra una certa situazione locale e le costruzioni che stanno in quel
luogo"[^35]. Tale rapporto -- definito da Rossi "singolare eppure
universale" -- ha a che vedere con la memoria collettiva tanto quanto,
per altri versi, ha a che vedere con il monumento. Ed è in questa
chiave che Aureli rilegge il progetto *Locomotiva 2* di Rossi, Polesello
e Luca Meda per il Centro direzionale di Torino (1962): un grande
edificio a corte (una forma chiusa, emblematicamente contrapposta alle
forme aperte cui si ispiravano le megastrutture e i progetti legati alla
"grande dimensione" e alla "città-territorio" elaborati in quel
periodo)[^36] che si impone all'interno della città per la sua natura di
monumento, associato non a caso alla Mole Antonelliana e al Lingotto di
Giacomo Mattè-Trucco.

> Il colossale edificio sospeso su una grande piazza non solo
> concentrava l'intero programma in una forma chiusa che non avrebbe
> permesso la sua eventuale espansione, ma, attraverso le sue dimensioni
> e la sua forma cosí singolarmente individuata, rendeva esplicita la
> posizione e il significato del nuovo centro direzionale della
> città[^37].

Per quanto non immune da nostalgie "neoclassiciste" o da tentazioni
"totalitarie", il progetto *Locomotiva 2* è la dimostrazione del modo in
cui, secondo Rossi, l'architettura avrebbe potuto farsi al tempo stesso
luogo e monumento, tornando cosí ad assumere il valore di architettura
*della* città, capace di esprimere la propria positiva autonomia[^38].

Nel caso del gruppo fiorentino Archizoom, infine, la questione
dell'autonomia dell'architettura si mescola esplicitamente alla
riflessione sull'autonomia politica elaborata nel corso degli anni
sessanta e settanta dal pensiero operaista, che essi provano a tradurre
in una proposta progettuale, sia pur estrema. Il presupposto da cui
muove Archizoom è che "la città moderna "nasce nel Capitale" e si
sviluppa all'interno della sua logica"[^39]. Pertanto i progetti del
gruppo mostrano un'"adesione totale ed enfatica alle condizioni
esistenti della città capitalista nella quale l'architettura non doveva
riformare, bensì radicalizzare le condizioni esistenti"[^40]. Si tratta
in una certa misura di un'attitudine *realista*, nel senso in cui lo è
-- nota Aureli -- la pop art che gli stessi membri di Archizoom
riprendono esplicitamente, soprattutto nei loro primi progetti: "Per
Archizoom la pop art rappresentava l'emergere di una cultura estetica
distruttiva dentro e contro l'estetica borghese". Ed è proprio un
"realismo pop", ossessivamente ripetitivo, di stampo warholiano (in
nulla imparentato, dunque, con il *neo*-realismo prevalente in Italia
nel corso del ventennio precedente) quello che Archizoom utilizza per
caratterizzare il Piano abitativo continuo e i Residential Parkings
della *No-Stop City*:

> L'estensione infinita dei "parcheggi residenziali" rappresentava il
> compimento estremo dello sviluppo capitalista e, al tempo stesso, il
> momento in cui lo sviluppo -- con la sua sovrabbondanza di merci e di
> conoscenza connessa ai processi di produzione -- avrebbe messo in
> crisi proprio la dipendenza dal lavoro salariato e dal suo apparato
> sociale e politico. Per questo la *No-Stop City* era proposta da
> Archizoom come l'antitesi dell'edilizia sociale che, dietro la
> facciata benevola dell'assistenza sociale, manteneva un regime di
> scarsità calcolata, strumentale a preservare la necessità del lavoro.
> La *No-Stop City* avrebbe dovuto essere intesa non come un'utopia ma
> come un esperimento nel quale tendenze già in atto venivano portate
> alle estreme conseguenze per verificarne gli effetti politici. La
> *No-Stop City* era dunque un progetto *propositivo* solo nella misura
> in cui rendeva intelligibili le condizioni stesse della città
> capitalista[^41].

La riproduzione infinita delle residenze assimilate a "parcheggi", cosí
come quella degli altri spazi che compongono la *No-Stop City*,
direttamente desunti dai modelli per eccellenza della società
capitalista -- la fabbrica e il supermarket --, nel costituirne
l'apparente affermazione, significa in realtà per Archizoom liberare la
città dall'architettura (ovvero l'esatto contrario di quanto affermato
da Bonfanti, citato in precedenza). Liberarsi dell'architettura
equivale a rifiutarne ogni valore simbolico-rappresentativo,
riportandola esclusivamente ai meccanismi della sua produzione; ciò che
comporta far evolvere la città capitalista fino alle sue conseguenze
ultime. "Solo in questo modo -- afferma Archizoom -- possiamo
interrompere la continuità del sistema produttivo e l'insieme dei suoi
collegamenti"[^42]. Al massimo di integrazione (vale a dire di
alienazione) sarebbe dunque corrisposto il massimo di possibilità di
libertà.

Di non minore importanza, agli occhi di Aureli -- e in realtà
strettamente connesso alle questioni precedenti -- è il fatto che
Archizoom, come per altri versi Tafuri,

> ... aprirono per l'architettura lo spazio di una critica irriducibile,
> ovvero di un'autonomia della critica dall'ideologia della città che,
> (...) nel caso di Archizoom, divenne autonomia del progetto dalla sua
> realizzazione costruita[^43].

Ed è proprio nella "validità in sé del progetto come *teoria*"[^44] che
per Aureli pare racchiudersi il senso più profondo del progetto
dell'autonomia: l'autonomia stessa della teoria. Nelle pagine finali di
*The Project of Autonomy*, Aureli si pone -- e pone al lettore -- una
domanda: "Perché tornare a considerare *il progetto
dell'autonomia*?"[^45]. La domanda apre ad alcune considerazioni che
(retrospettivamente) cercano di porre la lettura del libro in una
corretta prospettiva. Innanzitutto, spiega Aureli, il libro non va
letto in chiave post-moderna, come celebrazione della post-politica che
ha trionfato a partire dalla fine degli anni settanta. Nel prendere le
distanze da questa possibile interpretazione, egli dichiara la propria
affinità con le figure trattate nel libro e la propria adesione alle
posizioni da loro sostenute. Tale "presa di partito" sposta
completamente il significato di *The Project of Autonomy*, che
altrimenti potrebbe essere letto come un saggio storico distaccato,
"oggettivo", teso semplicemente a ricostruire un periodo circoscritto
della recente vicenda italiana e, all'interno di esso, una specifica
"attitudine" politica declinata in vari ambiti e secondo modalità
differenti. E invece, a fianco di tale ricostruzione, che impegna in
realtà la gran parte della trattazione, nelle righe finali del libro
Aureli riconosce la *sconfitta* che il progetto dell'autonomia ha dovuto
subire; una sconfitta impartitagli

> ... dal capitalismo che negli ultimi anni ha costretto la sinistra ad
> abbandonare tutto il suo bagaglio storico e culturale, a cominciare
> dalle sue parole chiave come conflitto, classe e, appunto,
> capitalismo[^46].

Non è compito né intento di Aureli analizzare le cause e le conseguenze
di questa sconfitta. Ciò che si ripromette è invece qualcosa di ancora
più difficile: provare a individuare una via d'uscita dall'impasse di
una cultura (politica non meno che architettonica) che si trovi a fare i
conti con la scomparsa di qualsiasi ideale alternativo alla realtà del
capitalismo, e conseguentemente al trionfo di quest'ultimo. Per farlo,
scrive, "diventa urgente e necessario cercare nuovi modi di pensare e
costruire una nuova soggettività politica". Ed è alla luce di ciò che
la lezione dell'operaismo (comprese le sue rielaborazioni in ambito
architettonico compiute nel corso degli anni sessanta e settanta), da
cui il filone principale del progetto dell'autonomia discende, torna a
essere utile:

> La lezione che oggi possiamo trarre dal lavoro di Tafuri, Rossi e
> Archizoom va al di là di facili *repêchage* e indica che nella
> *teoria* vi è qualcosa di irriducibile alla pratica dell'architettura
> come professione[^47].

L'autonomia della teoria, in questo senso, non vale soltanto come
un'indicazione metodologica ma assume un valore paradossalmente
*operativo*. All'interno del "contesto" del capitalismo quale unico
orizzonte di realtà attualmente possibile, la teoria assume la
fondamentale funzione di disinnescare la "coazione ad agire" e a
svilupparsi in concreto, che è propria di questo, fornendo una
prospettiva diversa, quantomeno pensabile. Da questo punto di vista,
l'architettura intesa in senso teorico può rappresentare una "forma di
conoscenza", un "modo di comprendere le cose" in cui è in gioco la
possibilità di pensare, criticare e persino "cambiare lo spazio in cui
viviamo". *Dentro* la realtà del capitalismo e al tempo stesso *contro*
di esso.

Il secondo libro pubblicato da Aureli, *The Possibility of an Absolute
Architecture*[^48], declina in una seconda accezione la tematica del
distacco. Lo fa avendo il coraggio di riaccostarsi ancora una volta ai
luoghi *più* comuni della disciplina architettonico-urbanistica;
mantenendosi distante dall'usanza, assai diffusa negli ultimi anni, di
"creare" nuovi concetti per cercare di spiegare una realtà contemporanea
spesso vista come inesorabilmente "mutante" rispetto al passato, e
dunque del tutto inconciliabile con questo; ma al tempo stesso senza
cedere alla tentazione -- altrettanto diffusa e frequente -- di
rifugiarsi nella sterile negazione della realtà, o di farsi paladino di
una critica programmaticamente "contro"[^49].

Non soltanto la gran parte dei progetti e degli oggetti architettonici
scelti da Aureli per sostenere il proprio discorso sono tra i più noti e
citati dalla storia e dalla critica architettonica, ma anche i concetti
e i termini a cui egli fa ricorso sono tra i più "basilari" e consueti
in questo settore: a partire dal campo stesso d'indagine da lui preso in
considerazione, il territorio che abbraccia architettura e città.

È proprio su questo terreno che si lasciano misurare fin da subito il
coraggio e la "portata" del libro di Aureli: esso infatti prova a
ristabilire un nesso intrinseco tra architettura e città, non più però
sulla scorta delle "ragioni" morfologico-tipologiche che ormai
cinquant'anni fa avevano guidato le ricerche, tra gli altri, di Aldo
Rossi e Carlo Aymonino. E neppure lo fa ricorrendo ad alcuna delle
tante "sociologie della città" (o della metropoli) correnti ai nostri
giorni. È piuttosto dalle categorie del "politico" e del "formale" --
categorie fondative e in una certa misura "preliminari" rispetto al
campo considerato -- che il suo discorso prende le mosse. Nel primo
capitolo, *Toward the Archipelago*, lasciando momentaneamente da parte
gli "avanzamenti" e gli "aggiornamenti" disciplinari, Aureli fa ritorno
ai fondamenti. E sono le parole, anzitutto, che egli interroga alla
ricerca del loro senso perduto, o rimosso. A partire dall'etimologia di
*ab-solutus* (sciolto da), l'aggettivo che qualifica la sua *idea* di
architettura: "qualcosa che è risolutamente se stesso dopo che è stato
"separato" dal suo altro"[^50]. Da ciò discende che "la condizione
effettiva della forma architettonica è di separare ed essere separata".

Aureli palesemente non è interessato all'aspetto formale
dell'architettura in senso estetico-figurativo: ciò che vuole mettere in
luce è la natura finita della *form*, non la sua *shape*. Il problema
della forma è dunque quello stesso del *limite*. Come già cent'anni fa
rilevava Georg Simmel:

> Il segreto della forma sta nel fatto che essa è confine; essa è la
> cosa stessa, e nello stesso tempo, il cessare della cosa, il
> territorio circoscritto in cui l'Essere e il Non-più-essere sono una
> cosa sola[^51].

Assumere come punto di partenza del discorso su architettura e città la
questione della forma *in quanto limite* significa additare come
fondamentale la questione delle *differenze*. I limiti infatti *sono*
le differenze. "Nel suo separare ed essere separata, l'architettura
rivela *in uno* l'essenza della città e la propria stessa essenza come
forma politica: la città come composizione di parti (separate)"[^52].
Il legame tra architettura e città, allora, non è qualcosa che
scaturisce dall'assunzione di uno specifico punto di vista interno alla
disciplina, quanto piuttosto qualcosa che appartiene già da sempre --
*ontologicamente* -- alla relazione dialettica che connette tra loro le
componenti che vi entrano in gioco. Questo legame si dà nella forma
della "composizione delle differenze"[^53]. In ciò consiste, in
definitiva, la città: architetture conviventi nel loro radicale
differire. E qui le differenze non vanno intese tanto in senso
tipologico o funzionale bensì in senso *formale*, come *oggettivazione
di un limite*.

Per Aureli l'idea di un'architettura *assoluta* si traduce
"concretamente" in una serie di isole chiare e distinte, relazionate tra
loro nella forma dell'*arcipelago*. La parola "arcipelago" non è certo
inedita nell'ambito del discorso architettonico e urbano degli ultimi
anni. Prima di lui l'avevano utilizzata tra gli altri -- a diverso
titolo e con diverse accezioni -- architetti come Oswald Mathias Ungers,
il giovane Koolhaas, studiosi come Colin Rowe, ma pure filosofi come
Massimo Cacciari[^54]. E tuttavia, nell'impiego che egli ne fa non vi è
traccia di alcuna sudditanza nei confronti di tali autori (che pure
cita), né alcuna dipendenza da "ricuperi" più o meno recenti o alla moda
di essi; anzi, proprio il fatto di impiegarla dimostra la sua totale
indifferenza nei confronti di questi.

D'altronde, per lui quella dell'arcipelago non è affatto una metafora,
un'espressione figurata da lasciar cadere non appena questa abbia finito
di svolgere il compito di portare là dove si voleva essere condotti.
Semmai egli intende l'arcipelago come un "archetipo", un paradigma
spaziale che, fin dalla Grecia antica, esprime una ben precisa (benché
non aprioristicamente definita) relazione tra corpi: una pluralità di
enti differenti (sia pure tra di loro congeneri), più o meno raggruppati
o sparpagliati, ma in qualunque caso *discontinui*: "Il concetto
dell'arcipelago descrive una condizione in cui le parti sono separate
ancorché unite dal terreno comune della loro giustapposizione"[^55]. È
questa condizione topologica che Aureli pensa come nesso essenziale tra
architettura e città, e in ultima analisi come forma stessa della città.

Ma in quale senso va inteso quest'ultimo termine? Ben lungi dall'essere
utilizzato in modo casuale o generico, anche il termine "città", nel
libro di Aureli, viene vagliato sotto il profilo etimologico nelle sue
diverse versioni: *polis*, *civitas* e *urbs*. E se la *polis* greca
raccoglie entro i suoi limiti dati i *polites* che la abitano come una
comunità omogenea per *genos*, *logos* ed *ethos*; se la *civitas*
romana equivale alla somma dei suoi *cives*, che hanno tra loro in
comune il "diritto" di occupare lo spazio che li ospita, è invece
l'*urbs* a incarnare nel modo più compiuto la costruzione materiale
della città:

> Mentre la *polis* greca era la città strettamente circoscritta entro
> il suo perimetro murato, l'*urbs* romana non era pensata per essere
> limitata, e di fatto si è espansa nella forma di un'organizzazione
> territoriale, in cui le strade hanno giocato un ruolo cruciale[^56].

Sarà proprio l'*urbs*, infatti, a divenire nel corso della storia la
"specie" di città planetariamente dominante, e addirittura l'unico
modello di aggregazione umana apparentemente possibile. Ildefons Cerdà,
l'ingegnere e urbanista iberico del XIX secolo, ha introdotto per la
prima volta il termine "urbanizzazione" per esprimere la condizione di
illimitatezza e la completa integrazione di movimento e comunicazione
determinata dal capitalismo. È questo "vasto e turbinante oceano di
persone, di cose, di interessi di ogni sorta, di migliaia di elementi
diversi"[^57], secondo le sue parole, che definisce con esattezza la
realtà delle città odierne, il loro *status* di metropoli *oltre* la
metropoli, senza più centro o periferia.

> L'essenza dell'urbanizzazione è dunque la distruzione di ogni limite,
> confine o forma che non sia l'infinita, compulsiva ripetizione della
> propria stessa riproduzione e il conseguente meccanismo di controllo
> totalizzante che garantisce questo processo di infinitezza[^58].

È in opposizione al mare dell'urbanizzazione, dilagante a macchia d'olio
e di fatto ormai sconfinata, che Aureli propone la sua idea di città:
che, se non si limita a confermare le condizioni attualmente esistenti,
non coltiva però neanche alcuna illusione di poter ricreare le
condizioni di esistenza di una *polis* organica. La città-arcipelago
non è pensata in alternativa alla realtà dell'urbanizzazione ("non c'è
via di ritorno dall'urbanizzazione")[^59]: semmai come integrativa di
essa. In questo senso, nella concezione di Aureli, la città-arcipelago
risulta inevitabilmente immersa nel mondo dell'urbanizzazione, e
affiorante da esso nella forma di un sistema discreto di architetture
finite, limitate, distinte; isole, appunto, che non arrivano mai
tuttavia a costituire un intero.

Si tratta di un'idea di architettura che reagisce criticamente alla
realtà dell'urbanizzazione, un'idea per formulare la quale Aureli arriva
a equiparare le categorie -- tra di loro apparentemente estranee -- del
"politico" e del "formale"[^60] quali espressioni entrambe del *limite*.

> Il politico ha luogo nella decisione in merito a come articolare la
> relazione, lo spazio *infra*, lo spazio *in between*. Lo spazio *in
> between* è un aspetto costitutivo del concetto di forma, fondato sulla
> contrapposizione delle parti. Cosí come non c'è un modo per pensare
> il politico all'interno dell'uomo stesso, non c'è neppure un modo per
> pensare lo spazio *in between* in se stesso. Lo spazio *in between*
> può materializzarsi soltanto come uno spazio di confronto tra le
> parti. La sua esistenza può essere decisa soltanto dalle parti che
> formano i suoi margini[^61].

A un capitolo a carattere eminentemente teoretico e fondativo ne seguono
altri quattro dedicati ad altrettanti "casi" storici: l'architettura di
Palladio e il progetto di una città anti-ideale; il Campo Marzio di
Piranesi *versus* la pianta di Roma del Nolli; l'architettura di Boullée
come "stato di eccezione"; l'idea di *City within the City* in Ungers e
Koolhaas. In questi capitoli Aureli mostra una solida conoscenza
dell'architettura e della sua storia. Ma non è strettamente da questo
punto di vista che vanno letti. La ragione di tali approfondimenti non
è quella di presentare documenti "inediti" o di fornire nuove
interpretazioni di cose già note. Essi piuttosto sono funzionali al
discorso di Aureli, che in questo modo cerca nel passato gli "indizi
probatori" -- o piuttosto gli adeguati "sostegni" -- della propria
teoria.

Non mancano, in questi capitoli, alcune forzature (basti pensare -- a
titolo esemplificativo -- all'applicazione alle architetture disegnate
di Boullée della categoria schmittiana-agambeniana dello "stato di
eccezione")[^62]. Sarebbe tuttavia pedante, oltreché in fondo inutile,
rimproverare ad Aureli un uso troppo disinvolto della storia, dal
momento che è proprio un uso troppo rigido e poco interessante della
storia che si può e si *deve* spesso rimproverare agli storici "di
professione". Le "forzature" di Aureli vanno dunque lette come
positivamente strumentali alla sua costruzione teorica, non diversamente
da quanto si potrebbe fare con alcuni testi di Robert Venturi, Peter
Eisenman o Rem Koolhaas, dove la storia è dichiaratamente -- e in fondo
non illegittimamente -- reinterpretata in chiave contemporanea.

La *finitio* classica palladiana, la sommatoria di edifici privi di
"tessitura" urbana del Campo Marzio piranesiano, la sequenza di edifici
pubblici monumentali di Boullée come "progetto per una metropoli", la
città "fatta di isole" dei progetti di Ungers, servono tutte ad Aureli
per dimostrare l'esistenza storica del rapporto tra architettura e città
nel medesimo senso in cui egli stesso lo afferma.

L'indicazione immediata che scaturisce da tutto ciò è la necessità di un
radicale ripensamento dell'architettura rispetto alla logica che informa
gli edifici "iconici" contemporanei: *landmarks* "solisti" che si
inseriscono perfettamente nella trama senza fine dell'urbanizzazione.
Contro tale logica, Aureli propone come modello di architettura per la
città-arcipelago l'isolamento e l'innalzamento dell'edificio sopra un
basamento (*plinth*), come dimostrativamente illustrato nel progetto
koolhaasiano *The City of the Captive Globe* (1972), o come
insistentemente ribadito nella gran parte dei progetti e degli edifici
di Mies van der Rohe. È proprio da una rilettura in tal senso delle
opere miesiane -- dal Padiglione di Barcellona (1929) alla
Nationalgalerie di Berlino (1962-68), passando per il Seagram Building
di New York (1954-58) -- che Aureli trae il miglior paradigma
*realizzato* della propria teoria e che la tesi del libro trova una sua
persuasiva conferma: "I basamenti di Mies reinventano lo spazio urbano
come un arcipelago di artefatti urbani definiti"[^63]. E ancora:

> Il basamento introduce un arresto nella fluidità dello spazio urbano,
> evocando cosí la possibilità di comprendere lo spazio urbano non come
> ubiquo, pervasivo e tirannico, bensì come qualcosa che può essere
> inquadrato, limitato, e in tal modo potenzialmente situato come cosa
> tra altre cose[^64].

La lezione di Mies viene cosí assunta per la sua capacità di definire
un'architettura che è al tempo stesso "un'attitudine particolare nei
confronti della città". Secondo Aureli, questa attitudine a inquadrare
e a delimitare deve essere sviluppata "sia come forma materiale di
architettura sia come principio politico di progettazione"[^65].

È una tale attitudine che, opponendosi alla generalizzata
omogeneizzazione contemporanea, ovvero alla "confusione" delle
differenze (o piuttosto, alla loro insistente e colpevole negazione),
rende possibile quella *composizione delle differenze* che si è citata
più sopra. In questo senso,

> ... l'architettura assoluta come forma finita non è semplicemente
> l'affermazione tautologica dell'oggetto in quanto tale; è anche il
> paradigma per una città non più guidata da un *ethos* di espansione e
> inclusione bensì dall'idea positiva di limiti e confronto[^66].

È su questo piano che architettura e città tornano a trovare un punto di
incontro necessario:

> La parte è *assoluta*; essa sta in solitudine, ma assume una posizione
> rispetto al tutto dal quale è stata separata. L'architettura
> dell'arcipelago deve essere un'architettura assoluta, un'architettura
> definita dalla -- e che rende chiara la -- presenza dei *limiti* che
> definiscono la città[^67].

Ed è ugualmente su questo piano che "formale" e "politico" s'incontrano
e dimostrano di poter costituire una cosa sola.

> Invece di sognare una società perfettamente integrata che può essere
> ottenuta soltanto come supremo compimento dell'urbanizzazione e del
> suo *avatar*, il capitalismo, un'architettura assoluta deve
> riconoscere la separatezza politica che potenzialmente si può
> manifestare, nel mare dell'urbanizzazione, attraverso i confini che
> definiscono la possibilità della città.

È qui -- più e meglio che altrove -- che si lascia riconoscere il già
ricordato coraggio di Aureli: nell'affermare, oggi, la *separatezza*
(ovvero, ancora una volta, la differenza) come un valore *politico*, non
*anti*-politico: l'unico -- l'ultimo -- modo, forse, per poter stare
*insieme* davvero. L'identico coraggio che lo porta a sostenere,
nell'ormai completo e generalizzato asservimento delle idee alla loro
"verifica" pratica, l'*autonomia della teoria*. In questo senso, se con
*The Possibility of an Absolute Architecture* egli definisce con tutta
evidenza il campo operativo in cui si muove come architetto, è
significativo però che rinunci a presentare nel libro i propri progetti:
una rinuncia che è nel contempo la miglior "dimostrazione" *in azione*
del suo stesso discorso sul limite.

La terza riflessione che Aureli affida a un sia pur piccolo volume ruota
intorno ai medesimi concetti di distacco e rinuncia, declinati con
accenti ancora una volta diversi. Rispetto ai due precedenti, *Less Is
Enough* è non soltanto un libro molto più agile, ma anche assai meno
focalizzato sull'architettura; questo aspetto però -- ben lungi dal
rappresentare un'indebita deviazione dal "percorso principale", o
addirittura una negazione di esso -- costituisce invece la riprova
dell'ampiezza del discorso *intellettuale* di Aureli[^68].

"Per molti anni *less is more* è stato il tormentone del
minimalismo"[^69]: l'*incipit* del libro prende le mosse dalla notissima
frase citata da Ludwig Mies van der Rohe nel corso di un'intervista del
1959. La ragione per cui Aureli ritorna su un *topos* tanto frequentato
e tanto citato (spesso a sproposito) dalla cultura architettonica è
quella che "in anni recenti, e specialmente a partire dalla recessione
economica del 2008, l'attitudine per il *less is more* è nuovamente
tornata di moda". Non a caso, dopo i fasti degli anni novanta e
dell'inizio del XXI secolo, segnato dalla proliferazione di edifici
iconici, la riduzione delle risorse e dei budget si è tradotta per
alcuni architetti nella scelta di una maggiore austerità formale, e per
altri in un approccio più attento al sociale. Ciò che accomuna tali due
atteggiamenti -- pur tra di loro diversi -- è l'opportunità di "fare di
più con meno", ciò che rende il *less is more* un imperativo economico,
più ancora che estetico.

> All'interno della storia del capitalismo *less is more* definisce i
> vantaggi della riduzione dei costi di produzione. I capitalisti hanno
> sempre cercato di ottenere di più con meno. Il capitalismo non è
> soltanto un processo di accumulazione ma anche, e specialmente,
> l'incessante ottimizzazione del processo produttivo verso una
> situazione in cui *meno* investimento di capitale equivale a più
> accumulazione di capitale[^70].

In una situazione di crisi economica, ciò che il capitale domanda è più
lavoro per meno denaro, più creatività con meno sicurezza sociale.

La condizione di ristrettezza economica e la propensione estetica per il
*less is more* sembrano convergere nella tradizione dell'ascetismo.
Questo termine (dal greco *askein*, esercizio, auto-addestramento)
indica comunemente, in ambito religioso, il ritiro dal mondo, la pratica
dell'astinenza dai piaceri mondani, propria degli eremiti e dei monaci.
In anni più recenti "l'ascetismo è stato invece identificato come la
fonte ideologica e morale dell'idea di austerità"[^71]. In senso
secolare, l'ascetismo equivale alla libertà dalle distrazioni mondane al
fine di dedicarsi interamente all'etica del lavoro e della produzione.
Questa seconda versione dell'ascetismo per Max Weber sta a fondamento
dell'etica del capitalismo[^72]. Come egli spiega, con il calvinismo si
registra l'uscita dell'ascetismo dai confini del monastero e la sua
trasformazione in una mentalità diffusa nelle città. L'ascetismo si
avvia in tal modo a divenire la disciplina di una razionalità etica
destinata a costituire il fondamento dello stile di vita borghese, e in
quanto tale a rappresentare il vero "spirito" del capitalismo.

Pur considerando questa lettura dell'ascetismo, Aureli ne abbraccia una
differente: "proprio perché la pratica dell'ascetismo persegue la
trasformazione del sé, sostengo che esso può essere sia un mezzo di
oppressione che una forma di resistenza al potere soggettivo del
capitalismo"[^73]. Nell'ascetismo i soggetti si focalizzano sulla loro
vita come il cuore della loro pratica, strutturandola in accordo con una
forma autodeterminata fatta di specifiche abitudini e regole. Di
conseguenza anche l'architettura che è connessa con questa pratica non è
focalizzata sulla rappresentazione ma sulla vita stessa, sul *bios*,
come il più generico substrato dell'esistenza umana. Lo stesso sviluppo
dell'architettura moderna, attenta all'igiene, al comfort e al controllo
sociale, è stata guidata da una logica biopolitica. Ma è soprattutto
nella storia del monachesimo, dove l'architettura del monastero era
espressamente progettata per definire la vita in tutti i suoi dettagli
più immanenti, che l'ascetismo trova il suo più significativo
compimento. Alle origini il principale proposito dell'ascetismo
monastico era di ottenere "una forma di reciprocità tra soggetti liberi
dal contratto sociale imposto dalle forme di potere"[^74], ed è sulla
scorta di questa possibilità che Aureli si domanda se l'ascetismo possa
condurci a un tipo di vita differente da quella imposta oggi dalle
società dominanti.

Nel prendere in considerazione questa possibilità, Aureli evidenzia come
l'ascetismo sia una pratica del sé, prima ancora di essere
esplicitamente rivolta al culto religioso; una pratica che in modo
intrinseco mette in questione le condizioni sociali e politiche date,
alla ricerca di un modo differente di vivere la propria vita. Del
resto, anche la scelta della vita monacale costituiva "un modo di
rifiutare l'integrazione della fede cristiana nelle istituzioni di
potere"[^75]. La radicale critica del potere condotta dal monachesimo
delle origini si manifestava sotto forme di opposizione non violenta:
come il rifiuto della casa e di qualsiasi ruolo all'interno della
società, e più in generale come un pacifico distacco.

Nell'evoluzione del monachesimo si registra il passaggio dalla
solitudine eremitica alla vita cenobitica (cenobio = *koinos bios*, vita
comune), in cui i monaci vivono nello stesso luogo e condividono la
stessa regola. Nel monastero la vita in comune non contraddice la
possibilità di stare da soli. "La rigorosa organizzazione del monastero
non intendeva rimpiazzare la vita con una regola, ma piuttosto rendere
la regola cosí coerente con la forma di vita scelta dai monaci che la
regola avrebbe potuto addirittura scomparire"[^76]. Da una tale
condizione deriva una forma di reciprocità fraterna in cui nessuno tende
a prevalere sugli altri; ed è proprio nell'organizzazione fisica del
monastero che si lascia rintracciare una possibile traduzione spaziale
della già citata *convivenza delle differenze*.

Da notare la convergenza di interessi sul tema dell'organizzazione
dell'architettura monastica tra Aureli e Rossi. Scrive infatti
quest'ultimo in un quaderno dell'inizio degli anni settanta, rimasto
inedito:

> La forma tipologica del convento è importantissima perché ci offre un
> tipo di abitazione dove la questione tipologica costituisce la stessa
> struttura organizzativa e dove, forse per la prima volta, vediamo
> sorgere un edificio collettivo potendone seguire tutta la genesi. La
> tipologia conventuale è riportabile a due soluzioni fondamentali: la
> prima quella benedettina e la seconda, più tarda, quella certosina.
> (...) Le due concezioni entrambe di straordinario interesse permangono
> vive come riferimento al mondo moderno e come da un lato accolgono
> tradizioni antiche, dall'altro sono il nucleo formale per le ipotesi
> moderne più avanzate nel campo della forma della città[^77].

Ma altrettanto significativo è che, approfondendo il discorso sugli
ordini monastici, Aureli si soffermi piuttosto su quello francescano.
Come sottolineato da Agamben[^78], i primi francescani rigettavano
l'idea della proprietà privata, non soltanto nella forma del possesso
individuale di beni ma anche in quanto possesso di capitale potenziale,
sotto forma di terra o di strumenti per lavorarla o, ancora, di possesso
del lavoro altrui. La forma di vita a cui aderivano i francescani,
modellata sulla vita evangelica, prevedeva semplicità, castità e
povertà; un'*altissima paupertas* che si estendeva anche a ciò che
comunemente è considerato appartenente "di diritto" al soggetto
individuale: la propria persona (affidata totalmente a Dio), il proprio
tempo (gestito dai superiori e dai confratelli), il proprio cibo
(soltanto consumato e non accumulato). In luogo della proprietà
privata, dunque, i francescani delle origini si limitavano a usare, vale
a dire ad appropriarsi temporaneamente di ciò che serviva loro. Ed è
proprio nell'uso come condivisione di qualcosa che si dà la forma
suprema del vivere in comune.

Per Aureli tali pratiche possono tornare ad assumere un senso nel mondo
contemporaneo, al di fuori di una prospettiva religiosa. Già negli anni
trenta Walter Benjamin, a seguito di quanto descrive come un
"impoverimento dell'esperienza", effetto tra i più devastanti della
prima guerra mondiale, parla di una "nuova barbarie", e si domanda: "A
cosa mai è indotto il barbaro dalla povertà di esperienza? È indotto a
ricominciare da capo; a iniziare dal nuovo; a farcela con il poco"[^79].
Benjamin dunque identifica gli aspetti più tragici dell'esperienza
moderna -- lo sradicamento culturale e territoriale e la precarietà
della vita in generale -- e li trasforma in una forza emancipante che
egli definisce "carattere distruttivo": "Il carattere distruttivo
conosce solo una parola d'ordine: creare spazio; una sola attività: far
pulizia. Il suo bisogno di aria fresca e di uno spazio libero è più
forte di ogni odio"[^80].

Spinto da circostanze storiche ed esistenziali, ma anche dall'adesione a
un modello di vita che Charles Baudelaire (suo beneamato e ammirato
"eroe") gli aveva ispirato, Benjamin vive in prima persona la condizione
di sradicamento e di precarietà. Come un monaco mendicante, Benjamin
riduce al minimo i suoi beni personali per usare la città stessa come
una vasta abitazione.

A ideale *pendant* di questa condizione di vita, Aureli pone la Co-op
Zimmer elaborata da Hannes Meyer in occasione della Mostra delle
cooperative a Gent (1924): un progetto concepito nella prospettiva di
una società senza classi, in cui ogni membro dovrebbe avere a
disposizione la medesima dotazione economica minima. Anche
l'arredamento è ridotto allo strettamente essenziale in questo perfetto
esemplare di *Existenzminimum*: poche mensole, due sedie pieghevoli, un
letto singolo. Soltanto la presenza di un grammofono dimostra che non
si tratta di "uno spazio dettato esclusivamente dalla "necessità", ma
anche predisposto per un tempo "improduttivo""[^81]. Questa stanza è
realizzata da Meyer non come forma di possesso bensì come spazio minimo
individuale che prevede di condividere altri spazi collettivi. "Qui la
vita privata (*privacy*) non è la proprietà (*property*), bensì
piuttosto la possibilità di godere di uno stato di solitudine e di
concentrazione"[^82]. Diversamente da Mies van der Rohe, dunque, per
Meyer "less is not more, less is just enough"[^83]. Per lui la povertà
non costituisce semplicemente una privazione, ma può arrivare a
rappresentare addirittura un valore, una condizione paradossalmente
lussuosa, che suggerisce "un senso di calma e di edonistico godimento".

Ma anche nella situazione sociale attuale, in cui da un lato per far
ripartire l'economia viene "suggerito" di consumare di più ma dall'altro
vengono diminuiti i salari e tagliate le forme di protezione sociali,
l'ascetismo può "ridefinire ciò che è realmente necessario e cosa non lo
è, al di là del regime di scarsità imposto dal mercato"[^84]. È in
questo contesto che l'ascetismo può rappresentare la possibilità di
riconquistare una miglior condizione di vita, vivendo con meno, senza
trasformare tale "meno" in un'ideologia: "less is *not* more, less is
just less". Soltanto oltrepassando la sua aura ideologica, il meno può
divenire il punto di partenza per una forma di vita alternativa che
superi al tempo stesso i falsi bisogni imposti dal mercato e le
politiche di austerità imposte dal debito. In questa prospettiva "*less
is enough* è un tentativo di definire un modo di vivere che vada oltre
la promessa di crescita e la minacciosa retorica della scarsità"; un
modo di vivere ascetico che pone al centro se stessi, ma che offre anche
la possibilità di una condivisione di spazi con altri.

Ed è forse proprio questa la condizione corrispondente a quello che Marx
definisce l'"essere sociale" dell'individuo[^85]\: una condizione che
questi vede insidiata dalla proprietà privata e che -- all'opposto --
può essere pienamente riattivata da una forma di reciprocità basata non
sul possesso ma sulla condivisione: dove il meno che si ha in termini di
possesso, diviene il più che si ha da condividere.

> Dire *enough* (anziché *more*) significa ridefinire ciò di cui abbiamo
> realmente bisogno al fine di vivere (...) una vita distaccata
> dall'ethos sociale della proprietà, dall'ansia della produzione e del
> possesso, e dove *less is just enough*[^86].

Autonomia, assolutezza, ascetismo: questi tre concetti, e i relativi
riflessi che essi hanno nella vita concreta, nei rapporti sociali,
nell'organizzazione spaziale, hanno tutti in comune -- come già rilevato
-- una forma di *distacco*. Una simile condizione si rivela
indispensabile per chi, come Aureli, intenda accostarsi alle questioni
contemporanee (non soltanto quelle relative al ristretto ambito
architettonico, bensì tutte quelle a cui quest'ambito sia in qualche
modo rapportabile) senza farsene "assorbire"; non limitandosi
semplicemente a ripetere e a far proprie opinioni diffuse e consolidate
a loro riguardo, e cercando piuttosto di affrontarle *ripensandone le
condizioni dall'interno*. È precisamente questa attitudine che
caratterizza l'architetto intellettuale, e l'intellettuale in generale:
la capacità di penetrare nelle cose mantenendosene però distaccato
abbastanza da poterle *mettere in prospettiva*, come avvertiva Tafuri,
ovverosia da poterle osservare da un punto di vista al tempo medesimo
interno ed esterno. L'uso consapevole della tecnica della prospettiva
richiede tanto una visione "da fuori" dello spazio da rappresentare,
quanto un minuzioso controllo di ogni parte di esso, vale a dire della
sua perfetta misurabilità; dove vedere "da fuori" non equivale in alcun
modo a una possibilità di "uscita" dallo spazio; e dove renderlo
misurabile non significa affatto aderire immediatamente a esso. Nell'un
caso come nell'altro, interno ed esterno vanno considerati come punti di
vista del tutto relativi: relativi alle possibilità di movimento di cui
chi utilizza la prospettiva dispone.

A questo posizionamento teorico da parte di Aureli corrisponde, sul
piano dell'attività progettuale, un progressivo cambio di scala nei
progetti di Dogma[^87]. Dalla genericità del *framework* che
abbracciava la foresta in *Stop City*, o dallo "spazio (...)
completamente sussunto dalla produzione"[^88] in *A Simple Heart*, si
passa ora a un'analisi focalizzata sulla casa in quanto "apparato per la
riproduzione della vita"[^89], ovvero come teatro di una vasta serie di
azioni e funzioni. In progetti come *Ladders* (2011), *Frame(s)*
(2011), *Every Day is Like Sunday* (2015), ma soprattutto *Communal
Villa* (2015) e *Like a Rolling Stone* (2016), Dogma concentra la
propria attenzione sull'abitazione come ambito in cui sempre di più vita
e produzione coincidono. Affiancati da una parallela ricerca storica
condotta dallo studio[^90], ma anche dagli esiti dell'attività didattica
laboratoriale svolta da Aureli con i suoi studenti[^91], questi progetti
si sforzano di ripensare radicalmente -- vale a dire fino ai fondamenti
-- le condizioni di possibilità di un'abitazione che sia luogo di
convivenza di spazi domestici e spazi lavorativi; convivenza che la
contemporaneità ha in realtà ereditato ma che ha però fortemente
esacerbato. *Like a Rolling Stone*, in tal senso, prende le mosse dallo
studio delle *boarding houses* (case-pensione) realizzate in Inghilterra
e in America tra la seconda metà del XIX secolo e la prima parte del XX,
per approdare a nuovi progetti di *boarding houses* per Londra, il cui
nucleo tematico ruota intorno al rapporto tra stanze destinate a singoli
individui e servizi condivisi[^92].

Il medesimo tema era stato già affrontato in *Communal Villa*, proposta
per uno spazio di vita e di lavoro rivolto ad artisti da collocarsi a
Berlino, sviluppato in collaborazione con Realism Working Group[^93].
Nel definire con precisione le circostanze del progetto (posizionamento
dell'edificio lungo assi infrastrutturali, urbani o suburbani;
individuazione per esso di sistemi costruttivi prefabbricati, in acciaio
o in cemento armato), gli autori non intendono sancirne la "veridicità":
piuttosto s'impegnano a fissarne le condizioni di fattibilità mediante
l'identificazione di soluzioni che ne consentano il massimo abbattimento
dei costi. Ma è ancora una volta nell'organizzazione spaziale che il
progetto prova a compiere un significativo "spostamento" delle
condizioni imposte dal mercato, misurandosi con la precarietà in cui di
sovente si trovano, nell'epoca contemporanea, categorie "deboli" come
quelle degli artisti. Attraverso una riduzione al minimo degli spazi
individuali e una dotazione di ampi spazi comuni (studi, sale riunioni,
cucine, spazi di gioco per i bambini e altri servizi), la *Communal
Villa* cerca di superare la consueta strutturazione abitativa basata sul
nucleo familiare, integrando in una comunità individui uniti tra loro da
interessi, uso di strumentazioni e modi di vita comuni. Lungi dal
confermare la tradizionale articolazione della casa (fatta assurgere in
questa circostanza addirittura a "villa", con tutte le risonanze
simboliche che questo termine porta con sé), il progetto di Dogma e
Realism Working Group è pensato per una forma di vita alternativa a
quella consueta, più flessibile e fors'anche più sostenibile di quanto
lo sia quest'ultima.

Come nel caso del monastero, da cui palesemente discende, questa forma
di vita si fonda sul presupposto che l'unico modo per vivere insieme sia
avere nel contempo la possibilità di vivere da soli. Solitudine e
comunità, da questo punto di vista, costituiscono due polarità non
banalmente opposte bensì complementari tra loro, proprio come lo sono
architettura e città. Ed è proprio nel riportare il dominio
dell'economia (nel senso originario dell'*oikonomia*, l'amministrazione
della casa) al dominio politico (inteso nel modo in cui lo intendeva
Carl Schmitt, come dimensione di un antagonismo)[^94] che Dogma dimostra
di saper ripensare il progetto nella sua prospettiva più propria. Il
medesimo obiettivo che tenacemente e con lucidità persegue lo stesso
Aureli in qualità di architetto intellettuale: far emergere --
attraverso le sue riletture, cosí come attraverso la sua pratica -- la
*dimensione politica dell'architettura*.

[^1]: Pier Vittorio Aureli, *The Difficult Whole. Typology and the
Singularity of the Urban Event in Aldo Rossi's Early Theoretical
Work. 1953-1964*, in "Log", n. 9 (inverno-primavera 2007), p. 42.

[^2]: Aureli si laurea nel 1999 allo IUAV; nel 2001 ottiene il master in
Architettura al Berlage Institute; nel 2003 consegue il dottorato di
ricerca in Pianificazione urbana allo IUAV e nel 2005 il PhD in
Architettura al Berlage Institute di Delft (Rotterdam).

[^3]: Pier Vittorio Aureli, *Schemi di città. La costruzione del
principio insediativo*, tesi di laurea, relatore Bernardo Secchi, IUAV,
a.a. 1997-98; Id., *La città arcipelago e il suo progetto*, tesi di
dottorato, relatori Elia Zenghelis e Bernardo Secchi, IUAV,
a.a. 2001-2002; Id., *The Possibility of Absolute Architecture*, PhD
Thesis, relatore Elia Zenghelis, Berlage Institute, Technische
Universiteit, Delft-Rotterdam, a.a. 2004-2005. Vedi Gabriele Mastrigli,
*Commanders of the Field: Notes on the Architecture of Dogma*, in
*Dogma: 11 Projects*, Architectural Association Publications, London
2013, pp. 109-13.

[^4]: Manfredo Tafuri, *Ricerca del Rinascimento*, Einaudi, Torino 1992,
p. XXI.

[^5]: Manfredo Tafuri, *Non c'è critica, solo storia*, intervista con
Richard Ingersoll, in "Casabella", n. 619-20, 1995, p. 96 (intervista
pubblicata per la prima volta nel 1986 su "Design Book Review").

[^6]: Di "distacco", riferito ai contenuti del lavoro intellettuale
svolto all'interno dell'organizzazione capitalistica, parla anche Tafuri
nel passo riportato al termine del capitolo precedente; una condizione
in apparenza "negativa", che tuttavia a suo avviso -- mediante uno
strategico rovesciamento -- deve essere riconosciuta come condizione
*positiva* "da cui ripartire, per elaborare un programma di attacco al
piano complessivo": Tafuri, *Lavoro intellettuale e sviluppo
capitalistico* cit., p. 280.

[^7]: Vedi al proposito, oltre ovviamente a Tafuri, *Il "progetto"
storico* cit., il saggio-recensione di Cacciari (*Eupalinos o
l'architettura*, in "Nuova Corrente", n. 76-77, 1978, p. 422) a
Manfredo Tafuri e Francesco Dal Co, *L'architettura contemporanea*,
Electa, Milano 1976.

[^8]: Dogma, *Dogma*, in *Portfolio*, Heverlee 2011, p. 5.

[^9]: Su ciò vedi la successiva ricerca di Pier Vittorio Aureli e
Martino Tattara, *Brussels: A Manifesto. Towards the Capital of
Europe*, a cura di Joachim Deklerck, Martino Tattara e Veronique
Patteeuw, NAi Publishers, Rotterdam 2007.

[^10]: Dogma, *Stop City* (2007), in *Dogma: 11 Projects* cit.,
pp. 10-19.

[^11]: Dogma, *A Simple Heart* (2011), in *Dogma: 11 Projects* cit.,
pp. 20-31.

[^12]: Dogma, *Stop City: per una architettura non-figurativa della
città (dopo la città post-fordista)*, in GIZMO, *MMX. Architettura zona
critica*, Zandonai, Rovereto 2011, p. 159.

[^13]: Paolo Virno, *Virtuosity and Revolution: The Political Theory of
Exodus*, in Virno e Hardt (a cura di), *Radical Thought in Italy* cit.,
pp. 189-212; Id., *Mondanità. L'idea di "mondo" tra esperienza
sensibile e sfera pubblica*, Manifestolibri, Roma 1994; Giorgio Agamben,
*Signatura rerum. Sul metodo*, Bollati Boringhieri, Torino 2008.

[^14]: Dogma, *A Simple Heart*, in *Dogma: 11 Projects* cit., p. 22.
Sul concetto di *kathecon* vedi Massimo Cacciari, *Il potere che frena*,
Adelphi, Milano 2013, ma anche Giorgio Agamben, *Il mistero del male.
Benedetto XVI e la fine dei tempi*, Laterza, Roma-Bari 2013.

[^15]: Dogma, *Stop City*, in *Dogma: 11 Projects* cit., p. 10.

[^16]: "Ipotesi di linguaggio architettonico non-figurativo": Archizoom
Associati, *No-Stop City* (1970), in Roberto Gargiani, *Archizoom
Associati, 1966-1974. Dall'onda pop alla superficie neutra*, Electa,
Milano 2007, pp. 169-73.

[^17]: Pier Vittorio Aureli, *The Project of Autonomy. Politics and
Architecture Within and Against Capitalism*, Princeton Architectural
Press, New York 2008; trad. it. *Il progetto dell'autonomia. Politica e
architettura dentro e contro il capitalismo*, Quodlibet, Macerata 2016.

[^18]: Al proposito vedi *Raniero Panzieri e i "Quaderni Rossi"*, in
"aut aut", n. speciale (149-50), 1975, con contributi, tra gli altri, di
Antonio Negri e Massimo Cacciari.

[^19]: Questa espressione ricorre di sovente nelle pagine di "Quaderni
Rossi", "Classe Operaia" e "Contropiano": vedi Steve Wright, *L'assalto
al cielo. Per una storia dell'operaismo*, Edizioni Alegre, Roma 2008.

[^20]: Raniero Panzieri, *Sull'uso capitalistico delle macchine nel
neocapitalismo*, in "Quaderni Rossi", n. 1, 1961, pp. 53-72.

[^21]: Mario Tronti, *Marx, forza-lavoro, classe operaia* (1965), in
Id., *Operai e capitale* cit., pp. 259-63.

[^22]: *Ibid.*, p. 260.

[^23]: Mario Tronti, *Sull'autonomia del politico*, Feltrinelli, Milano
1977.

[^24]: Aureli, *Il progetto dell'autonomia* cit., p. 65.

[^25]: *Ibid.*, p. 25.

[^26]: Tra gli altri, vedi Massimo Cacciari, *Sviluppo capitalistico e
ciclo delle lotte. La Montedison di Porto Marghera 1. La "fase"
1950-1966*, in "Contropiano", n. 3, 1968, pp. 579-627; Id., *Sviluppo
capitalistico e ciclo delle lotte. La Montedison di Porto Marghera. 2.
La "fase" 1966 -- estate 1969*, ivi, n. 2, 1969, pp. 397-447; Umberto
Coldagelli, *Forza-lavoro e sviluppo capitalistico*, ivi, n. 1, 1969,
pp. 81-127; Enzo Schiavuta, *Ricerca scientifica e sviluppo
capitalistico*, ivi, n. 2, 1970, pp. 285-309; Mario Tronti, *Classe
operaia e sviluppo*, ivi, n. 3, 1970, p. 471. A questa analisi Tafuri
dà il suo contributo con *Lavoro intellettuale e sviluppo capitalistico*
cit. (1970).

[^27]: Aureli, *Il progetto dell'autonomia* cit., p. 79.

[^28]: *Ibid.*, p. 80.

[^29]: *Ibid.*, p. 87.

[^30]: Tafuri, *Per una critica dell'ideologia architettonica* cit.,
p. 60.

[^31]: Aureli, *Il progetto dell'autonomia* cit., p. 95.

[^32]: Rossi, *L'architettura della città* cit., p. 23.

[^33]: Ezio Bonfanti, *Autonomia dell'architettura*, in "Controspazio",
n. 1, 1969, p. 29.

[^34]: Aureli, *Il progetto dell'autonomia* cit., p. 102.

[^35]: Rossi, *L'architettura della città* cit., p. 117.

[^36]: Reyner Banham, *Le tentazioni dell'architettura. Megastrutture*,
Roma-Bari, Laterza 1980; ILSES (Istituto lombardo per gli studi
economici e sociali), *Relazioni del Seminario "La nuova dimensione
della città -- La città-regione"*, Atti del convegno, Stresa, 19-21
gennaio, Milano 1962; *La città territorio. Un esperimento didattico
sul centro direzionale di Centocelle in Roma*, Leonardo da Vinci
Editrice, Bari 1964.

[^37]: Aureli, *Il progetto dell'autonomia* cit., p. 110. Vedi anche
Id., *Aldo Rossi: Locomotiva 2, Competition Entry for a Directional
Centre, Turin, Italy*, in Brett Steele e Francisco Gonzalez de Canales
(a cura di), *First Works: Emerging Architectural Experimentation of the
1960s and 1970s*, Architectural Association Publications, London 2009,
pp. 88-89.

[^38]: Al progetto di Rossi, Polesello e Meda si rifà esplicitamente il
progetto di Dogma, *Locomotiva 3*, una proposta per l'area denominata
Spina 4 a Torino, elaborata nel 2010; vedi *Dogma: 11 Projects* cit.,
pp. 74-81.

[^39]: Archizoom Associati, *Città catena di montaggio del sociale.
Ideologia e teoria della metropoli*, in "Casabella", n. 350-51, 1970,
p. 44.

[^40]: Aureli, *Il progetto dell'autonomia* cit., p. 118.

[^41]: *Ibid.*, pp. 115-16.

[^42]: Archizoom Associati, *Città catena di montaggio del sociale*
cit., p. 8.

[^43]: Aureli, *Il progetto dell'autonomia* cit., p. 131.

[^44]: *Ibid.*, p. 127.

[^45]: *Ibid.*, pp. 139-40.

[^46]: *Ibid.*, p. 140.

[^47]: *Ibid.*, p. 141.

[^48]: Pier Vittorio Aureli, *The Possibility of an Absolute
Architecture*, The MIT Press, Cambridge (Mass.) 2011.

[^49]: Vedi, ad esempio, Franco La Cecla, *Contro l'architettura*,
Bollati Boringhieri, Torino 2008; Id., *Contro l'urbanistica*, Einaudi,
Torino 2015.

[^50]: Aureli, *The Possibility of an Absolute Architecture* cit., p.
IX.

[^51]: Georg Simmel, *Metafisica della morte* (1910), in Id.,
*Metafisica della morte e altri scritti*, a cura di Lucio Perucchi, SE,
Milano 2012, pp. 9-10.

[^52]: Aureli, *The Possibility of an Absolute Architecture* cit., pp.
IX-X.

[^53]: *Ibid.*, p. 32.

[^54]: Massimo Cacciari, *L'arcipelago*, Adelphi, Milano 1997.

[^55]: Aureli, *The Possibility of an Absolute Architecture* cit., p.
XI.

[^56]: *Ibid.*, p. 4.

[^57]: Ildefons Cerdà, *Teoría general de la urbanización* (1867),
citato *ibid.*, p. 9.

[^58]: Aureli, *The Possibility of an Absolute Architecture* cit.,
p. 16.

[^59]: *Ibid.*, p. 32.

[^60]: Su ciò vedi anche Pier Vittorio Aureli, *City as Political Form:
Four Archetypes of Urban Transformation*, in "Architectural Design",
vol. 81, n. 1, 2011, pp. 32-37.

[^61]: Aureli, *The Possibility of an Absolute Architecture* cit.,
p. 27.

[^62]: Carl Schmitt, *Teologia politica: quattro capitoli sulla dottrina
della sovranità* (1922), in Id., *Le categorie del "politico". Saggi di
teoria politica*, a cura di Gianfranco Miglio e Pierangelo Schiera, il
Mulino, Bologna 1972, pp. 27-86; Giorgio Agamben, *Lo stato di
eccezione*, Bollati Boringhieri, Torino 2003.

[^63]: Aureli, *The Possibility of an Absolute Architecture* cit.,
p. 37.

[^64]: *Ibid.*, pp. 40-41.

[^65]: *Ibid.*, p. 41.

[^66]: *Ibid.*, p. 42.

[^67]: *Ibid.*, p. 45.

[^68]: Pier Vittorio Aureli, *Less Is Enough*, Strelka Press, Moscow
2013.

[^69]: *Ibid.*, p. 7.

[^70]: Aureli, *Less Is Enough* cit., p. 8.

[^71]: *Ibid.*, p. 9.

[^72]: Max Weber, *L'etica protestante e lo spirito del capitalismo*
(1905), Rizzoli, Milano 1991.

[^73]: Aureli, *Less Is Enough* cit., pp. 11-12.

[^74]: *Ibid.*, p. 13.

[^75]: *Ibid.*, p. 16.

[^76]: Aureli, *Less Is Enough* cit., p. 24.

[^77]: Aldo Rossi, *Quaderno inedito (Varie 1 -- Milano -- Arch. Veneta
- Abitazione -- Pref. II ed. L'arch. della città -- Politecnico)*,
1969-70, citato in Gianni Braghieri, *Presentazione*, in "Soundings",
n. 1, 2017, numero monografico dedicato a Aldo Rossi, a cura di Lamberto
Amistadi e Ildebrando Clemente, p. 68.

[^78]: Giorgio Agamben, *Altissima povertà. Regole monastiche e forme
di vita*, Neri Pozza, Vicenza 2011.

[^79]: Benjamin, *Esperienza e povertà* cit., p. 53.

[^80]: Walter Benjamin, *Il carattere distruttivo* (1931), in Id.,
*Esperienza e povertà* (2018), a cura di Massimo Palma, cit., p. 41.

[^81]: Aureli, *Less Is Enough* cit., p.
40. Vedi anche Id., *A Room Without Ownership*, in *Hannes Meyer: Co-op
Interieur*, Spector Book, Leipzig 2015, pp. 33-39.

[^82]: Aureli, *Less Is Enough* cit., pp. 40-41.

[^83]: *Ibid.*, p. 41.

[^84]: *Ibid.*, p. 58.

[^85]: Karl Marx, *Manoscritti economici-filosofici del 1844*, a cura di
Norberto Bobbio, Einaudi, Torino 2018, p. 113.

[^86]: Aureli, *Less Is Enough* cit., p. 59.

[^87]: Su questo passaggio di scala vedi Pier Vittorio Aureli e Martino
Tattara, *A Limit to the Urban: Notes on Large-Scale Design*, in *Dogma:
11 Projects* cit., pp. 42-45, e Id., *Barbarism Begins at Home: Notes on
Housing*, *ibid.*, pp. 86-90.

[^88]: Dogma, *A Simple Heart*, in *Dogma: 11 Projects* cit., p. 22.

[^89]: Aureli e Tattara, *Barbarism Begins at Home* cit., p. 86.

[^90]: Svolta a partire dal 2013, la ricerca *Living/Working* ha avuto
come esito la pubblicazione di Dogma, *The Room of One's Own*, Black
Square Press, Milano 2017.

[^91]: Pier Vittorio Aureli e Maria S. Giudici, *The Grand Domestic
Revolution. Revisiting the Architecture of Housing*, Diploma 14,
Architectural Association School, London, a.a. 2013-14; Pier Vittorio
Aureli e altri, *How to Live To­gether. Homes for Houston*, Advanced
Design Studio -- Yale School of Architecture, New Haven (primavera)
2014.

[^92]: Dogma + Black Square, *Like a Rolling Stone. Revisiting the
Architecture of the Boarding Houses*, Black Square Press, Milano 2016.

[^93]: Dogma + Realism Working Group, *Communal Villa. Production and
Reproduction in Artists' Housing*, Spector Books, Leipzig 2016. Realism
Working Group è un collettivo di artisti che opera nella capitale
tedesca.

[^94]: Carl Schmitt, *Il concetto di "politico"* (1932), in Id., *Le
categorie del "politico"* cit., pp. 101-65.

# Architettura dentro e contro

"L'arte di costruire è la volontà dell'epoca \[*Zeitwille*\] tradotta in
spazio"[^1]. La nota affermazione di Ludwig Mies van der Rohe, da lui
enunciata e ribadita in più circostanze[^2], potrebbe a prima vista
apparire la più compiuta espressione del totale asservimento
dell'architettura alle forze operanti nel tempo in cui questa nasce e si
colloca. E in effetti, proprio il "servire" costituisce per Mies van
der Rohe il compito essenziale dell'architettura: "L'opera degli
architetti deve servire la vita \[*dem Leben dienen*\]. Soltanto la
vita deve essere la loro guida"[^3]. Parrebbe cosí giustificarsi
concettualmente, per voce di uno dei più lucidi e profondi architetti
del secolo scorso, l'attitudine dell'architettura a "mettersi al
servizio" della società e dei "soggetti" agenti al suo interno; ciò che
finirebbe con il ridurre l'architettura -- almeno in una certa misura --
a un semplice "riflesso" di questi, delle loro dinamiche e "volontà",
appunto.

Ma come va inteso esattamente il "servire la vita" di Mies van der Rohe?
In un saggio di straordinaria intensità Massimo Cacciari ha interpretato
in maniera forse definitiva la connessione tra *dem Leben dienen* e
*Zeitwille* nel pensiero dell'architetto tedesco:

> ... si cadrebbe grossolanamente in errore ritenendo che tale servizio
> si riferisca soltanto alla "vita" in quanto somma di esigenze,
> domande, imperativi. Se cosí fosse, non saremmo agli antipodi, ma nel
> bel mezzo dell'idea funzionalistica del progetto (...) Ben altro
> timbro ha *das Leben* per Mies. Vita e Ergon, Vita *e* trascendenza
> dell'idea dell'opera formano un insieme indissolubile. Si serve la
> vita soltanto servendo l'opera -- si è al servizio del proprio tempo
> (...) soltanto se si è capaci di "immaginare" l'opera[^4].

Il servizio alla vita, dunque, non è affatto un semplice assoggettarsi
ai "doveri" quotidiani, mondani, cui l'architettura è comunque
destinata, e neppure ai compiti più eccezionali, "di facciata", dei
quali a volte essa è investita, tanto quanto l'essere in accordo con la
volontà dell'epoca non si lascia in alcun modo ridurre a un semplice
rispecchiamento di ciò che l'epoca "si aspetta" dall'opera.

> Vita è sempre intesa come en-érgheia, vita nel e dell'ergon: molto più
> che un mero dato di fatto, la vita, di cui Mies parla, è quella vita
> in cui l'ergon si manifesta, in cui può aver luogo la verità
> dell'ergon. Vita compiuta, perciò,

ma compiuta nel suo essere in-atto, en-érgheia. E ancora:

> Vita, per Mies, è sempre spirituale decisione nei confronti dell'opera
> -- distacco (...) da ogni vita "immediata", da ogni vita
> naturalisticamente-immediatamente intesa[^5].

Ancorché sancire un legame deterministico, l'affermazione miesiana che
mette in correlazione volontà dell'epoca e architettura sottende la
precisa condizione che le lega l'una all'altra: tradurre la volontà
dell'epoca in spazio, vale a dire "immaginare" l'opera, non è mai
un'operazione meccanica, meramente servile; piuttosto implica una
*potenza*, una *en-*érgheia, appunto, che è quella derivante dall'opera
stessa, che l'epoca non può semplicemente prevedere o prescrivere.
Anzi, nel caso di un'opera come quella di Mies che ritiene decisiva
l'"essenza dell'arte di costruire"[^6], questa non può derivare da una
semplice "invenzione" soggettiva, e a rigore neppure da una
intenzionalità progettante, bensì deve "limitarsi" a
presentare-manifestare la verità che la precede e la trascende.

Concepire il rapporto tra opera e epoca in termini non deterministici
implica dunque da parte dell'architetto una comprensione effettiva della
struttura dell'epoca in cui è immerso, comprensione da cui scaturisce
quella "potenza immaginativa" che nulla ha a che vedere con la fantasia
o con la creatività, e che piuttosto richiede un "ascolto" dell'opera.

Quale sia la struttura della *sua* epoca -- e in quale misura essa si
differenzi sostanzialmente da quella delle epoche precedenti -- appare
molto chiaro agli occhi di Mies:

> Da tempo la macchina è diventata padrona della produzione. Questa era
> approssimativamente la situazione prebellica. Sebbene il ritmo di
> questo sviluppo sia stato ridotto dallo scoppio della guerra, la sua
> direzione è rimasta immutata. Anzi, la situazione si è persino
> acutizzata. Se prima per mille motivi l'economia era praticata in
> modo libero, attualmente altrettanti motivi costringono alle più
> serrate riflessioni. Quanto già prima della guerra la vita fosse
> legata all'economia, ci è apparso del tutto evidente soltanto nel
> periodo post-bellico. Ora esiste "soltanto" l'economia. Essa domina
> ogni cosa, la politica e la vita[^7].

Esattamente negli stessi termini, oggi si potrebbe affermare che "esiste
"soltanto" l'economia". Ciò che non impedisce, a chi sia dotato di
capacità di comprensione e di ascolto, di servire la vita liberando la
potenza immaginativa dell'opera, proprio come fa Mies van der Rohe.

In un'epoca come quella attuale, in cui sempre di più predomina
l'economia e declina la politica (non tanto in termini di governo,
quanto di capacità di affermazione di idee o di presa di posizione su
questioni di interesse generale), diventa indubbiamente difficile
distaccarsi dalla vita in senso "immediato" e servire invece la vita in
un senso superiore, come quello appena indicato. Ma ancora più
difficile, in una condizione del genere, risulta resistere -- o
addirittura opporsi apertamente -- alla "volontà dell'epoca". E ciò
tanto più poi quando si cerchi di far coincidere le forme di
"resistenza" o di "opposizione" con quelle architettoniche.

Per cercare almeno di nominare le condizioni che rendono possibile
assumere tali posizioni può essere utile tornare a osservare in
quest'ottica alcuni momenti o episodi, in certi casi anche largamente
noti, di un più o meno recente passato.

Quando Benjamin menziona il mutismo di coloro che ritornavano dai campi
di battaglia della prima guerra mondiale come sintomo dell'inaridirsi
della loro capacità di comunicare le esperienze vissute, quando
sottolinea la "miseria del tutto nuova" che "ha colpito gli uomini (...)
con questo immenso sviluppo della tecnica"[^8], appare del tutto chiaro
come per lui una simile "povertà di esperienza" vada intesa non nel
senso che manchi loro qualcosa, "come se gli uomini anelassero a una
nuova esperienza"[^9], bensì piuttosto nel senso che "essi desiderano
essere esonerati dalle esperienze". La "povertà di esperienza" è la
reazione a un eccesso: quelle persone "hanno "divorato" tutto, la
*Kultur* e l'"uomo", e ne sono divenuti più che sazi e stanchi"[^10].
La conseguenza di ciò è lo svilupparsi di quel "nuovo positivo concetto
di barbarie"[^11] già citato in precedenza, da cui chi ne risulta
soggetto "è indotto a ricominciare da capo; a iniziare dal nuovo; a
farcela con il poco; a costruire a partire dal poco". Si potrebbe
considerarla una rinuncia; ma si tratta anche di
un'opportunità. "Ricominciare da capo", cosí come "far pulizia, (...)
creare spazio"[^12], sono azioni che hanno tra loro in comune la
liberazione da qualcosa, si tratti di oggetti oppure di forme e schemi
mentali ormai invecchiati. Distaccarsene, abbandonarli, dimenticarli
comporta sempre una nuova apertura.

Non sarà forse casuale che, nello stesso contesto del primo dopoguerra
tedesco, all'interno dell'appena nato Staatlisches Bauhaus di Weimar, il
primo insegnamento cui vengono sottoposti gli studenti (il corso
preparatorio, il cosiddetto *Vorkurs*), affidato da Gropius all'artista
svizzero Johannes Itten, consista in una radicale rifondazione della
loro grammatica percettiva e cognitiva mediante una serie di esercizi
che hanno lo scopo fondamentale di cancellare quanto da essi
precedentemente imparato o conosciuto, per predisporli a nuove
esperienze di apprendimento. La didattica di Itten deve molto agli
insegnamenti impartitigli dal pedagogo Ernst Schneider presso la Scuola
di formazione per insegnanti di Berna-Hofwil. Il metodo di Schneider
prevedeva tra l'altro l'impiego delle teorie psicoanalitiche junghiane e
di pratiche pedagogiche progressiste che tendevano a non correggere il
lavoro creativo degli studenti per non reprimerne le inclinazioni. A
questi principî Itten affianca quelli appresi dalla frequentazione della
scuola del pittore tedesco Adolf Hölzel a Stoccarda, negli anni
precedenti la guerra, basati su accostamenti cromatici contrastanti e
sulla loro applicazione a forme elementari, ma anche su attività fisiche
di rilassamento da svolgere in stretta connessione con il lavoro
creativo. Prendendo spunto da tutto ciò e combinando esercizi corporei
e gestuali, respirazione ritmica, reinterpretazioni delle opere degli
antichi maestri, indottrinamento filosofico-religioso ispirato alla
religione neo-zoroastriana Mazdaznan, dieta vegetariana, rivoluzione nel
vestiario e altro ancora[^13], il corso preliminare di Itten mirava a
conferire una nuova "unità" allo studente, risvegliandolo al tempo
stesso dal "sonno del mondo".

> Fondamentale per il corso propedeutico al Bauhaus appariva l'obiettivo
> di liberare le energie creative e l'autonomia degli studenti,
> esaltandone capacità e soggettive predilezioni. "Si trattava -- per
> Itten -- di costruire l'uomo nella sua interezza come un essere
> creativo" capace di affrontare con successo la complessità di un
> "progetto figurativo" che pretendeva la sinergia di forze e capacità
> diverse, fisiche, morali, spirituali, intellettuali[^14].

D'altronde, pur con accenti e "stili" diversi da quelli di Itten ("Itten
vuol fare del Bauhaus un monastero, con tanto di santi e di monaci",
scrive Oskar Schlemmer in una lettera del 1921)[^15], anche Walter
Gropius, con il corso di studi del Bauhaus, intende restituire
integralità all'architetto, attraverso l'apprendimento di teorie,
tecniche e materiali che soltanto in un momento finale avrebbero dovuto
sintetizzarsi nella pratica progettuale vera e propria. Un architetto
-- quello uscito dal Bauhaus -- il cui "obiettivo programmatico"
potrebbe essere fatto coincidere esattamente con il benjaminiano
"ricominciare da capo", "iniziare dal nuovo", "farcela con il poco".
L'emancipazione dalle incrostazioni di una cultura sino a quel momento
tramandata e passivamente accettata conduce cosí a una trasformazione
radicale, e dischiude la possibilità di costruire *davvero* per la
propria epoca.

Tra i "costruttori" barbarici citati da Benjamin -- insieme a René
Descartes, Albert Einstein, Paul Klee, Paul Scheerbart, Adolf Loos e Le
Corbusier -- vi è anche il Bauhaus[^16]. Loro comune segno distintivo è
"una totale mancanza d'illusioni nei confronti dell'epoca e ciò
nonostante un pronunciarsi senza riserve per essa"[^17]. La stessa
fusione di coinvolgimento e distacco che si lascia rilevare anche in
Mies van der Rohe.

Ma in quale misura -- è lecito chiedersi -- ci si potrebbe giovare oggi
di questo insegnamento? Nell'"età dell'inconsistenza"[^18] in cui ci
troviamo, non meno che nel primo dopoguerra tedesco, gli uomini sono
vittime di un eccesso, di qualche cosa di "troppo"; non meno di allora,
sentono -- *sentiamo* -- di avere "divorato" tutto, e di esserne "più
che sazi e stanchi". E ancora una volta in maniera analoga a quella
circostanza, ciò appare causato da un "immenso sviluppo della tecnica".

Nella nostra epoca, la sensazione di sazietà e di stanchezza costituisce
una reazione a un "eccesso dell'Eguale", come lo denomina Byung-Chul
Han[^19], derivante da una "sovrapproduzione", da un "eccesso di
prestazione o di comunicazione"[^20]. Gli eccessi dell'Eguale generano
una condizione saturativa. Troppe immagini, troppi eventi, troppe
possibilità. La stanchezza che ne deriva è il prodotto di un
esaurimento, un'estenuazione psichica a fronte della quale non vi sono
facili rimedi.

Ma vi è anche un altro genere di stanchezza: quella che suggerisce di
rallentare il passo, di non far seguire un'azione alle azioni già
compiute in precedenza; una stanchezza che induce al riposo, al
non-fare, all'ascolto, alla contemplazione. È lo stesso tipo di stato
che provoca la "povertà di esperienza" di cui parla Benjamin:

> ... agli occhi della gente, stancatasi delle complicazioni senza fine
> della vita quotidiana e per la quale il fine della vita affiora solo
> come un lontanissimo punto di fuga in un'infinita prospettiva di
> mezzi, appare liberante un'esistenza che in ogni frangente basta a se
> stessa nel modo più semplice e contemporaneamente più
> confortevole[^21].

Per ottenerlo bisogna rinunciare a qualcosa, prendere tempo, "creare
spazio", retrocedere, rilassarsi, oziare.

D'altra parte, nota ancora Han, "la pura frenesia non crea nulla di
nuovo, ma riproduce e accelera ciò che è già disponibile"[^22]. È
interessante che il filosofo sudcoreano introduca questa considerazione
in relazione a quanto affermato da Benjamin a proposito della "noia
profonda" come presupposto di un'attenzione profonda, contemplativa, in
un saggio di poco successivo a quello appena citato e ad esso
strettamente connesso[^23]. Lo stato di distensione spirituale di cui
per Benjamin la noia costituisce il culmine ("La noia è l'uccello
incantato che cova l'uovo dell'esperienza"), per Han è l'esatto rovescio
della forma attuale della concentrazione: l'"iper-attenzione", vale a
dire un'attenzione dispersa tra troppi obiettivi simultaneamente: "un
rapido cambiamento di focus tra compiti, sorgenti d'informazioni e
processi diversi"[^24] che si traduce nel vano iperattivismo
contemporaneo.

"Farcela con il poco", "costruire a partire dal poco", cessano a questo
punto di risuonare come formule vuote e si presentano invece come
*soluzioni concrete* per coloro i quali -- al pari dei "costruttori"
additati da Benjamin ("uomini che del radicalmente nuovo hanno fatto la
loro causa e lo hanno fondato su comprensione e rinuncia")[^25] -- siano
pronti a sottrarre il proprio agire agli eccessi di lavoro e produzione,
all'iperattivismo frenetico contrabbandato per "dovere" sociale (e
spesso giustificato ai propri stessi occhi in nome del denaro) per
assumere in alternativa un comportamento ispirato a una contemplazione
attiva, a una "distensione" che sia al tempo stesso operante.

Potrebbe sembrare un'evenienza impossibile, oppure completamente
distante da ogni applicazione architettonica. In realtà, esiste un
tentativo compiuto in tal senso in un passato relativamente recente:
quello dell'Internationale Situationniste, organizzazione (e rivista)
attiva tra la fine degli anni cinquanta e i sessanta. Per Guy Debord,
Asger Jorn, Constant Nieuwenhuys, Gilles Ivain e per gli altri
componenti del gruppo, "l'architettura è il mezzo più semplice per
*articolare* il tempo e lo spazio, per *modellare* la realtà, per far
sognare", come si legge nel primo fascicolo della rivista. Ma con una
ben precisa avvertenza:

> Non si tratta solamente di articolazione e di modulazione plastica,
> espressione di una bellezza passeggera. Ma di una modulazione
> influenzale che si inscrive nella curva eterna dei desideri umani e
> dei progressi nella realizzazione di questi desideri[^26].

Tradotto in un linguaggio meno altisonante, i situazionisti rifiutano
fin da subito di intervenire in modo trasformativo nei confronti della
realtà, negandosi lo strumento del progetto come mezzo attuativo
concreto, ma pure come semplice ipotesi alternativa, come fuga dal reale
(e infatti la fuoriuscita di Constant dall'Internationale
Situationniste, nel 1960, sarà causata proprio dai dissapori legati a
*New Babylon*, il suo progetto di città utopica, e in particolar modo
alla contrapposizione tra la maniera in cui egli lo sviluppa,
maggiormente legata alle componenti strutturali e alle forme
architettoniche, e quella richiesta dagli altri situazionisti, più
strettamente connessa ai contenuti)[^27]. A partire da questo
presupposto le pratiche situazioniste si svilupperanno, anziché in
direzione della costruzione architettonica nel senso tradizionale del
termine, in quella della *costruzione di situazioni*; dove per
"situazione" -- secondo la definizione che essi stessi ne danno -- va
inteso un "momento della vita, concretamente e deliberatamente costruito
mediante l'organizzazione collettiva di un ambiente unitario e di un
gioco di avvenimenti"[^28]. La rinuncia a compiere interventi materiali
e durevoli non equivale automaticamente a una riduzione al mutismo o
all'inazione; piuttosto comporta uno spostamento del punto di vista
sulla realtà, un "lavoro" su di essa che ne produce di fatto una
*risemantizzazione*. Per i situazionisti ciò si traduce in "azioni"
denominate *derive*: attraversamenti casuali dello spazio urbano
finalizzati unicamente a rileggerlo in modo imprevisto, mettendone in
luce aspetti alternativi, dimenticati o nascosti. Alla città borghese
(o a parti -- o anche a semplici frammenti o dettagli -- di essa)
vengono cosí attribuiti nuovi significati e nuovi "usi" ai margini
dell'utile.

Un tale genere di atteggiamento nei confronti della città e della realtà
potrebbe apparire del tutto inefficace. Non producendo frutti immediati
e tangibili risulta a prima vista completamente superfluo. Tuttavia, è
proprio in una rimessa in discussione dei valori socialmente condivisi
in quel determinato momento storico che affonda le proprie radici
l'analisi -- e la critica -- situazionista. Si equivocherebbe il senso
di tale operare scambiandolo (come spesso è stato fatto in periodi più
recenti) per una produzione di performance artistiche. In realtà tutte
le elaborazioni situazioniste -- dai rilievi psico-geografici delle
città alle derive, passando per i materiali pubblicati sulla rivista --
hanno un intento profondamente e inequivocabilmente *politico*, anche
dietro le mentite spoglie della leggerezza e dell'ironia. Ed è proprio
a partire da una riconsiderazione politica delle categorie dell'utile e
dell'inutile, cosí come del lavoro produttivo e del gioco, che i
situazionisti impostano le loro esperienze. Le quali sono sí
caratterizzate da una programmatica impermanenza e aleatorietà; ma al
tempo stesso vengono assoggettate dai componenti del gruppo a un certo
"rigore" metodologico che le rende comunicabili e scambiabili, e dunque
anche condivisibili. Fondamentale per i situazionisti, da questo punto
di vista, è che le derive da essi compiute non rimangano delle
esperienze isolate, soggettive, ma vengano invece sempre socializzate.
Soltanto cosí l'opera di risignificazione di alcuni luoghi della città
può giungere a compimento; e in questo modo avviare un processo di
"riqualificazione" (anche solo virtuale) dei medesimi luoghi. Il fatto
che questo processo si attui in una prospettiva ludica -- ovvero nella
dimensione in cui l'*homo ludens* si sostituisce all'*homo faber*[^29]
-- non lo rende per questo meno pensabile: semmai meno facilmente
realizzabile, vale a dire realizzabile soltanto a costo di forzare i
consueti termini della realtà, infrangendo cioè il patto che questa
tacitamente istituisce con un modo "serio" di intendere la società e il
mondo.

È verso la fine del Settecento, rileva Johan Huizinga, nel momento in
cui si sviluppano simultaneamente classe borghese, rivoluzione
industriale e Illuminismo, che "lavoro e produzione assurgono a ideale,
anzi quasi a idolo"[^30]. Si tratta dell'infanzia dell'epoca odierna. È
in quel momento infatti che, secondo lo storico olandese, sorge

> ... \[l'\]equivoco secondo il quale le forze economiche e l'interesse
> economico determinerebbero e dominerebbero il corso del mondo. La
> sopravvalutazione del fattore economico nella società e nello spirito
> umano era in certo senso il frutto naturale del razionalismo e
> dell'utilitarismo.

Il ritorno -- o l'approdo -- a una società ludica, per i situazionisti,
corrisponde appunto alla messa in crisi del razionalismo e
dell'utilitarismo, cioè a dire del capitalismo. Il rifiuto di
quest'ultimo è il rifiuto innanzitutto di una logica produttiva in senso
economico, non della produzione *tout court*. È in questa logica che
essi pongono il "gioco" al centro del proprio interesse. Pur se
improduttivo in senso economico, il gioco in compenso produce
divertimento. Ed è precisamente quest'ultimo che si prefiggono di
"produrre" i situazionisti. Un divertimento che non costituisce una
semplice evasione dalle consuete regole sociali, una pausa dalla
"serietà" altrimenti dominante, bensì il fondamento stesso di una
società basata sul gioco anziché sul lavoro, sull'avventura anziché
sulla noia; una società nomade anziché stanziale, proprio come la *New
Babylon* di Constant immaginava di esserlo[^31].

Ma non è soltanto nel progetto di Constant che il gioco assume un ruolo
centrale nella costruzione di situazioni urbane alternative a quelle
esistenti. Il concetto di "urbanismo unitario" formulato
dall'Internationale Situationniste, ovvero la "costruzione integrale di
un ambiente in legame dinamico con esperienze di comportamento"[^32], è
al tempo stesso una critica alla città del capitale e la prefigurazione
di uno spazio sociale inteso nella prospettiva del ludico:

> L'urbanismo unitario non è una dottrina urbanistica ma una critica
> dell'urbanistica. (...) Nessuna disciplina separata può essere
> accettata in sé, noi andiamo verso una creazione globale
> dell'esistenza. L'urbanismo unitario è distinto dai problemi
> dell'habitat e tuttavia è destinato ad inglobarli; a maggior ragione è
> distinto dagli attuali scambi commerciali. In questo momento prende
> in considerazione un campo di esperienza per lo *spazio sociale* delle
> città future. Non è una reazione contro il funzionalismo, ma il suo
> superamento: si tratta di realizzare, al di là dell'utilità immediata,
> un ambiente funzionale appassionante. (...) Cosí come l'habitat,
> l'urbanismo unitario è distinto dai problemi estetici. Va contro lo
> spettacolo passivo, principio della nostra cultura in cui
> l'organizzazione dello spettacolo si estende tanto più scandalosamente
> quanto più aumentano i mezzi dell'intervento umano. Mentre oggi le
> stesse città vengono offerte come un penoso spettacolo, un supplemento
> ai musei, per i turisti trasportati su corriere di vetro, l'urbanismo
> unitario prende in considerazione l'ambiente urbano come terreno di un
> gioco di partecipazione. L'urbanismo unitario non è idealmente
> separato dall'attuale terreno della città. Si è formato
> dall'esperienza di questo terreno e a partire dalle costruzioni
> esistenti. Noi dobbiamo sia sfruttare gli attuali scenari con
> l'affermazione di uno spazio urbano ludico quale lo fa riconoscere la
> deriva, sia costruirne di totalmente inediti. (...) L'urbanismo
> unitario si contrappone alla fissazione delle città nel tempo. (...)
> L'urbanismo unitario è contro la fissazione delle persone in dati
> punti di una città. È lo zoccolo di una civiltà del tempo libero e del
> gioco[^33].

Le "tecniche" situazioniste, pur in apparenza estremamente elementari, e
certamente assai modeste se confrontate con quelle impiegate dalle forze
loro antagoniste, si fondano tuttavia su una lucida comprensione delle
dinamiche in campo; una comprensione che consente loro di "anticipare"
le mosse dell'avversario, o in certi casi addirittura di appropriarsi
dei meccanismi regolativi di tali dinamiche. L'esempio più emblematico
è proprio quello relativo alla spettacolarizzazione della città e della
società capitaliste, presagita con largo anticipo e criticata nella sua
natura "passiva" dai situazionisti, prima di essere approfonditamente
analizzata, anni più tardi, da Guy Debord, in *La Société du Spectacle*
(1967). Lungi dall'essere semplicemente rifiutata, la nozione di
spettacolo è invece assunta e direttamente (e coscientemente) impiegata
anche in alcune delle pratiche situazioniste. Si pensi ad esempio
all'uso delle immagini -- sorprendenti e a volte provocatorie -- nelle
pagine della rivista, a corredo di ponderosi saggi con i quali esse non
intrattengono palesemente alcun rapporto; o alle copertine della rivista
stessa, tutte diversamente colorate e metallizzate in modo tale da
renderle specchianti, una lavorazione complessa e costosa all'epoca, il
cui unico scopo è evidentemente quello di rendere i fascicoli -- appunto
-- più spettacolari, e dunque attraenti. D'altronde, al di là della
singolarità di questi esempi, quanto si offre come lezione più generale
e durevole dal caso dell'Internationale Situationniste è che per
combattere efficacemente qualcosa bisogna penetrarvi in profondità e, da
tale posizione interna, capirne le regole, giungendo al limite persino a
impiegarle. L'essere *dentro* -- anche nella sovversiva logica
situazionista -- non è dunque soltanto una condizione fattuale imposta
da ostili circostanze "esterne", bensì l'irrinunciabile presupposto per
poter essere *contro*.

A fronte di ciò si potrebbe obiettare che le "azioni" situazioniste --
ovvero le situazioni --, essendo per loro natura impersistenti e del
tutto prive di sostanzialità, non lasciano alcuna traccia dietro di sé,
o perlomeno non tracce abbastanza tangibili da poter essere oggettivate,
e di conseguenza disgiunte, fatte altro da chi le ha vissute. La
rinuncia alla produttività delle proprie azioni parrebbe dunque lo
"scotto" che l'Internationale Situationniste è costretta a pagare per
mantenere dal proprio punto di vista una posizione "politicamente
corretta". In realtà la prospettiva dei situazionisti è radicalmente
opposta: affidare per intero il proprio operare a un "lavoro
improduttivo" significa implicitamente sottrarlo alla possibilità di
trasformarsi in merce. Rifiutando di farsi "opera" (la cui produttività
"aggiunge nuovi oggetti al mondo umano artificiale")[^34], la situazione
-- come la forza lavoro -- "non "produce" altro che vita". Una vita che
non a caso i situazionisti definiscono correttamente in termini di
"esperienza".

L'"improduttività" situazionista non è comunque l'unico modo per
liberarsi dal carico di valori sociali da lungo tempo assunti come
"naturali". Non sono pochi i casi in cui gli architetti hanno cercato
almeno di infrangere il "cerchio magico" che racchiude in un unico
abbraccio progetto e realtà; rinunciando deliberatamente a quest'ultima
ed esonerando in questo modo il progetto dal compito di dover fare i
conti con essa. Ciò non spezza, sia chiaro, l'equazione architettura =
merce, dal momento che ogni progetto incarna, almeno potenzialmente,
entrambe. Di progetti non realizzati, ovviamente, ne esiste un numero
sterminato, senza che questo comporti una altrettanto alta ricorrenza di
casi in cui i progetti intendano opporsi intenzionalmente alla realtà.
Anzi, si potrebbe facilmente affermare che la maggior parte dei progetti
che rimangono tali anelerebbe sopra ogni altra cosa a essere realizzata.
Quanto invece qui interessa sono quegli assai più rari casi -- in tutti
i sensi "eccezioni" -- in cui il progetto mette in difficoltà, e
addirittura impedisce, ostacola letteralmente, la possibilità della
propria realizzazione, arrivando a *progettare* le condizioni della
propria irrealizzabilità.

Sarebbe fin troppo facile citare al proposito i molti progetti utopici
prodotti dalla cultura architettonica tra la seconda metà del Settecento
e gli ultimi decenni del Novecento: ai quali progetti tuttavia difetta,
nella gran parte di casi, la consapevolezza (o forse sarebbe meglio
dire, la disillusione) di essere inevitabilmente "dentro" per poter
essere davvero contro. La vera debolezza delle utopie, in questo senso,
non è tanto quella di non poter essere realizzate, quanto piuttosto
d'illudersi di non essere condizionate dalla realtà, di porsi come una
vera alternativa rispetto a quest'ultima. Ciò che è utopico in tali
progetti è proprio questa chimerica speranza. Cosí come ciò che in essi
finisce per essere davvero ineffettuale, più che il tentativo di
osservare il mondo con uno sguardo diverso, è la persuasione che tale
sguardo non appartenga comunque a "questo mondo", che possa esistere in
esso, nonostante esso.

Al di fuori delle utopie architettoniche e delle ideologie che
inevitabilmente vi sono connesse[^35], è in una dimensione meno carica
di "messianiche attese" che l'allontanamento del progetto dalla realtà
(ovvero dal rispetto delle condizioni per una sua realizzazione almeno
possibile) produce esiti più interessanti. Con intenti che si
presentano comunque critici o polemici -- anche se espressi a volte in
maniera silenziosa o sottile -- nei confronti del contesto economico,
sociale, politico, insomma del complessivo panorama valoriale in cui si
inseriscono (o che piuttosto rifiutano).

Tra i tanti che si potrebbero citare, un caso estremamente affascinante
da questo punto di vista è quello di John Hejduk. Dopo gli studi
compiuti in diverse università americane, come la Cooper Union di New
York e la Harvard University, viene chiamato a insegnare alla School of
Architecture di Austin (Texas), dove -- insieme ad altri colleghi tra i
quali Colin Rowe, Robert Slutzky, Werner Seligmann e Bernhard Hoesli --
dà vita al gruppo dei Texas Rangers[^36]. Anche grazie all'influenza
del lavoro astratto-geometrico -- grafico e pittorico -- di Josef Albers
(allievo e poi maestro del Bauhaus -- nonché insegnante del *Vorkurs*,
già tenuto da Itten -- prima dell'emigrazione negli Stati Uniti, quindi
direttore del Black Mountain College in North Carolina e del
dipartimento di Design alla Yale University) il gruppo sviluppa un
approccio al progetto architettonico tendente a marginalizzare i
problemi concreti come il programma, la funzione o gli aspetti
costruttivi, focalizzandosi invece su principî visuali e su
un'architettura intesa come disciplina autonoma. È in questo contesto
che Hejduk esplora le possibilità insite nella *nine-square grid*, la
griglia di nove quadrati come matrice per infinite variazioni
compositive. Su questi esercizi si basano le sette "Texas Houses",
elaborate tra il 1954 il 1963[^37]. Dopo diverse esperienze lavorative
presso studi di qualificati professionisti quali I. M. Pei and
Partners, nel 1965 Hejduk apre un proprio studio di architettura a New
York. Nei progetti che produce a cavallo di questi anni -- serie
Diamond (1963-67), serie 1/4, 1/2, 3/4 (1968-74), Wall Houses
(1971-73)[^38] --, il tema insistentemente affrontato è quello della
casa: tema che tuttavia, contrariamente a quanto non accada di norma,
esclude dal proprio orizzonte qualsiasi ipotesi di fattibilità. Facendo
ricorso a diverse "strategie" compositive (rotazioni, concentrazioni,
dimezzamenti, prolungamenti), Hejduk pone sul cammino del progetto
differenti generi d'impedimenti, tali da mantenere quanto più lontano
possibile da esso lo "spettro" della costruibilità. Si tratta con tutta
evidenza di un'architettura preoccupata di rispondere a requisiti
puramente teorici. Ma una "teoria" che ha ben poco di positivo da
dimostrare. Al di là di elementari figure geometriche e di forme
puriste di esplicita discendenza lecorbusieriana, questi progetti di
case o di altri tipi di spazi non contengono altro che l'esatto
contrario di quanto comunemente si potrebbe ritenere comodo, agevole,
funzionale. In questo senso va inteso, ad esempio, il lunghissimo
corridoio che collega-e-divide le stanze poste alle due estremità della
3/4 House; o che si "tende" all'infinito nella Gunn House; o ancora, che
fa da "spina" centrale nella Extension House: vere e proprie "barriere"
architettoniche che s'interpongono beffardamente all'usabilità della
casa; la quale, in tal modo, più che un rifugio, appare un luogo di
pena. Ed effetti analoghi si lasciano riscontrare nei progetti della
serie Diamond (Diamond House A, Diamond House B, Diamond Museum C), dove
lo spazio quadrato è recintato e scandito internamente da pareti
ortogonali o da forme curvilinee "libere" soltanto di rendere possibile
la circolazione dentro quella che si rivela essere a tutti gli effetti
una prigione.

Ha certamente ragione Manfredo Tafuri nel ritenere John Hejduk "il più
empirico e il meno intellettualistico"[^39] dei componenti del gruppo
dei New York Five, al quale aderisce in occasione dell'incontro
organizzato da Kenneth Frampton nell'ambito della Conference of
Architects for the Study of Environment, svoltosi al MoMA nel 1969[^40].
E tuttavia, tale empirismo dei suoi progetti teorici non si lascerebbe
definire meglio che come un tentativo di minare alle basi idee e
consuetudini che vogliono l'architettura (e in particolar modo quella
della casa) come qualcosa di lontano dalle insidie delle vuote
speculazioni, tutta assorbita dallo svolgimento di compiti utili, e la
cui perfetta integrazione alle regole del mercato è garantita dal
sistema stesso che la detiene e controlla. In forma essenziale, quasi
elementare, i progetti impossibili di Hejduk sembrano costituire
un'opposizione a tale sistema; un'opposizione niente affatto aggressiva,
bensì condotta con le "armi" di una serissima ironia e di un poetico
candore. Né d'altronde risulta inverosimile, nell'ottica della seconda
metà degli anni sessanta, ribellarsi alle logiche del professionismo
spersonalizzato dei grandi studi americani, dominati -- più che dagli
*architects* -- dai *builders*, occupati perlopiù in stanche repliche
degli stilemi dell'*International Style*. E farlo doveva essere tanto
più significativo dalla particolare prospettiva newyorkese.

Allorché Hejduk nel 1965 apre uno studio di architettura e inizia a
produrre i propri progetti lo fa non già per integrarsi a tale sistema,
bensì piuttosto per sottrarsi a esso. E anche in seguito -- con rare
eccezioni rappresentate dai pochi progetti realizzati, tutti accomunati
da un gusto per la giocosità e da un'irriverente irrisione nei confronti
del "buon senso" (dai surreali interventi effettuati all'interno della
Cooper Union School, a New York, alla "macchina celibe" dello Studio for
a Musician, fino agli stranianti edifici costruiti a Berlino nell'ambito
dell'Internationale Bauausstellung 1987)[^41] -- egli persisterà nella
sua volontaria "astensione" dalla realtà e in una ricerca del senso
dell'architettura al di là della sua costruzione, spostando
preferenzialmente la propria attenzione sul terreno del disegno e della
poesia. Rompendo i limiti dell'oggettività e fissità tradizionali, gli
edifici diventano cosí personaggi, oggetti-soggetti protagonisti di un
"viaggio" che da Venezia li porta via via a Praga, Berlino, Riga,
Vladivostok[^42]. Negli espressivi e infantili disegni che compongono i
libri-avventure di Hejduk rivivono lo spirito surrealista e
situazionista, ma soprattutto si agita uno spirito che nel rifiuto della
dimensione costruttiva-costrittiva dell'architettura non identifica la
sua negazione, quanto piuttosto vede la sua libertà dal reale come un
valore.

Sulla medesima lunghezza d'onda dell'"esposizione lucida e perversa
dell'inutilità del gioco intrapreso"[^43] dai progetti di Hejduk si
pongono le speculazioni sull'architettura elaborate da Peter Eisenman.
Il loro carattere è molto più intellettuale; la loro volontà
dimostrativa molto più stringente, e tuttavia non dissimili sono il
contesto in cui questi si muove e gli obiettivi che lo animano. In
particolar modo nel noto ciclo delle Houses I-X, progettate e in parte
realizzate tra il 1967 e il 1976, il tema centrale è quello delle
variazioni compiute su operazioni compositive ed elementi semplici e
lineari, ma via via resi sempre più complessi nelle loro relazioni: una
sorta di *ars combinatoria*, o di "grammatica trasformazionale" *à la*
Chomsky, alla quale peraltro Eisenman si rifà esplicitamente. Come già
nel caso dei progetti di Hejduk, anche qui l'architettura vive una vita
propria staccata dalla realtà: essa *parla di se stessa*, del proprio
sistema di segni privati di senso, autoreferenziali, tautologici. Ma
appunto, nell'affermare il linguaggio come perfettamente fine a se
stesso, si sancisce la separazione della forma architettonica dalla
dimensione esperienziale. Scrive Eisenman a proposito della House III
(1969-71), realizzata a Lakeville (Connecticut):

> Quando entra nella "propria casa", il proprietario è un intruso che
> tenta di prenderne possesso e, di conseguenza, distrugge, seppur in
> senso positivo, l'unità e la completezza iniziale della struttura
> architettonica[^44].

E Tafuri:

> La spietata operazione di Eisenman consiste nel riconoscere che non si
> dà lingua architettonica se non al di fuori della prassi, che il
> laboratorio sintattico evocato da oggetti perfettamente circoscritti
> nel colloquio dei segni fra loro *non ammette intrusi*[^45].

"Al di fuori della prassi": ancora una volta si ripresenta la non
accettazione dell'architettura come semplice "cosa pratica", come mera
*machine à fonctionner*. Ma ciò a cui s'oppone Eisenman, a ben
guardare, è qualcosa di più che il funzionamento o l'uso
dell'architettura: piuttosto è il destino di superfluità, di
"inoperatività" che ai suoi occhi l'architettura finisce per assumere
nell'epoca del capitalismo maturo. Ridotta a oggetto solo-funzionale,
essa rischia di diventare paradossalmente un oggetto inutile. Di tale
inutilità -- o per meglio dire, di tale *intransitività* -- le stesse
case di Eisenman, da lui stesso battezzate *Cardboard Architecture*
(architettura di cartone)[^46], sono la pur esile prova. Nella House
VI, ad esempio, realizzata con il nome di House Frank a Cornwall
(Connecticut, 1972-75), l'incrocio di piani verticali perpendicolari tra
loro produce una costruzione gremita di contraddizioni spaziali:
passaggi interdetti, collegamenti imprevisti, scale che finiscono nel
nulla. Le aporie dello spazio, concepite come parti inerenti al
sistema, ridanno alla casa un imprevisto interesse "autonomo": la casa
diviene interessante *in sé*, non in quanto capace di essere comoda o
funzionale, o per il suo valore di mercato.

Applicata al corpo concreto dell'architettura, tuttavia, la teoria
eisenmaniana dello "svuotamento di senso dei segni" si espone a
possibili "cadute"; o quantomeno, in certi casi risulta essere un piano
pericolosamente inclinato, come lo sono le pareti della House X (1975),
l'ultima della serie: una casa concepita come un'assonometria
tridimensionale, in cui la realtà è virtualmente "piegata" alla sua
rappresentazione e nella quale di conseguenza vivere sarebbe
letteralmente impossibile (e infatti non verrà realizzata). O come lo
sono -- ancora di più -- alcune sue opere degli anni ottanta e novanta
(Uffici della Koizumi Sangyo Corporation, Tokyo, 1988-90; Aronoff Center
for Design and Art, Cincinnati, 1988-96; Sede centrale della Nunotani
 Corporation, Tokyo, 1990-92, tutte realizzate), in cui singoli
 elementi e interi volumi si presentano storti al punto da mettere
 quasi a repentaglio il loro stesso utilizzo. È proprio qui che
 l'incursione della teoria all'interno dei territori della realtà
 mostra la sua debolezza. Fuori dalla zona di costitutiva ambiguità
 tra astrazione e realtà in cui vivevano i suoi primi progetti di case
 concettuali, le quali -- nonostante gli sporadici affondi nella
 materia -- rimangono comunque "fantasmi virtuali", corpi disincarnati
 fino ai limiti del possibile, le architetture successive di Eisenman
 riescono al più a mettere in scena una parodia del conflitto; la loro
 "decostruzione" del mondo è soltanto una maschera destinata a fornire
 a quel mondo l'ennesima copertura (*intellettuale*) con cui
 perpetuarsi, non certo la spia dell'aprirsi al suo interno di "crepe".
 Dietro la rottura dell'ordine non vi è la minaccia di alcun dissidio
 con il mondo bensì -- neanche troppo paradossalmente -- l'annuncio
 della nascita di una "nuova alleanza" con esso, come dimostra tra
 l'altro il consenso ricevuto dagli edifici sopra citati e da altri
 loro consimili da parte di diverse *corporations*. E lo stesso si può
 dire dell'"architettura non classica", "rappresentazione di se stessa,
 dei propri valori e della sua esperienza interna"[^47], che Eisenman
 teorizza e contestualmente realizza in quegli stessi anni;
 un'architettura auto-generata a partire da presupposti totalmente
 arbitrari, e che tuttavia -- unici -- garantirebbero a suo avviso una
 completa autonomia dalle tre *fictions* (rappresentazione, ragione,
 storia) sotto il cui giogo essa sarebbe rimasta dal Rinascimento fin
 quasi alla fine del XX secolo. Ma dare vita a "un'*architettura come
 discorso indipendente*, libero da valori esterni"[^48], esattamente
 come elevare l'arbitrarietà a nuovo fondamento, si dimostreranno
 possibilità tanto seducenti quanto in fin dei conti illusorie.

Al di là comunque di tutte le possibili fughe nel "mondo dei sogni"
della teoria e del progetto (e persino di quegli oggetti che -- pur
materiali e tridimensionali -- si lasciano agevolmente inquadrare in una
cornice di irrealtà, com'è il caso di quelli di Eisenman), a
un'architettura che pretenda di posizionarsi in maniera effettivamente
diversa rispetto alle logiche e all'universo valoriale dominanti si
richiederà di confrontarsi con questi in modo più stringente, più
sostanziale. Per spingersi oltre le facili apparenze di libertà o di
insubordinazione, insomma, o meglio ancora, per evitare di accontentarsi
di una semplice "*dis*simulazione" della libertà dai valori, è
necessario trovare qualcosa -- e qualcuno -- che sia in grado di
confrontarsi sul serio con la realtà. Con la ben precisa coscienza che,
nel compiere questo passaggio, architettura e architetto si trovano a
dover affrontare "appesantimenti" di vario genere assai più gravosi,
quali ad esempio il rispetto delle leggi fisiche, dei regolamenti
edilizi e di tutti gli altri vincoli -- espliciti o sottintesi -- che
appartengono al mondo reale.

Non sono numerosi -- stanti queste premesse -- i casi in cui un edificio
e il suo architetto possano dirsi davvero capaci di rompere norme e
convenzioni, *non* sul versante formale quanto piuttosto su quello delle
regole comunemente diffuse e accettate, mostrando cosí di saperle
modificare dall'interno. Tra queste rare eccezioni, vi è senza alcun
dubbio John N. Habraken, architetto olandese che ha dedicato la sua
intera carriera a una riconsiderazione integrale del ruolo rivestito da
sé o da altri all'interno del processo di produzione edilizia, e
conseguentemente a una modificazione dello stesso processo. Nel 1961
pubblica un libro, *De dragers en de mensen, het einde van de
massawoningbouw* (tradotto in inglese nel 1972 con il titolo *Supports:
An Alternative to Mass Housing*)[^49], che susciterà l'interesse
dell'ambiente accademico e professionale olandese. In stretta
connessione con ciò, nel 1964 viene fondato lo Stichting Architecten
Research (SAR), un'organizzazione per la ricerca nel settore della
residenza, finanziata da un gruppo di architetti olandesi e diretta
dallo stesso Habraken. Pur senza impegnarsi nella diretta redazione di
progetti, il SAR ha fornito la propria consulenza ad altri architetti,
amministrazioni pubbliche ed enti olandesi per coadiuvarne la
sperimentazione progettuale nel campo dell'edilizia residenziale.
L'idea elaborata da Habraken si basa sulla distinzione, all'interno dei
nuclei abitativi, tra elementi stabili, sia per la loro funzione che per
il loro contenuto tecnico, denominati "supporti" (*supports*), ed
elementi variabili, il cui utilizzo è più soggettivo e mutevole nel
tempo, denominati "unità staccabili" (*infills*). Rispetto alle
"tradizioni" precedenti (compresa quella moderna) si istituisce cosí una
prima differenza: se infatti i supporti devono essere messi in opera in
cantiere, le unità staccabili sono prodotte dall'industria. Ma la
distinzione riguarda anche i soggetti coinvolti nel processo di
definizione di ciascun nucleo residenziale: se per i *supports* è ancora
indispensabile la presenza delle figure che di norma presiedono al
processo costruttivo (architetto, ingegnere), i "detentori del potere"
sulle *infills* sono invece gli utenti. Ed è a partire da qui che
Habraken svilupperà, negli anni seguenti, un discorso relativo alla
relazione esistente tra chi esercita il potere all'interno del processo
progettuale e la forma che questo assume. Cosí, come in tutti gli altri
casi,

> ... anche nell'edilizia di massa la morfologia esprime i valori di chi
> assume le decisioni: in questo caso l'élite intellettuale,
> professionale, che stabilisce i giudizi di valore e ne risponde
> soltanto nei confronti del suo stesso gruppo sociale. Il dibattito
> sulla qualità -- su ciò che è valido o meno, su ciò che si deve o non
> si deve fare -- si svolge soltanto tra i professionisti. Le regole
> vengono fissate dagli stessi che le mettono in pratica. L'architetto
> che sostiene una nuova forma non si preoccupa di mettersi in contatto
> con i futuri utenti ma solo con le autorità. Le autorità ascoltano
> solo i professionisti e gli esperti. I risultati vengono poi
> confrontati sul piano internazionale attraverso riviste, congressi,
> mostre, visite: il dialogo tra professionisti continua[^50],

tralasciando del tutto coloro che -- in quanto direttamente implicati --
avrebbero al contrario il diritto di prendervi parte.

Pur essendo uno dei massimi sostenitori di un reale coinvolgimento,
ovvero di una "partecipazione", di tali soggetti, Habraken è anche molto
chiaro e realistico in merito: "Una partecipazione reale (...) può
essere basata soltanto su un rapporto di potere. (...) Chiedere
partecipazione significa che non si ha potere nell'ambito della
controparte". Il processo di partecipazione, pertanto,

> ... può funzionare soltanto se il rapporto si sviluppa tra due poteri
> che in qualche modo si equilibrano -- tra due poteri che operano in
> una diversa direzione e devono trovare un equilibrio. È necessario che
> nel processo entrambi i poteri siano identificabili e riconosciuti.
> (...) Finché questo equilibrio non esiste, i cosiddetti processi
> partecipatori sono soltanto un'espressione del problema, non la sua
> soluzione[^51].

È muovendo da questi presupposti che si può assumere nel suo significato
effettivo il "caso" del Villaggio Matteotti di Terni (1969-75), il cui
"artefice" è Giancarlo De Carlo: un intervento giustamente celebre, non
solo per i suoi esiti, che ne fanno un "frammento" di architettura di
grande qualità del secondo dopoguerra, nonché un complesso fortemente
identitario e unitario (nonostante la mancata realizzazione della parte
destinata ai servizi pubblici), ma soprattutto per la ragione che -- tra
i primi e i pochi casi in Italia -- il Villaggio ha visto appunto la
partecipazione degli utenti al processo di progettazione.

In realtà, quella della partecipazione, pur rivestendo un ruolo
importante, è soltanto una delle condizioni poste da De Carlo al
committente -- le Acciaierie di Terni -- per accettare l'incarico che
gli era stato offerto. E qui è interessante notare come la posizione di
De Carlo nei confronti della sua "controparte" sia abissalmente distante
da quella assunta dalla maggior parte dei colleghi suoi contemporanei, e
ancora di più dalla pressoché totalità degli architetti del giorno
d'oggi. Per comprendere quale sia con esattezza la posizione di De
Carlo basta leggere il testo scritto da lui stesso che ripercorre con
precisione la vicenda di Terni[^52]. Durante il fascismo, all'estrema
periferia sud-orientale di Terni, era stato realizzato un quartiere
operaio per i dipendenti delle Acciaierie. La situazione di degrado del
quartiere, l'assenza di servizi e la programmatica carenza di
collegamenti con la città suggeriscono alla direzione delle Acciaierie
di intervenire in qualche modo:

> La direzione propendeva per vendere le case ai loro abitanti e
> togliersi una volta per tutte il peso di dovere intervenire con forti
> spese di manutenzione o, peggio, di risanamento. I consigli di
> fabbrica invece sostenevano l'ipotesi di radere al suolo tutto e
> ricostruire sulla stessa area il volume di residenza che era
> consentito dal piano regolatore. Dopo lunghe discussioni, visto che
> non si trovava uno sbocco tra le due inconciliabili alternative, la
> direzione decideva di girare il problema a un architetto, e cioè a
> qualcuno che fosse in grado di risolverlo in termini puramente
> tecnici, e perciò inequivocabili[^53].

In quest'ultimo passaggio va sottolineata l'ingenua -- o piuttosto la
ben calcolata -- identificazione della figura dell'architetto con quella
del "tecnico": dove con questo termine la direzione delle Acciaierie
intendeva evidentemente alludere a qualcuno in grado di svolgere una
funzione -- e di fornire una prestazione -- oggettiva, misurabile,
"scientifica"; perfetta incarnazione, secondo le attese della
committenza, del "rifornitore" del sistema. E invece, l'architetto
prescelto disattenderà tale aspettativa:

> Ma l'architetto -- che poi ero io -- si rendeva subito conto che se
> avesse tagliato il nodo, invece di tentare di scioglierlo, si sarebbe
> trovato a svolgere un ruolo equivoco al servizio di un potere che non
> gli piaceva.

De Carlo mette a punto cinque diverse ipotesi di intervento: dal
risanamento integrale del vecchio villaggio, senza variare la sua
configurazione originale ma dotandolo dei servizi collettivi necessari e
ristrutturando integralmente gli edifici residenziali, alla sostituzione
del tessuto edilizio originale con un sistema di edifici a torri uguali
a quello già utilizzato in un altro intervento dalle Acciaierie di
Terni; dall'utilizzo di un sistema di edifici in linea analogo a quelli
utilizzati dagli istituti di case popolari in giro per l'Italia in
quegli anni, all'adozione di due possibili sistemi di edifici costituiti
da tre piastre sovrapposte all'interno delle quali sono previste
sequenze di edifici lineari includenti la residenza, i servizi di
diretta pertinenza dell'abitazione e i canali del movimento pedonale.
"Ciascuna delle cinque alternative era corredata dalla descrizione dei
vantaggi e degli svantaggi che comportava, in relazione ai diversi punti
di vista che era possibile considerare". Ma soprattutto:

> Le cinque alternative venivano consegnate e accompagnate da una nota
> nella quale si diceva che l'architetto sarebbe stato interessato a
> elaborare il progetto, e quindi ad assumere l'incarico, soltanto se la
> scelta fosse caduta sulla quarta o la quinta soluzione: le prime tre
> le Acciaierie avrebbero potuto attuarle in proprio o rivolgendosi ad
> altri che si sentissero di condividerle[^54].

Lungi dal mettersi completamente "al servizio" del suo committente, del
tutto prono di fronte alle richieste di questi, come suo puro
"rifornitore", De Carlo pone le condizioni in base alle quali è
disponibile a farsi carico del progetto. E non si tratta affatto di
richieste di ordine economico. Piuttosto, quelle alle quali egli mira
sono le condizioni che ritiene migliori *per il progetto*, e di
conseguenza migliori per chi dovrà usufruirne. Il concetto -- e la
pratica -- della "partecipazione" discendono precisamente da questi
presupposti. Nell'ottica di quest'ultima, "il compito del progettista
non è più di sfornare soluzioni finite e inalterabili, ma di estrarre le
soluzioni da un confronto continuo con chi utilizzerà la sua
opera"[^55]. Un *processo*, non più semplicemente un progetto[^56].

Ma la questione della partecipazione apre anche ulteriori prospettive
che De Carlo sviluppa solo parzialmente. Ad esempio quella relativa
alla "gestione del potere" intimamente connesso all'architettura.

Scrive De Carlo:

> Si ha la partecipazione quando tutti intervengono in egual misura
> nella gestione del potere, oppure -- forse cosí è più chiaro -- quando
> non esiste più il potere perché tutti sono direttamente ed egualmente
> coinvolti nel processo delle decisioni[^57].

L'idea di De Carlo, sulla scia delle tendenze del comunismo anarchico
verso cui era orientato[^58], è quella di una sorta di "dissoluzione del
potere" attraverso la sua condivisione. In realtà, ciò che qui egli
sembra soprattutto voler mettere in discussione fino alle sue radici è
il ruolo dell'architetto: "La prospettiva che mi sembra molto
interessante è quella di sottrarre l'architettura agli architetti per
restituirla alla gente che la usa"[^59]. È l'architetto che può e che
*deve* compiere -- ai suoi occhi -- un atto di rinuncia nei confronti
della propria stessa natura di *autore* (della propria *auctoritas*,
dunque), per far divenire il progetto davvero utilizzabile dai suoi
fruitori.

Ma se l'architetto può arrivare a compiere questa rinuncia, rendendo
l'architettura, attraverso la partecipazione, "sempre meno la
rappresentazione di chi la progetta e sempre più la rappresentazione di
chi la usa"[^60], ciò può avvenire soltanto a patto che l'architetto
stesso abbia compiuto un'altra "liberazione", esattamente simmetrica
alla prima, nei confronti della committenza. È infatti evidente come a
quest'ultima non possa essere forzatamente richiesto di essere sensibile
alle esigenze dell'utenza, né imposto un ascolto attento di essa.
Quando ciò si verifica, va ritenuta più una fortunata eccezione che non
un'indefettibile regola. Se l'esperienza descritta da De Carlo
testimonia di una sia pur cauta apertura da parte del committente alle
richieste dell'architetto, attesta altresí in maniera inequivocabile
l'*autonomia* dell'architetto nei confronti della sua "controparte".
Nel saper rifiutare (o quantomeno riformulare) il proprio ruolo di
"tecnico", De Carlo reimposta il rapporto con la committenza in termini
*politici*. E come in tutte le questioni di carattere politico,
l'efficacia o meno di una data azione si misura sulla base della
capacità di persuadere (o di lasciarsi persuadere) dei suoi "attori",
ovvero sulla base dei rapporti di forza esistenti tra loro. Non deve
stupire, in tal senso, che De Carlo non sia riuscito a vincere per
intero la propria battaglia, e anzi sia stato costretto a incassare
diverse sconfitte. Soltanto la sua presa di distanza dalle pretese
della committenza, comunque, ovverosia la sua manifesta indipendenza da
esse, ha reso possibile il Villaggio Matteotti nelle forme e nei modi
attuali: un intreccio strettissimo di spazi residenziali, spazi comuni e
spazi aperti; quasi un labirinto tridimensionale, o una *casbah*
moderna, in cui cemento armato e natura, anziché essere posti in
alternativa o in antitesi, convivono in una relazione dialettica, in
condizione di confrontarsi e di fondersi. Ma soprattutto, un
insediamento *umano* prima ancora che urbano, una *comunità organica*
dove gli abitanti ritrovano una centralità che altrove, nell'epoca
contemporanea, appare ormai inesorabilmente perduta.

Pur non essendo frequenti, le "lotte" dell'architetto per ottenere
condizioni migliori non sono tanto rare da potersi dire inesistenti.
Anche se spesso non giungono alla notorietà del caso appena citato,
consumandosi senza troppi clamori, nell'"anonimato" del rapporto tra
committente e architetto, queste "lotte" hanno come obiettivo di
ridefinire, almeno provvisoriamente e localmente, le modalità con cui
viene prodotta l'architettura, dal progetto preliminare all'edificio
finito. Si potrebbe ritenere che oggetto di simili "rivendicazioni" sia
immancabilmente la richiesta di miglioramenti del trattamento economico
da parte dell'architetto. In realtà, pur non escludendo certo questa
possibilità, in moltissimi casi l'architetto si batte pure per un
innalzamento della qualità del progetto, oppure -- ciò che non è poi
tanto diverso -- per un allungamento dei tempi della sua esecuzione, con
un conseguente beneficio nelle condizioni di lavoro e un aumento
dell'accuratezza nella sua attuazione.

Qualunque sia l'oggetto e il tenore di tali trattative (o -- in certi
casi -- bracci di ferro), l'elemento costante è che da esse rimangono
esclusi gli utenti dell'edificio in questione, futuri proprietari o
locatari che siano. Anche quando -- assai raramente -- è prevista una
loro compartecipazione alla definizione del progetto (come nel caso
appena citato, ad esempio), i destinatari dell'architettura hanno scarsa
o nessuna voce in capitolo, soprattutto in merito agli aspetti economici
relativi al "bene" a cui intendono accedere. È proprio quello
dell'accessibilità al "bene"-architettura (nella gran parte dei casi, la
residenza) il problema con cui in ogni parte del mondo è costretta a
confrontarsi un'enorme quantità di persone. Non c'è bisogno di
rileggere i "classici" testi di Friedrich Engels[^61] per sapere quali
siano i problemi che le classi economicamente più disagiate -- ancora
oggi -- devono fronteggiare per potersi "permettere" la "propria"
abitazione: un'abitazione il cui costo -- si tratti di affitto o di
proprietà -- è spesso fonte di indebitamento. Senza dimenticare che il
crollo finanziario del 2008, cui è seguito un lungo periodo di crisi
economica, è stato causato dall'esplosione della "bolla" dei mutui
*subprime*, concessi a persone dall'insufficiente capacità di assolvere
a essi.

È per questa ragione che un ulteriore modo di essere fattivamente
"dentro e contro" le regole imposte dal mercato -- ma anche "dentro e
contro" le condizioni che, in molti paesi del mondo, portano alla "falsa
alternativa" della realizzazione di insediamenti spontanei, "informali"
-- è rappresentato dalla strategia attivata da Alejandro Aravena
attraverso il programma Elemental. Avviato nel 2001 in Cile, suo paese
natale, insieme all'ingegner Andrés Iacobelli e all'architetto Pablo
Allard, anch'essi cileni, incontrati alla Harvard University, tale
programma utilizza il sussidio statale a fondo perduto di 7500 dollari
americani, concesso alle fasce più povere della popolazione dal
programma Vivienda Social Dinámica sin Deuda (Edilizia sociale dinamica
senza debito) del ministero per la Casa e l'Urbanistica cileno, per
realizzare una casa migliore -- in termini dimensionali e qualitativi --
di quanto non sia quella normalmente assegnata dallo Stato con i
medesimi fondi. La somma stanziata doveva essere in grado di coprire i
costi del terreno, nonché quelli della progettazione e della costruzione
di ogni singola unità abitativa.

L'approfondita ricerca compiuta da Aravena e da un team di altri
architetti ed esperti in diverse materie porta all'individuazione dei
requisiti indispensabili per rendere l'abitazione sociale un
investimento e non una semplice spesa per la collettività:

> Tutti noi, quando compriamo una casa, ci aspettiamo che incrementi il
> suo valore. Questa è la ragione per cui una casa, quasi per
> definizione, è un investimento. Sfortunatamente, non è quel che
> succede con l'edilizia sociale. L'edilizia sociale è più simile
> all'acquisto di un'automobile che a quello di una casa: ogni giorno
> che passa, il suo valore diminuisce[^62].

Perché ciò possa avvenire, la stessa abitazione deve diventare uno
strumento per il superamento della povertà, e non un semplice riparo
dall'ambiente circostante. Per Elemental i requisiti fondamentali sono
il posizionamento non troppo lontano dal centro delle aree sulle quali
far sorgere i nuovi insediamenti, per evitare che si creino disagi nel
raggiungimento del posto di lavoro e della scuola da parte degli
abitanti; la possibilità che le unità abitative si espandano rispetto ai
36 m^2^ iniziali, fino a un massimo di 72 m^2^ totali; la possibilità
che questa seconda metà della casa venga realizzata dagli stessi
abitanti con tecniche di autocostruzione a costi molto bassi; la
partecipazione dei medesimi utenti alle scelte progettuali, e in
generale il loro consenso alle operazioni compiute. Al proposito
scrivono gli autori del programma:

> Come nel judo, intendevamo prendere la forza del nostro avversario --
> in questo caso la scarsità di mezzi -- e usarla a nostro vantaggio,
> ridirigendola verso gli obiettivi del nostro progetto. Nello
> specifico ci siamo concentrati sulle costituzionali capacità
> organizzative delle famiglie[^63].

Il primo, storico intervento realizzato da Elemental, terminato nel
2004, si colloca a Iquique, città situata nel nord del Cile, in una zona
desertica del paese. Assegnato dal programma ministeriale Chile Barrio,
il sito, denominato "Quinta Monroy", è collocato in una parte centrale
della città, e nei trent'anni precedenti l'intervento era stato occupato
da un centinaio di famiglie che vi avevano costruito delle residenze
informali. Il problema tuttavia non si presenta di facile risoluzione:

> Se per rispondere alla richiesta avessimo assunto 1 casa = 1 famiglia
> = 1 lotto, saremmo stati in grado di ospitare solo 30 famiglie sul
> sito. (...) Se per cercare di usare il terreno in modo più efficiente,
> avessimo impiegato delle case a schiera, anche riducendo la larghezza
> del lotto fino a farlo coincidere con la larghezza della casa, e
> ancora di più, con la larghezza di una stanza, saremmo stati in grado
> di ospitare solo 60 famiglie[^64].

La soluzione trovata -- basata sull'idea di corpi edilizi disposti su
tre livelli alternati a spazi vuoti utilizzabili per le possibili
espansioni, consente di alloggiare tutte le 93 famiglie e al tempo
stesso di effettuare gli ampliamenti delle unità abitative.

Da un punto di vista architettonico, le case Elemental (replicate in
seguito in diverse altre località in America Latina, anche al di fuori
del Cile, per un totale di qualche migliaio di unità abitative
realizzate), in perfetto accordo con il loro nome, presentano
caratteristiche elementari, essenziali: parallelepipedi in pannelli di
cemento prefabbricati all'interno dei quali i progettisti si limitano a
disporre le componenti più complesse, che una famiglia raramente è in
grado di costruire da sola: solai, muri divisori, scale, impianti, bagni
e cucine. Il resto viene lasciato all'iniziativa degli abitanti,
monitorata però per evitare possibili abusi o situazioni di insicurezza.
Dal 2006, inoltre, con la creazione di un "Do Tank", la Elemental SA, la
prosecuzione del programma è stata resa possibile grazie al supporto
della Pontificia Universidad Catolica de Chile di Santiago (presso la
quale lo stesso Aravena insegna), e della Empresas Copec, una società
petrolifera cilena che estende i propri interessi anche ai settori
dell'energia, della pesca, della silvicoltura e del *real estate*.

Senza bisogno di dettagliare ulteriormente un caso di per sé già molto
noto, vale la pena soffermarsi piuttosto su che cosa rende esemplare
Elemental dal punto di vista della capacità di confrontarsi con un
problema reale senza rimanere impigliati nei suoi meccanismi.
Innanzitutto il programma Elemental non è concepito con l'obiettivo di
conseguire riconoscimenti per coloro che se ne sono occupati, o
risultati in qualche modo comparabili con quelli che fanno bella mostra
di sé nelle monografie o nei siti dedicati ad altri architetti.
L'obiettivo di Elemental è rendere economicamente sostenibile
l'acquisizione di una casa per una tipologia di abitanti che nelle
condizioni normali sono invece obbligati a sottostare, alternativamente,
al "capestro" della contrazione di un mutuo per diventare proprietari di
casa, o anche semplici affittuari (entrambe condizioni spesso
inarrivabili per costoro), oppure al "capestro" di accettare la "logica"
degli insediamenti "informali" (leggi *villas miseria*, *poblaciónes
callampas* o *favelas*, a seconda delle lingue e dei luoghi), con tutti
i problemi che questo comporta. Non meno rilevante è il benessere
sociale degli abitanti, che implica l'inserimento delle case in contesti
accettabili in termini di collocazione urbana e di sicurezza, e la
creazione di spazi collettivi. Ma altrettanto prioritaria, per
Elemental, è la qualità del progetto, strenuamente difesa non come un
valore in sé (e per sé), bensì come condizione indispensabile
all'ottenimento degli altri obiettivi.

Per raggiungere tutto ciò Aravena e i suoi soci e collaboratori si
servono di tutte le forze a disposizione, deboli o potenti che siano: da
quelle degli abitanti, interpellati sulle scelte progettuali e resi
partecipi attraverso iniziative comunitarie, fino a quelle di un
soggetto potenzialmente "ostile" quale potrebbe essere considerato una
compagnia petrolifera. Senza falsi moralismi o pregiudizi ideologici,
con una combinazione di "realismo", "pragmatismo" e "ambizione"[^65],
Elemental analizza, comprende e utilizza con la massima precisione le
complesse dinamiche politiche, sociali, economiche connesse alle
operazioni che compie, fino a giungere al punto di *trasformarle* in
quegli aspetti essenziali che consentono di volgerle a proprio favore.

Naturalmente gli esiti progettuali potrebbero apparire non appetibili --
e conseguentemente non proponibili -- per uno standard occidentale,
anche nel campo dell'edilizia sociale; ma vanno tenuti presenti il
contesto e le condizioni emergenziali in cui Elemental si trova a
operare. E sono proprio questi fattori che rovesciano polarmente la
prospettiva del discorso fatto in precedenza: è accettando il confronto
con situazioni difficili, ovvero rinunciando a dedicarsi a progetti più
agevoli ma potenzialmente anche più "sensazionali", che Elemental
ottiene *sensazionali risultati*. Facendocela "con il poco". Dentro la
realtà e contro ogni attesa. A riprova di ciò si veda la copiosa messe
di premi e riconoscimenti raccolti in tutte le parti del mondo, dai
primi anni Duemila in avanti, dai progetti Elemental[^66], nonché il
Pritzker Prize assegnato nel 2016 ad Alejandro Aravena per lo stesso
progetto[^67]. Ed è significativo -- e quasi paradossale -- che sia
proprio la giuria del Pritzker Prize a riconoscere ad Aravena la
capacità di "trasforma(re) il professionista in una figura universale",
e a salutare con lui "la rinascita di un architetto più impegnato
socialmente", capace di "lottare (...) per affrontare le crisi abitative
globali (...) e trovare soluzioni veramente collettive per l'ambiente
costruito"[^68].

[^1]: Ludwig Mies van der Rohe, *Edificio per uffici* (1923), in Id.,
*Gli scritti e le parole*, a cura di Vittorio Pizzigoni, Einaudi, Torino
2010, p. 5.

[^2]: Vedi, tra gli altri, Ludwig Mies van der Rohe, *Architettura e
volontà dell'epoca* (1924), *ibid.*, p. 25.

[^3]: Ludwig Mies van der Rohe, *Minuta di un articolo* (1923), *ibid.*,
p. 7. Nello stesso testo, poche righe più oltre, è ribadita la natura
della *Baukunst* come "volontà dell'epoca tradotta in spazio".

[^4]: Massimo Cacciari, *Res aedificatoria. Il "classico" di Mies van
der Rohe*, in "Casabella", n. 629, dicembre 1995, p. 4.

[^5]: *Ibid.*

[^6]: Ludwig Mies van der Rohe, *Quello che intendiamo per formazione
elementare* (1924), in Id., *Gli scritti e le parole* cit., p. 19.

[^7]: Ludwig Mies van der Rohe, *Il costruire è legato alla vita*
(1926), in Id., *Gli scritti e le parole* cit., p. 35.

[^8]: Benjamin, *Esperienza e povertà* cit., p. 52.

[^9]: *Ibid.*, p. 56.

[^10]: *Ibid.*, p. 57.

[^11]: *Ibid.*, p. 53.

[^12]: Si riprendono qui le parole -- anch'esse già citate -- dell'altro
breve saggio, "gemello" del precedente, di Benjamin, *Il carattere
distruttivo* cit., p. 41.

[^13]: Johannes Itten, *Design and Form. The Basic Course at the
Bauhaus and later*, Thames and Hudson, London
1965. Sulle pratiche di insegnamento di Itten vedi, tra gli altri, Éva
Forgács, *The Bauhaus Idea and Bauhaus Politics*, Central European
University Press, London -- New York 1995.

[^14]: Marco De Michelis e Agnes Kohlmeyer, *Bauhaus-Bauhaus 1919-1933*,
in Id. (a cura di), *Bauhaus 1919-1933. Da Klee a Kandinsky, da Gropius
a Mies van der Rohe*, Mazzotta, Milano 1996, p. 18.

[^15]: Oskar Schlemmer a Otto Meyer-Amden, 14 luglio 1921, citato in
Peter Hahn, *Idee e utopie degli anni della fondazione*, in De Michelis
e Kohlmeyer (a cura di), *Bauhaus 1919-1933* cit., p. 48.

[^16]: Benjamin, *Esperienza e povertà* cit., p. 56.

[^17]: *Ibid.*, p. 53.

[^18]: Roberto Calasso, *L'innominabile attuale*, Adelphi, Milano 2017,
p. 14.

[^19]: Byung-Chul Han, *La società della stanchezza*, Nottetempo, Roma
2012, p. 15.

[^20]: *Ibid.*, p. 16.

[^21]: Benjamin, *Esperienza e povertà* cit., p. 57.

[^22]: Han, *La società della stanchezza* cit., p. 32.

[^23]: Walter Benjamin, *Il narratore. Considerazioni sull'opera di
Nicolaj Leskov* (1936), in Id., *Angelus Novus. Saggi e frammenti*,
Einaudi, Torino 1962, in particolare p. 243.

[^24]: Han, *La società della stanchezza* cit., p. 31.

[^25]: Benjamin, *Esperienza e povertà* cit., p. 58.

[^26]: Gilles Ivain, *Formulario per un nuovo urbanismo* (1953), in
*Internazionale Situazionista 1958-1969*, Nautilus, Torino 1994, fasc.
I, p. 16.

[^27]: *Informazioni situazioniste*, *ibid.*, fasc. V, p. 10. Vedi
inoltre Simon Ford, *The Situationist International. A User's Guide*,
Black Dog Publishing, London 2005; Simon Sadler, *The Situationist
City*, The MIT Press, Cambridge (Mass.) 1998.

[^28]: *Definizioni*, in *Internazionale Situazionista 1958-1969* cit.,
fasc. I, p. 13.

[^29]: Johan Huizinga, *Homo ludens* (1939), Einaudi, Torino 2002.

[^30]: *Ibid.*, p. 225.

[^31]: Francesco Careri, *Constant. New Babylon, una città nomade*,
Testo & Immagine, Torino 2001. Vedi anche Constant, *Un'altra città per
un'altra vita*, in *Internazionale Situazionista 1958-1969* cit., fasc.
III, pp. 37-40.

[^32]: *Definizioni*, in *Internazionale Situazionista 1958-1969* cit.,
fasc. I, p. 13.

[^33]: *L'urbanismo unitario alla fine degli anni '50*, in
*Internazionale Situazionista 1958-1969* cit., fasc. III, pp. 12-14.

[^34]: Arendt, *Vita activa* cit., p. 63.

[^35]: Su ciò vedi Karl Mannheim, *Ideologia e utopia* (1929), il
Mulino, Bologna 1999.

[^36]: Alexander Caragonne, *The Texas Rangers. Notes from the
Architectural Underground*, The MIT Press, Cambridge (Mass.) 1995.

[^37]: Kenneth Frampton, *John Hejduk: 7 Houses*, The Institute for
Architecture and Urban Studies, New York
1980. Scrive Hejduk a proposito di questi progetti: "Speravo di
stabilire un punto di vista, con la convinzione che attraverso una
disciplina autoimposta, uno studio intenso e circoscritto e un'estetica,
sarebbe stata possibile una liberazione della mente e della mano che
conducesse a visioni e trasformazioni della forma spaziale. (...) Se
l'evoluzione della forma prosegue o si ferma dipende dall'uso
dell'intelletto non come uno strumento accademico, ma come un elemento
di vita passionale": John Hejduk, *Statement 1964*, *ibid.*, p. 116.

[^38]: John Hejduk, *Mask of Medusa. Works 1947-1983*, a cura di Kim
Shkapich, Rizzoli, New York 1985, pp. 241-309.

[^39]: Manfredo Tafuri, *"Les bijoux indiscrets"*, in *Five architects
N.Y.*, a cura di Camillo Gubitosi e Alberto Izzo, Officina, Roma 1977,
p. 17.

[^40]: Su ciò, vedi *Five architects: Eisenman, Graves, Gwathmey,
Hejduk, Meier*, Museum of Modern Art, Wittenborn (New York) 1972.

[^41]: Hejduk, *Mask of Medusa* cit., pp. 310-25; K. Michael Hays,
*Sanctuaries. The last works of John Hejduk*, Canadian Centre for
architecture, Montreal and the Menil collection, Houston 2002.

[^42]: Vedi, tra gli altri, John Hejduk, *Vladivostok*, Rizzoli
International, New York 1989; Id., *Soundings*, Rizzoli International,
New York 1993.

[^43]: Tafuri, *"Les bijoux indiscrets"* cit., p. 18.

[^44]: Peter Eisenman, *House III*, in Aureli, Biraghi e Purini, *Peter
Eisenman. Tutte le opere* cit., p. 68.

[^45]: Tafuri, *"Les bijoux indiscrets"* cit., p. 16.

[^46]: Peter Eisenman, *Architettura di cartone. House I and House II*
(1972), in Id., *Inside out. Scritti 1963-1988* cit., pp. 57-74.

[^47]: Peter Eisenman, *La fine del Classico. La fine dell'Inizio, la
fine della Fine* (1984), in Id., *Inside out. Scritti 1963-1988* cit.,
p. 264.

[^48]: *Ibid.*, p. 263.

[^49]: John N. Habraken, *Strutture per una residenza alternativa*, Il
Saggiatore, Milano 1974.

[^50]: John N. Habraken, *L'ambiente costruito e i limiti della pratica
professionale*, in "Spazio e Società", n. 1, 1978, p. 80.

[^51]: *Ibid.*, p. 81. Sulla percezione e sul ruolo reale
dell'architetto odierno vedi anche il più recente John N. Habraken,
*Palladio's Children*, a cura di Jonathan Teicher, Taylor & Francis,
Oxon 2005.

[^52]: Vedi Giancarlo De Carlo, *Il Villaggio Matteotti a Terni*, in
Id., *L'architettura della partecipazione*, a cura di Sara Marini,
Quodlibet, Macerata 2013, pp. 97-112.

[^53]: *Ibid.*, p. 103.

[^54]: De Carlo, *Il Villaggio Matteotti a Terni* cit., p. 104.

[^55]: Giancarlo De Carlo, *L'architettura della partecipazione* (1973),
in Id., *L'architettura della partecipazione* cit., p. 70.

[^56]: *Ibid.*, p. 71.

[^57]: *Ibid.*, p. 61.

[^58]: Francesco Samassa, *"Un edificio non è un edificio non è un
edificio". L'anarchitettura di Giancarlo De Carlo*, in Id. (a cura di),
*Giancarlo De Carlo. Percorsi*, Il Poligrafo, Padova, pp. 125-61.

[^59]: *Ibid.*, p. 60.

[^60]: *Ibid.*, p. 78.

[^61]: Friedrich Engels, *La situazione della classe operaia in
Inghilterra* (1845), in Karl Marx e Friedrich Engels, *Opere complete*,
Editori Riuniti, Roma 1972, vol. IV, pp. 235-514; Friedrich Engels,
*La questione delle abitazioni* (1872), Editori Riuniti, Roma 1971.

[^62]: Alejandro Aravena e Andrés Iacobelli, *Elemental. Manual de
vivienda incremental y diseño participativo / Incremental Housing and
Participatory Design Manual*, Hatje Cantz Verlag, Ostfildern 2012,
p. 18; più in generale vedi anche Id., *Elemental Chile. A Handbook on
Progressive Housing*, Actarbirkhauser, Barcelona 2010.

[^63]: Aravena e Iacobelli, *Elemental. Manual* cit., p. 107.

[^64]: Aravena e Iacobelli, *Elemental. Manual* cit., pp. 92-94.

[^65]: *Ibid.*, p. 503.

[^66]: Tra essi, il Premio Bicentenario del governo del Cile nel 2004;
il Gran Premio Biennale alla XV Biennale di Architettura di Santiago del
Cile nel 2006; il Leone d'argento alla Biennale internazionale di
Architettura di Venezia nel 2008; il Brit Insurance Design Award a
Londra nel 2010; il primo premio INDEX a Copenhagen nel 2010; la
medaglia d'argento al premio HOLCIM a Basilea nel 2011; il primo premio
ZUMTOBEL a Vienna nel 2014.

[^67]: Nello stesso 2016 ad Aravena viene affidata la direzione della
Biennale internazionale di Architettura di Venezia. La mostra da lui
curata, "Reporting From the Front", intendeva scrutare l'orizzonte
dell'architettura attuale "alla ricerca di nuovi campi di azione,
offrendo esempi in cui più dimensioni vengono sintetizzate, integrando
il pragmatico con l'esistenziale, la pertinenza con l'audacia, la
creatività con il buonsenso": dall'*Intervento* di Alejandro Aravena, in
*Reporting From the Front*, 2 voll., catalogo della XV Mostra
internazionale di Architettura -- Biennale di Venezia, Studio Elemental,
Santiago del Cile, Marsilio Editori, Venezia 2016.

[^68]: Motivazioni del premio in *Alejandro Aravena of Chile receives
the 2016 Pritzker Architecture Prize*, in
<https://www.pritzkerprize.com/laureates/2016>. La giuria era composta
da Lord Peter Palumbo, Stephen Breyer, Yung Ho Chang, Kristin Feireiss,
Glenn Murcutt, Richard Rogers, Benedetta Tagliabue, Ratan N. Tata e
Martha Thorne.

# Libertà e architettura

> ... leggere l'ideologia architettonica come elemento -- secondario,
> forse, ma pur sempre tale -- di un ciclo di produzione ha come
> conseguenza il ribaltamento della piramide di valori comunemente
> accettata. Diventerà del tutto ridicolo, infatti, una volta adottato
> tale metro di giudizio, chiedersi quanto una scelta linguistica o
> un'organizzazione strutturale esprima o tenti di anticipare modi "più"
> liberi di esistenza[^1].

Yvonne Farrell e Shelley McNamara, curatrici della XVI Mostra
Internazionale di Architettura alla Biennale di Venezia 2018, hanno
scelto come titolo della manifestazione la parola *FREESPACE*. Lungo le
Corderie dell'Arsenale, nel padiglione centrale e nei numerosi
padiglioni nazionali sparsi per i Giardini, gli architetti invitati
hanno variamente interpretato lo "spazio libero" in questione: chi --
come Caruso St John, in collaborazione con l'artista Marcus Taylor --
lasciando interamente vuoto il Padiglione Britannico, e montando al di
sopra di esso una terrazza di legno sostenuta da un ponteggio metallico,
accedendo alla quale si poteva osservare la laguna dall'alto,
accomodarsi sulle sedie che vi erano disposte, prendere il sole o
sorseggiare il tè puntualmente servito alle 16; chi invece -- come
l'architetto portoghese Álvaro Siza -- disponendo all'interno
dell'Arsenale una panchina di marmo di forma semicircolare, fronteggiata
da un muro bianco altrettanto curvo, per offrire uno spazio di
raccoglimento e riposo agli stanchi visitatori; o chi ancora -- come lo
svizzero Valerio Olgiati -- collocando al termine della lunghissima
navata delle medesime Corderie una piccola selva di colonne, candide e
prive di ornamenti o di ordine. Non è chiaro, in quest'ultimo caso, a
quale libertà si volesse fare allusione. Lo si potrebbe ritenere uno
spazio evocativo, simbolico, anche se di che cosa precisamente non è
dato saperlo; o forse -- meglio ancora -- a ciascuno è lasciata la
libertà di attribuirvi il significato che gli pare.

Ma è soprattutto all'interno del progetto curatoriale di Farrell e
McNamara (architette irlandesi che a partire dal 1978 hanno dato vita
allo studio Grafton Architects), che lo "spazio libero" occupa un posto
centrale; un posto che le due curatrici hanno significativamente pensato
di segnare scrivendo un vero e proprio "manifesto". In esso si legge
tra l'altro:

> FREESPACE rappresenta la generosità di spirito e il senso di umanità
> che l'architettura pone al centro della propria agenda, concentrando
> l'attenzione sulla qualità stessa dello spazio.
>
> FREESPACE si concentra sulla capacità dell'architettura di offrire in
> dono nuovi spazi liberi a coloro che la utilizzano, nonché sulla sua
> capacità di soddisfare i desideri inespressi.
>
> FREESPACE celebra la capacità dell'architettura di trovare in ogni
> progetto una nuova e inattesa generosità, anche nelle condizioni più
> private, difensive, esclusive o commercialmente limitate.
>
> FREESPACE invita a riesaminare il nostro modo di pensare, stimolando
> nuovi modi di vedere il mondo, di inventare soluzioni in cui
> l'architettura provvede al benessere e alla dignità di ogni abitante
> di questo fragile pianeta.
>
> ...[^2].

Da questo "manifesto" promana un'idea ottimistica e umanistica
dell'architettura, un'idea che pecca indubbiamente di vaghezza e
astrattezza ma che altrettanto sicuramente prende le distanze dal modo
in cui l'architettura è generalmente intesa nell'epoca attuale:
un'architettura non soltanto finalizzata nella gran parte dei casi a
scopi commerciali ma anche del tutto immersa in una prospettiva
esclusivamente economica. Il "manifesto" di Farrell e McNamara, da
questo punto di vista, risuona più come un appello che come una
dichiarazione di poetica o la presa d'atto d'una condizione corrente. E
per quanto possa risultare ingenuo e sotto molti aspetti inattuale, tale
appello si presenta come la "novità" più interessante della Biennale
2018.

Pur con tutti i suoi limiti, l'appello lanciato dalle Grafton Architects
ha il merito -- se non di offrire soluzioni per esso -- almeno di
indicare il problema: quella libertà (dello spazio: ma il discorso si
lascia applicare anche a un contesto più generale) che a una prima
apparenza si direbbe a disposizione di tutti nelle società occidentali,
in realtà è proprio ciò che maggiormente si rivela sfuggente; non forse
assente del tutto, ma quantomeno *ambiguamente* presente.

Sarebbe però semplicistico illudersi di poterla afferrare esclusivamente
evocandola. Anzi, è proprio nelle sue troppo ripetute ostensioni che la
libertà dimostra attualmente di appartenere assai più al mondo delle
apparenze che non a quello della sostanza. Senza peccare di eccessivo
allarmismo, si può paradossalmente affermare che oggi l'esercizio della
"libertà" passa attraverso una miriade di condizionamenti. E lo stesso
vale anche per l'architettura. D'altronde, sono proprio i
condizionamenti (visibili e invisibili) a rendere avvertito e reattivo
chi cerca di svolgere il proprio lavoro *dentro* e *contro* le
circostanze assegnate. Ed è soltanto nella piena coscienza dei *limiti*
del proprio operare che diviene possibile ritrovare forme effettive di
libertà.

È a partire da qui che dev'essere reimpostato qualsiasi discorso
sull'architetto intellettuale. Ben lungi dall'identificarsi con una
vaga propensione culturale, o con un'inclinazione per sterili
speculazioni filosofiche o elucubrazioni mentali, il suo segno
distintivo sta nella capacità di appropriarsi di quei margini di libertà
che ogni società non per forza "offre" spontaneamente ma che tuttavia,
almeno a volte, consente.

In un mondo dominato da una relativistica pluralità di valori
(abissalmente distante da ciò che Max Weber definiva un "Polytheismus
der Werte")[^3], quello della libertà è uno dei pochi -- l'unico, forse
-- sul possesso del quale siamo assolutamente sicuri di non volere o
potere recedere. In altre parole, tra molti valori su cui si è disposti
a trattare -- e tra altrettanti ormai "fuori uso", avendo perduto la
loro importanza --, il valore della libertà resiste pressoché ovunque
nel mondo come una pietra di fondamento non alienabile. E ciò, tanto
per chi già ne usufruisce quanto per chi la deve ancora conquistare. Ma
la libertà ha un'altra caratteristica peculiare: è uno dei pochi valori
di cui si può ritenere di disporre anche quando in realtà non se ne
gode. È esattamente questa la condizione in cui si trova al giorno
d'oggi una buona parte delle società occidentali: una condizione che,
proprio per la varietà delle scelte che in apparenza vi si possono
compiere, e per la molteplicità e relatività dei valori che vi sono
presenti, conferisce a chi vi è introdotto una perfetta "sensazione di
libertà".

Michel Foucault negli anni sessanta parlava di "società
disciplinari"[^4], cioè di quelle società in cui ogni individuo è
incasellato dentro a un preciso spazio fisico. Le ricerche di Foucault
si riferivano a quella che egli stesso chiama l'"epoca classica"[^5],
vale a dire l'epoca moderna, storicamente intesa, e avevano come
fondamento un'idea molto esatta, e cioè che il potere si spazializza: il
potere non è mai assoluto, non è mai astratto, è sempre esercitato qui e
ora, all'interno di spazi fisici precisi. Gli spazi sono quelli che
Foucault analizza nei suoi libri, vale a dire il manicomio, l'ospedale,
la prigione, ma anche la caserma, la scuola, la fabbrica. Questi spazi,
pur diversi tra loro, hanno però tutti un elemento in comune: in tutti è
inscritto un "esercizio del controllo" che nel *Panopticon* (1787) di
Jeremy Bentham era espresso fisicamente, quasi geometricamente[^6], ma
che negli altri spazi ugualmente sussiste. Si tratta in tutti i casi di
spazi del controllo, organizzati precisamente a questo fine.

E tuttavia, nell'epoca moderna, mentre lo spazio viene organizzato in
termini di controllo, concresce anche l'idea di libertà[^7]. I due
fenomeni sono tutt'uno, come le due facce di una stessa medaglia. Non
per nulla lo stesso Bentham è uno dei padri del liberalismo, ovvero di
quella dottrina che al proprio centro pone i diritti individuali,
all'interno dei quali campeggia la libertà. Certo, quella delle società
disciplinari è una libertà in larga parte "vigilata"; e ciò nondimeno,
nell'accezione moderna del termine, vale a dire illuminista, in quanto
valore individuale assunto a fondamento sociale, la libertà nasce lí:
nel momento in cui ciascun individuo è inquadrato dentro lo spazio
fisico delle diverse "macchine" del controllo[^8].

Oggi, invece, la società disciplinare sembra essere stata soppiantata da
una società "trasparente". La "società della trasparenza", come la
chiama Han[^9], è la società digitale neoliberalista, dove la libertà si
è trasformata in un'occasione di sfruttamento:

> Il neoliberalismo è un sistema molto efficace nello sfruttare la
> libertà, intelligente perfino: viene sfruttato tutto ciò che rientra
> nelle pratiche e nelle forme espressive della libertà, come
> l'emozione, il gioco e la comunicazione. Sfruttare qualcuno contro la
> sua volontà non è efficace: nel caso dello sfruttamento da parte di
> altri il rendimento è assai basso. Soltanto lo sfruttamento della
> libertà raggiunge il massimo rendimento[^10].

più ancora che il lavoro, lo scontro tra classi o l'organizzazione
spaziale delle città, la vera frontiera critica odierna è divenuta la
libertà dell'individuo, sottoposto alla costante "attenzione" della rete
e di tutti gli altri invisibili sistemi di sorveglianza che ne rilevano
gli spostamenti, ne registrano gli acquisti, ne monitorano i
desideri[^11]; il tutto, con l'esplicito consenso -- o quantomeno, con
la muta "complicità" -- dell'individuo stesso. E ancora di più, senza
la minima parvenza di alcuna privazione della libertà individuale, e
anzi con quel senso di onnipotenza e di indipendenza che la società
digitale riesce a trasmettere, come ogni utente di Google, di Wikipedia
o di un qualsiasi social network ben sa: le cui possibilità, in termini
di relazioni e di informazioni, inducono spesso a credere di possedere
un'infinità di conoscenze, un'istantanea rapidità d'azione e
un'incondizionata fluidità di movimenti. Una somma di elementi che si
traducono appunto in una totale *illusione di libertà*.

Tanto più credibile e ingannevole è questa illusione, quanto meno
risulta coercitiva, ovvero quanto meno è -- almeno in apparenza --
coartata e vincolante. E proprio qui sta l'astuzia suprema di una
società "trasparente": all'interno di essa l'individuo non viene
ordinatamente disposto e inquadrato come nelle società disciplinari,
bensì -- proprio al contrario -- egli stesso vi aderisce spontaneamente
e quasi con entusiasmo. Ciascuno collabora alla sua costruzione, al suo
rafforzamento, al suo perpetuamento. La sensazione che ne deriva è di
essere "soggetti" perfettamente svincolati, perfettamente liberi; ma è
proprio in quanto tale, ovvero in quanto *subiectum* (letteralmente,
sottomesso, assoggettato)[^12] che l'individuo dimostra di essere assai
meno padrone del proprio destino di quanto comunemente non ritenga. In
tal modo si disvela tutta l'intrinseca *potenza* di una società della
trasparenza: in essa, infatti, non soltanto la libertà diviene il nuovo,
fertile terreno di uno sfruttamento, ma -- come sostiene Han -- tale
sfruttamento è opera del "soggetto" stesso, il quale cosí realizza un
*autosfruttamento* vero e proprio, divenendo schiavo di se stesso:

> L'io come progetto, che crede di essersi liberato da obblighi esterni
> e costrizioni imposte da altri, si sottomette ora a obblighi interiori
> e a costrizioni autoimposte, forzandosi alla prestazione e
> all'ottimizzazione[^13].

E ancora:

> I detenuti del panottico benthamiano venivano isolati l'uno dall'altro
> allo scopo di imporre una disciplina e non potevano parlare tra loro.
> Gli abitanti del panottico digitale, al contrario, comunicano
> intensamente l'uno con l'altro e si denudano volontariamente.
> *Con*tribuiscono cosí, in modo attivo, alla costruzione del panottico
> digitale. La società del controllo digitale fa un uso massiccio della
> libertà: essa è possibile soltanto grazie all'autoesposizione,
> all'autodenudamento volontari[^14].

E in effetti, nei contesti digitali, *noi, utenti*, consegniamo
quotidianamente, senza alcuna coercizione, i nostri dati, le nostre
vite, la nostra intimità, i nostri affetti, tutto quello che siamo
(pensieri, gusti, esperienze, ricordi) ai grandi motori di ricerca, ai
grandi social network. Liberi di essere-in-rete (ovvero, letteralmente,
*irretiti*), e dunque in condizione di spontanea schiavitú. Si tratta
di quello che Byung-Chul Han definisce un "capitalismo del like", che
"si distingue nella sostanza dal capitalismo del XIX secolo, che operava
mediante obblighi e divieti disciplinari"[^15]. *Mi piace*, *ci piace*:
è questa la frontiera di una libertà percepita come "naturale" da un
lato, e sfruttata dall'altro, e per questo doppiamente insidiosa.

Come si rapporta a tutto ciò l'architettura? Quali trasformazioni
subisce -- o piuttosto, mette in atto -- nell'epoca della libertà
autoimposta? In una prospettiva moderna, l'architettura che si fregiava
orgogliosamente di questo aggettivo faceva della libertà il proprio
vessillo: libertà assunta come un affrancamento dell'uomo dai vincoli a
cui aveva dovuto sottostare fino ad allora, e che si traduceva tutta in
termini spaziali. *Plan libre*, *façade libre*, risuonano cosí -- non a
caso -- due dei "comandamenti" lecorbusieriani per "un'architettura
assolutamente nuova, dalla casa d'abitazione fino al palazzo"[^16]. Ma
se per l'ideologia dell'architettura moderna la libertà è una conquista,
per la postmodernità libertà e architettura sembrano ormai coincidenti.
A dire il vero, più che di libertà, si dovrebbe parlare di
"liberazione"[^17]. A questa si possono riferire alcune delle pratiche
o tendenze postmoderniste, quali "un certo carattere ludico della forma,
la produzione aleatoria di nuove forme o l'allegra cannibalizzazione di
quelle vecchie"[^18]. Sono tutte modalità relative a -- e sotto diversi
aspetti "reattive" nei confronti di -- quanto le ha precedute,
espressamente finalizzate, non per nulla, a una sovversione totale dei
"vari rituali" e dei "valori formali" modernisti.

Al giorno d'oggi l'opera di liberazione postmodernista dagli "spettri"
modernisti può dirsi pienamente compiuta nella misura in cui,
abbandonata l'esclusiva tattica del rovesciamento, l'architettura
odierna utilizza *qualunque mezzo* a sua disposizione per ottenere "ciò
che vuole", ivi *comprese* le forme e i linguaggi moderni. Ripuliti dei
loro retaggi ideologici, spogliati ormai di qualsiasi "messaggio", tali
forme e linguaggi possono cosí tornare a essere usati (insieme,
potenzialmente, a tutti gli altri). Ciò nondimeno, non si tratta
affatto di un uso neutrale, meramente "tecnico". Il ritorno a forme e
linguaggi moderni -- se possibile, sottoposti a depurazioni ulteriori --
ha il ben preciso obiettivo di fare dell'architettura attuale un emblema
della libertà in una misura in cui forse neppure alle origini,
nell'epoca moderna, era immaginabile farlo. Campioni assoluti di questa
aspirazione a incarnare la "filosofia" (ma al tempo stesso anche
l'economia, il *lifestyle*) della società della "trasparenza"
contemporanea sono proprio gli edifici che rappresentano le grandi
aziende produttrici, promotrici e diffonditrici dei prodotti digitali.
Loro modello è con piena evidenza la leggerezza, la flessibilità,
l'ingegnosità propria dei dispositivi elettronici contemporanei. Cosí
gli Apple Store sparsi per il mondo, ad esempio (si pensi soltanto a
quello sulla Fifth Avenue a Manhattan, di Bohlin Cywinski Jackson, 2006,
e a quello più recente in piazza Liberty a Milano, di Norman Foster +
Partners, 2018) si fanno portatori di un'estetica che è la precisa
traduzione dell'immaterialità e della virtualità dell'universo
informatico e del web: pareti vetrate, interamente trasparenti;
superfici lisce e candide; una luce uniforme, diffusa. Immagini di uno
spazio tridimensionale, per quanto possibile privo di "corpo", che
infonde in chi lo attraversa e vi sosta la sensazione di una completa
assenza di gravità: spazio al di sopra di ogni pensiero, di ogni
"affanno", dove l'essere-liberi coincide semplicemente con l'essere.
Uno spazio dunque dove tutto è possibile, in cui nulla pesa, neppure
l'acquisto di uno smartphone o di un laptop.

Nella storia -- si usa dire -- i fatti si presentano sempre due volte:
"la prima volta come tragedia, la seconda volta come farsa"[^19]. Verso
la metà degli anni sessanta, a fronte del progressivo esaurirsi della
"funzione storica" dell'architettura moderna, gli architetti si sono
trovati a un bivio: abbandonarla a favore di un suo superamento, oppure
conservarla radicalizzandone (ovvero depurandone e stilizzandone al
massimo) gli aspetti formali. Da questa seconda possibilità nasce il
"minimalismo", l'*ultimo* degli stili, non in senso cronologico ma
logico; lo stile che -- shakerando estetica giapponese e Mies van der
Rohe, più un'abbondante aggiunta di ghiaccio -- ottiene il brillante
risultato di far passare per sobri ambienti nella gran parte dei casi
lussuosi[^20]. Quarant'anni più tardi, il minimalismo ritorna come
"risposta" alla crisi economica mondiale, ma anche come stile di un
capitalismo che preferisce pur sempre ottenere "migliori risultati con
meno mezzi"[^21]. Non è dunque un caso che, nei luoghi di massima
"intensificazione" della società "trasparente", tali caratteri si
presentino al massimo livello di concentrazione. Né deve stupire che
questi stessi caratteri, gradatamente, fuoriescano dall'invisibile
"recinto" dei *flagship stores*, arrivando a conformare anche altri
spazi commerciali. Il Westfield World Trade Center Mall (noto anche
come Oculus), progettato da Santiago Calatrava e inaugurato a Manhattan
nel 2016, ne costituisce un esempio emblematico. Costruito accanto al
luogo in cui sorgevano le Twin Towers, con le sue candide ali distese
pronte per spiccare il volo, l'edificio dall'esterno sembrerebbe voler
rinverdire la tradizione dei *landmarks*. Ma la sua vera natura si
rivela non appena varcato l'ingresso, accedendo alla grande piazza
ellissoidale che ospita lo shopping center. Qui, sotto la muscolare
copertura, caratteristica anche di altri edifici dell'architetto e
ingegnere spagnolo, lo spazio sembra perdere i propri contorni,
smaterializzarsi, svanire. Nell'epoca delle "piazze virtuali", la
piazza reale dell'Oculus pare faccia un passo indietro rispetto alla
realtà, per "virtualizzarsi" a sua volta. Condizione apparentemente
imprescindibile, questa, per infondere quel "senso di libertà" che
avvince i consumatori con il potere del *like*.

In altre occasioni l'architettura della società della trasparenza assume
toni esplicitamente ludici. È il caso del Googleplex a Mountain View
(Silicon Valley -- California), quartier generale di Google, terminato
nel 2004 ma negli anni seguenti continuamente rinnovato, soprattutto per
quanto riguarda gli spazi interni. Dall'esterno gli edifici del
Googleplex presentano un aspetto riconducibile -- con poche e in fondo
marginali correzioni -- a quell'"efficientismo internazionale" che è lo
stile dominante delle sedi delle grandi compagnie in tutto il mondo. Ma
è dentro gli edifici che accadono le cose più interessanti. Il
brillante e spiritoso "stile della casa", impresso come un saluto di
benvenuto nel logo multicolore dell'azienda, e riassumibile nella parola
d'ordine "smart", produce ambienti che sono interamente penetrati dalla
"filosofia" Google: gli uffici (o quelli che dovrebbero essere tali) e
gli altri spazi di lavoro sono concepiti con l'esplicito intento di
comunicare l'idea che "qui non si lavora": ci si diverte. *Smart
working*. E in effetti, all'interno di questi spazi si può giocare
davvero. Il carattere ludico si incorpora in essi come una componente
essenziale. *Google Play*. E non certo come induzione all'ozio, bensì
per ottenere una maggiore produttività, una maggiore efficienza, una
maggiore creatività[^22]. Lavoro e divertimento finiscono per diventare
una cosa sola, un'unica e indissolubile condizione. L'*homo ludens*
situazionista viene cosí recuperato al sistema, "messo al lavoro" senza
quasi che se ne accorga.

Non è un caso che nel vocabolario dell'architettura attuale siano
prepotentemente entrati -- ormai anche a grande distanza dalla Silicon
Valley, e con specifico riferimento agli spazi del lavoro e del
commercio -- termini come "intelligente", "flessibile", "ibrido"; e che
gli ultimi miti dell'agenda contemporanea siano "stare insieme",
"condividere", "interagire". In modo lampante, Google *docet*. Gli
spazi fisici in cui si svolgono queste azioni al giorno d'oggi vengono
diffusamente pensati ed offerti come luoghi capaci di infondere in chi
li utilizza felicità e benessere, prima e più ancora che idee di
sobrietà ed efficienza. Per suscitare queste sensazioni gli spazi
lavorativi sempre più di frequente si travestono da luoghi d'abitazione
(fenomeno esattamente speculare a quello dell'*home working*).
Familiarità, informalità, *libertà* della casa diventano i nuovi *idola*
del "lavoro intelligente". Forse non abbastanza però da non far sorgere
il dubbio che sia proprio *questo* il luogo di attuazione della
minacciosa promessa di Auschwitz: "Arbeit Macht Frei".

Intanto, a poche miglia dal Googleplex, a Cupertino, sorge l'Apple Park,
realizzato da Norman Foster + Partners e aperto nel 2017. Si tratta di
un edificio a forma di anello interamente vetrato, di oltre 450 m di
diametro e di 1,6 km di circonferenza, cui si va ad affiancare lo Steve
Jobs Theater, di dimensioni molto più ridotte ma anch'esso circolare e
completamente vetrato nella parte emergente. Nell'epoca del panottico
digitale -- senza forma, immateriale, ubiquo -- ritorna
imprevedibilmente in scena il panottico benthamiano: lo spazio di un
controllo fisico, che nel caso dell'Apple Park però è da intendersi in
senso soltanto metaforico. Anzi, a ben guardare, in un senso
esattamente rovesciato rispetto a quello originario: la forma del
controllo disciplinare come "dimostrazione" della libertà digitale.

A immagini come queste, di una sin troppo *ambigua* libertà, il panorama
architettonico contemporaneo -- sovraffollato di molteplici offerte e
all'apparenza assai variegato -- sembra poter agevolmente fornire la
*chance* di contrapporne altre più autentiche, e al tempo stesso più
"esterne al sistema". Gli esempi potrebbero essere tanti, quanto
soggettive le scelte. Meglio rivolgersi allora a chi ha affrontato il
tema in maniera cosciente. In una serie di conferenze organizzate da
Owen Hopkins alla Royal Academy of Arts di Londra nel 2015 su
*Architecture and Freedom* ("L'architettura è in balia degli interessi
privati e dei bisogni del capitale come mai prima d'ora")[^23], Reinier
de Graaf (OMA), J.MAYER.H, Farshid Moussavi (FMA, già FOA) e Patrik
Schumacher (Zaha Hadid Architects) hanno presentato i loro punti di
vista sul tema. Quattro architetti diversi, per provenienze ed
esperienze, che hanno però tutti in comune un'attività all'interno di
grandi studi internazionali operanti su scala globale, ma anche
un'attenzione per la speculazione teorica, secondo un intreccio di piani
che appartiene di diritto all'eredità degli architetti intellettuali.
Pur non essendoci la possibilità di analizzare nei dettagli le
argomentazioni dibattute da ciascun relatore, è interessante notare come
gli architetti in questione -- con la sola eccezione di Reinier de
Graaf, impegnato a dimostrare come il mondo in cui si trova a operare
OMA dopo il 1991, in seguito alla dissoluzione dell'Unione Sovietica,
non sia affatto unito nell'abbraccio delle democrazie liberali
occidentali, come sentenziato da Fukuyama[^24]; e come ciò, dal punto di
vista di uno studio di architettura, non rappresenti un dramma --, più
che compiere una critica della condizione attuale, prendano casomai lo
spunto da questa per inserire la propria architettura nei processi in
atto, cercando di leggerli nella maniera il più possibile coerente con
essa. Cosí per Schumacher soltanto il parametricismo può farsi
interprete delle dinamiche urbane di un libero mercato "sfrenato" in una
società post-fordista, riuscendo ad accordare -- in maniera analoga al
complesso e variegato ordine degli ambienti naturali -- le molteplici
forze che vi con-fluiscono[^25].

Per Jürgen Hermann Mayer la libertà sembra più che altro consistere in
un carico di potenzialità -- tecnologiche e comunicative -- per le
attività umane che la sua architettura cerca di tradurre facendosi
generatrice e luogo d'incontro di interazioni sociali, come nella
copertura -- terrazza -- spazio urbano *Metropol Parasol* in Plaza de la
Encarnación a Siviglia (2004-11)[^26]. Farshid Moussavi infine, pur con
abbondanza di citazioni e definizioni filosofiche del concetto di
libertà, riconduce la questione a una sorta di *aut aut* tra "stile"
come affermazione di identità (dell'architetto) e stile come performance
dell'edificio e dei suoi singoli elementi, analizzati minuziosamente e
progettati sforzandosi di avvicinarli al massimo grado a un loro uso
"partecipato" [^27].

In conclusione, chi nelle parole degli architetti citati cercasse una
bussola per orientarsi nella ricerca di una "rappresentanza" in un mondo
in profondo mutamento rischierebbe di rimanere deluso. Per molti di
loro, a quanto sembra, quello della libertà non costituisce affatto un
problema, al contrario di quanto è accaduto in altri momenti ad altri
architetti[^28].

Tra gli ultimi tentativi in ordine di tempo di affrontare il tema del
rapporto tra libertà e architettura va citata la mostra dedicata dalla
Fondation Cartier pour l'art contemporain di Parigi, tra marzo e giugno
2018, all'opera del giovane architetto giapponese Junya Ishigami.
Ospitata nei diafani spazi pensati da Jean Nouvel (a loro volta
un'ipotesi di libertà costruita)[^29], la mostra *Freeing Architecture*
presentava 17 progetti elaborati da Ishigami tra il 2004 e il 2018. Che
cosa egli intenda con "liberazione dell'architettura" si lascia intuire
osservando i grandi modelli e gli altri materiali in esposizione:
espressione di un'architettura a volte essenziale, strutturalmente
ardita ma figurativamente esile, al limite dell'anoressia, altre volte
ottenuta scavando, per sottrazione di materia, altre ancora mediante il
processo esattamente opposto, di accumulazione di quelle che potrebbero
apparire masse glaciali che danno luogo a corpi globosi e cavernosi.
Un'architettura al tempo stesso "minimale" e desiderosa di sorprendere,
ma anche perennemente tesa nella ricerca di un'integrazione con la
natura. Ciò di cui sembra volersi liberare l'architettura di Ishigami
sono dunque i legami con quei retaggi disciplinari che provino a
irreggimentare l'edificio da un punto di vista tipologico, funzionale,
spaziale, strutturale. La riscrittura da lui proposta in tal senso vale
come tentativo di sottrazione dell'architettura dai *nomoi* che di
consueto la regolano, per (ri)condurla a una sorta di "età
dell'innocenza", dove essa possa continuare a sussistere in una
dimensione "sospesa". E ancora di più, questo "disegno" risulta palese
esaminando il catalogo, un libro di grande formato, illustrato con
immagini a metà strada tra l'infantile e il pittorico, inframezzate da
brevi testi dal tono quasi poetico[^30].

L'ingenuità di tali intendimenti è però almeno in parte contraddetta
dall'efficacia dei risultati ottenuti dalle opere realizzate da Junya
Ishigami. È il caso del KAIT Workshop, un edificio concepito come spazio
per gli studenti del Kanagawa Institute of Technology, in Giappone
(2004-2008). In questo spazio essi possono progettare, scrivere ma
anche chiacchierare e oziare. Le immagini cui Ishigami fa ricorso per
spiegarlo sono quelle delle costellazioni e degli alberi di una foresta:

> Per migliaia di anni noi umani abbiamo osservato il cielo notturno,
> evocando immagini e storie dalla disposizione casuale delle stelle.
>
> La natura ha leggi severe. Sebbene queste possano essere al di là
> della nostra comprensione, le aggiriamo abitualmente, decifrandole
> soggettivamente, a nostro piacimento.
>
> Può l'architettura essere liberata nello stesso modo?
>
> Data la libertà, nonostante sia rigorosa nella sua destinazione d'uso,
> e progettando di conseguenza, trascendere tutto ciò e vedere lo spazio
> in modo soggettivo, consentendone usi diversi. Una libertà aperta a
> molteplici interpretazioni.
>
> Un laboratorio per studenti.
>
> Questo edificio non ha pareti. Tutte le strutture sono rette
> esclusivamente da pilastri. Tutti i pilastri hanno proporzioni
> diverse, sono orientati in modi diversi, posizionati a intervalli
> diversi.
>
> Ogni pilastro è progettato individualmente, meticolosamente. Allo
> stesso tempo, un piano meticoloso è reso trasparente.
>
> Pianificare mentre l'intento del piano non è più visibile, diventa
> l'intento di questo piano.
>
> Una disposizione casuale. Un pianterreno di alberi in una foresta. La
> disposizione delle stelle assomiglia a quella degli alberi in una
> foresta. Il fatto che percepiamo una casualità condivisa in queste
> due cose che sembrano non correlate può essere dovuto alla casualità
> che appartiene all'essenza della natura[^31].

Nonostante gli accenti con cui è presentato, il KAIT sotto molti aspetti
potrebbe essere assimilato ai *flagship stores* visti più sopra:
identico il candore della pavimentazione e delle 305 colonne di
dimensioni variabili, disposte irregolarmente a sostegno della copertura
piana -- anch'essa bianca -- solcata da lucernari; identiche le pareti
perimetrali interamente vetrate; identica l'assenza di peso che promana
dall'insieme. E identiche -- si può pure presumere -- le dotazioni
tecnologiche a disposizione degli studenti che rendono lo spazio
perfettamente connesso con il mondo. E tuttavia, predisponendo un
layout massimamente flessibile, in grado di includere le esigenze
mutevoli degli studenti, suggerendo usi senza imporli, Ishigami
sembrerebbe alludere a un altro genere di libertà: più che una "messa a
disposizione" di possibilità senza limiti, una capacità di *accogliere*
possibilità illimitate. Un'*apertura* dello spazio a interazioni
spontanee che potrebbe essere intesa come una condizione di *non*
sfruttamento di esso. Scrive ancora Ishigami:

> La nostra vita quotidiana si svolge tra la manifestazione di risultati
> attentamente calcolati, e la libera interpretazione.
>
> Pensare alla progettazione di un'architettura che, anziché postulare
> ordine e disordine come valori opposti, li tratta allo stesso modo.
>
> Scoprire spazi liberamente, assegnando loro ogni volta una funzione.
>
> Ogni volta che un pezzo di architettura è completato, si rivela
> attraente in tutti i modi possibili, al di là delle stesse intenzioni
> dell'architetto[^32].

Che l'architettura di Ishigami sia profondamente immersa nel mondo
contemporaneo, che precisamente a esso si rivolga ("Un'architettura per
l'era del libero accesso all'informazione. Un'architettura per l'era
della libera connessione. Un'architettura per l'era della libertà dei
valori")[^33], risulta evidente. E però è altrettanto evidente come
essa non si "accontenti" di ciò che la realtà in quanto tale propone.
In questo senso, la flessibilità degli spazi del KAIT -- almeno nelle
intenzioni del loro autore -- vorrebbe dimostrare di essere l'esatto
opposto della "flessibilità" come "libera imposizione" che le società
odierne assegnano ai loro "soggetti": là dove infatti a questi ultimi
viene richiesta una capacità di adattamento, nel suo caso è lo spazio
che sembra adattarsi alle svariate esigenze di chi lo utilizza.

Si potrebbe denominare questa architettura -- riprendendo una discussa
espressione di Colin Rowe -- "delle buone intenzioni"[^34]. Intenzioni
"preterintenzionali", verrebbe da aggiungere, sulla base delle parole
appena citate dello stesso Ishigami; il quale tuttavia, subito dopo,
richiama la necessità "di essere maggiormente coscienti (...) fin dalla
fase della progettazione"[^35] dei possibili gradi di libertà che
l'architettura *autonomamente* può assumere.

Ma la conclusione potrebbe essere anche diversa: che per Ishigami -- al
pari degli altri architetti di cui si è discusso in precedenza -- la
suadente libertà "obbligatoria" della società della trasparenza sia
soltanto un'allettante occasione per scatenare le proprie "fantasie
creative", e dunque per cogliere nuove, fruttuose opportunità di lavoro;
mentre per tutto ciò una libertà "vera", una libertà incondizionata --
come sembra suggerire Reinier de Graaf -- sarebbe più che altro di
ostacolo.

[^1]: Tafuri, *La sfera e il labirinto* cit., p. 315.

[^2]: Yvonne Farrell e Shelley McNamara, *Freespace-Manifesto*, in
*Freespace*, catalogo della XVI Mostra Internazionale di Architettura -
Biennale di Venezia, Venezia 2018, p. 51.

[^3]: Max Weber, *Il senso dell'"avalutatività" delle scienze
sociologiche ed economiche* (1917), in Id., *Il metodo delle scienze
storico-sociali*, Einaudi, Torino 2012, p. 265. Prosegue Weber: "Tra i
valori si tratta ovunque e sempre, in ultima analisi, non già di
semplici alternative, ma di una lotta mortale senza possibilità di
conciliazione, come tra "dio" e il "demonio". Tra di essi non è
possibile nessuna relativizzazione e nessun compromesso".

[^4]: Oltre ai "classici" testi citati alla nota seguente, vedi
Foucault, *La società disciplinare*, a cura di Salvo Vaccaro, Mimesis,
Sesto San Giovanni 2010, e Id., *La società punitiva. Corso al Collège
de France (1972-1973)*, Feltrinelli, Milano 2016.

[^5]: Michel Foucault, *Storia della follia nell'età classica*, Rizzoli,
Milano 1963; vedi anche Id., *Nascita della clinica. Una archeologia
dello sguardo medico*, Einaudi, Torino 1969; Id., *Sorvegliare e punire.
Nascita della prigione*, ivi 1976.

[^6]: Jeremy Bentham, *Panopticon ovvero la casa d'ispezione*, a cura di
M. Foucault e M. Perrot, Marsilio, Venezia 2002.

[^7]: Jean Starobinski, *L'invenzione della libertà 1700-1789*,
Abscondita, Milano 2008.

[^8]: È quanto rileva lo stesso Foucault, *Disciplina e democrazia.
Intervista di J.-L. Ezine* (1975), in Id., *La società disciplinare*
cit., p. 87: "La disciplina è l'altra faccia della democrazia".

[^9]: Byung-Chul Han, *La società della trasparenza*, Nottetempo, Roma
2014.

[^10]: Byung-Chul Han, *Psicopolitica. Il neoliberalismo e le nuove
tecniche del potere*, Nottetempo, Roma 2016, p. 11.

[^11]: Lo aveva intuito già Foucault, *Disciplina e democrazia.
Intervista di J.-L. Ezine* cit., p. 87 (nel 1975!): "Si vedono apparire
ora sorveglianze di altro tipo, ottenute senza che quasi la gente se ne
renda conto, attraverso la pressione del consumo".

[^12]: Questo il significato che Aristotele attribuiva a ὑποκείμενον,
tradotto con il latino *subiectum*; per una discussione di questo
termine prima e dopo Cartesio, e dunque con l'imporsi del Mondo Moderno,
vedi Martin Heidegger, *L'epoca dell'immagine del mondo*, in Id.,
*Sentieri interrotti*, La Nuova Italia, Firenze 1984, pp. 71-101.

[^13]: Han, *Psicopolitica* cit., p. 9.

[^14]: *Ibid.*, p. 18.

[^15]: *Ibid.*, p. 25.

[^16]: Le Corbusier, *Cinque punti per una nuova architettura* (1927),
in Mara De Benedetti e Attilio Pracchi, *Antologia dell'architettura
moderna. Testi, manifesti, utopie*, Zanichelli, Bologna 1988, p. 381.
Continua Le Corbusier a proposito della pianta libera: "Non esistono più
pareti portanti, ma soltanto membrane dello spessore desiderato.
Conseguenza di ciò l'assoluta libertà nella progettazione della pianta,
cioè la libera disposizione delle risorse esistenti".

[^17]: Fredric Jameson, *Postmodernismo ovvero la logica culturale del
tardo capitalismo*, Fazi Editore, Roma 2007, pp. 315-20.

[^18]: *Ibid.*, pp. 319-20.

[^19]: Karl Marx, *Il 18 brumaio di Luigi Napoleone* (1852), in Marx e
Engels, *Opere complete* cit., vol. XI, p. 107.

[^20]: Vittorio Savi e Josep Maria Montaner, *Less is more. Minimalisme
en arquitectura i d'altres arts*, Col•legi d'Arquitectes de Catalunya -
editorial Actar, Barcelona 1996.

[^21]: Aureli, *Less Is Enough* cit., p. 8.

[^22]: Han, *Psicopolitica* cit., p. 46.

[^23]: Owen Hopkins, *Architecture and Freedom: a changing connection*,
in
<https://www.royalacademy.org.uk/article/exploring-architecture-and-freedom>,
2 settembre 2015. Vedi anche "Architectural Design", vol. 88, n. 3,
maggio-giugno 2018, fascicolo curato dallo stesso Hopkins e interamente
dedicato a *Architecture and Freedom. Searching for Agency in a
Changing World*.

[^24]: Francis Fukuyama, *La fine della storia e l'ultimo uomo*,
Rizzoli, Milano 1992.

[^25]: Su ciò vedi Patrik Schumacher (a cura di), *Parametricism 2.0.
Rethinking Architecture's Agenda for the 21st Century*, Academy
Editions, London 2016.

[^26]: Jürgen Mayer H., *Metropol Parasol*, Hatje Cantz Verlag,
Ostfildern 2011; vedi inoltre Id., *Could Should Would*, scritti di
Georges Teyssot, Ana Miljacki e John Paul Ricco, ivi 2015.

[^27]: Farshid Moussavi, *The Function of Style*, Actar, New York 2014,
ma anche Id., *The Function of Form*, Actar, Barcelona 2009.

[^28]: Vedi ad esempio Giancarlo De Carlo e Franco Bunčuga,
*Conversazioni su architettura e libertà* (2000), Elèuthera, Milano
2018.

[^29]: Scrive lo stesso Jean Nouvel, *Real/Virtual*
([www.jeannouvel.com/en/projects/fondation-cartier-2/](http://www.jeannouvel.com/en/projects/fondation-cartier-2/)),
a proposito di quello che significativamente chiama "il fantasma nel
parco": "L'architettura riguarda la leggerezza, con una raffinata
struttura di acciaio e vetro. Architettura in cui il gioco consiste nel
confondere i confini tangibili dell'edificio e rendere superflua la
lettura di un volume solido tra la poetica della sfocatura e
dell'effervescenza. Quando la virtualità è attaccata dalla realtà,
l'architettura deve avere più che mai il coraggio di assumere l'immagine
della contraddizione". La Fondation Cartier pour l'art contemporain è
del 1991-94.

[^30]: Junya Ishigami, *Freeing Architecture*, catalogo della mostra,
Fondation Cartier pour l'art contemporain -- LIXIL Publishing,
Paris-Tokyo 2018.

[^31]: Ishigami, *Freeing Architecture* cit., pp. 180-89.

[^32]: *Ibid.*, pp. 190-94.

[^33]: *Ibid.*, p. 309.

[^34]: Colin Rowe, *L'architettura delle buone intenzioni. Verso una
visione retrospettiva possibile* (1994), Pendragon, Bologna 2005.

[^35]: Ishigami, *Freeing Architecture* cit., p. 309.

# L'architetto come "produttore" e l'architettura come progetto

> Per gli architetti, la scoperta del loro declino come ideologhi
> attivi, la constatazione delle enormi possibilità tecnologiche
> utilizzabili per razionalizzare le città e i territori, unita alla
> quotidiana constatazione del loro spreco, l'invecchiamento dei metodi
> specifici di progettazione, prima ancora di poterne verificare nella
> realtà le ipotesi, generano un clima ansioso, che lascia intravvedere
> all'orizzonte uno sfondo molto concreto e temuto come il peggiore dei
> mali: il declino della "professionalità" dell'architetto e
> l'inserimento di questi, senza più remore tardoumanistiche, in
> programmi in cui il ruolo ideologico dell'architettura sia minimo[^1].

Per comprendere quanto si sia trasformata la condizione dell'architetto
dal momento in cui Manfredo Tafuri ha formulato la sua analisi -- ma al
tempo stesso quanto di quest'ultima si sia nel frattempo avverato --, è
necessario ripartire proprio dal punto in cui tale analisi è stata
giudicata eccessivamente "drammatica", e dunque nella sostanza è stata
del tutto fraintesa. Si tratta della famosa (e presunta) "profezia"
della "morte dell'architettura". Lo stesso Tafuri vi allude, facendo
riferimento alle reazioni a *Per una critica dell'ideologia
architettonica*, da molti letto come un "omaggio a un atteggiamento
apocalittico, come "poetica della rinuncia", come estrema denuncia di
una "morte dell'architettura""[^2]. Tale lettura distorta,
sorprendentemente diffusa[^3], ha finito per distorcere a sua volta il
quadro critico successivo. Non soltanto quindi l'analisi tafuriana,
cosí travisata, è stata bollata come "oscura profezia", del tutto priva
di "valore scientifico"[^4], ma ha spinto anche molti (architetti non
meno che storici e critici) a diffidare a priori di ciò che in essa era
contenuto; mancando in questo modo di scorgervi quanto per loro -- e per
le generazioni che sarebbero venute dopo di loro -- poteva invece essere
utile.

Quando Tafuri parla di "estinguersi (...) del ruolo di una
disciplina"[^5], di "crisi della funzione ideologica
dell'architettura"[^6], intende riferirsi all'esaurirsi di un compito
storico, non certo formulare catastrofistici pronostici in merito al
futuro di entrambe. In questo senso, se proprio di "morte" si dovesse
parlare, ciò non riguarderebbe per nulla l'architettura intesa come
fatto materiale (costruito o anche solo progettato): piuttosto
l'architettura come sistema di pratiche, come professione che
tradizionalmente al proprio centro custodisce l'idea di disegnare (ossia
progettare)[^7] e organizzare lo spazio, da quello domestico a quello
urbano (e volendo anche oltre), e che in quanto tale comporta sempre,
necessariamente, anche aspetti relazionali, sociali, etici e
politici[^8]. Se "morte" (o forse meglio, eclissi) vi è, ciò che viene
meno è un certo modo di concepire alcune parti (o addirittura l'intero
*corpus*) dell'architettura intesa in questo senso.

Come l'architettura nella sua dimensione materiale, cosí anche
l'architettura come processo è soggetta alle dinamiche storiche; e
dunque, cosí come cambiano gli edifici nel corso della storia, cambia
anche il modo in cui la disciplina architettonica viene intesa da un
punto di vista concettuale. In *Per una critica dell'ideologia
architettonica* e *Progetto e utopia*, Tafuri ha cercato di articolare
storicamente le cause (e in misura minore, gli effetti) di questi
cambiamenti. Dall'Illuminismo alle avanguardie del Novecento,
dall'utopia come progetto ideologico alla depurazione dell'ideologia da
ogni tratto utopistico, il ciclo storico da lui individuato mostra una
traiettoria ben precisa per quanto riguarda la concezione
dell'architettura da un punto di vista disciplinare: l'assunzione su di
sé di compiti di gestione dei grandi mutamenti produttivi e sociali che
hanno avuto luogo a partire dalla Rivoluzione industriale, e che si
prolungheranno fino ai primi tre decenni del XX secolo, per essere
riattivati ancora dopo la guerra. Per la cultura disciplinare, faro di
questo vorticoso e spesso contraddittorio sviluppo sono i miti della
razionalizzazione e della pianificazione, declinati a vario titolo e in
diversi contesti, fino al momento in cui -- come rileva Tafuri -- le
verranno sottratti dalle politiche dei "paesi a capitalismo avanzato
come gli Usa o a capitale socializzato come l'Urss"[^9]. Cosicché,

> ... dopo aver anticipato ideologicamente la ferrea legge del piano,
> gli architetti, incapaci di leggere storicamente il percorso compiuto,
> si ribellano alle estreme conseguenze dei processi che essi hanno
> contribuito a innescare[^10].

La comprensione di tali mutamenti -- oggi come allora -- si rivela un
elemento fondamentale. Rimanerne all'oscuro, o addirittura negarli,
equivale a rimanere del tutto estranei alla propria epoca, e di
conseguenza essere esclusi dalla possibilità di leggerla criticamente.
Per utilizzare la già richiamata distinzione proposta da Benjamin, in
una misura non trascurabile questo tipo di condizione costituisce il
presupposto "migliore" per mettere chi vi si dispone nella posizione del
"rifornitore", vale a dire in uno stato di muta e cieca acquiescenza nei
confronti della società per cui opera.

Ma prima di passare ad analizzare quali siano gli effetti del cambio di
statuto dell'architettura attuale rispetto a quello di precedenti epoche
storiche, bisogna sgombrare il campo dalla possibile "impressione" che
la supposta eclissi di una certa idea di architettura, verificatasi a
partire dagli anni sessanta e settanta, possa essere il frutto esclusivo
di una "deformazione" tafuriana. A corroborare l'ipotesi relativa alla
"crisi della funzione ideologica" dell'architettura, con particolare
riferimento a quel periodo, può quindi essere utile la coeva
testimonianza di De Carlo:

> Guardando con freddezza quel che accade, si può dire che
> l'architettura non interessa più nessuno. Non interessa i clienti
> tradizionali perché non risolve in modo efficiente e rapido i loro
> problemi di investimento e di potere; non interessa le istituzioni
> perché produce simboli troppo flebili e sbiaditi in confronto a quelli
> che producono altri settori di attività più potenti e aggressivi; non
> interessa la gente comune perché non propone nulla che corrisponda
> alle sue aspettative. Perciò, dal momento che non interessa più
> nessuno, l'architettura è condannata a una rapida estinzione[^11].

La fosca premonizione di Giancarlo De Carlo, formulata quasi mezzo
secolo fa, sembrerebbe a prima vista sconfessata dall'evidenza dei
fatti: l'architettura -- nonostante tutto -- esiste, continua a
esistere.

Tuttavia, a un'analisi più attenta, le parole di De Carlo non sono poi
cosí lontane dal vero: l'architettura, intesa nel senso in cui la
intende l'architetto genovese -- qualcosa che sia il frutto di un vero
*interesse*, ovvero di un effettivo *essere-tra*, un intreccio di
relazioni tra *esseri* diversi, ciascuno dotato di un proprio status di
correlazione ma al tempo stesso d'indipendenza dagli altri --, non
soltanto è destinata a sparire ma probabilmente non esiste già più
(ammesso poi che, in una forma più "piena", sia mai esistita). E qui,
ancora una volta, bisogna fare chiarezza: l'architettura esiste, certo,
nella sua concretezza, in forma di edifici per la "gente comune",
rispetto alle cui "aspettative" però risulta spesso deludente. Ed
esiste in forma di sedi di rappresentanza di quelle "istituzioni"
(pubbliche o private) che tuttavia in effetti, nella gran parte dei
casi, cercano e trovano altrove i propri simboli, in settori "più
potenti e aggressivi" -- primi fra tutti il marketing e la pubblicità --
cui la stessa architettura è subordinata e spesso assimilata. Per
quanto riguarda i "clienti tradizionali", invece -- appartenenti, lungo
tutto il corso del Novecento, in modo preponderante al mondo
imprenditoriale e politico --, sono proprio questi a essere scomparsi,
soppiantati da nuovi committenti desiderosi assai meno di radicare i
loro "interessi" in oggetti stabili e materiali, per investirli di
preferenza in entità immateriali e "volatili". Con significative
differenze, comunque, tra nuova committenza politica -- strenuamente
impegnata a ostentare il massimo distacco (apparente) del potere dal
"palazzo", e dunque poco interessata a farsene emblema --, e nuova
committenza imprenditoriale. In quest'ultimo caso, il problema non è
tanto la differente accezione del termine "interesse", la sua
declinazione in senso prettamente economico anziché relazionale. Che
gli interessi degli investitori siano di tipo economico è qualcosa che
non riesce a sconvolgere neanche i più incalliti idealisti. La
metamorfosi decisiva in questo campo è piuttosto quella relativa al
passaggio da un capitalismo "padronale", ancora radicato in territori e
culture, a un capitalismo finanziario, senza volto e senza "testa", e
dunque impersonale e invisibile; un capitalismo per il quale sono assai
poco importanti le appartenenze, le vicende, i linguaggi e le
problematiche locali. Ed è proprio questo sradicamento, con tutte le
sue conseguenze, di cui De Carlo "pre-sente" minacciosamente l'arrivo.

Non è dunque tanto sul piano dell'architettura realizzata (o anche solo
pensata) che oggi sembra avverarsi la "prognosi" di De Carlo, quanto
piuttosto sul piano concettuale e simbolico. Sul piano -- si potrebbe
dire -- del *senso*. Nella società odierna l'architettura non "conta",
o lo fa molto meno di un tempo. Si legga ancora De Carlo:

> Per convincersi che non è una battuta terroristica, e neanche una
> semplice battuta, basta scorrere le diagnosi degli esperti che
> confortano le decisioni dei politici ai quali sono affidate le sorti
> del mondo. Queste diagnosi concordano nel dichiarare che la questione
> dell'organizzazione dello spazio fisico è molto grave, ma anche molto
> semplice. Per risolverla basta identificare i problemi più salienti
> che sono quelli della residenza e del trasporto -- e affidarli a chi è
> in grado di affrontarli con la massima rapidità e col minimo
> sforzo[^12].

Massima rapidità e minimo sforzo: sono le modalità con cui agisce
preferenzialmente la logica capitalista, anzi -- per l'esattezza -- sono
i suoi obiettivi primari. D'altronde, dalle parole di De Carlo risulta
evidente come, in *questa* logica, "chi è in grado di affrontare" tali
problemi non sia niente affatto l'architetto cosí come egli stesso lo
intende, capace di organizzare lo spazio nella sua complessità, fisica e
concettuale; non certo l'architetto per il quale tempo e lavoro
costituiscono quantità spesso non precisate, sulle quali comunque non
lesinare. Piuttosto, il pericolo che egli vede incombente è che, per la
risoluzione di questioni spaziali, in un futuro ormai prossimo, si
faccia ricorso "agli strumenti più efficaci utilizzandoli per quel che
possono dare, senza pretendere prestazioni qualitative che sono estranee
alla loro natura". Difficile dire con esattezza che cosa abbia qui in
mente De Carlo; l'utilizzo della parola "strumenti" lascia però
evidentemente intuire il carattere "strumentale" di tali interventi.
Mentre la via d'uscita che per parte sua ritiene possibile -- e che di
fatto in diverse circostanze nel corso della sua carriera ha proposto --
è quella dell'architettura "dalla parte della gente"[^13],
l'architettura della partecipazione.

La natura dell'architettura, intesa come somma dei compiti in carico
all'architetto è, fin dalle sue origini, essenzialmente organizzativa,
*gestionale*[^14]. Si tratta in sostanza dell'espletamento di alcune
mansioni specifiche (progettazione, disegno, estimo, scelta dei
materiali, ecc.) che tuttavia in larga parte sono assorbite nella
capacità più complessiva dell'architetto medesimo di sovrintendere,
coordinare e soprattutto *comprendere* le condizioni di possibilità del
progetto, quand'anche questo venga realizzato da altri. Pur essendo
parte costitutiva del suo profilo tradizionale, questa attività di
gestione si è accresciuta nel tempo in tale misura da divenire la parte
preponderante del suo lavoro. Ma c'è di più: l'estensione dei mercati
potenziali in seguito alla globalizzazione, la conseguente crescita
quantitativa e dimensionale degli edifici, la loro sempre maggiore
complessità tecnologica, la richiesta di competenze sempre più
specialistiche e diversificate, sono alcuni dei fattori che hanno
contribuito a togliere all'architetto quella centralità nella produzione
del progetto che in precedenza deteneva. Ed è qui che l'analisi storica
di Tafuri "incontra" le considerazioni sulla professione di De Carlo.
Se infatti la ricognizione genealogica compiuta dal primo individua le
cause scatenanti della crisi dell'architettura come disciplina, la
"fenomenologia" del secondo ne nomina lucidamente gli effetti. Che sono
appunto alla base delle evoluzioni che stiamo vivendo attualmente.

Il formidabile sviluppo degli studi di architettura, in particolar modo
dalla seconda metà del XIX secolo in avanti, non soltanto in termini di
numero di persone impiegate ma anche di articolazione interna, di
complessificazione organizzativa (basti pensare agli *architectural
firms* sorti a Chicago dopo l'incendio del 1871, vere e proprie aziende
di progettazione impegnate a fronteggiare l'enorme richiesta di
*commercial buildings* e *tall buildings*[^15]; o all'*Architekturbüro*
scientificamente impostato da Otto Wagner per realizzare le stazioni
della metropolitana e le chiuse del canale del Danubio, affidategli nel
1894 dalla municipalità di Vienna in qualità di consigliere superiore
all'edilizia)[^16], corrisponde in epoche più recenti a un altrettanto
imponente incremento degli apparati gestionali presenti in tali studi,
perfettamente espresso dal dispiegamento di computer al posto di quelli
che un tempo erano i tavoli da disegno. È questa la plastica
dimostrazione del fatto che oggi i sistemi di elaborazione e di
controllo del progetto sono diventati pressoché interamente
*strumentali*, come aveva preconizzato De Carlo. E tuttavia, pur
trattandosi di un mutamento importante, addirittura epocale, non è in
fondo cosí rilevante da provocare un vero sovvertimento nel modo di
mettere in rapporto architettura e architetto. Certamente, crescendo
dimensionalmente, ma soprattutto facendo proprio il modello della
taylorizzazione del lavoro, gli studi di architettura hanno visto nel
tempo accrescersi pure la divisione e la specializzazione delle mansioni
al loro interno; cosicché, negli studi più grandi, accanto agli
architetti variamente aggettivati (partner, senior, junior, ecc.), si
trovano oggi frequentemente caddisti, renderisti, specialisti di
progettazione computazionale, BIM manager, architetti Revit, modellisti,
archivisti, responsabili dello sviluppo aziendale, esperti in *public
relations*, addetti ufficio stampa, per nominare solo alcune delle
posizioni possibili. Ed è altrettanto innegabile che il lavoro di
architettura, negli studi maggiori per mole e produttività, possa essere
assimilato a quello svolto in una fabbrica, con tutti gli effetti di
sfruttamento e alienazione che ne conseguono[^17]. In questa
condizione, con l'ampliarsi a dismisura della divaricazione tra chi
occupa posizioni di vertice, di norma in grado di abbracciare la
complessità -- e in qualche caso anche il senso -- delle operazioni
eseguite, e chi invece è relegato nelle zone inferiori della scala
gerarchica, costretto a produrre semplici "spezzoni" di tali
operazioni[^18], diventa pressoché impossibile parlare di "lavoro
dell'architetto" in maniera generalizzata e univoca. Aspetto, questo,
confermato anche dai diversi "nomi" con cui si suole spesso indicare il
contributo degli uni e degli altri: "opera", nel caso dei primi,
semplice "lavoro", in quello dei secondi:

> La parola "opera" evoca la dimensione autoriale di un prodotto, ovvero
> l'idea che il prodotto, progetto o edificio, sia il frutto
> dell'architetto. Al contrario, il lavoro (...) in architettura,
> supera i risultati architettonici tradizionali e comprende l'intero
> sforzo -- la fatica -- necessario per sostenere la produzione
> dell'"opera", dal mantenimento personale agli umili lavori che un
> architetto deve compiere per eseguire un incarico[^19].

Benché ovviamente "l'idea stessa di *opera* come qualcosa che possa
essere limitato alla creazione di un oggetto -- come è ancora preteso
nella nostra professione -- sia un'insostenibile farsa"[^20].

Ma il vero nodo della questione consiste nella profonda modificazione
che ha subito l'intero processo produttivo dell'architettura, sottoposto
alle tensioni delle trasformazioni epocali citate più sopra; una
modificazione che "scavalca" la stessa organizzazione del lavoro dentro
gli studi (ormai raggiunti dal "modello" post-fordista, con modalità di
lavoro più "libere" rispetto a quelle precedenti e con un controllo
delle conoscenze disponibili al suo interno che porta a intenderle ora
come un "capitale cognitivo")[^21] e che pone urgentemente l'architetto
di fronte alla necessità di riflettere in merito al proprio ruolo. Se
da un lato infatti questo è radicalmente cambiato, dall'altro in molti
casi gli architetti si ostinano a vederlo immutato, se non nei suoi
aspetti pratici, nel suo significato intrinseco, nel suo valore
simbolico. A partire da quell'"immagine ideologicamente costruita
dell'architetto come indiscutibile creatore"[^22] che ancora resiste,
non soltanto presso un pubblico distratto e poco informato ma anche
nell'autorappresentazione di molti architetti. Nell'odierna realtà
progettuale, invece, non muta soltanto l'"identità" dei protagonisti, ma
anche -- e radicalmente -- il "punto di vista" secondo cui questi vanno
osservati: in essa, infatti, non più l'architetto, bensì "il progetto,
suddiviso in parti condotte separatamente, individua diversi ruoli di
responsabilità e capacità dispiegati lungo il suo processo"[^23]. È il
*progetto stesso* a "scrivere il proprio destino", cioè a dettare le
regole, a imporre la propria agenda a tutte le figure professionali che
incontra sul suo cammino. Se un tempo "ruotava" intorno allo studio di
architettura (fatta eccezione per gli indispensabili interventi
ingegneristici, finalizzati all'elaborazione dei calcoli strutturali e
all'inserimento dei sistemi impiantistici, nonché -- in casi più rari --
di progettisti d'interni), oggi si potrebbe dire che il progetto ha il
proprio "centro" in se stesso: dopo essere stato ideato e sviluppato in
uno studio di architettura nelle fasi preliminare e definitiva, non è
infrequente che passi di mano e che venga integralmente trasferito a
società di ingegneria che lo porteranno in modo del tutto autonomo alla
fase esecutiva, ottimizzandolo (in linguaggio tecnico,
"ingegnerizzandolo") in vista della realizzazione. Ma spesso i passaggi
non sono cosí definiti, perché può capitare che il progetto venga
rielaborato e modificato, anche radicalmente, sotto un profilo
strutturale, estetico o dei materiali, da altri operatori, prima di
arrivare alla fase costruttiva; la quale, anch'essa, è di sovente
frazionata dalla società capo-commessa in molteplici porzioni, ciascuna
delle quali eseguita da altre imprese mediante appalti separati. Un
complesso iter nello svolgersi del quale il progetto (o "servizio di
progettazione", come lo denomina ora il linguaggio burocratico italiano)
viene variamente -- e da svariati soggetti -- "processato"; termine,
questo, che lascia involontariamente intendere come il progetto venga
sottoposto a revisioni nel corso delle quali -- di passaggio in
passaggio -- perde via via ogni traccia di una paternità (o
maternità)[^24] che in altre epoche l'affiancarsi di altri nomi e
competenze a quelli dell'architetto poteva contribuire semmai a
precisare, ma in nessun modo mettere in dubbio.

Si tratta dunque di un "processo" -- frutto di una competizione più che
di una cooperazione -- che può portare anche alla completa alienazione
dei "diritti" sul progetto da parte del suo ideatore originario; sempre
ammesso poi che abbia ancora senso definire "autore" di un progetto chi,
come accade in molte circostanze, ne cede di fatto la proprietà
materiale e intellettuale nel momento stesso in cui questo passa di
mano.

Il fatto che nell'epoca contemporanea il progetto -- dietro apparenze
spesso ingannevoli -- sia costitutivamente "in cerca di autore",
dimostra quanto esso sia indipendente dallo stesso architetto. Ma si
tratta soltanto di una "spia" che segnala una situazione di allarme più
generale. È la prova che l'architettura, ben lungi dall'essere il punto
focale del progetto, è ormai soltanto una "tappa" -- e a volte neppure
la più rilevante -- di un percorso ben più lungo e intricato. Ma
proprio qui sta il problema: nell'accettare il lavoro di architettura
come mansione limitata, parziale, scorporabile da una lettura e da
un'interpretazione più complessiva e allargata della città e della
società, ovvero della politica e dell'economia -- nell'accettare
l'architettura come *mestiere specializzato*, come "comparto" operativo
del capitale --, l'architetto definisce la propria posizione rispetto a
esso prima ancora di aver compiuto qualsiasi "gesto" progettuale.

Certo, si è detto, l'architettura intesa come edificio materiale
continua -- nonostante tutto -- a sussistere. E, a dispetto delle
insidie di cui si fa portatore ogni giorno il mondo virtuale, non è
stato ancora trovato un valido sostituto per gli edifici reali, in
"carne e ossa". Pur attraversando fasi altalenanti, dunque, il settore
delle costruzioni rimane sempre uno dei comparti migliori a cui affidare
capitali in cerca di collocazioni sicure. Di conseguenza, architetti e
studi di architettura, nella misura in cui riescono a sconfiggere una
concorrenza che si presenta sempre più numerosa e agguerrita, sembrano
avere lavoro assicurato. Non tutti naturalmente se la cavano bene, ma
l'obiettivo comune alla gran parte di essi risulta ben chiaro:
concorrere ciascuno alla costruzione di un pezzo del mondo come lo
conosciamo, *lasciandolo cosí com'è* (con soltanto marginali
aggiustamenti, nella maggioranza dei casi di carattere estetico). Sono
gli architetti "rifornitori". Ma che cosa ne è degli architetti
"produttori"? È cosí che Benjamin chiama coloro che trasformano *in
senso tecnico* l'apparato produttivo[^25].

Va chiarito immediatamente che non esistono architetti "rifornitori" e
architetti "produttori" *a priori*. È soltanto in relazione alla
posizione che ciascuno di essi assume nella realtà concreta dei processi
produttivi dell'architettura -- se li accetta passivamente facendosene
semplice tramite o se invece piuttosto li reinterpreta criticamente al
punto da riuscire a *trasformarli* sotto qualche profilo
dall'interno[^26] -- che si determinerà il loro essere "rifornitori" o
"produttori". Esattamente la stessa posizione sulla base della quale,
nota ancora Benjamin, "può essere stabilito o meglio *scelto* (...) il
posto dell'intellettuale nella lotta di classe"[^27]. E qui è
necessario affrontare una questione essenziale: ha ancora senso questo
discorso *al di fuori* della prospettiva della "lotta di classe"? Vale
a dire, al di fuori di una prospettiva *rivoluzionaria* quale sussisteva
per Benjamin? Non è forse proprio la mancanza di questa -- o quantomeno
di un'ideologia o di una finalità condivisa, sia pur meno radicale -- a
rendere difficile, se non addirittura impossibile, attualizzare il
discorso di Benjamin? Alla risposta più apparentemente ovvia e immediata
-- in assenza di una "lotta di classe" tale discorso è *ipso facto*
destituito di senso -- bisogna opporre una risposta più meditata.
L'attuale mancanza di un'alternativa politica al capitalismo è un fatto
assodato. Se mai ce ne fosse bisogno, sotto un profilo disciplinare
questo è "provato" dall'odierna rilettura in senso puramente
"scientifico" (con Carl Schmitt si potrebbe dire "neutralizzazione",
ovvero *de-politicizzazione*)[^28] dell'architettura, i cui obiettivi --
dall'edificio alla città, per giungere ad *habitat* ancora più allargati
-- sono umani e sociali, e dunque eminentemente politici. Oggi, al
posto degli obiettivi collettivi politicamente condivisi il cui
raggiungimento Benjamin poteva quantomeno indicare, si impongono
interessi individuali in cui, al di là di una pur significativa ma nella
maggior parte dei casi generica vocazione a "cambiare il mondo" con il
proprio intervento, prevalgono "obiettivi" come l'affermazione personale
e l'ottenimento di maggiori guadagni.

E tuttavia, a ben guardare, esiste un più che diffuso malessere nei
confronti di condizioni di vita e di lavoro che tocca punti di vista non
soltanto individuali. Si tratta di un disagio che trascende, in larga
misura, la singolarità di una visione soggettiva, limitata e parziale, e
che coinvolge ormai quella che Paolo Virno chiama una
"moltitudine"[^29]. Pur essendo priva di una prospettiva unitaria, la
moltitudine ha in comune "il linguaggio, l'intelletto, le comuni facoltà
del genere umano"[^30]. I tanti soggetti individuali che la compongono
condividono tra loro aspirazioni e bisogni. E ciò tanto più in un
comparto ben definito qual è quello che ruota intorno al mondo
dell'architettura. All'interno di questo, da alcuni anni a questa
parte, si sono individuati non soltanto motivi d'insoddisfazione comuni
(primo fra tutti, condizioni di sfruttamento selvaggio dei lavoratori
che spesso non hanno paragoni nel panorama del lavoro intellettuale, e
neppure di quello manuale)[^31], ma anche forme di relazioni
intersoggettive che, se non arrivano certo a definire un vero e proprio
soggetto politico, hanno però almeno la capacità di inquadrare i
problemi in modo analitico[^32], e istituire reti di comunicazione e di
scambio tra i soggetti coinvolti. Sono ancora lontani dall'essere messi
a fuoco, in tutto ciò, comportamenti solidali e rivendicazioni
condivise; ma soprattutto manca una vera e propria "coscienza di
classe", sostituita al momento da una più generica consapevolezza di
appartenenza, di compartecipazione a una medesima condizione o
"destino". Al tempo stesso, però, vi sono diffusi e ricorrenti segnali
di un risveglio di attenzione e di interesse nei confronti di una
lettura politica della disciplina architettonica nel suo complesso, in
netta controtendenza rispetto all'orientamento ancora dominante che vede
in essa l'esclusiva espressione di una cultura scientifico-tecnologica,
cui corrispondere in termini "prestazionali" e professionalistici. Ed è
sulla strada -- pur lunga e difficoltosa -- dell'individuazione di
strategie e dell'adozione di tattiche finalizzate all'organizzazione di
una maggior "resistenza" e di una lotta più efficace e consapevole, che
i testi di Benjamin -- e in particolare quello citato -- hanno spesso
rappresentato un fondamentale viatico per la cultura
architettonica[^33]. Benché naturalmente al di fuori di qualsiasi
realistica prospettiva di rivoluzione, la *prospettiva rivoluzionaria*
proposta da Benjamin -- specificamente rivolta al lavoro intellettuale
-- ha fornito e continua a fornire un impulso e una possibile "linea di
condotta" per i soggetti coinvolti a vario titolo nel processo
produttivo dell'architettura. Distogliendo lo sguardo dagli scenari più
"eroici" della lotta di classe, per fissarlo sull'obiettivo più
circoscritto delle dinamiche interne ai rapporti di produzione, il testo
di Benjamin apre uno squarcio in un momento storico quasi senza
speranze. L'alternativa tra farsi "rifornitori" o "produttori" di tali
rapporti mantiene infatti la propria validità anche al di fuori di
prospettive politiche più radicali, offrendosi come opportunità per chi,
pur essendo *dentro* di essi, intenda porsi *contro* le logiche che li
informano.

E proprio dal testo di Benjamin emerge un dato importante: le posizioni
occupate nel processo produttivo sono frutto di una *scelta*. Nessun
ostacolo logico esiste, di ordine trascendentale, che impedisca di
posizionarsi nell'una o nell'altra. Ciò non significa che sia una
"libera" scelta: essa dipende comunque da condizionamenti e congiunture,
cosí come dipende dal punto a partire dal quale viene compiuta. Vi sono
fattori economici in gioco, ma anche culturali e sociali, che vincolano
tale scelta, orientandola in un senso o nell'altro. Ma pur con tutti i
limiti ipotizzabili ed entro condizioni storicamente determinate, la
scelta della propria posizione nel processo produttivo da parte
dell'architetto si presenta -- se non certo libera in assoluto --
quantomeno *possibile*. Come in altre contingenze della vita
individuale e sociale, è il risultato della composizione, in positivo o
in negativo, di convenzioni e convenienze che possono influenzarla,
quando non addirittura determinarla del tutto. Ma ciò nondimeno è e
rimane anche una *decisione*: un "taglio" netto, deliberato, che risolve
la *quaestio* in un modo o nell'altro. Come tutte le decisioni,
comporta un'assunzione di responsabilità e l'esercizio di una
convinzione[^34]. Non è insomma possibile -- di fronte all'occupazione
dell'una o dell'altra posizione -- invocare l'ineluttabilità delle
circostanze o del "fato", non comunque in una misura determinante.

Ma, come non esistono architetti "rifornitori" e architetti "produttori"
*a priori*, neppure esistono architetti "rifornitori" e architetti
"produttori" una volta per tutte. Ciascun architetto compie la propria
scelta ogni giorno, in ogni momento, spesso inconsapevolmente, e
altrettanto di frequente in modo inapparente, non dichiarato. Lo fa
nell'ambito del proprio lavoro, accogliendo o meno offerte che le/gli
vengono fatte, soddisfacendo o meno condizioni che le/gli vengono
imposte, ridiscutendo progetti che le/gli vengono commissionati,
ponendosi o meno a disposizione nell'accettare compromessi o
imposizioni.

Insomma, si tratta di casi molto frequenti e di scelte molto concrete,
che portano l'architetto a posizionarsi come "rifornitore" dell'apparato
di produzione, oppure piuttosto come "produttore". Ma produttore di che
cosa? Come va inteso esattamente questo termine? Non è forse anche
l'architetto "rifornitore" un produttore, nella misura in cui realizza
per l'appunto "prodotti"? Innanzitutto si può dire -- anzi ribadire --
che tutta l'architettura è un prodotto, vale a dire una merce. La
natura di merce dell'architettura non è minimamente revocata, e neppure
insidiata, dall'intervento dell'architetto "produttore" invece che da
quello dell'architetto "rifornitore", o viceversa. Ma se l'architettura
è senza dubbio un prodotto nel caso di entrambi, in quello
dell'architetto "produttore" si può dire che essa è *anche* un prodotto,
ma non solo: ovvero non è un prodotto-e-basta. Essa è anche -- ed
essenzialmente -- un *progetto*. Non però quel "progetto" che
l'architetto in quanto architetto produce (o meglio, dovrebbe produrre,
se altri operatori, altri "attori" -- come si è visto -- non ne
insidiassero il compito) in vista di una possibile realizzazione.
Piuttosto un progetto da intendersi come *idea*, come *finalità* (e non
come semplice presupposto) dell'architettura medesima.

L'avvicinamento di prodotto e progetto non è affatto inedito o
sorprendente.

> Pro-durre e pro-getto sono termini solidali, rappresentano, nel nostro
> linguaggio, un'unica "famiglia". Il progetto è inteso come
> intrinsecamente produttivo: esso elabora modelli di produzione. Il
> pro-durre è compreso nel pro-getto che ne illumina il senso e il
> fine[^35].

In realtà, molto più di quanto si possa pensare, il progetto è distante
da una dimensione semplicemente produttiva-predittiva (idea che
linearmente anticipa la propria realizzazione), per aprirsi invece alla
"massima (...) irruzione dell'imprevedibile"[^36]. È questa idea di
progetto che s'affaccia nella produzione dell'architetto "produttore":
dove dunque l'architettura *come progetto* non indica il mero
svolgimento di un'intenzione iniziale, l'attuazione di qualcosa di
interamente presente in essa, e perciò di perfettamente aderente a un
programma "dato" (e "dato" appunto dal processo produttivo come tale),
bensì qualcosa che "eccede" da esso, che si apre a possibilità
ulteriori, non previste, azzardate, che mettono in crisi il processo
produttivo medesimo.

Architettura come progetto significa che l'architettura *nel suo
complesso*, come disciplina pratica *e* concettuale, in tutti i suoi
aspetti e passaggi -- dall'elaborazione teorica all'organizzazione
produttiva, passando naturalmente anche per il progetto architettonico
inteso in senso tradizionale, con tutti i processi che ne rendono
possibile la realizzazione -- è ripensata in una prospettiva
progettuale, nell'accezione "aperta", arrischiata al futuro, enunciata
poc'anzi.

Per rendere più facilmente comprensibile come ciò vada inteso (e per
dissolvere il possibile equivoco ingenerato dalla somiglianza formale
delle espressioni "architettura come progetto" e progetto
architettonico, cui corrisponde nei fatti un'abissale distanza), si
potrebbe richiamare il senso che il termine "progetto" assume allorché
ci si riferisce a un progetto letterario o artistico o, ancora, a un
progetto politico, o a un progetto di vita; dove il "progetto" in
questione non ha palesemente nulla a che fare con pratiche relative a
quegli ambiti, come accade invece nel caso dell'architettura. Oppure,
più propriamente, si potrebbe richiamare l'uso che ne ha fatto Tafuri a
proposito del "progetto" storico[^37]; appare chiaro, infatti, in questo
caso, come non soltanto il lavoro storico in generale venga assimilato a
un "progetto" ma come tale "progetto" sia per molti versi assimilabile a
quello aperto, arrischiato e capace di mettere in crisi il proprio
stesso processo produttivo descritto in precedenza[^38]: un "progetto"
che non a caso egli definisce "progetto di crisi"[^39]. È lo stesso
orizzonte a cui si riferisce Cacciari parlando della tecnica in
relazione al noto saggio di Benjamin: "Non si dà discorso autentico
sulle tecniche, finché non se ne *teorizza* la struttura di *crisi*:
esse non avvengono che in base a crisi -- a causa del trasformarsi degli
assetti culturali precedenti"[^40]. E ancora: "La crisi non è un
momento che lo sviluppo delle tecniche attraversa, ma la loro immanente
struttura". Una "coincidenza" niente affatto casuale, dal momento che è
l'analisi dello stesso Cacciari a "finire" per occuparsi proprio
dell'*Autore come produttore*. Qui, quanto precedentemente affermato in
merito alla capacità del progetto di mettere in crisi --
*trasformandoli* -- i processi produttivi, viene ulteriormente
illuminato: infatti

> \[La\] crisi non può essere operata speculativamente -- riflettendo
> *dall'esterno* sul processo di trasformazione. Essa deve essere
> *prodotta*. (...) Qualsiasi posizione intellettuale che non si ponga
> come *produttiva* è reazionaria. Ma *produttiva* significa: non
> soltanto integrata nel rapporto di produzione -- ma in grado di
> trasformarne-metterne in crisi l'apparato tecnico-linguistico[^41].

L'architettura come progetto non indica dunque un "progetto" *per* essa
o *con* essa: piuttosto indica l'essere progetto *essa stessa*. E un
progetto non semplicemente confermativo bensì effettivamente
*trasformativo* degli apparati produttivi; un progetto di crisi.
Soggetto di tale progetto di crisi è l'architetto come produttore, o per
dir meglio, l'architetto che accetti di calarsi *dentro* tali apparati,
confrontandosi con essi, con le loro forme, i loro linguaggi, e al tempo
stesso scelga di criticarli, andando *contro* una loro riproposizione
immutata. Non si tratta affatto -- si badi bene -- di mere
"astrazioni". Piuttosto di ben precise *relazioni* sviluppabili
all'interno della catena di produzione attraverso i diversi anelli della
quale il progetto architettonico man mano transita: relazioni con gli
altri soggetti e le altre competenze della catena di produzione;
relazioni con le amministrazioni pubbliche, con le istituzioni e con i
committenti privati; relazioni con le imprese di costruzioni e con le
maestranze; relazioni con i fornitori; relazioni con l'utenza di un
edificio e più in generale con la cittadinanza e con il pubblico;
relazioni con gli altri componenti dello studio; relazioni con gli altri
studi; relazioni con il mondo della comunicazione dell'architettura
(editoria, riviste, giornali, internet); relazioni infragenerazionali e
con gli studenti. Tali relazioni risultano naturalmente tanto più
significative quanto più i soggetti implicati sono disponibili a
lasciarsi coinvolgere e a farsi mutare, ma non escludono neppure il
ricorso a modalità conflittuali[^42]; anzi, spesso ciò è inevitabile.

A questo elenco si possono aggiungere l'organizzazione del lavoro
interna allo studio; il quadro legislativo entro il quale l'architetto
si muove; il corpus teorico disciplinare; le possibili analisi storiche,
sociologiche, economiche, politiche compiute su architettura e città; e
ovviamente il progetto vero e proprio, alle sue possibili scale diverse,
architettonica e urbana, visto sotto *tutti* i suoi aspetti, e in
particolare sotto il profilo delle modalità alternative di concepire e
organizzare lo spazio, unico terreno di applicazione e verifica della
politica all'architettura. Si tratta di una molteplicità di campi
diversi, con cui -- in differenti modi e in vari momenti nel corso del
suo lavoro -- l'architetto viene a contatto. Agendo su uno o più di
questi ambiti, vale a dire mettendoli in crisi, modificandoli, per
innovarli -- ma soprattutto per *migliorarli* nella misura del
possibile[^43] --, l'architetto propone se stesso come intellettuale.

Nella condizione attuale, in modo nettamente contrastante rispetto ad
altre epoche storiche precedenti, la figura dell'intellettuale appare
fortemente screditata. In realtà, pur non risalendo a tempi troppo
recenti, la condizione di crisi non sembra affatto essere endemica per
l'intellettuale: il quale, in un passato più o meno distante, ha
rivestito posizioni centrali non solo al fianco di regnanti o potenti,
né solo in qualità di membro della *respublica litterarum*, ma anche in
settori vitali e operanti della società[^44]. Non è dunque qui il caso
di ritornare sulla questione già accennata della sua (presunta) "crisi",
se non per far notare che curiosamente l'intellettuale, stante quanto
detto sin qui, sembrerebbe porsi in un duplice rapporto con la crisi: da
un lato come colei/colui che la patisce, dall'altro come colei/colui che
la impartisce. Al punto da far sorgere il dubbio che la crisi
dell'intellettuale, in ultima istanza, non sia nient'altro che il
rovesciamento su di sé della propria stessa attitudine a mettere in
crisi. Ormai da tempo affermatisi come ceto separato, con un'espressa
funzione "contemplativa" -- di osservatori privilegiati -- della
società[^45], gli intellettuali sconterebbero in tal modo la propria
crescita ipertrofica, o sarebbero vittime di un "delirio di
onnipotenza", giungendo a rivolgere le proprie armi contro se stessi. O
forse piuttosto, agendo e "abitando" costantemente la crisi, la loro
esistenza non è contraddetta dalla presenza di questa.

Di certo comunque si può dire che il ruolo dell'intellettuale, oltre a
quello più ovvio di istruire la società propagandovi la cultura sotto
varie forme, consista nel "rompere" costellazioni di saperi consolidate,
riconfigurandole secondo altre strutture di senso[^46]. Quest'opera di
"rottura" è sempre stata fondamentale per l'intellettuale produttivo e
progressivo. Ben lungi dal confermare condizioni e opinioni già note e
diffuse, questi si presenta come un "quieto agitatore", il portatore di
un conflitto che non è tuttavia frutto di una "visione personale", bensì
appartiene alle *cose stesse*. "Per "ritornare alla cosa" occorre (...)
saperla porre nel suo dissidio rispetto alle altre"[^47].
L'intellettuale weberiano, da questo punto di vista, costituisce forse
il culmine della capacità di rendere continuamente presente il conflitto
che è nelle cose, con *disincanto*; una forma di distacco, quest'ultima,
che non può essere adottata però come un semplice "atteggiamento" e che
è invece il motore stesso del suo agire.

Per quanto concerne l'architettura, le figure analizzate in precedenza
rispondono perfettamente a questi caratteri: sia che -- come fa Aldo
Rossi -- si ridisegni a livello teorico il nesso tra architettura e
città, facendo ampio ricorso ad altre culture disciplinari[^48]; sia che
-- come fa Aldo van Eyck -- si intervenga a livello urbano escogitando
un intelligente riuso di un ingente numero di spazi pubblici residuali e
istituendo al tempo stesso una proficua collaborazione con una
municipalità[^49]; oppure, sfidando convenzioni sociali e tipologiche,
si offrano spazi di relazione davvero capaci di commisurarsi agli
utenti[^50], è sempre e comunque l'impronta di un architetto
intellettuale quella che qui si lascia riconoscere. Come da questi due
esempi risulta evidente, nell'entrare in rapporto con singoli ambiti o
temi, i diversi architetti citati utilizzano metodi e strumentazioni
differenti: dalla ricerca più tradizionale, svolta individualmente, a
quella che prevede una pluralità di contributi, che vanno dunque
selezionati e coordinati tra loro, fino al diretto intervento sulla
città o su un edificio. E molti altri ancora sono e potrebbero essere i
mezzi impiegati. Con ciò si dimostra l'ampiezza dello spettro d'azione
dell'architetto intellettuale, ma anche la sua completa libertà da
qualsiasi "obbligo" culturalistico. Come avverte Gramsci nel Quaderno
già ricordato[^51], del resto, per il costruttore, per l'organizzatore
-- e dunque anche per l'architetto --, l'attività intellettuale si
estrinseca non più nell'"eloquenza (...) ma nel mescolarsi attivamente
alla vita pratica". Nessun vuoto "intellettualismo" è pertanto
richiesto (e concesso) all'architetto che agisca *sub specie
intellectualis*. Semmai, a questo punto, ostentazioni di cultura e
fumose "astrattezze" divengono i migliori indici della presenza di ormai
intollerabili pseudo-intellettuali (architetti o altro che siano)! E
come l'architetto intellettuale non deve per forza disporre di capacità
oratorie o retoriche, cosí non per forza deve profondere il suo impegno
su un terreno diverso da quello dell'architettura.

Riletti in questa chiave, i "casi" più interessanti che emergono dalla
storia dell'architettura sono proprio quelli *produttori di crisi*, più
che quelli portatori di ordine (oppure quelli portatori di un ordine che
mette in crisi a sua volta). Sono i momenti di "rottura", più che i
momenti di continuità. Sono le opere che tolgono certezze, più che le
opere che le confermano. Ovviamente nella misura in cui ciò sia
fondato. Da questo punto di vista, persino una nozione pur pesantemente
gravata da una matrice idealistica qual è quella di "capolavoro"
potrebbe essere recuperata a una critica produttiva. Idealistica, nella
categoria di "capolavoro", è la maniera di concepire l'opera d'arte (o
di architettura) come un prodotto eccezionale, isolato, frutto
dell'intuizione sublime di un genio; e idealistica è parimenti la
presunzione dell'esistenza di un rapporto di "continuità" tra il
presunto "capolavoro" e la sua epoca, di cui esso rappresenterebbe
semplicemente il "culmine". In realtà, volendosi servire ancora di
questa vecchia categoria degradata, bisognerebbe riconoscere nel
"capolavoro" da un lato la piena implicazione nelle vicissitudini
produttive del proprio autore, e dall'altro una capacità -- questa sí
davvero straordinaria -- di rompere con il proprio tempo, di mettere in
crisi l'ordine precedente, e di istituirne al suo posto uno nuovo. Da
questo punto di vista, lungi dall'esserne estraneo, il capolavoro ha a
che fare con l'epoca nel preciso senso che esso *fa epoca*, vale a dire
che provoca un arresto del corso del tempo (*epoché*, sospensione). Ma,
nel "far epoca", il capolavoro mostra la propria attitudine
rivoluzionaria, non certamente l'opposta tendenza a occupare un posto
centrale all'interno d'un quadro lasciato però sostanzialmente immutato.

Per l'architetto come intellettuale, inoltre, al pari dell'autore come
produttore di Benjamin, "il progresso tecnico è la base del suo
progresso politico"[^52]. Tale discorso non va assolutamente confuso
con un progresso tecnologico. Per quanto rivesta un ruolo fondamentale
per gli apporti che dà al processo produttivo dell'architettura, la
tecnologia non ha nulla a che fare con la tecnica nel modo in cui
Benjamin la intende in questo contesto. Parlando di "progresso
tecnico", egli si riferisce piuttosto al padroneggiamento di competenze
specifiche, nonché ai possibili avanzamenti rappresentati dall'ulteriore
acquisizione di esse. Ma soprattutto, per Benjamin il vero "progresso
tecnico" non consiste affatto nell'incremento delle potenzialità degli
strumenti che l'uomo ha a disposizione; esso piuttosto va inteso come
qualcosa di cui l'uomo di per sé dispone, ovvero -- ancora una volta --
la capacità di intervenire sui processi produttivi in maniera tale da
modificarli. A questo fine -- in qualità di architetto -- può anche
servirsi di dispositivi informatici e digitali, ma non solo: oltre alle
tecniche tradizionali di rappresentazione legate al progetto e alla
pianificazione (dallo schizzo al disegno, fino alla fotografia e al
video), un "buon" architetto sa -- o dovrebbe sapere -- impiegare,
almeno entro certi limiti, competenze strutturali, estimative,
giuridiche, sociologiche, psicologiche, politiche e di altre discipline
ancora. Nel fare tutto ciò egli si avvale della parola (in forma
scritta o verbale), strumento massimamente duttile e diversificato che
offre a chi la usa coscientemente la possibilità di fare ricorso a un
vasto numero di "tecniche". Ed è su questo terreno che si lasciano
misurare le capacità *produttive* dell'architetto intellettuale. Al di
là del suo essere mezzo di comunicazione oggi eccessivamente abusato,
infatti, la parola è -- o dovrebbe essere -- anche e soprattutto suprema
"innescatrice" di relazioni e impareggiabile apportatrice di
potenzialità inventive e trasformative. Non "vuote" parole, destinate
di conseguenza a cadere nel vuoto, dunque, bensì parole corpose,
precise, circostanziate, la cui fondamentale missione si presenta quella
di ridefinire ogni volta il senso della disciplina nei suoi diversi
aspetti, ma anche quella di renderne partecipi gli altri ambiti, il
"resto del mondo", che troppo spesso ne rimane all'oscuro.

Rispetto al lavoro di *routine* svolto dal semplice "rifornitore", a
quello dell'architetto intellettuale è richiesto qualcosa di più: a esso
non è sufficiente ripetere soluzioni già note; piuttosto deve
sperimentare soluzioni inventive, conquistando cosí nuovi territori e
nuovi rapporti da esplorare. In questo senso, "contro" può significare
anche contro il lavoro assegnato, prestabilito, contro le convenzioni,
contro le abitudini non più verificate. Nell'ottica del lavoro
intellettuale, del resto, proprio il tema della "verifica" è
fondamentale, come già ricordato in precedenza con parole di Franco
Fortini che presentano forse inconsapevoli risonanze benjaminiane[^53].
Non si dà lavoro autenticamente produttivo senza un'attenta verifica
delle sue implicazioni e ricadute. E come esso non può "confidare" su
un atto puramente ri-produttivo, cosí il suo autore non può
"pretendersi" libero dalla necessità di dare continuità al proprio
operato: soltanto cosí si comprova il suo ruolo. La sua attendibilità
di "produttore" dipende da essa e va parimenti sottoposta a verifica. E
in ogni caso, nulla vieta che l'architetto "produttore" torni nuovamente
a "rifornire". Alla libertà della sua scelta è data anche la
possibilità dell'incoerenza.

Può questo *idealtypus* dell'architetto intellettuale -- portatore di
inquietudine e di "sconvolgimenti" (*produttore di crisi*) nel cuore
stesso del proprio lavoro, destinato per sua essenza a "edificare"
(*ædes facere*), o quantomeno a occuparsi di *rerum
ædificatoriarum*[^54] -- aderire all'architetto attuale? Ovvero,
corrispondono gli architetti *reali* a questa figura ideale? Si potrebbe
rispondere che è certamente possibile, come lo è stato in momenti e in
epoche precedenti, a patto naturalmente di non idealizzare la realtà in
modo eccessivo. Ma la vera questione qui non è dare volti e nomi reali
a un profilo ideale; né compilare liste di eletti e di proscritti, che
per di più sarebbero comunque soggettive e parziali. Alla "famiglia"
degli architetti infatti appartengono non soltanto i "grandi" nomi ma
anche i nomi "normali", e le miriadi di "anonimi" che compiono il loro
lavoro quotidiano negli studi, coloro che svolgono le stesse mansioni in
altre posizioni, coloro che insegnano, coloro che per perversione o
passione si dedicano alla storia e alla critica...[^55]. Insomma, una
"famiglia" molto vasta e complessa, tutta impegnata nel suo insieme in
un'attività intellettuale, ma all'interno della quale non tutti i suoi
membri risultano *produttivi* nel senso indicato. La vera questione
insomma non è individuale ("non esistono più gli architetti
intellettuali di una volta...") bensì collettiva. Detto in altri
termini, la vera questione su cui interrogarsi è la funzione storica
dell'architetto intellettuale *nel momento attuale*.

Se un tratto specifico sembra contrassegnare il momento attuale (vale a
dire una società neoliberalista), esso potrebbe essere identificato con
un'assoluta "refrattarietà" da parte di questa per qualsiasi tipo di
critica. La mentalità dominante pare costitutivamente lontana da uno
spirito critico, cosí come lo è dall'elaborazione di un pensiero critico
(un pensiero *di crisi*). Lungi dall'essere una caratteristica
accidentale o neutrale, tale mancanza risponde invece -- almeno in prima
istanza -- a una precisa volontà di autoaffermazione apodittica. La
stessa spasmodica ricerca del consenso va letta precisamente in questa
ottica: come massima avversità per la crisi (il fatto poi che la crisi
si ripresenti ciclicamente sotto forma "economica", non diminuisce di
certo -- e semmai anzi aumenta -- tale avversità). Ma al tempo stesso,
è proprio in quest'epoca apparentemente priva di spirito critico che si
può sviluppare uno spirito critico, sia pure sporadico e disorganizzato,
e complessivamente estraneo alle logiche dominanti. Si tratta di uno
sviluppo *non imprevisto*; esso cioè non soltanto è tollerato ma in
qualche modo finisce anche per essere funzionale al sistema. In una
società come quella attuale, infatti,

> ... la tensione antagonistica tra diversi punti di vista è appiattita
> nella pluralità dei punti di vista indifferenti. "Contraddizione"
> perde cosí il proprio significato sovversivo: in uno spazio di
> permissivismo globalizzato, punti di vista incoerenti coesistono
> cinicamente[^56].

Inoltre, essendo il capitalismo in quanto tale *sviluppo*[^57], esso
ingloba al suo interno e *sfrutta* in una certa misura le critiche
avanzate nei suoi stessi confronti; al punto che -- come è stato
affermato -- il fattore principale di trasformazione del capitalismo
sarebbe la critica stessa[^58].

Con tutto ciò -- che piaccia o meno -- questo è il momento attuale. E
se all'interno di esso l'intellettuale (e l'architetto intellettuale)
può avere un suo ruolo, per quanto esposto a rischi di fraintendimenti e
di strumentalizzazioni, è questa la partita che è chiamato a giocare:
senza alcun vano "principio speranza" ma anche senza alcuna preventiva
disillusione. Semmai con il disincanto -- e/o il distacco -- più sopra
evocati. Tentativi in tal senso ci sono, e alcuni di essi sono stati
oggetto di analisi nelle pagine precedenti. In linea generale, comunque
-- si potrebbe affermare --, tali tentativi appaiono oggi meno
strutturati, e fors'anche meno "impegnati", rispetto a quelli compiuti
in altre epoche. Sicuramente minore appare la loro efficacia, se
l'architetto come intellettuale può risultare pressoché del tutto
sparito dall'orizzonte attuale, e neppure entrare a far parte -- stando
a "impressioni" potenzialmente anche ingannevoli -- dell'agenda dei
maggiori esponenti della disciplina. Ma forse non è lí che bisogna
cercare. In una situazione come quella attuale, difficoltosamente
costretta tra crisi e sviluppo, il mondo dell'architettura sembra per
una parte accontentarsi di quello che ha, e per la parte restante
aspirare a ciò che non ha, mostrando segni di sfiducia e stanchezza nei
confronti della possibilità di cambiare qualcosa. Si tratta certo di
una situazione difficile, magari persino *più* difficile di quelle
storicamente attraversate sinora. Ma -- come scrive Hölderlin citato da
Heidegger -- "là dove c'è il pericolo, cresce anche ciò che salva"[^59].
E proprio la storia dimostra come, in condizioni e momenti cruciali, non
soltanto le difficoltà non si presentino affatto come un impedimento al
raggiungimento dei risultati auspicati, ma come a volte questi stessi
possano essere ottenuti proprio grazie alla presenza di esse. Un caso
emblematico in tal senso -- vale a dire una lampante dimostrazione di
come ogni occasione possa essere "buona" per chi operi come
"produttore", anziché accontentarsi di essere un "rifornitore" -- è
rappresentata dal complesso realizzato per "The Economist Group"
(1959-64) a Londra dai coniugi Alison e Peter Smithson. Ottenuto grazie
alla vittoria di un concorso a inviti, l'incarico prevedeva la
realizzazione della sede dell'importante settimanale economico inglese,
fondato nel 1843 dal banchiere e uomo d'affari James Wilson. Da quel
momento in avanti la testata ha sempre sostenuto una posizione
liberalista, avente come propri fondamenti la proprietà privata e
l'economia di mercato. Dovendo inserirsi in un lotto non distante dalla
City, prospiciente St James Street, ma confinante anche con un club
preesistente costruito alla metà del XVIII secolo, gli Smithson hanno
disposto i tre edifici (la sede di "The Economist", una banca e un
edificio residenziale, rispettivamente di 15, 4 e 8 piani) su un plateau
quadrato sopraelevato rispetto alla quota della città circostante. Pur
richiamandosi a strutture presenti nella zona (dai vicoli alle *arcades*
e ai cortili che penetrano negli edifici), la soluzione trovata dai due
architetti rappresenta una vera e propria "rottura" rispetto agli
interventi urbani precedenti: la *plaza* pedonale, rivestita di pietra
arenaria, si offre come un'isola di tranquillità all'interno della densa
e caotica rete di strade della capitale britannica. Né l'intervento
manca pure di una lucida coscienza del proprio significato strategico e
del ruolo che potrebbe assumere in una prospettiva urbana più allargata.
Nelle parole dei suoi stessi autori, esso

> ... offre uno spazio di "pre-ingresso", in cui c'è il tempo di
> riordinare la propria sensibilità, preparandosi a entrare negli uffici
> per una visita o per lavoro. La città è lasciata al di fuori dei
> limiti dell'area e le si aggiunge un altro tipo di spazio
> "intermedio"; se, come nel passato, più proprietari contribuissero a
> realizzare queste "pause", allora altri modelli di movimento sarebbero
> possibili; l'uomo per strada potrebbe scegliere di cercare il proprio
> percorso "segreto" attraverso la città, potrebbe ulteriormente
> sviluppare una sensibilità urbana, elaborando il proprio contributo
> alla qualità d'uso[^60].

E ancora:

> The Economist costituisce un insieme "didattico", volutamente
> asciutto, di edifici. E questo, fra duecento anni, potrà sembrare un
> errore; ma nella nostra situazione non c'è altra strada se non quella
> di "costruire" e di "dimostrare". La lezione non sta solo in ciò che
> abbiamo fatto, ma in ciò che non abbiamo fatto[^61].

Nel sottolineare il significato "pedagogico" del loro intervento (a
proposito dei "produttori", Benjamin ne rimarca proprio il
"comportamento didattico")[^62], gli Smithson rivelano in pieno la sua
natura *politica*: un frammento di "arcipelago" urbano *dentro e contro*
nel cuore del maggior centro finanziario internazionale. E infatti, in
perfetto accordo con ciò, il *corretto uso* di questo spazio è indicato
dalla scena iniziale del film *Blow up* (1966) di Michelangelo
Antonioni: una jeep carica di una compagnia di mimi mascherati fa
improvvisamente irruzione nella *plaza*; dopo un breve giro dello spazio
deserto tra gli edifici, la jeep viene abbandonata e la compagnia di
giovani festanti si sparge a piedi per le vie di Londra. La città del
capitale è cosí riletta come palcoscenico di un gran teatro
dell'assurdo; il seme a "reazione ludica" che vi viene impiantato
diviene generatore di comportamenti "eversivi" in cui si colgono echi
surrealisti e situazionisti.

A fronte di un "caso" come questo viene da chiedersi se ci troviamo in
un'epoca in cui una simile "immagine del mondo" è ancora possibile. Non
è forse un caso che oggi gli incarichi più allettanti, in termini
economici e di prestigio, finiscano in larga parte nelle mani degli
architetti più propensi a "rifornire" (o per dir meglio, trovino
adeguati studi e progetti a cui affidare il proprio sicuro
"rifornimento"). Di questo "materiale" sono fatte in prevalenza le
città contemporanee: gigantesche confezioni regalo senza sorprese. E
qui non bisogna lasciarsi ingannare dai facili effetti di carattere
estetico: la *sostanza* rimane quella di una spesso elegante
salvaguardia dell'ordine costituito. Ma non sono solo gli incarichi
importanti quelli con cui un architetto "produttore" deve misurarsi per
potersi mostrare all'altezza del compito: il ruolo di intellettuale
pubblico e mediatizzato, con tutte le responsabilità che ne conseguono.
Né è in questa chiave soltanto che va valutato il suo possibile ruolo di
intellettuale. Esistono -- per limitarsi all'esclusivo piano
progettuale -- operazioni di dimensioni assai più misurate, a volte
persino di dimensioni modeste, che costituiscono però un valido banco di
prova per effettuare sperimentazioni e innovazioni capaci di originare
trasformazioni produttive. Si tratta di operazioni in cui l'architetto
è spesso chiamato a ruoli di "supplenza" che lo impegnano
nell'elaborazione di programmi che devono variamente tener conto di
condizioni locali particolari, di fruizioni insolite, di soggetti
deboli, di situazioni economiche d'emergenza. Ma soprattutto si tratta
di una questione di "mentalità". Si pensi ai molti interventi compiuti
negli ultimi vent'anni da Lacaton & Vassal (Anne Lacaton e Jean Philippe
Vassal), dal Palais de Tokyo di Parigi (2001-14) al FRAC (Fond régional
d'art contemporain) Nord-Pas de Calais a Dunkerque (2009-15), differenti
tra loro per genere e dimensioni, ma tutti ugualmente improntati alla
medesima volontà di offrire qualcosa di più e di diverso rispetto alle
attese. Arrivando anche a "forzare" le richieste poste dai bandi[^63],
i progetti degli architetti francesi si segnalano per la "generosità"
dei loro spazi, spesso quantitativamente maggiori di quelli previsti, e
per la contemporanea rinuncia ad assumere un ruolo da protagonisti, per
lasciare piuttosto la scena alle azioni destinate a installarvisi[^64].
O ancora, ai pochi interventi di Maria Giuseppina Grasso Cannizzo, tanto
misurati quanto attenti a ogni minimo dettaglio: con ammirevole
caparbietà e semplicità l'architetta siciliana produce le proprie opere
-- la Torre di controllo nel porto turistico di Marina di Ragusa
(2008-2009) e un esiguo numero di case private in Sicilia[^65] --
controllandone per intero il processo progettuale ed esecutivo secondo
una modalità "artigianale" apparentemente appartenente ad altri tempi.

Denominare questo tipo di interventi "architettura responsabile"[^66]
significa mettere in evidenza la loro capacità di rispondere a domande
socialmente complesse, ma anche singolarmente essenziali, anziché
perdersi in vaniloqui o in narcisistici rispecchiamenti. E non meno
rilevante, sotto il profilo della dimostrazione di "responsabilità", è
il fatto che per conquistare il "diritto a esistere" a questi
interventi, l'architetto -- in ciò "produttore" davvero straordinario di
conflitti per buone cause -- sia non di rado costretto a ingaggiare vere
e proprie battaglie *contro* tutte le circostanze che dovrebbero invece
renderli attuabili.

In altri casi -- e per altri livelli e posizioni -- sono sufficienti
gesti invisibili, dal basso, destinati a non passare alla Storia.
"Aggiustamenti", "riconfigurazioni", "rimodulazioni", che possono
riguardare i rapporti interni a determinate condizioni lavorative od
organizzative. Modalità silenziose di agire in senso migliorativo,
uguali e contrarie a quelle solitamente adottate dagli apparati
produttivi, che cambiano nel concreto il modo di operare al suo interno,
predisponendo a un *minor* sfruttamento e a una *maggior* condivisione
di saperi.

Anche queste ultime modalità d'intervento, cosí come le prime -- per non
dire poi di quelle di carattere più direttamente culturale --, prevedono
sempre, al fine di poter essere produttive, uno studio, una conoscenza,
un'applicazione, un *impegno* che, se non può propriamente essere
definito politico, si connota però di sovente in un senso civile. Tutto
ciò deve avvenire -- quando avviene -- senza dar luogo a illusioni di
false liberazioni o rivoluzioni; spesso piuttosto come un'ardua e oscura
"opera di resistenza" all'interno delle condizioni date e nei confronti
di esse. E non deve stupire che questo terreno, alla fine, possa essere
non soltanto parimenti difficile ma addirittura *più* difficile ancora
per *star architects* e altri cacciatori di esposizione mediatica che
non per gli architetti "normali", animati da una reale voglia di
cambiare e dal coraggio e dalla pazienza di farlo. Per chiunque
intraprenda questo cammino, comunque, il percorso non manca di rivelarsi
accidentato e irto di pericoli: innanzitutto quello di "perdersi" nella
propria stessa immagine di "architetto intellettuale"; inoltre, di
tradire il proprio "mandato", ritenendolo erroneamente una "delega"
conferita e ricevuta in modo permanente, e non invece da riguadagnare
ogni volta da capo, con la credibilità delle proprie "azioni"; e ancora,
di incorrere in vuote e sterili ripetizioni di se stesso,
nell'affermazione -- e più di frequente nella difesa -- di posizioni
(professionali, culturali) ormai superate ed esaurite. Da questo punto
di vista, sono sempre esistite forme di lotta "intestina" fra
intellettuali per la conquista dell'egemonia in un determinato ambiente
e in un certo periodo; e queste, per quanto siano il segnale di una
"volontà di potere" più e oltre ogni legittima "volontà di sapere",
possono costituire a loro volta un auspicabile fattore di rinnovamento.
Ciò, nello specifico ambito architettonico, riguarda gli spesso
difficoltosi ricambi generazionali, e dunque l'inevitabile scontro tra
vecchi e nuovi baricentri intellettuali[^67]: dove i primi tendono a
perpetuare se stessi sulla base delle posizioni acquisite, dell'autorità
guadagnata, cosí come pure di sterili arroccamenti a protezione del
proprio universo di riferimenti, concepito come l'unico e il solo
possibile; mentre i secondi si propongono come nuova "intelligenza" del
mondo, incardinata su altri "punti archimedici", portatori non soltanto
di punti di vista ma anche di saperi diversi, alla ricerca del
riconoscimento di una piena dignità culturale. A ben guardare, allorché
esuli da contrapposizioni puramente personali, questo scontro
costituisce a sua volta un elemento capace di far avanzare il dibattito,
sottoponendo a critica antiche tesi "incrostate" e passando al vaglio
ipotesi inedite. Per entrambi -- anziani e giovani rappresentanti
dell'ambizione a detenere l'egemonia intellettuale --, comunque, rimane
da esercitare una sorveglianza reciproca a fronte del pericolo ulteriore
di vecchi e nuovi accademismi. Non soltanto quello che si verifica
all'interno delle scuole, dove gli architetti insegnanti -- già in un
non lontano passato ma nuovamente anche oggi -- rischiano sempre di
risultare "scollati" dalle problematiche attuali[^68]; ma pure il
pericolo di una "stilizzazione" dei propri prodotti, di qualunque tipo
essi siano; pericolo che si concretizza ad esempio nella consueta
tendenza, da parte degli uni, a "sterilizzare" la propria grammatica e
sintassi progettuale, e nell'insorgente (ma già sufficientemente
affermato) orientamento, da parte degli altri, verso l'esercizio di un
disegno completamente scollegato dalla prassi, nonché soprattutto da
qualsiasi fondamento teorico.

Nella scelta che l'architetto *può* sempre compiere -- va rammentato
ancora una volta -- vi sono in gioco obiettivi e azioni *reali*, non
utopie o chimere. Ciò a patto naturalmente che dimostri di possedere
alcune capacità basilari: tra queste, innanzitutto la capacità di
pensare e fare *insieme*, in modo coerente, come differenti espressioni
di un'*unica* intenzione; poi la capacità di compiere ricerche, di cui i
propri progetti siano la conseguenza, e non già il presupposto; la
capacità di usare la storia con piena consapevolezza, perché possiede
un'idea, sa a che cosa questa le/gli serve, ancora una volta in vista
dei propri progetti; la capacità di interrogare parole, concetti, forme,
figure, anche basilari, che l'architettura utilizza, per riverificarne
il senso in vista di un loro possibile uso; la capacità di incrociare
saperi diversi, tutti indispensabili a una comprensione del quadro
complesso in cui il proprio lavoro si colloca; la capacità di pensare la
relazione concreta tra lo *spazio* e la *vita*, che in ultima analisi è
l'oggetto e lo scopo del suo intero lavoro; infine la capacità di
tradurre tutto ciò in spazio.

Quanto più l'architetto intellettuale è padrone dei mezzi che ha -- o
che dovrebbe avere -- a propria disposizione, tanto più "tecnicamente"
sa intervenire sui processi produttivi. Per fare che cosa? Da un lato,
si potrebbe rispondere, per produrre grandi o piccoli mutamenti nel
mondo che lo circonda. E non è tanto importante che si tratti di grandi
o di piccole visioni; non è la dimensione che conta. Ovvero (si
potrebbe anche dire), obiettivo dell'architetto come intellettuale
dovrebbe essere di avere grandi visioni anche in piccole dimensioni. Se
non è più tempo per le utopie, lo è però sempre ancora per i *progetti*;
progetti mirati, circoscritti, anche minimi, ma in ogni caso progetti
nel senso più sopra indicato, aventi per *soggetto* l'architettura nella
sua accezione più onnicomprensiva. Dall'altro, per far diventare quegli
stessi processi e il mondo in cui si collocano più comprensibili; non
per rivoluzionarli, forse, ma almeno per portarli alla luce, per
renderli riconoscibili. In questa prospettiva, l'opera dell'architetto
intellettuale si presenta (o dovrebbe presentarsi) anche sempre come un
"disvelamento", un lavoro di scavo all'interno delle condizioni date per
recuperare da esse qualcosa di sottratto a un sapere collettivo. Perché
quella che persegue è una causa collettiva, non individuale.

Conoscere, far conoscere, demistificare, progettare, condividere.
Espresso in questo modo il programma di un architetto che voglia
produrre se stesso come un intellettuale apparirà più che improbo: una
molteplicità di prospettive, anche contraddittorie tra loro, troppo
gravose per un singolo individuo. Ma è qui che gli effetti della
condivisione, "spezzando" la falsa naturalità della divisione del lavoro
e dei processi produttivi, possono farsi sentire.

> L'unico modo per riguadagnare una propensione ad agire è quello di
> trovare nuove forme di cooperazione nella progettazione architettonica
> che metterebbero allo stesso livello tutte le professioni che fanno
> parte del progetto e del processo di costruzione: architetti,
> costruttori e ingegneri, cosí come educatori, storici, critici,
> grafici, editori, fotografi e tecnici. Coinvolgendo conoscenze
> condivise, anziché specializzate, questo approccio collaborativo
> all'architettura potrebbe portare a una maggiore forza professionale e
> una maggior equità economica, in cui i compiti lavorativi potrebbero
> essere ugualmente e non più gerarchicamente distribuiti. Ciò
> porterebbe con sé una nuova definizione istituzionale di architettura
> che non sarebbe più basata su relazioni gerarchiche e di sfruttamento
> e su autorialità singole ma sulla cooperazione dei lavoratori come
> co-produttori di architettura[^69].

Potrebbe essere questa *trasformazione* (non morte!) il futuro
dell'architettura? Oppure il futuro dell'architettura (come le
condizioni attuali sembrerebbero far presagire) sarà più spettrale?
Un'architettura non solo prefabbricata ma addirittura preconfezionata?
Un'architettura *prêt-à-porter*? La semplice risultante della complicata
equazione "problema = soluzione"? Un vero paradiso per i "rifornitori" a
venire...

La risposta però potrebbe non essere già scritta, potrebbe passare anche
attraverso una decisione, una *scelta*, pur nei limiti delle comuni
"alienazioni". La scelta di scacciare i fantasmi affrontando le
questioni.

Potrà essere l'architetto intellettuale a farsene carico? O forse
piuttosto qualcuno che -- come Foucault -- avrà il coraggio e la
lucidità di riferirsi a se stesso come "un mercante di strumenti, un
fabbricante di ricette, un suggeritore di obiettivi, un cartografo, un
rilevatore di piani, un armaiolo..."[^70].

[^1]: Tafuri, *Progetto e utopia* cit., pp. 166-67.

[^2]: *Ibid.*, p. 2. Vedi anche R. Amirante, F. Dumontet, M.
Perriccioli e S. Pone, *Fortuna critica della "Tendenza"*, in "Op.cit.",
n. 50, 1981, pp. 5-20, in cui gli autori accennano alla "nota tesi
tafuriana della "morte dell'architettura"", cui Tafuri replica con una
lettera ("Op. cit.", n. 51, 1981, p. 83) in cui definisce la frase
citata "una vulgata da cui mi è persino superfluo prendere le distanze".
Aggiungendo subito dopo: "Non ricordo (\...) di aver mai cantato su
tombe inesistenti. (\...) Ma di estinzione di ruoli per vecchie
discipline ho certo parlato".

[^3]: Vedi ad esempio l'intervista di Hans van Dijk a Rem Koolhaas, in
cui si legge tra l'altro: "Ho la netta impressione che Tafuri e i suoi
amici abbiano in odio l'architettura. Costoro dichiarano morta
l'architettura. Per lui l'architettura è una schiera di cadaveri
all'obitorio": Hans van Dijk, *Rem Koolhaas Interview*, in
"Wonen-TA/BK", n. 11, 1978, p. 18.

[^4]: Paolo Portoghesi, *Autopsia o vivisezione dell'architettura?*, in
"Controspazio", n. 6, 1969, p. 7. La lunga recensione di Portoghesi è
comunque la più lucida nel criticare e -- in parte -- nel decostruire le
posizioni tafuriane.

[^5]: Tafuri, *Progetto e utopia* cit., p. 3.

[^6]: *Ibid.*, p. 169.

[^7]: Come noto, Leon Battista Alberti nel *De re ædificatoria*
definisce *lineamenta* quello che potrebbe essere definito altrettanto
"disegno" che "progetto"; vedi Alberti, *L'architettura* cit., vol. I,
pp. 18-19.

[^8]: "Il ruolo dell'architetto è quello di mediatore tra il cliente o
committente, cioè la persona che decide di costruire, e la forza lavoro
con i suoi supervisori, che potremmo chiamare collettivamente i
costruttori": Spiro Kostof, *Preface*, in Id. (a cura di), *The
Architect* cit., p. XVII.

[^9]: Tafuri, *Per una critica dell'ideologia architettonica* cit.,
p. 77.

[^10]: Tafuri, *Progetto e utopia* cit., p. 167.

[^11]: De Carlo, *L'architettura della partecipazione* (1973) cit.,
pp. 76-77. La sezione a cui appartiene il brano citato s'intitola
significativamente *È morta l'architettura: Viva l'architettura!*

[^12]: *Ibid.*, p. 77.

[^13]: De Carlo, *L'architettura della partecipazione* cit., p. 78. più
in generale va ricordato l'impegno di De Carlo in questa direzione
attraverso la rivista "Spazio e Società", da lui fondata e diretta dal
1978 al 2000: vedi Isabella Daidone, *Giancarlo De Carlo. Gli
editoriali di Spazio e Società*, Gangemi, Roma 2018.

[^14]: Si rammenti la già citata definizione vitruviana. Interessante
tuttavia notare come il ruolo di "controllore" delle forze produttive
impegnate sul cantiere assegnato all'architetto, affermato nel 1567 da
Philibert Delorme nel suo *Premier tome de l'architecture* (e, un secolo
prima prima di lui, da Leon Battista Alberti), appaia ancora
"sorprendente" nella Francia del XVI secolo: vedi il bel saggio di
Catherine Wilkinson, *The New Professionalism in the Renaissance*, in
Kostof (a cura di), *The Architect* cit., pp. 124-60, in particolare
p. 131.

[^15]: Carl W. Condit, *The Chicago School of Architecture. A History
of Commercial and Public Building in the Chicago Area, 1875-1925*, The
University of Chicago Press, Chicago 1964.

[^16]: Otto Antonia Graf, *Otto Wagner: Das Werk des Architekten
1860-1918*, 2 voll., Bölhau, Wien 1994; Robert Trevisiol, *Otto Wagner*,
Laterza, Roma-Bari 2006.

[^17]: Su ciò vedi Riccardo M. Villa, *L'architetto e la fabbrica*, in
GIZMO, *Backstage. L'architettura come lavoro concreto*, a cura di
Florencia Andreola, Mauro Sullam, Riccardo M. Villa, Franco Angeli,
Milano 2016, pp. 17-27. più in generale, sul tema dell'evoluzione del
lavoro di architettura nell'epoca della digitalizzazione, vedi Peggy
Deamer e Phillip G. Bernstein (a cura di), *Building (in) the Future.
Recasting Labor in Architecture*, Yale School of Architecture -
Princeton Architectural Press, New Haven -- New York 2010.

[^18]: A ciò per costoro si aggiungono di sovente orari molto pesanti,
ben oltre le otto ore giornaliere, una "flessibilità" dell'orario che si
traduce in serate e nottate occupate, un'estensione del lavoro ai sabati
e alle domeniche. Il tutto all'interno di un quadro in cui le ferie
sono un sogno, il trattamento di fine rapporto un miraggio e la pensione
una chimera. Di questi temi mi sono occupato in *L'architettura come
mestiere*, in
[www.gizmoweb.org/2012/03/larchitettura-come-mestiere/](http://www.gizmoweb.org/2012/03/larchitettura-come-mestiere/),
25 marzo 2012, e *Architettura e lotta di classe*, in
[www.gizmoweb.org/2014/05/architettura-e-lotta-di-classe/](http://www.gizmoweb.org/2014/05/architettura-e-lotta-di-classe/),
4 maggio 2014.

[^19]: Aureli, *Labor and Work in Architecture* cit., p. 72.

[^20]: *Ibid.*, p. 74.

[^21]: Carlo Vercellone (a cura di), *Capitalismo cognitivo. Conoscenza
e finanza nell'epoca postfordista*, Manifestolibri, Roma 2006.

[^22]: Pier Vittorio Aureli, *History, Architecture and Labour: A
Program for Research*, in Aaron Cayer, Peggy Deamer, Sben Korsh, Eric
Peterson e Manuel Shvartz­berg (a cura di), *Asymmetric Labors: The
Economy of Architecture in Theory and Practice*, The Architecture Lobby,
New York 2016, p. 158.

[^23]: Giulio Barazzetta, *Che fare*, in GIZMO, *Backstage.
L'architettura come lavoro concreto* cit., p. 50.

[^24]: Filarete, *Trattato di architettura* cit., libro II, pp. 39-41.

[^25]: Benjamin, *L'autore come produttore* cit., pp. 207 sgg.

[^26]: In realtà, come scrive Massimo Cacciari, *Introduzione* a Max
Weber, *Il lavoro intellettuale come professione*, Mondadori, Milano
2018, p. XXVII, "... per quest'epoca, non si dà (...) interpretazione
che non sia trasformazione".

[^27]: Benjamin, *L'autore come produttore* cit., p. 207 (il corsivo è
mio).

[^28]: Carl Schmitt, *L'epoca delle neutralizzazioni e delle
spoliticizzazioni* (1929), in Id., *Le categorie del "politico"* cit.,
pp. 167-83.

[^29]: Virno, *Grammatica della moltitudine* cit.

[^30]: *Ibid.*, p. 14.

[^31]: Su ciò rimando al mio *L'architettura come lavoro concreto*, in
GIZMO, *Backstage. L'architettura come lavoro concreto* cit., pp. 7-10.

[^32]: Oltre ai lavori citati in precedenza, vedi Peggy Deamer (a cura
di), *The Architect as Worker. Immaterial Labor, The Creative Class and
the Politics of Design*, Bloomsbury, London 2015. Sul tema, in senso
più allargato, vedi anche *IWW: Immaterial Workers of the World*, in
"DeriveApprodi", n. 18, numero monografico, 1999.

[^33]: Non è letteralmente possibile dar conto del numero delle
citazioni di *Der Autor als Produzent* nel dibattito architettonico,
dapprima degli anni settanta, e poi nuovamente in quello più recente,
quasi sempre però senza adeguate storicizzazioni di esso. Sulle
possibili ambiguità del suo impiego, basti ricordare che i medesimi
passi del saggio sono utilizzati *contra* Tafuri da Portoghesi,
*Autopsia o vivisezione dell'architettura?* cit. (recensione a *Per una
critica dell'ideologia architettonica*), e poi dallo stesso Tafuri con
altre finalità in *L'Architecture dans le Boudoir. The language of
criticism and the criticism of language*, in "Oppositions", n. 3, 1974,
pp. 37-62, dove nota tra l'altro che "qui Benjamin si rivela ambiguo e
può prestarsi a diverse interpretazioni" (p. 62).

[^34]: Il rimando è evidentemente a Max Weber, *La politica come
professione* (1919), in *Il lavoro intellettuale come professione* cit.,
pp. 49-130.

[^35]: Massimo Cacciari, *Progetto*, in "Laboratorio Politico", n. 2,
1981, p. 88.

[^36]: *Ibid.*, p. 114.

[^37]: Tafuri, *Il "progetto" storico* cit., pp. 3-30.

[^38]: Scrive Tafuri, *ibid.*, p. 13: "L'autentico problema è come
progettare una critica capace di porre di continuo in crisi se stessa
mettendo in crisi il reale".

[^39]: "Il "progetto" storico è sempre "progetto di una crisi"":
*ibid.*, p. 5. Su ciò vedi Biraghi, *Progetto di crisi* cit., pp. 9-53.

[^40]: Massimo Cacciari, *Di alcuni motivi in Walter Benjamin*, in
"Nuova Corrente", n. 67, 1975, p. 238. Il saggio di Benjamin cui si fa
riferimento è *L'opera d'arte nell'epoca della sua riproducibilità
tecnica* (1936).

[^41]: Cacciari, *Di alcuni motivi in Walter Benjamin* cit., p. 241.

[^42]: Vedi al proposito la concezione della "relazione" in Enzo Paci,
*Dall'esistenzialismo al relazionismo*, D'Anna, Messina-Firenze 1957.

[^43]: Sugli effetti "migliorativi" delle trasformazioni dei rapporti di
produzione, vedi Benjamin, *L'autore come produttore* cit., p. 212.
Ovviamente, nel suo caso, tale "miglioramento" va inteso in relazione
alla funzione didattico-organizzativa della produzione in vista di una
rivoluzione comunista. Nella situazione odierna ogni "miglioramento"
degli apparati citati va invece valutato alla luce della sua capacità di
apportare una maggiore equità al loro interno e di fornire migliori
condizioni ai loro fruitori.

[^44]: Per quanto limitato alla sola Italia, è interessante
*Intellettuali e potere* (*Storia d'Italia Einaudi. Annali 4*, a cura
di Corrado Vivanti, Torino 1981), in cui la figura dell'intellettuale si
frange in molteplici soggetti che, a seconda dei contesti sociali e
storici, sono impegnati in settori e a livelli tra di loro molto
differenti (medicina, pedagogia, arte, religione, ecc.). Vedi inoltre
Alberto Asor Rosa, *Intellettuali*, in *Enciclopedia Einaudi*, Torino
1979, vol. VII, pp. 801 sgg.

[^45]: Corrado Vivanti, *Presentazione*, in *Intellettuali e potere*
cit., pp. XIX-XX.

[^46]: Sull'intellettuale come "destabilizzatore" e "risvegliatore di
coscienze" (da Socrate a Heinrich Heine -- ma anche, si potrebbe
aggiungere, a Karl Kraus e oltre), vedi Maldonado, *Che cos'è un
intellettuale?* cit., pp. 92-95. Inoltre vedi Edward W. Said, *Dire la
verità. Gli intellettuali e il potere*, Feltrinelli, Milano 2014.

[^47]: Cacciari, *Introduzione* cit., p. XI.

[^48]: Il riferimento è a Rossi, *L'architettura della città* cit. Per
un'analisi delle fonti rossiane del libro, vedi Elisabetta Vasumi
Roveri, *Aldo Rossi e "L'architettura della città". Genesi e fortuna di
un testo*, Allemandi, Torino 2010.

[^49]: Ci si riferisce ai *playgrounds* realizzati da van Eyck ad
Amsterdam per conto dell'amministrazione pubblica tra il 1947 e il
1978. Oltre a Lefaivre (a cura di), *Aldo van Eyck. Playgrounds* cit.,
vedi anche Anna van Lingen e Denisa Kollarova, *Aldo van Eyck.
Seventeen Playgrounds*, Lecturis, Eindhoven 2016, e Merijn Oudenampsen,
*Aldo van Eyck and the City as Playground*, in *Urbanacción 07/09*, a
cura di Ana Mendez de Andés, La Casa Encendida, Madrid 2010, pp. 25-39.

[^50]: È il caso dell'Orphanage di Amsterdam (1955-60) dello stesso van
Eyck, su cui vedi Francis Strauven, *Aldo Van Eyck's Orphanage. A
Modern Monument*, NAi Publishers, Rotterdam 1997.

[^51]: Gramsci, *Quaderni del carcere* cit., vol. III, Quaderno 12
(XXIX), § 3, p. 1551.

[^52]: Benjamin, *L'autore come produttore* cit., p. 209.

[^53]: Fortini, *Verifica dei poteri* cit., pp. 41-57.

[^54]: Va qui rammentata l'ambiguità del titolo albertiano *De re
ædificatoria*, che esclude deliberatamente l'uso dell'ovvio vocabolo
vitruviano *architectura* per i suoi dieci libri, scegliendone uno più
"edificante". Per un'accurata analisi di tale titolo, vedi Leon
Battista Alberti, *Prologo al 'De re ædificatoria'*, a cura di
Elisabetta Di Stefano, Edizioni ETS, Pisa 2012, pp. 9-17.

[^55]: Tra coloro che con maggior costanza e serietà si sono impegnati
in questi anni in una lettura dei ruoli rivestiti dall'architetto e
dallo storico dell'architettura nel corso del Novecento vi è Carlo Olmo:
vedi in particolare *Architettura e Novecento. Diritti, conflitti,
valori*, Donzelli, Roma 2010, e *Architettura e storia. Paradigmi della
discontinuità*, Donzelli, Roma 2013.

[^56]: Slavoj Žižek, *Il parallasse architettonico. Pennacchi e altri
fenomeni di lotta di classe*, in Id., *Il trash sublime*, a cura di
Marco Senaldi, Mimesis, Sesto San Giovanni 2013, pp. 56-57.

[^57]: Come scrive Raniero Panzieri (in *Relazione sul neocapitalismo*
(1961), in Id., *La ripresa del marxismo-leninismo in Italia*, Nuove
Edizioni Operaie, Roma 1977, pp. 170-71), "si potrebbe dire che i due
termini capitalismo e sviluppo sono la stessa cosa".

[^58]: Luc Boltanski e Ève Chiapello, *Il nuovo spirito del
capitalismo*, Mimesis, Sesto San Giovanni 2014.

[^59]: Martin Heidegger, *La questione della tecnica* (1953), in Id.,
*Saggi e discorsi*, a cura di Gianni Vattimo, Mursia, Milano 1980,
p. 22. L'inno da cui è tratto il verso citato di Friedrich Hölderlin è
*Patmos* (1803).

[^60]: Alison Smithson e Peter Smithson, *The Charged Void:
Architecture*, The Monacelli Press, New York 2001, p. 248.

[^61]: Alison Smithson e Peter Smithson, in Marco Vidotto, *A + P
Smithson*, Sagep Editrice, Genova 1991, p. 35. Sul carattere
"didattico" del progetto per "The Economist" insiste anche Kenneth
Frampton, *The Economist and the Hauptstadt*, in "Architectural Design",
n. 194, 1965, p. 62.

[^62]: E aggiunge: "La migliore tendenza è falsa se non insegna quale
  atteggiamento si deve tenere per soddisfarla": Benjamin, *L'autore
  come produttore* cit., p. 212.

[^63]: È il caso, tra gli altri, dell'École d'Architecture di Nantes
  (2003-2009) dove, "come uno strumento pedagogico, il progetto mette
  in discussione il program­ma e le pratiche della scuola tanto quanto
  le norme, le tecnologie e il proprio processo di elaborazione": vedi
  www.lacatonvassal.com/index.php?idp=55#.

[^64]: Antonio Lavarello, *Indifferenza come forma di impegno politico*,
  in
  www.gizmoweb.org/2015/12/indifferenza-come-forma-di-impegno-politico-edifici-e-spazi-pubblici-nellopera-di-lacaton-vassal/#\_ftn14,
  24 dicembre 2015.

[^65]: Maria Giuseppina Grasso Cannizzo, *Loose Ends*, a cura di Sara
  Marini, Lars Muller Publishers, Zürich 2014; Sara Marini,
  *Sull'autore. Maria Giuseppina Grasso Cannizzo e le sue foreste di
  cristallo*, Quodlibet, Macerata 2017.

[^66]: Vedi il capitolo *L'architettura responsabile*, in Biraghi e
  Micheli, *Storia dell'architettura italiana 1985-2015* cit.,
  pp. 329-52.

[^67]: Su ciò rimando ai miei *L'ultima resistenza ovvero la lotta degli
  anziani contro i giovani*, in GIZMO, *MMX. Architettura zona
  critica* cit., pp. 15-21, e *Non si può fare meno
  dell'architettura*, in Chiara Baglione (a cura di), *Ernesto Nathan
  Rogers 1909-1969*, Franco Angeli, Milano 2012, pp. 196-98.

[^68]: Vedi il capitolo *Dall'architettura disegnata all'architettura
  insegnata: l'accademia della composizione*, in Biraghi e Micheli,
  *Storia dell'architettura italiana 1985-2015* cit., pp. 183-95.
  Sempre valida -- pur con i necessari adeguamenti -- rimane la
  critica condotta da Massimo Scolari in *Una generazione senza nomi*,
  in "Casabella", n. 606, 1993, pp. 45-47.

[^69]: Aureli, *Labor and Work in Architecture* cit., p. 81.

[^70]: Foucault, *Disciplina e democrazia. Intervista di J.-L. Ezine*
  cit., p. 90.

---
# vim: spelllang=it spell
...
